@charset "UTF-8";
/*!
 * # Semantic UI 2.2.12 - Reset
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Reset
*******************************/
/* Border-Box */
* {
  box-sizing: inherit; }
  *:before, *:after {
    box-sizing: inherit; }

html {
  box-sizing: border-box; }

/* iPad Input Shadows */
input[type="text"], input[type="email"], input[type="search"], input[type="password"] {
  -webkit-appearance: none;
  -moz-appearance: none;
  /* mobile firefox too! */ }

/*! normalize.css v7.0.0 | MIT License | github.com/necolas/normalize.css */
/* Document
   ========================================================================== */
/**
 * 1. Correct the line height in all browsers.
 * 2. Prevent adjustments of font size after orientation changes in
 *    IE on Windows Phone and in iOS.
 */
html {
  line-height: 1.15;
  /* 1 */
  -ms-text-size-adjust: 100%;
  /* 2 */
  -webkit-text-size-adjust: 100%;
  /* 2 */ }

/* Sections
   ========================================================================== */
/**
 * Remove the margin in all browsers (opinionated).
 */
body {
  margin: 0; }

/**
 * Add the correct display in IE 9-.
 */
article, aside, footer, header, nav, section {
  display: block; }

/**
 * Correct the font size and margin on `h1` elements within `section` and
 * `article` contexts in Chrome, Firefox, and Safari.
 */
h1 {
  font-size: 2em;
  margin: 0.67em 0; }

/* Grouping content
   ========================================================================== */
/**
 * Add the correct display in IE 9-.
 * 1. Add the correct display in IE.
 */
figcaption, figure, main {
  /* 1 */
  display: block; }

/**
 * Add the correct margin in IE 8.
 */
figure {
  margin: 1em 40px; }

/**
 * 1. Add the correct box sizing in Firefox.
 * 2. Show the overflow in Edge and IE.
 */
hr {
  box-sizing: content-box;
  /* 1 */
  height: 0;
  /* 1 */
  overflow: visible;
  /* 2 */ }

/**
 * 1. Correct the inheritance and scaling of font size in all browsers.
 * 2. Correct the odd `em` font sizing in all browsers.
 */
pre {
  font-family: monospace, monospace;
  /* 1 */
  font-size: 1em;
  /* 2 */ }

/* Text-level semantics
   ========================================================================== */
/**
 * 1. Remove the gray background on active links in IE 10.
 * 2. Remove gaps in links underline in iOS 8+ and Safari 8+.
 */
a {
  background-color: transparent;
  /* 1 */
  -webkit-text-decoration-skip: objects;
  /* 2 */ }

/**
 * 1. Remove the bottom border in Chrome 57- and Firefox 39-.
 * 2. Add the correct text decoration in Chrome, Edge, IE, Opera, and Safari.
 */
abbr[title] {
  border-bottom: none;
  /* 1 */
  text-decoration: underline;
  /* 2 */
  text-decoration: underline dotted;
  /* 2 */ }

/**
 * Prevent the duplicate application of `bolder` by the next rule in Safari 6.
 */
b, strong {
  font-weight: inherit; }

/**
 * Add the correct font weight in Chrome, Edge, and Safari.
 */
b, strong {
  font-weight: bolder; }

/**
 * 1. Correct the inheritance and scaling of font size in all browsers.
 * 2. Correct the odd `em` font sizing in all browsers.
 */
code, kbd, samp {
  font-family: monospace, monospace;
  /* 1 */
  font-size: 1em;
  /* 2 */ }

/**
 * Add the correct font style in Android 4.3-.
 */
dfn {
  font-style: italic; }

/**
 * Add the correct background and color in IE 9-.
 */
mark {
  background-color: #ff0;
  color: #000; }

/**
 * Add the correct font size in all browsers.
 */
small {
  font-size: 80%; }

/**
 * Prevent `sub` and `sup` elements from affecting the line height in
 * all browsers.
 */
sub, sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline; }

sub {
  bottom: -0.25em; }

sup {
  top: -0.5em; }

/* Embedded content
   ========================================================================== */
/**
 * Add the correct display in IE 9-.
 */
audio, video {
  display: inline-block; }

/**
 * Add the correct display in iOS 4-7.
 */
audio:not([controls]) {
  display: none;
  height: 0; }

/**
 * Remove the border on images inside links in IE 10-.
 */
img {
  border-style: none; }

/**
 * Hide the overflow in IE.
 */
svg:not(:root) {
  overflow: hidden; }

/* Forms
   ========================================================================== */
/**
 * 1. Change the font styles in all browsers (opinionated).
 * 2. Remove the margin in Firefox and Safari.
 */
button, input, optgroup, select, textarea {
  font-family: sans-serif;
  /* 1 */
  font-size: 100%;
  /* 1 */
  line-height: 1.15;
  /* 1 */
  margin: 0;
  /* 2 */ }

/**
 * Show the overflow in IE.
 * 1. Show the overflow in Edge.
 */
button, input {
  /* 1 */
  overflow: visible; }

/**
 * Remove the inheritance of text transform in Edge, Firefox, and IE.
 * 1. Remove the inheritance of text transform in Firefox.
 */
button, select {
  /* 1 */
  text-transform: none; }

/**
 * 1. Prevent a WebKit bug where (2) destroys native `audio` and `video`
 *    controls in Android 4.
 * 2. Correct the inability to style clickable types in iOS and Safari.
 */
button, html [type="button"], [type="reset"], [type="submit"] {
  -webkit-appearance: button;
  /* 2 */ }

/**
 * Remove the inner border and padding in Firefox.
 */
button::-moz-focus-inner, [type="button"]::-moz-focus-inner, [type="reset"]::-moz-focus-inner, [type="submit"]::-moz-focus-inner {
  border-style: none;
  padding: 0; }

/**
 * Restore the focus styles unset by the previous rule.
 */
button:-moz-focusring, [type="button"]:-moz-focusring, [type="reset"]:-moz-focusring, [type="submit"]:-moz-focusring {
  outline: 1px dotted ButtonText; }

/**
 * Correct the padding in Firefox.
 */
fieldset {
  padding: 0.35em 0.75em 0.625em; }

/**
 * 1. Correct the text wrapping in Edge and IE.
 * 2. Correct the color inheritance from `fieldset` elements in IE.
 * 3. Remove the padding so developers are not caught out when they zero out
 *    `fieldset` elements in all browsers.
 */
legend {
  box-sizing: border-box;
  /* 1 */
  color: inherit;
  /* 2 */
  display: table;
  /* 1 */
  max-width: 100%;
  /* 1 */
  padding: 0;
  /* 3 */
  white-space: normal;
  /* 1 */ }

/**
 * 1. Add the correct display in IE 9-.
 * 2. Add the correct vertical alignment in Chrome, Firefox, and Opera.
 */
progress {
  display: inline-block;
  /* 1 */
  vertical-align: baseline;
  /* 2 */ }

/**
 * Remove the default vertical scrollbar in IE.
 */
textarea {
  overflow: auto; }

/**
 * 1. Add the correct box sizing in IE 10-.
 * 2. Remove the padding in IE 10-.
 */
[type="checkbox"], [type="radio"] {
  box-sizing: border-box;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
 * Correct the cursor style of increment and decrement buttons in Chrome.
 */
[type="number"]::-webkit-inner-spin-button, [type="number"]::-webkit-outer-spin-button {
  height: auto; }

/**
 * 1. Correct the odd appearance in Chrome and Safari.
 * 2. Correct the outline style in Safari.
 */
[type="search"] {
  -webkit-appearance: textfield;
  /* 1 */
  outline-offset: -2px;
  /* 2 */ }
  [type="search"]::-webkit-search-cancel-button, [type="search"]::-webkit-search-decoration {
    -webkit-appearance: none; }

/**
 * Remove the inner padding and cancel buttons in Chrome and Safari on macOS.
 */
/**
 * 1. Correct the inability to style clickable types in iOS and Safari.
 * 2. Change font properties to `inherit` in Safari.
 */
::-webkit-file-upload-button {
  -webkit-appearance: button;
  /* 1 */
  font: inherit;
  /* 2 */ }

/* Interactive
   ========================================================================== */
/*
 * Add the correct display in IE 9-.
 * 1. Add the correct display in Edge, IE, and Firefox.
 */
details, menu {
  display: block; }

/*
 * Add the correct display in all browsers.
 */
summary {
  display: list-item; }

/* Scripting
   ========================================================================== */
/**
 * Add the correct display in IE 9-.
 */
canvas {
  display: inline-block; }

/**
 * Add the correct display in IE.
 */
template, [hidden] {
  display: none; }

/* Hidden
   ========================================================================== */
/**
 * Add the correct display in IE 10-.
 */
/*******************************
         Site Overrides
*******************************/
/*!
 * # Semantic UI 2.2.12 - Site
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Page
*******************************/
html, body {
  height: 100%; }

html {
  font-size: 14px; }

body {
  margin: 0px;
  padding: 0px;
  overflow-x: hidden;
  min-width: 320px;
  background: #FFFFFF;
  font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
  font-size: 14px;
  line-height: 1.4285em;
  color: rgba(0, 0, 0, 0.87);
  font-smoothing: antialiased; }

/*******************************
             Headers
*******************************/
h1, h2, h3, h4, h5 {
  font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
  line-height: 1.28571429em;
  margin: calc(2rem -  0.14285714em) 0em 1rem;
  font-weight: bold;
  padding: 0em; }

h1 {
  min-height: 1rem;
  font-size: 2rem; }

h2 {
  font-size: 1.71428571rem; }

h3 {
  font-size: 1.28571429rem; }

h4 {
  font-size: 1.07142857rem; }

h5 {
  font-size: 1rem; }

h1:first-child, h2:first-child, h3:first-child, h4:first-child, h5:first-child {
  margin-top: 0em; }

h1:last-child, h2:last-child, h3:last-child, h4:last-child, h5:last-child {
  margin-bottom: 0em; }

/*******************************
             Text
*******************************/
p {
  margin: 0em 0em 1em;
  line-height: 1.4285em; }
  p:first-child {
    margin-top: 0em; }
  p:last-child {
    margin-bottom: 0em; }

/*-------------------
        Links
--------------------*/
a {
  color: #4c8bd6;
  text-decoration: none; }
  a:hover {
    color: #4679b7;
    text-decoration: none; }

/*******************************
         Scrollbars
*******************************/
/*******************************
          Highlighting
*******************************/
/* Site */
::-webkit-selection, ::-moz-selection, ::selection {
  background-color: #CCE2FF;
  color: rgba(0, 0, 0, 0.87); }

/* Form */
textarea::-webkit-selection, input::-webkit-selection, textarea::-moz-selection, input::-moz-selection, textarea::selection, input::selection {
  background-color: rgba(100, 100, 100, 0.4);
  color: rgba(0, 0, 0, 0.87); }

/* Force Simple Scrollbars */
body ::-webkit-scrollbar {
  -webkit-appearance: none;
  width: 10px; }

body ::-webkit-scrollbar-track {
  background: rgba(0, 0, 0, 0.1);
  border-radius: 0px; }

body ::-webkit-scrollbar-thumb {
  cursor: pointer;
  border-radius: 5px;
  background: rgba(0, 0, 0, 0.25);
  -webkit-transition: color 0.2s ease;
  transition: color 0.2s ease; }
  body ::-webkit-scrollbar-thumb:window-inactive {
    background: rgba(0, 0, 0, 0.15); }
  body ::-webkit-scrollbar-thumb:hover {
    background: rgba(128, 135, 139, 0.8); }

body .ui.inverted::-webkit-scrollbar-track {
  background: rgba(255, 255, 255, 0.1); }

body .ui.inverted::-webkit-scrollbar-thumb {
  background: rgba(255, 255, 255, 0.25); }
  body .ui.inverted::-webkit-scrollbar-thumb:window-inactive {
    background: rgba(255, 255, 255, 0.15); }
  body .ui.inverted::-webkit-scrollbar-thumb:hover {
    background: rgba(255, 255, 255, 0.35); }

/*!
 * # Semantic UI 2.2.12 - Button
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Button
*******************************/
.ui.button {
  cursor: pointer;
  display: inline-block;
  min-height: 1em;
  outline: none;
  border: none;
  vertical-align: baseline;
  background: #E0E1E2 none;
  color: #rgba 0, 0, 0, 0.6;
  font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
  margin: 0em 0.25em 0em 0em;
  padding: 0.78571429em 1.5em 0.78571429em;
  text-transform: none;
  text-shadow: none;
  font-weight: bold;
  line-height: 1em;
  font-style: normal;
  text-align: center;
  text-decoration: none;
  border-radius: 0.28571429rem;
  box-shadow: 0px 0px 0px 1px transparent inset, 0px 0em 0px 0px #rgba 34, 36, 38, 0.15 inset;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-transition: opacity 0.1s ease, background-color 0.1s ease, color 0.1s ease, box-shadow 0.1s ease, background 0.1s ease;
  transition: opacity 0.1s ease, background-color 0.1s ease, color 0.1s ease, box-shadow 0.1s ease, background 0.1s ease;
  will-change: '';
  -webkit-tap-highlight-color: transparent; }
  .ui.button:hover {
    background-color: #CACBCD;
    background-image: none;
    box-shadow: 0px 0px 0px 1px transparent inset, 0px 0em 0px 0px #rgba 34, 36, 38, 0.15 inset;
    color: #rgba 0, 0, 0, 0.8; }
    .ui.button:hover .icon {
      opacity: 0.85; }
  .ui.button:focus {
    background-color: #CACBCD;
    color: #rgba 0, 0, 0, 0.8;
    background-image: '' !important;
    box-shadow: '' !important; }
    .ui.button:focus .icon {
      opacity: 0.85; }
  .ui.button:active {
    background-color: #BABBBC;
    background-image: '';
    color: #rgba 0, 0, 0, 0.9;
    box-shadow: 0px 0px 0px 1px transparent inset, none; }

.ui.active.button {
  background-color: #C0C1C2;
  background-image: none;
  box-shadow: 0px 0px 0px 1px transparent inset;
  color: #rgba 0, 0, 0, 0.95; }
  .ui.active.button:active {
    background-color: #C0C1C2;
    background-image: '';
    color: #rgba 0, 0, 0, 0.9;
    box-shadow: 0px 0px 0px 1px transparent inset, none; }
  .ui.active.button:hover {
    background-color: #C0C1C2;
    background-image: none;
    color: #rgba 0, 0, 0, 0.95; }
  .ui.active.button:active {
    background-color: #C0C1C2;
    background-image: none; }

.ui.loading.loading.loading.loading.loading.loading.button {
  position: relative;
  cursor: default;
  text-shadow: none !important;
  color: transparent !important;
  opacity: 1;
  pointer-events: auto;
  -webkit-transition: all 0s linear, opacity 0.1s ease;
  transition: all 0s linear, opacity 0.1s ease; }

.ui.loading.button:before {
  position: absolute;
  content: '';
  top: 50%;
  left: 50%;
  margin: -0.64285714em 0em 0em -0.64285714em;
  width: 1.28571429em;
  height: 1.28571429em;
  border-radius: 500rem;
  border: 0.2em solid rgba(0, 0, 0, 0.15); }

.ui.loading.button:after {
  position: absolute;
  content: '';
  top: 50%;
  left: 50%;
  margin: -0.64285714em 0em 0em -0.64285714em;
  width: 1.28571429em;
  height: 1.28571429em;
  -webkit-animation: button-spin 0.6s linear;
  animation: button-spin 0.6s linear;
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite;
  border-radius: 500rem;
  border-color: #FFFFFF transparent transparent;
  border-style: solid;
  border-width: 0.2em;
  box-shadow: 0px 0px 0px 1px transparent; }

.ui.labeled.icon.loading.button .icon {
  background-color: transparent;
  box-shadow: none; }

.ui.basic.loading.button:not(.inverted):before {
  border-color: rgba(0, 0, 0, 0.1); }

.ui.basic.loading.button:not(.inverted):after {
  border-top-color: #767676; }

.ui.buttons .disabled.button, .ui.disabled.button, .ui.button:disabled {
  cursor: default;
  opacity: 0.45 !important;
  background-image: none !important;
  box-shadow: none !important;
  pointer-events: none !important; }

.ui.disabled.button:hover, .ui.disabled.active.button {
  cursor: default;
  opacity: 0.45 !important;
  background-image: none !important;
  box-shadow: none !important;
  pointer-events: none !important; }

.ui.basic.buttons .ui.disabled.button {
  border-color: rgba(34, 36, 38, 0.5); }

.ui.animated.button {
  position: relative;
  overflow: hidden;
  padding-right: 0em !important;
  vertical-align: middle;
  z-index: 1; }
  .ui.animated.button .content {
    will-change: transform, opacity; }
  .ui.animated.button .visible.content {
    position: relative;
    margin-right: 1.5em; }
  .ui.animated.button .hidden.content {
    position: absolute;
    width: 100%; }
  .ui.animated.button .visible.content,
  .ui.animated.button .hidden.content {
    -webkit-transition: right 0.3s ease 0s;
    transition: right 0.3s ease 0s; }
  .ui.animated.button .visible.content {
    left: auto;
    right: 0%; }
  .ui.animated.button .hidden.content {
    top: 50%;
    left: auto;
    right: -100%;
    margin-top: -0.5em; }
  .ui.animated.button:focus .visible.content,
  .ui.animated.button:hover .visible.content {
    left: auto;
    right: 200%; }
  .ui.animated.button:focus .hidden.content,
  .ui.animated.button:hover .hidden.content {
    left: auto;
    right: 0%; }

.ui.vertical.animated.button .visible.content,
.ui.vertical.animated.button .hidden.content {
  -webkit-transition: top 0.3s ease, -webkit-transform 0.3s ease;
  transition: top 0.3s ease, -webkit-transform 0.3s ease;
  transition: top 0.3s ease, transform 0.3s ease;
  transition: top 0.3s ease, transform 0.3s ease, -webkit-transform 0.3s ease; }

.ui.vertical.animated.button .visible.content {
  -webkit-transform: translateY(0%);
  transform: translateY(0%);
  right: auto; }

.ui.vertical.animated.button .hidden.content {
  top: -50%;
  left: 0%;
  right: auto; }

.ui.vertical.animated.button:focus .visible.content,
.ui.vertical.animated.button:hover .visible.content {
  -webkit-transform: translateY(200%);
  transform: translateY(200%);
  right: auto; }

.ui.vertical.animated.button:focus .hidden.content,
.ui.vertical.animated.button:hover .hidden.content {
  top: 50%;
  right: auto; }

.ui.fade.animated.button .visible.content,
.ui.fade.animated.button .hidden.content {
  -webkit-transition: opacity 0.3s ease, -webkit-transform 0.3s ease;
  transition: opacity 0.3s ease, -webkit-transform 0.3s ease;
  transition: opacity 0.3s ease, transform 0.3s ease;
  transition: opacity 0.3s ease, transform 0.3s ease, -webkit-transform 0.3s ease; }

.ui.fade.animated.button .visible.content {
  left: auto;
  right: auto;
  opacity: 1;
  -webkit-transform: scale(1);
  transform: scale(1); }

.ui.fade.animated.button .hidden.content {
  opacity: 0;
  left: 0%;
  right: auto;
  -webkit-transform: scale(1.5);
  transform: scale(1.5); }

.ui.fade.animated.button:focus .visible.content,
.ui.fade.animated.button:hover .visible.content {
  left: auto;
  right: auto;
  opacity: 0;
  -webkit-transform: scale(0.75);
  transform: scale(0.75); }

.ui.fade.animated.button:focus .hidden.content,
.ui.fade.animated.button:hover .hidden.content {
  left: 0%;
  right: auto;
  opacity: 1;
  -webkit-transform: scale(1);
  transform: scale(1); }

.ui.inverted.button {
  box-shadow: 0px 0px 0px 2px #FFFFFF inset !important;
  background: transparent none;
  color: #FFFFFF;
  text-shadow: none !important; }

.ui.inverted.buttons .button {
  margin: 0px 0px 0px -2px; }
  .ui.inverted.buttons .button:first-child {
    margin-left: 0em; }

.ui.inverted.vertical.buttons .button {
  margin: 0px 0px -2px 0px; }
  .ui.inverted.vertical.buttons .button:first-child {
    margin-top: 0em; }

.ui.inverted.button:hover, .ui.inverted.button:focus {
  background: #FFFFFF;
  box-shadow: 0px 0px 0px 2px #FFFFFF inset !important;
  color: rgba(0, 0, 0, 0.8); }

.ui.inverted.button.active {
  background: #FFFFFF;
  box-shadow: 0px 0px 0px 2px #FFFFFF inset !important;
  color: rgba(0, 0, 0, 0.8); }
  .ui.inverted.button.active:focus {
    background: #DCDDDE;
    box-shadow: 0px 0px 0px 2px #DCDDDE inset !important;
    color: rgba(0, 0, 0, 0.8); }

.ui.labeled.button:not(.icon) {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -ms-flex-direction: row;
  flex-direction: row;
  background: none !important;
  padding: 0px !important;
  border: none !important;
  box-shadow: none !important; }

.ui.labeled.button > .button {
  margin: 0px; }

.ui.labeled.button > .label {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -ms-flex-align: center;
  align-items: center;
  margin: 0px 0px 0px -1px !important;
  padding: '';
  font-size: 1em;
  border-color: rgba(34, 36, 38, 0.15); }

.ui.labeled.button > .tag.label:before {
  width: 1.85em;
  height: 1.85em; }

.ui.labeled.button:not([class*="left labeled"]) > .button {
  border-top-right-radius: 0px;
  border-bottom-right-radius: 0px; }

.ui.labeled.button:not([class*="left labeled"]) > .label {
  border-top-left-radius: 0px;
  border-bottom-left-radius: 0px; }

.ui[class*="left labeled"].button > .button {
  border-top-left-radius: 0px;
  border-bottom-left-radius: 0px; }

.ui[class*="left labeled"].button > .label {
  border-top-right-radius: 0px;
  border-bottom-right-radius: 0px; }

.ui.facebook.button {
  background-color: #3B5998;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }
  .ui.facebook.button:hover {
    background-color: #304d8a;
    color: #FFFFFF;
    text-shadow: none; }
  .ui.facebook.button:active {
    background-color: #2d4373;
    color: #FFFFFF;
    text-shadow: none; }

.ui.twitter.button {
  background-color: #55ACEE;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }
  .ui.twitter.button:hover {
    background-color: #35a2f4;
    color: #FFFFFF;
    text-shadow: none; }
  .ui.twitter.button:active {
    background-color: #2795e9;
    color: #FFFFFF;
    text-shadow: none; }

.ui.google.plus.button {
  background-color: #DD4B39;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }
  .ui.google.plus.button:hover {
    background-color: #e0321c;
    color: #FFFFFF;
    text-shadow: none; }
  .ui.google.plus.button:active {
    background-color: #c23321;
    color: #FFFFFF;
    text-shadow: none; }

.ui.linkedin.button {
  background-color: #1F88BE;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.linkedin.button:hover {
    background-color: #147baf;
    color: #FFFFFF;
    text-shadow: none; }
  .ui.linkedin.button:active {
    background-color: #186992;
    color: #FFFFFF;
    text-shadow: none; }

.ui.youtube.button {
  background-color: #CC181E;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }
  .ui.youtube.button:hover {
    background-color: #bd0d13;
    color: #FFFFFF;
    text-shadow: none; }
  .ui.youtube.button:active {
    background-color: #9e1317;
    color: #FFFFFF;
    text-shadow: none; }

.ui.instagram.button {
  background-color: #49769C;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }
  .ui.instagram.button:hover {
    background-color: #3d698e;
    color: #FFFFFF;
    text-shadow: none; }
  .ui.instagram.button:active {
    background-color: #395c79;
    color: #FFFFFF;
    text-shadow: none; }

.ui.pinterest.button {
  background-color: #BD081C;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }
  .ui.pinterest.button:hover {
    background-color: #ac0013;
    color: #FFFFFF;
    text-shadow: none; }
  .ui.pinterest.button:active {
    background-color: #8c0615;
    color: #FFFFFF;
    text-shadow: none; }

.ui.vk.button {
  background-color: #4D7198;
  color: #FFFFFF;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }
  .ui.vk.button:hover {
    background-color: #41648a;
    color: #FFFFFF; }
  .ui.vk.button:active {
    background-color: #3c5876;
    color: #FFFFFF; }

.ui.button > .icon:not(.button) {
  height: 0.85714286em;
  opacity: 0.8;
  margin: 0em 0.42857143em 0em -0.21428571em;
  -webkit-transition: opacity 0.1s ease;
  transition: opacity 0.1s ease;
  vertical-align: '';
  color: ''; }

.ui.button:not(.icon) > .icon:not(.button):not(.dropdown) {
  margin: 0em 0.42857143em 0em -0.21428571em; }

.ui.button:not(.icon) > .right.icon:not(.button):not(.dropdown) {
  margin: 0em -0.21428571em 0em 0.42857143em; }

.ui[class*="left floated"].buttons, .ui[class*="left floated"].button {
  float: left;
  margin-left: 0em;
  margin-right: 0.25em; }

.ui[class*="right floated"].buttons, .ui[class*="right floated"].button {
  float: right;
  margin-right: 0em;
  margin-left: 0.25em; }

.ui.compact.buttons .button, .ui.compact.button {
  padding: 0.58928571em 1.125em 0.58928571em; }

.ui.compact.icon.buttons .button, .ui.compact.icon.button {
  padding: 0.58928571em 0.58928571em 0.58928571em; }

.ui.compact.labeled.icon.buttons .button, .ui.compact.labeled.icon.button {
  padding: 0.58928571em 3.69642857em 0.58928571em; }

.ui.mini.buttons .button,
.ui.mini.buttons .or {
  font-size: 0.78571429rem; }

.ui.mini.button {
  font-size: 0.78571429rem; }

.ui.tiny.buttons .button,
.ui.tiny.buttons .or {
  font-size: 0.85714286rem; }

.ui.tiny.button {
  font-size: 0.85714286rem; }

.ui.small.buttons .button,
.ui.small.buttons .or {
  font-size: 0.92857143rem; }

.ui.small.button {
  font-size: 0.92857143rem; }

.ui.buttons .button,
.ui.buttons .or {
  font-size: 1rem; }

.ui.button {
  font-size: 1rem; }

.ui.large.buttons .button,
.ui.large.buttons .or {
  font-size: 1.14285714rem; }

.ui.large.button {
  font-size: 1.14285714rem; }

.ui.big.buttons .button,
.ui.big.buttons .or {
  font-size: 1.28571429rem; }

.ui.big.button {
  font-size: 1.28571429rem; }

.ui.huge.buttons .button,
.ui.huge.buttons .or {
  font-size: 1.42857143rem; }

.ui.huge.button {
  font-size: 1.42857143rem; }

.ui.massive.buttons .button,
.ui.massive.buttons .or {
  font-size: 1.71428571rem; }

.ui.massive.button {
  font-size: 1.71428571rem; }

.ui.icon.buttons .button, .ui.icon.button {
  padding: 0.78571429em 0.78571429em 0.78571429em; }

.ui.icon.buttons .button > .icon,
.ui.icon.button > .icon {
  opacity: 0.9;
  margin: 0em !important;
  vertical-align: top; }

.ui.basic.buttons .button, .ui.basic.button {
  background: transparent none !important;
  color: rgba(0, 0, 0, 0.6) !important;
  font-weight: normal;
  border-radius: 0.28571429rem;
  text-transform: none;
  text-shadow: none !important;
  box-shadow: 0px 0px 0px 1px rgba(34, 36, 38, 0.15) inset; }

.ui.basic.buttons {
  box-shadow: none;
  border: 1px solid rgba(34, 36, 38, 0.15);
  border-radius: 0.28571429rem; }
  .ui.basic.buttons .button {
    border-radius: 0em; }
    .ui.basic.buttons .button:hover {
      background: #FFFFFF !important;
      color: rgba(0, 0, 0, 0.8) !important;
      box-shadow: 0px 0px 0px 1px rgba(34, 36, 38, 0.35) inset, 0px 0px 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.basic.button:hover,
.ui.basic.buttons .button:focus, .ui.basic.button:focus {
  background: #FFFFFF !important;
  color: rgba(0, 0, 0, 0.8) !important;
  box-shadow: 0px 0px 0px 1px rgba(34, 36, 38, 0.35) inset, 0px 0px 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.basic.buttons .button:active, .ui.basic.button:active {
  background: #F8F8F8 !important;
  color: rgba(0, 0, 0, 0.9) !important;
  box-shadow: 0px 0px 0px 1px rgba(0, 0, 0, 0.15) inset, 0px 1px 4px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.basic.buttons .active.button, .ui.basic.active.button {
  background: rgba(0, 0, 0, 0.05) !important;
  box-shadow: '' !important;
  color: rgba(0, 0, 0, 0.95); }

.ui.basic.buttons .active.button:hover, .ui.basic.active.button:hover {
  background-color: rgba(0, 0, 0, 0.05); }

.ui.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 1px rgba(34, 36, 38, 0.35) inset, 0px 0px 0px 0px rgba(34, 36, 38, 0.15) inset inset; }

.ui.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 1px rgba(0, 0, 0, 0.15) inset, 0px 1px 4px 0px rgba(34, 36, 38, 0.15) inset inset; }

.ui.basic.buttons .active.button {
  box-shadow: '' !important; }

.ui.basic.inverted.buttons .button, .ui.basic.inverted.button {
  background-color: transparent !important;
  color: #F9FAFB !important;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important; }

.ui.basic.inverted.buttons .button:hover, .ui.basic.inverted.button:hover,
.ui.basic.inverted.buttons .button:focus, .ui.basic.inverted.button:focus {
  color: #FFFFFF !important;
  box-shadow: 0px 0px 0px 2px #ffffff inset !important; }

.ui.basic.inverted.buttons .button:active, .ui.basic.inverted.button:active {
  background-color: rgba(255, 255, 255, 0.08) !important;
  color: #FFFFFF !important;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.9) inset !important; }

.ui.basic.inverted.buttons .active.button, .ui.basic.inverted.active.button {
  background-color: rgba(255, 255, 255, 0.08);
  color: #FFFFFF;
  text-shadow: none;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.7) inset; }

.ui.basic.inverted.buttons .active.button:hover, .ui.basic.inverted.active.button:hover {
  background-color: rgba(255, 255, 255, 0.15);
  box-shadow: 0px 0px 0px 2px #ffffff inset !important; }

.ui.basic.buttons .button {
  border-left: 1px solid rgba(34, 36, 38, 0.15);
  box-shadow: none; }

.ui.basic.vertical.buttons .button {
  border-left: none;
  border-left-width: 0px;
  border-top: 1px solid rgba(34, 36, 38, 0.15); }
  .ui.basic.vertical.buttons .button:first-child {
    border-top-width: 0px; }

.ui.labeled.icon.buttons .button, .ui.labeled.icon.button {
  position: relative;
  padding-left: 4.07142857em !important;
  padding-right: 1.5em !important; }

.ui.labeled.icon.buttons > .button > .icon,
.ui.labeled.icon.button > .icon {
  position: absolute;
  height: 100%;
  line-height: 1;
  border-radius: 0px;
  border-top-left-radius: inherit;
  border-bottom-left-radius: inherit;
  text-align: center;
  margin: 0em;
  width: 2.57142857em;
  background-color: rgba(0, 0, 0, 0.05);
  color: '';
  box-shadow: -1px 0px 0px 0px transparent inset; }

.ui.labeled.icon.buttons > .button > .icon,
.ui.labeled.icon.button > .icon {
  top: 0em;
  left: 0em; }

.ui[class*="right labeled"].icon.button {
  padding-right: 4.07142857em !important;
  padding-left: 1.5em !important; }
  .ui[class*="right labeled"].icon.button > .icon {
    left: auto;
    right: 0em;
    border-radius: 0px;
    border-top-right-radius: inherit;
    border-bottom-right-radius: inherit;
    box-shadow: 1px 0px 0px 0px transparent inset; }

.ui.labeled.icon.buttons > .button > .icon:before,
.ui.labeled.icon.button > .icon:before,
.ui.labeled.icon.buttons > .button > .icon:after,
.ui.labeled.icon.button > .icon:after {
  display: block;
  position: absolute;
  width: 100%;
  top: 50%;
  text-align: center;
  -webkit-transform: translateY(-50%);
  transform: translateY(-50%); }

.ui.labeled.icon.buttons .button > .icon {
  border-radius: 0em; }

.ui.labeled.icon.buttons .button:first-child > .icon {
  border-top-left-radius: 0.28571429rem;
  border-bottom-left-radius: 0.28571429rem; }

.ui.labeled.icon.buttons .button:last-child > .icon {
  border-top-right-radius: 0.28571429rem;
  border-bottom-right-radius: 0.28571429rem; }

.ui.vertical.labeled.icon.buttons .button:first-child > .icon {
  border-radius: 0em;
  border-top-left-radius: 0.28571429rem; }

.ui.vertical.labeled.icon.buttons .button:last-child > .icon {
  border-radius: 0em;
  border-bottom-left-radius: 0.28571429rem; }

.ui.fluid[class*="left labeled"].icon.button, .ui.fluid[class*="right labeled"].icon.button {
  padding-left: 1.5em !important;
  padding-right: 1.5em !important; }

.ui.toggle.buttons .active.button,
.ui.buttons .button.toggle.active {
  background-color: #21BA45 !important;
  box-shadow: none !important;
  text-shadow: none;
  color: #FFFFFF !important; }

.ui.button.toggle.active {
  background-color: #21BA45 !important;
  box-shadow: none !important;
  text-shadow: none;
  color: #FFFFFF !important; }
  .ui.button.toggle.active:hover {
    background-color: #16ab39 !important;
    text-shadow: none;
    color: #FFFFFF !important; }

.ui.circular.button {
  border-radius: 10em; }
  .ui.circular.button > .icon {
    width: 1em;
    vertical-align: baseline; }

.ui.buttons .or {
  position: relative;
  width: 0.3em;
  height: 2.57142857em;
  z-index: 3; }
  .ui.buttons .or:before {
    position: absolute;
    text-align: center;
    border-radius: 500rem;
    content: 'or';
    top: 50%;
    left: 50%;
    background-color: #FFFFFF;
    text-shadow: none;
    margin-top: -0.89285714em;
    margin-left: -0.89285714em;
    width: 1.78571429em;
    height: 1.78571429em;
    line-height: 1.78571429em;
    color: rgba(0, 0, 0, 0.4);
    font-style: normal;
    font-weight: bold;
    box-shadow: 0px 0px 0px 1px transparent inset; }
  .ui.buttons .or[data-text]:before {
    content: attr(data-text); }

.ui.fluid.buttons .or {
  width: 0em !important; }
  .ui.fluid.buttons .or:after {
    display: none; }

.ui.attached.button {
  position: relative;
  display: block;
  margin: 0em;
  border-radius: 0em;
  box-shadow: 0px 0px 0px 1px rgba(34, 36, 38, 0.15) !important; }

.ui.attached.top.button {
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }

.ui.attached.bottom.button {
  border-radius: 0em 0em 0.28571429rem 0.28571429rem; }

.ui.left.attached.button {
  display: inline-block;
  border-left: none;
  text-align: right;
  padding-right: 0.75em;
  border-radius: 0.28571429rem 0em 0em 0.28571429rem; }

.ui.right.attached.button {
  display: inline-block;
  text-align: left;
  padding-left: 0.75em;
  border-radius: 0em 0.28571429rem 0.28571429rem 0em; }

.ui.attached.buttons {
  position: relative;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  border-radius: 0em;
  width: auto !important;
  z-index: 2;
  margin-left: -1px;
  margin-right: -1px; }
  .ui.attached.buttons .button {
    margin: 0em; }
    .ui.attached.buttons .button:first-child, .ui.attached.buttons .button:last-child {
      border-radius: 0em; }

.ui[class*="top attached"].buttons {
  margin-bottom: -1px;
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
  .ui[class*="top attached"].buttons .button:first-child {
    border-radius: 0.28571429rem 0em 0em 0em; }
  .ui[class*="top attached"].buttons .button:last-child {
    border-radius: 0em 0.28571429rem 0em 0em; }

.ui[class*="bottom attached"].buttons {
  margin-top: -1px;
  border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
  .ui[class*="bottom attached"].buttons .button:first-child {
    border-radius: 0em 0em 0em 0.28571429rem; }
  .ui[class*="bottom attached"].buttons .button:last-child {
    border-radius: 0em 0em 0.28571429rem 0em; }

.ui[class*="left attached"].buttons {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  margin-right: 0em;
  margin-left: -1px;
  border-radius: 0em 0.28571429rem 0.28571429rem 0em; }
  .ui[class*="left attached"].buttons .button:first-child {
    margin-left: -1px;
    border-radius: 0em 0.28571429rem 0em 0em; }
  .ui[class*="left attached"].buttons .button:last-child {
    margin-left: -1px;
    border-radius: 0em 0em 0.28571429rem 0em; }

.ui[class*="right attached"].buttons {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  margin-left: 0em;
  margin-right: -1px;
  border-radius: 0.28571429rem 0em 0em 0.28571429rem; }
  .ui[class*="right attached"].buttons .button:first-child {
    margin-left: -1px;
    border-radius: 0.28571429rem 0em 0em 0em; }
  .ui[class*="right attached"].buttons .button:last-child {
    margin-left: -1px;
    border-radius: 0em 0em 0em 0.28571429rem; }

.ui.fluid.buttons {
  width: 100%; }

.ui.fluid.button {
  width: 100%;
  display: block; }

.ui.two.buttons {
  width: 100%; }
  .ui.two.buttons > .button {
    width: 50%; }

.ui.three.buttons {
  width: 100%; }
  .ui.three.buttons > .button {
    width: 33.333%; }

.ui.four.buttons {
  width: 100%; }
  .ui.four.buttons > .button {
    width: 25%; }

.ui.five.buttons {
  width: 100%; }
  .ui.five.buttons > .button {
    width: 20%; }

.ui.six.buttons {
  width: 100%; }
  .ui.six.buttons > .button {
    width: 16.666%; }

.ui.seven.buttons {
  width: 100%; }
  .ui.seven.buttons > .button {
    width: 14.285%; }

.ui.eight.buttons {
  width: 100%; }
  .ui.eight.buttons > .button {
    width: 12.500%; }

.ui.nine.buttons {
  width: 100%; }
  .ui.nine.buttons > .button {
    width: 11.11%; }

.ui.ten.buttons {
  width: 100%; }
  .ui.ten.buttons > .button {
    width: 10%; }

.ui.eleven.buttons {
  width: 100%; }
  .ui.eleven.buttons > .button {
    width: 9.09%; }

.ui.twelve.buttons {
  width: 100%; }
  .ui.twelve.buttons > .button {
    width: 8.3333%; }

.ui.fluid.vertical.buttons {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  width: auto; }
  .ui.fluid.vertical.buttons > .button {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    width: auto; }

.ui.two.vertical.buttons > .button {
  height: 50%; }

.ui.three.vertical.buttons > .button {
  height: 33.333%; }

.ui.four.vertical.buttons > .button {
  height: 25%; }

.ui.five.vertical.buttons > .button {
  height: 20%; }

.ui.six.vertical.buttons > .button {
  height: 16.666%; }

.ui.seven.vertical.buttons > .button {
  height: 14.285%; }

.ui.eight.vertical.buttons > .button {
  height: 12.500%; }

.ui.nine.vertical.buttons > .button {
  height: 11.11%; }

.ui.ten.vertical.buttons > .button {
  height: 10%; }

.ui.eleven.vertical.buttons > .button {
  height: 9.09%; }

.ui.twelve.vertical.buttons > .button {
  height: 8.3333%; }

.ui.black.buttons .button {
  background-color: #1B1C1D;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.black.button {
  background-color: #1B1C1D;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.black.buttons .button:hover, .ui.black.button:hover {
  background-color: #27292a;
  color: #FFFFFF;
  text-shadow: none; }

.ui.black.buttons .button:focus, .ui.black.button:focus {
  background-color: #2f3032;
  color: #FFFFFF;
  text-shadow: none; }

.ui.black.buttons .button:active, .ui.black.button:active {
  background-color: #343637;
  color: #FFFFFF;
  text-shadow: none; }

.ui.black.buttons .active.button {
  background-color: #0f0f10;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.black.buttons .active.button:active {
    background-color: #0f0f10;
    color: #FFFFFF;
    text-shadow: none; }

.ui.black.active.button,
.ui.black.button .active.button:active {
  background-color: #0f0f10;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.black.buttons .button, .ui.basic.black.button {
  box-shadow: 0px 0px 0px 1px #1B1C1D inset !important;
  color: #1B1C1D !important; }

.ui.basic.black.buttons .button:hover, .ui.basic.black.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #27292a inset !important;
  color: #27292a !important; }

.ui.basic.black.buttons .button:focus, .ui.basic.black.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #2f3032 inset !important;
  color: #27292a !important; }

.ui.basic.black.buttons .active.button, .ui.basic.black.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #0f0f10 inset !important;
  color: #343637 !important; }

.ui.basic.black.buttons .button:active, .ui.basic.black.button:active {
  box-shadow: 0px 0px 0px 1px #343637 inset !important;
  color: #343637 !important; }

.ui.buttons:not(.vertical) > .basic.black.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.black.buttons .button, .ui.inverted.black.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #D4D4D5 inset !important;
  color: #FFFFFF; }

.ui.inverted.black.buttons .button:hover, .ui.inverted.black.button:hover,
.ui.inverted.black.buttons .button:focus, .ui.inverted.black.button:focus,
.ui.inverted.black.buttons .button.active, .ui.inverted.black.button.active,
.ui.inverted.black.buttons .button:active, .ui.inverted.black.button:active {
  box-shadow: none !important;
  color: #FFFFFF; }

.ui.inverted.black.buttons .button:hover, .ui.inverted.black.button:hover,
.ui.inverted.black.buttons .button:focus, .ui.inverted.black.button:focus,
.ui.inverted.black.buttons .active.button, .ui.inverted.black.active.button,
.ui.inverted.black.buttons .button:active, .ui.inverted.black.button:active {
  background-color: #000000; }

.ui.inverted.black.basic.buttons .button,
.ui.inverted.black.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.black.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.black.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #000000 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.black.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #000000 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.black.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #000000 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.black.basic.buttons .button:focus, .ui.inverted.black.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #000000 inset !important;
  color: #545454 !important; }

.ui.inverted.black.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #000000 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.black.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #000000 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.black.basic.active.button,
.ui.inverted.black.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #000000 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.black.buttons .basic.button:active, .ui.inverted.black.basic.button:active {
  box-shadow: 0px 0px 0px 2px #000000 inset !important;
  color: #FFFFFF !important; }

.ui.grey.buttons .button {
  background-color: #767676;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.grey.button {
  background-color: #767676;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.grey.buttons .button:hover, .ui.grey.button:hover {
  background-color: #838383;
  color: #FFFFFF;
  text-shadow: none; }

.ui.grey.buttons .button:focus, .ui.grey.button:focus {
  background-color: #8a8a8a;
  color: #FFFFFF;
  text-shadow: none; }

.ui.grey.buttons .button:active, .ui.grey.button:active {
  background-color: #909090;
  color: #FFFFFF;
  text-shadow: none; }

.ui.grey.buttons .active.button {
  background-color: #696969;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.grey.buttons .active.button:active {
    background-color: #696969;
    color: #FFFFFF;
    text-shadow: none; }

.ui.grey.active.button,
.ui.grey.button .active.button:active {
  background-color: #696969;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.grey.buttons .button, .ui.basic.grey.button {
  box-shadow: 0px 0px 0px 1px #767676 inset !important;
  color: #767676 !important; }

.ui.basic.grey.buttons .button:hover, .ui.basic.grey.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #838383 inset !important;
  color: #838383 !important; }

.ui.basic.grey.buttons .button:focus, .ui.basic.grey.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #8a8a8a inset !important;
  color: #838383 !important; }

.ui.basic.grey.buttons .active.button, .ui.basic.grey.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #696969 inset !important;
  color: #909090 !important; }

.ui.basic.grey.buttons .button:active, .ui.basic.grey.button:active {
  box-shadow: 0px 0px 0px 1px #909090 inset !important;
  color: #909090 !important; }

.ui.buttons:not(.vertical) > .basic.grey.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.grey.buttons .button, .ui.inverted.grey.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #D4D4D5 inset !important;
  color: #FFFFFF; }

.ui.inverted.grey.buttons .button:hover, .ui.inverted.grey.button:hover,
.ui.inverted.grey.buttons .button:focus, .ui.inverted.grey.button:focus,
.ui.inverted.grey.buttons .button.active, .ui.inverted.grey.button.active,
.ui.inverted.grey.buttons .button:active, .ui.inverted.grey.button:active {
  box-shadow: none !important;
  color: rgba(0, 0, 0, 0.6); }

.ui.inverted.grey.buttons .button:hover, .ui.inverted.grey.button:hover {
  background-color: #cfd0d2; }

.ui.inverted.grey.buttons .button:focus, .ui.inverted.grey.button:focus {
  background-color: #c7c9cb; }

.ui.inverted.grey.buttons .active.button, .ui.inverted.grey.active.button {
  background-color: #cfd0d2; }

.ui.inverted.grey.buttons .button:active, .ui.inverted.grey.button:active {
  background-color: #c2c4c5; }

.ui.inverted.grey.basic.buttons .button,
.ui.inverted.grey.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.grey.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.grey.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #cfd0d2 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.grey.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #cfd0d2 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.grey.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #cfd0d2 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.grey.basic.buttons .button:focus, .ui.inverted.grey.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #c7c9cb inset !important;
  color: #DCDDDE !important; }

.ui.inverted.grey.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #cfd0d2 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.grey.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #cfd0d2 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.grey.basic.active.button {
  box-shadow: 0px 0px 0px 2px #cfd0d2 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.grey.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #c2c4c5 inset !important;
  color: #FFFFFF !important; }

.ui.inverted.grey.buttons .basic.button:active, .ui.inverted.grey.basic.button:active {
  box-shadow: 0px 0px 0px 2px #c2c4c5 inset !important;
  color: #FFFFFF !important; }

.ui.brown.buttons .button {
  background-color: #A5673F;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.brown.button {
  background-color: #A5673F;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.brown.buttons .button:hover, .ui.brown.button:hover {
  background-color: #975b33;
  color: #FFFFFF;
  text-shadow: none; }

.ui.brown.buttons .button:focus, .ui.brown.button:focus {
  background-color: #90532b;
  color: #FFFFFF;
  text-shadow: none; }

.ui.brown.buttons .button:active, .ui.brown.button:active {
  background-color: #805031;
  color: #FFFFFF;
  text-shadow: none; }

.ui.brown.buttons .active.button {
  background-color: #995a31;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.brown.buttons .active.button:active {
    background-color: #995a31;
    color: #FFFFFF;
    text-shadow: none; }

.ui.brown.active.button,
.ui.brown.button .active.button:active {
  background-color: #995a31;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.brown.buttons .button, .ui.basic.brown.button {
  box-shadow: 0px 0px 0px 1px #A5673F inset !important;
  color: #A5673F !important; }

.ui.basic.brown.buttons .button:hover, .ui.basic.brown.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #975b33 inset !important;
  color: #975b33 !important; }

.ui.basic.brown.buttons .button:focus, .ui.basic.brown.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #90532b inset !important;
  color: #975b33 !important; }

.ui.basic.brown.buttons .active.button, .ui.basic.brown.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #995a31 inset !important;
  color: #805031 !important; }

.ui.basic.brown.buttons .button:active, .ui.basic.brown.button:active {
  box-shadow: 0px 0px 0px 1px #805031 inset !important;
  color: #805031 !important; }

.ui.buttons:not(.vertical) > .basic.brown.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.brown.buttons .button, .ui.inverted.brown.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #D67C1C inset !important;
  color: #D67C1C; }

.ui.inverted.brown.buttons .button:hover, .ui.inverted.brown.button:hover,
.ui.inverted.brown.buttons .button:focus, .ui.inverted.brown.button:focus,
.ui.inverted.brown.buttons .button.active, .ui.inverted.brown.button.active,
.ui.inverted.brown.buttons .button:active, .ui.inverted.brown.button:active {
  box-shadow: none !important;
  color: #FFFFFF; }

.ui.inverted.brown.buttons .button:hover, .ui.inverted.brown.button:hover {
  background-color: #c86f11; }

.ui.inverted.brown.buttons .button:focus, .ui.inverted.brown.button:focus {
  background-color: #c16808; }

.ui.inverted.brown.buttons .active.button, .ui.inverted.brown.active.button {
  background-color: #cc6f0d; }

.ui.inverted.brown.buttons .button:active, .ui.inverted.brown.button:active {
  background-color: #a96216; }

.ui.inverted.brown.basic.buttons .button,
.ui.inverted.brown.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.brown.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.brown.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #c86f11 inset !important;
  color: #D67C1C !important; }

.ui.inverted.brown.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #c86f11 inset !important;
  color: #D67C1C !important; }

.ui.inverted.brown.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #c86f11 inset !important;
  color: #D67C1C !important; }

.ui.inverted.brown.basic.buttons .button:focus, .ui.inverted.brown.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #c16808 inset !important;
  color: #D67C1C !important; }

.ui.inverted.brown.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #cc6f0d inset !important;
  color: #D67C1C !important; }

.ui.inverted.brown.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #cc6f0d inset !important;
  color: #D67C1C !important; }

.ui.inverted.brown.basic.active.button {
  box-shadow: 0px 0px 0px 2px #cc6f0d inset !important;
  color: #D67C1C !important; }

.ui.inverted.brown.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #a96216 inset !important;
  color: #D67C1C !important; }

.ui.inverted.brown.buttons .basic.button:active, .ui.inverted.brown.basic.button:active {
  box-shadow: 0px 0px 0px 2px #a96216 inset !important;
  color: #D67C1C !important; }

.ui.blue.buttons .button {
  background-color: #2185D0;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.blue.button {
  background-color: #2185D0;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.blue.buttons .button:hover, .ui.blue.button:hover {
  background-color: #1678c2;
  color: #FFFFFF;
  text-shadow: none; }

.ui.blue.buttons .button:focus, .ui.blue.button:focus {
  background-color: #0d71bb;
  color: #FFFFFF;
  text-shadow: none; }

.ui.blue.buttons .button:active, .ui.blue.button:active {
  background-color: #1a69a4;
  color: #FFFFFF;
  text-shadow: none; }

.ui.blue.buttons .active.button {
  background-color: #1279c6;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.blue.buttons .active.button:active {
    background-color: #1279c6;
    color: #FFFFFF;
    text-shadow: none; }

.ui.blue.active.button,
.ui.blue.button .active.button:active {
  background-color: #1279c6;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.blue.buttons .button, .ui.basic.blue.button {
  box-shadow: 0px 0px 0px 1px #2185D0 inset !important;
  color: #2185D0 !important; }

.ui.basic.blue.buttons .button:hover, .ui.basic.blue.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #1678c2 inset !important;
  color: #1678c2 !important; }

.ui.basic.blue.buttons .button:focus, .ui.basic.blue.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #0d71bb inset !important;
  color: #1678c2 !important; }

.ui.basic.blue.buttons .active.button, .ui.basic.blue.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #1279c6 inset !important;
  color: #1a69a4 !important; }

.ui.basic.blue.buttons .button:active, .ui.basic.blue.button:active {
  box-shadow: 0px 0px 0px 1px #1a69a4 inset !important;
  color: #1a69a4 !important; }

.ui.buttons:not(.vertical) > .basic.blue.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.blue.buttons .button, .ui.inverted.blue.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #54C8FF inset !important;
  color: #54C8FF; }

.ui.inverted.blue.buttons .button:hover, .ui.inverted.blue.button:hover,
.ui.inverted.blue.buttons .button:focus, .ui.inverted.blue.button:focus,
.ui.inverted.blue.buttons .button.active, .ui.inverted.blue.button.active,
.ui.inverted.blue.buttons .button:active, .ui.inverted.blue.button:active {
  box-shadow: none !important;
  color: #FFFFFF; }

.ui.inverted.blue.buttons .button:hover, .ui.inverted.blue.button:hover {
  background-color: #3ac0ff; }

.ui.inverted.blue.buttons .button:focus, .ui.inverted.blue.button:focus {
  background-color: #2bbbff; }

.ui.inverted.blue.buttons .active.button, .ui.inverted.blue.active.button {
  background-color: #3ac0ff; }

.ui.inverted.blue.buttons .button:active, .ui.inverted.blue.button:active {
  background-color: #21b8ff; }

.ui.inverted.blue.basic.buttons .button,
.ui.inverted.blue.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.blue.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.blue.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #3ac0ff inset !important;
  color: #54C8FF !important; }

.ui.inverted.blue.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #3ac0ff inset !important;
  color: #54C8FF !important; }

.ui.inverted.blue.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #3ac0ff inset !important;
  color: #54C8FF !important; }

.ui.inverted.blue.basic.buttons .button:focus, .ui.inverted.blue.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #2bbbff inset !important;
  color: #54C8FF !important; }

.ui.inverted.blue.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #3ac0ff inset !important;
  color: #54C8FF !important; }

.ui.inverted.blue.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #3ac0ff inset !important;
  color: #54C8FF !important; }

.ui.inverted.blue.basic.active.button {
  box-shadow: 0px 0px 0px 2px #3ac0ff inset !important;
  color: #54C8FF !important; }

.ui.inverted.blue.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #21b8ff inset !important;
  color: #54C8FF !important; }

.ui.inverted.blue.buttons .basic.button:active, .ui.inverted.blue.basic.button:active {
  box-shadow: 0px 0px 0px 2px #21b8ff inset !important;
  color: #54C8FF !important; }

.ui.green.buttons .button {
  background-color: #21BA45;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.green.button {
  background-color: #21BA45;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.green.buttons .button:hover, .ui.green.button:hover {
  background-color: #16ab39;
  color: #FFFFFF;
  text-shadow: none; }

.ui.green.buttons .button:focus, .ui.green.button:focus {
  background-color: #0ea432;
  color: #FFFFFF;
  text-shadow: none; }

.ui.green.buttons .button:active, .ui.green.button:active {
  background-color: #198f35;
  color: #FFFFFF;
  text-shadow: none; }

.ui.green.buttons .active.button {
  background-color: #13ae38;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.green.buttons .active.button:active {
    background-color: #13ae38;
    color: #FFFFFF;
    text-shadow: none; }

.ui.green.active.button,
.ui.green.button .active.button:active {
  background-color: #13ae38;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.green.buttons .button, .ui.basic.green.button {
  box-shadow: 0px 0px 0px 1px #21BA45 inset !important;
  color: #21BA45 !important; }

.ui.basic.green.buttons .button:hover, .ui.basic.green.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #16ab39 inset !important;
  color: #16ab39 !important; }

.ui.basic.green.buttons .button:focus, .ui.basic.green.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #0ea432 inset !important;
  color: #16ab39 !important; }

.ui.basic.green.buttons .active.button, .ui.basic.green.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #13ae38 inset !important;
  color: #198f35 !important; }

.ui.basic.green.buttons .button:active, .ui.basic.green.button:active {
  box-shadow: 0px 0px 0px 1px #198f35 inset !important;
  color: #198f35 !important; }

.ui.buttons:not(.vertical) > .basic.green.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.green.buttons .button, .ui.inverted.green.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #2ECC40 inset !important;
  color: #2ECC40; }

.ui.inverted.green.buttons .button:hover, .ui.inverted.green.button:hover,
.ui.inverted.green.buttons .button:focus, .ui.inverted.green.button:focus,
.ui.inverted.green.buttons .button.active, .ui.inverted.green.button.active,
.ui.inverted.green.buttons .button:active, .ui.inverted.green.button:active {
  box-shadow: none !important;
  color: #FFFFFF; }

.ui.inverted.green.buttons .button:hover, .ui.inverted.green.button:hover {
  background-color: #22be34; }

.ui.inverted.green.buttons .button:focus, .ui.inverted.green.button:focus {
  background-color: #19b82b; }

.ui.inverted.green.buttons .active.button, .ui.inverted.green.active.button {
  background-color: #1fc231; }

.ui.inverted.green.buttons .button:active, .ui.inverted.green.button:active {
  background-color: #25a233; }

.ui.inverted.green.basic.buttons .button,
.ui.inverted.green.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.green.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.green.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #22be34 inset !important;
  color: #2ECC40 !important; }

.ui.inverted.green.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #22be34 inset !important;
  color: #2ECC40 !important; }

.ui.inverted.green.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #22be34 inset !important;
  color: #2ECC40 !important; }

.ui.inverted.green.basic.buttons .button:focus, .ui.inverted.green.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #19b82b inset !important;
  color: #2ECC40 !important; }

.ui.inverted.green.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #1fc231 inset !important;
  color: #2ECC40 !important; }

.ui.inverted.green.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #1fc231 inset !important;
  color: #2ECC40 !important; }

.ui.inverted.green.basic.active.button {
  box-shadow: 0px 0px 0px 2px #1fc231 inset !important;
  color: #2ECC40 !important; }

.ui.inverted.green.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #25a233 inset !important;
  color: #2ECC40 !important; }

.ui.inverted.green.buttons .basic.button:active, .ui.inverted.green.basic.button:active {
  box-shadow: 0px 0px 0px 2px #25a233 inset !important;
  color: #2ECC40 !important; }

.ui.orange.buttons .button {
  background-color: #F2711C;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.orange.button {
  background-color: #F2711C;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.orange.buttons .button:hover, .ui.orange.button:hover {
  background-color: #f26202;
  color: #FFFFFF;
  text-shadow: none; }

.ui.orange.buttons .button:focus, .ui.orange.button:focus {
  background-color: #e55b00;
  color: #FFFFFF;
  text-shadow: none; }

.ui.orange.buttons .button:active, .ui.orange.button:active {
  background-color: #cf590c;
  color: #FFFFFF;
  text-shadow: none; }

.ui.orange.buttons .active.button {
  background-color: #f56100;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.orange.buttons .active.button:active {
    background-color: #f56100;
    color: #FFFFFF;
    text-shadow: none; }

.ui.orange.active.button,
.ui.orange.button .active.button:active {
  background-color: #f56100;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.orange.buttons .button, .ui.basic.orange.button {
  box-shadow: 0px 0px 0px 1px #F2711C inset !important;
  color: #F2711C !important; }

.ui.basic.orange.buttons .button:hover, .ui.basic.orange.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #f26202 inset !important;
  color: #f26202 !important; }

.ui.basic.orange.buttons .button:focus, .ui.basic.orange.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #e55b00 inset !important;
  color: #f26202 !important; }

.ui.basic.orange.buttons .active.button, .ui.basic.orange.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #f56100 inset !important;
  color: #cf590c !important; }

.ui.basic.orange.buttons .button:active, .ui.basic.orange.button:active {
  box-shadow: 0px 0px 0px 1px #cf590c inset !important;
  color: #cf590c !important; }

.ui.buttons:not(.vertical) > .basic.orange.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.orange.buttons .button, .ui.inverted.orange.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #FF851B inset !important;
  color: #FF851B; }

.ui.inverted.orange.buttons .button:hover, .ui.inverted.orange.button:hover,
.ui.inverted.orange.buttons .button:focus, .ui.inverted.orange.button:focus,
.ui.inverted.orange.buttons .button.active, .ui.inverted.orange.button.active,
.ui.inverted.orange.buttons .button:active, .ui.inverted.orange.button:active {
  box-shadow: none !important;
  color: #FFFFFF; }

.ui.inverted.orange.buttons .button:hover, .ui.inverted.orange.button:hover {
  background-color: #ff7701; }

.ui.inverted.orange.buttons .button:focus, .ui.inverted.orange.button:focus {
  background-color: #f17000; }

.ui.inverted.orange.buttons .active.button, .ui.inverted.orange.active.button {
  background-color: #ff7701; }

.ui.inverted.orange.buttons .button:active, .ui.inverted.orange.button:active {
  background-color: #e76b00; }

.ui.inverted.orange.basic.buttons .button,
.ui.inverted.orange.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.orange.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.orange.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #ff7701 inset !important;
  color: #FF851B !important; }

.ui.inverted.orange.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #ff7701 inset !important;
  color: #FF851B !important; }

.ui.inverted.orange.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #ff7701 inset !important;
  color: #FF851B !important; }

.ui.inverted.orange.basic.buttons .button:focus, .ui.inverted.orange.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #f17000 inset !important;
  color: #FF851B !important; }

.ui.inverted.orange.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #ff7701 inset !important;
  color: #FF851B !important; }

.ui.inverted.orange.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #ff7701 inset !important;
  color: #FF851B !important; }

.ui.inverted.orange.basic.active.button {
  box-shadow: 0px 0px 0px 2px #ff7701 inset !important;
  color: #FF851B !important; }

.ui.inverted.orange.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #e76b00 inset !important;
  color: #FF851B !important; }

.ui.inverted.orange.buttons .basic.button:active, .ui.inverted.orange.basic.button:active {
  box-shadow: 0px 0px 0px 2px #e76b00 inset !important;
  color: #FF851B !important; }

.ui.pink.buttons .button {
  background-color: #E03997;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.pink.button {
  background-color: #E03997;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.pink.buttons .button:hover, .ui.pink.button:hover {
  background-color: #e61a8d;
  color: #FFFFFF;
  text-shadow: none; }

.ui.pink.buttons .button:focus, .ui.pink.button:focus {
  background-color: #e10f85;
  color: #FFFFFF;
  text-shadow: none; }

.ui.pink.buttons .button:active, .ui.pink.button:active {
  background-color: #c71f7e;
  color: #FFFFFF;
  text-shadow: none; }

.ui.pink.buttons .active.button {
  background-color: #ea158d;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.pink.buttons .active.button:active {
    background-color: #ea158d;
    color: #FFFFFF;
    text-shadow: none; }

.ui.pink.active.button,
.ui.pink.button .active.button:active {
  background-color: #ea158d;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.pink.buttons .button, .ui.basic.pink.button {
  box-shadow: 0px 0px 0px 1px #E03997 inset !important;
  color: #E03997 !important; }

.ui.basic.pink.buttons .button:hover, .ui.basic.pink.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #e61a8d inset !important;
  color: #e61a8d !important; }

.ui.basic.pink.buttons .button:focus, .ui.basic.pink.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #e10f85 inset !important;
  color: #e61a8d !important; }

.ui.basic.pink.buttons .active.button, .ui.basic.pink.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #ea158d inset !important;
  color: #c71f7e !important; }

.ui.basic.pink.buttons .button:active, .ui.basic.pink.button:active {
  box-shadow: 0px 0px 0px 1px #c71f7e inset !important;
  color: #c71f7e !important; }

.ui.buttons:not(.vertical) > .basic.pink.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.pink.buttons .button, .ui.inverted.pink.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #FF8EDF inset !important;
  color: #FF8EDF; }

.ui.inverted.pink.buttons .button:hover, .ui.inverted.pink.button:hover,
.ui.inverted.pink.buttons .button:focus, .ui.inverted.pink.button:focus,
.ui.inverted.pink.buttons .button.active, .ui.inverted.pink.button.active,
.ui.inverted.pink.buttons .button:active, .ui.inverted.pink.button:active {
  box-shadow: none !important;
  color: #FFFFFF; }

.ui.inverted.pink.buttons .button:hover, .ui.inverted.pink.button:hover {
  background-color: #ff74d8; }

.ui.inverted.pink.buttons .button:focus, .ui.inverted.pink.button:focus {
  background-color: #ff65d3; }

.ui.inverted.pink.buttons .active.button, .ui.inverted.pink.active.button {
  background-color: #ff74d8; }

.ui.inverted.pink.buttons .button:active, .ui.inverted.pink.button:active {
  background-color: #ff5bd1; }

.ui.inverted.pink.basic.buttons .button,
.ui.inverted.pink.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.pink.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.pink.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #ff74d8 inset !important;
  color: #FF8EDF !important; }

.ui.inverted.pink.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #ff74d8 inset !important;
  color: #FF8EDF !important; }

.ui.inverted.pink.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #ff74d8 inset !important;
  color: #FF8EDF !important; }

.ui.inverted.pink.basic.buttons .button:focus, .ui.inverted.pink.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #ff65d3 inset !important;
  color: #FF8EDF !important; }

.ui.inverted.pink.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #ff74d8 inset !important;
  color: #FF8EDF !important; }

.ui.inverted.pink.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #ff74d8 inset !important;
  color: #FF8EDF !important; }

.ui.inverted.pink.basic.active.button {
  box-shadow: 0px 0px 0px 2px #ff74d8 inset !important;
  color: #FF8EDF !important; }

.ui.inverted.pink.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #ff5bd1 inset !important;
  color: #FF8EDF !important; }

.ui.inverted.pink.buttons .basic.button:active, .ui.inverted.pink.basic.button:active {
  box-shadow: 0px 0px 0px 2px #ff5bd1 inset !important;
  color: #FF8EDF !important; }

.ui.violet.buttons .button {
  background-color: #6435C9;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.violet.button {
  background-color: #6435C9;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.violet.buttons .button:hover, .ui.violet.button:hover {
  background-color: #5829bb;
  color: #FFFFFF;
  text-shadow: none; }

.ui.violet.buttons .button:focus, .ui.violet.button:focus {
  background-color: #4f20b5;
  color: #FFFFFF;
  text-shadow: none; }

.ui.violet.buttons .button:active, .ui.violet.button:active {
  background-color: #502aa1;
  color: #FFFFFF;
  text-shadow: none; }

.ui.violet.buttons .active.button {
  background-color: #5626bf;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.violet.buttons .active.button:active {
    background-color: #5626bf;
    color: #FFFFFF;
    text-shadow: none; }

.ui.violet.active.button,
.ui.violet.button .active.button:active {
  background-color: #5626bf;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.violet.buttons .button, .ui.basic.violet.button {
  box-shadow: 0px 0px 0px 1px #6435C9 inset !important;
  color: #6435C9 !important; }

.ui.basic.violet.buttons .button:hover, .ui.basic.violet.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #5829bb inset !important;
  color: #5829bb !important; }

.ui.basic.violet.buttons .button:focus, .ui.basic.violet.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #4f20b5 inset !important;
  color: #5829bb !important; }

.ui.basic.violet.buttons .active.button, .ui.basic.violet.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #5626bf inset !important;
  color: #502aa1 !important; }

.ui.basic.violet.buttons .button:active, .ui.basic.violet.button:active {
  box-shadow: 0px 0px 0px 1px #502aa1 inset !important;
  color: #502aa1 !important; }

.ui.buttons:not(.vertical) > .basic.violet.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.violet.buttons .button, .ui.inverted.violet.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #A291FB inset !important;
  color: #A291FB; }

.ui.inverted.violet.buttons .button:hover, .ui.inverted.violet.button:hover,
.ui.inverted.violet.buttons .button:focus, .ui.inverted.violet.button:focus,
.ui.inverted.violet.buttons .button.active, .ui.inverted.violet.button.active,
.ui.inverted.violet.buttons .button:active, .ui.inverted.violet.button:active {
  box-shadow: none !important;
  color: #FFFFFF; }

.ui.inverted.violet.buttons .button:hover, .ui.inverted.violet.button:hover {
  background-color: #8a73ff; }

.ui.inverted.violet.buttons .button:focus, .ui.inverted.violet.button:focus {
  background-color: #7d64ff; }

.ui.inverted.violet.buttons .active.button, .ui.inverted.violet.active.button {
  background-color: #8a73ff; }

.ui.inverted.violet.buttons .button:active, .ui.inverted.violet.button:active {
  background-color: #7860f9; }

.ui.inverted.violet.basic.buttons .button,
.ui.inverted.violet.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.violet.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.violet.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #8a73ff inset !important;
  color: #A291FB !important; }

.ui.inverted.violet.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #8a73ff inset !important;
  color: #A291FB !important; }

.ui.inverted.violet.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #8a73ff inset !important;
  color: #A291FB !important; }

.ui.inverted.violet.basic.buttons .button:focus, .ui.inverted.violet.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #7d64ff inset !important;
  color: #A291FB !important; }

.ui.inverted.violet.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #8a73ff inset !important;
  color: #A291FB !important; }

.ui.inverted.violet.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #8a73ff inset !important;
  color: #A291FB !important; }

.ui.inverted.violet.basic.active.button {
  box-shadow: 0px 0px 0px 2px #8a73ff inset !important;
  color: #A291FB !important; }

.ui.inverted.violet.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #7860f9 inset !important;
  color: #A291FB !important; }

.ui.inverted.violet.buttons .basic.button:active, .ui.inverted.violet.basic.button:active {
  box-shadow: 0px 0px 0px 2px #7860f9 inset !important;
  color: #A291FB !important; }

.ui.purple.buttons .button {
  background-color: #A333C8;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.purple.button {
  background-color: #A333C8;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.purple.buttons .button:hover, .ui.purple.button:hover {
  background-color: #9627ba;
  color: #FFFFFF;
  text-shadow: none; }

.ui.purple.buttons .button:focus, .ui.purple.button:focus {
  background-color: #8f1eb4;
  color: #FFFFFF;
  text-shadow: none; }

.ui.purple.buttons .button:active, .ui.purple.button:active {
  background-color: #82299f;
  color: #FFFFFF;
  text-shadow: none; }

.ui.purple.buttons .active.button {
  background-color: #9724be;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.purple.buttons .active.button:active {
    background-color: #9724be;
    color: #FFFFFF;
    text-shadow: none; }

.ui.purple.active.button,
.ui.purple.button .active.button:active {
  background-color: #9724be;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.purple.buttons .button, .ui.basic.purple.button {
  box-shadow: 0px 0px 0px 1px #A333C8 inset !important;
  color: #A333C8 !important; }

.ui.basic.purple.buttons .button:hover, .ui.basic.purple.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #9627ba inset !important;
  color: #9627ba !important; }

.ui.basic.purple.buttons .button:focus, .ui.basic.purple.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #8f1eb4 inset !important;
  color: #9627ba !important; }

.ui.basic.purple.buttons .active.button, .ui.basic.purple.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #9724be inset !important;
  color: #82299f !important; }

.ui.basic.purple.buttons .button:active, .ui.basic.purple.button:active {
  box-shadow: 0px 0px 0px 1px #82299f inset !important;
  color: #82299f !important; }

.ui.buttons:not(.vertical) > .basic.purple.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.purple.buttons .button, .ui.inverted.purple.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #DC73FF inset !important;
  color: #DC73FF; }

.ui.inverted.purple.buttons .button:hover, .ui.inverted.purple.button:hover,
.ui.inverted.purple.buttons .button:focus, .ui.inverted.purple.button:focus,
.ui.inverted.purple.buttons .button.active, .ui.inverted.purple.button.active,
.ui.inverted.purple.buttons .button:active, .ui.inverted.purple.button:active {
  box-shadow: none !important;
  color: #FFFFFF; }

.ui.inverted.purple.buttons .button:hover, .ui.inverted.purple.button:hover {
  background-color: #d65aff; }

.ui.inverted.purple.buttons .button:focus, .ui.inverted.purple.button:focus {
  background-color: #d24aff; }

.ui.inverted.purple.buttons .active.button, .ui.inverted.purple.active.button {
  background-color: #d65aff; }

.ui.inverted.purple.buttons .button:active, .ui.inverted.purple.button:active {
  background-color: #cf40ff; }

.ui.inverted.purple.basic.buttons .button,
.ui.inverted.purple.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.purple.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.purple.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #d65aff inset !important;
  color: #DC73FF !important; }

.ui.inverted.purple.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #d65aff inset !important;
  color: #DC73FF !important; }

.ui.inverted.purple.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #d65aff inset !important;
  color: #DC73FF !important; }

.ui.inverted.purple.basic.buttons .button:focus, .ui.inverted.purple.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #d24aff inset !important;
  color: #DC73FF !important; }

.ui.inverted.purple.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #d65aff inset !important;
  color: #DC73FF !important; }

.ui.inverted.purple.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #d65aff inset !important;
  color: #DC73FF !important; }

.ui.inverted.purple.basic.active.button {
  box-shadow: 0px 0px 0px 2px #d65aff inset !important;
  color: #DC73FF !important; }

.ui.inverted.purple.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #cf40ff inset !important;
  color: #DC73FF !important; }

.ui.inverted.purple.buttons .basic.button:active, .ui.inverted.purple.basic.button:active {
  box-shadow: 0px 0px 0px 2px #cf40ff inset !important;
  color: #DC73FF !important; }

.ui.red.buttons .button {
  background-color: #DB2828;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.red.button {
  background-color: #DB2828;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.red.buttons .button:hover, .ui.red.button:hover {
  background-color: #d01919;
  color: #FFFFFF;
  text-shadow: none; }

.ui.red.buttons .button:focus, .ui.red.button:focus {
  background-color: #ca1010;
  color: #FFFFFF;
  text-shadow: none; }

.ui.red.buttons .button:active, .ui.red.button:active {
  background-color: #b21e1e;
  color: #FFFFFF;
  text-shadow: none; }

.ui.red.buttons .active.button {
  background-color: #d41515;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.red.buttons .active.button:active {
    background-color: #d41515;
    color: #FFFFFF;
    text-shadow: none; }

.ui.red.active.button,
.ui.red.button .active.button:active {
  background-color: #d41515;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.red.buttons .button, .ui.basic.red.button {
  box-shadow: 0px 0px 0px 1px #DB2828 inset !important;
  color: #DB2828 !important; }

.ui.basic.red.buttons .button:hover, .ui.basic.red.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #d01919 inset !important;
  color: #d01919 !important; }

.ui.basic.red.buttons .button:focus, .ui.basic.red.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #ca1010 inset !important;
  color: #d01919 !important; }

.ui.basic.red.buttons .active.button, .ui.basic.red.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #d41515 inset !important;
  color: #b21e1e !important; }

.ui.basic.red.buttons .button:active, .ui.basic.red.button:active {
  box-shadow: 0px 0px 0px 1px #b21e1e inset !important;
  color: #b21e1e !important; }

.ui.buttons:not(.vertical) > .basic.red.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.red.buttons .button, .ui.inverted.red.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #FF695E inset !important;
  color: #FF695E; }

.ui.inverted.red.buttons .button:hover, .ui.inverted.red.button:hover,
.ui.inverted.red.buttons .button:focus, .ui.inverted.red.button:focus,
.ui.inverted.red.buttons .button.active, .ui.inverted.red.button.active,
.ui.inverted.red.buttons .button:active, .ui.inverted.red.button:active {
  box-shadow: none !important;
  color: #FFFFFF; }

.ui.inverted.red.buttons .button:hover, .ui.inverted.red.button:hover {
  background-color: #ff5144; }

.ui.inverted.red.buttons .button:focus, .ui.inverted.red.button:focus {
  background-color: #ff4335; }

.ui.inverted.red.buttons .active.button, .ui.inverted.red.active.button {
  background-color: #ff5144; }

.ui.inverted.red.buttons .button:active, .ui.inverted.red.button:active {
  background-color: #ff392b; }

.ui.inverted.red.basic.buttons .button,
.ui.inverted.red.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.red.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.red.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #ff5144 inset !important;
  color: #FF695E !important; }

.ui.inverted.red.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #ff5144 inset !important;
  color: #FF695E !important; }

.ui.inverted.red.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #ff5144 inset !important;
  color: #FF695E !important; }

.ui.inverted.red.basic.buttons .button:focus, .ui.inverted.red.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #ff4335 inset !important;
  color: #FF695E !important; }

.ui.inverted.red.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #ff5144 inset !important;
  color: #FF695E !important; }

.ui.inverted.red.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #ff5144 inset !important;
  color: #FF695E !important; }

.ui.inverted.red.basic.active.button {
  box-shadow: 0px 0px 0px 2px #ff5144 inset !important;
  color: #FF695E !important; }

.ui.inverted.red.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #ff392b inset !important;
  color: #FF695E !important; }

.ui.inverted.red.buttons .basic.button:active, .ui.inverted.red.basic.button:active {
  box-shadow: 0px 0px 0px 2px #ff392b inset !important;
  color: #FF695E !important; }

.ui.teal.buttons .button {
  background-color: #00B5AD;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.teal.button {
  background-color: #00B5AD;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.teal.buttons .button:hover, .ui.teal.button:hover {
  background-color: #009c95;
  color: #FFFFFF;
  text-shadow: none; }

.ui.teal.buttons .button:focus, .ui.teal.button:focus {
  background-color: #008c86;
  color: #FFFFFF;
  text-shadow: none; }

.ui.teal.buttons .button:active, .ui.teal.button:active {
  background-color: #00827c;
  color: #FFFFFF;
  text-shadow: none; }

.ui.teal.buttons .active.button {
  background-color: #009c95;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.teal.buttons .active.button:active {
    background-color: #009c95;
    color: #FFFFFF;
    text-shadow: none; }

.ui.teal.active.button,
.ui.teal.button .active.button:active {
  background-color: #009c95;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.teal.buttons .button, .ui.basic.teal.button {
  box-shadow: 0px 0px 0px 1px #00B5AD inset !important;
  color: #00B5AD !important; }

.ui.basic.teal.buttons .button:hover, .ui.basic.teal.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #009c95 inset !important;
  color: #009c95 !important; }

.ui.basic.teal.buttons .button:focus, .ui.basic.teal.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #008c86 inset !important;
  color: #009c95 !important; }

.ui.basic.teal.buttons .active.button, .ui.basic.teal.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #009c95 inset !important;
  color: #00827c !important; }

.ui.basic.teal.buttons .button:active, .ui.basic.teal.button:active {
  box-shadow: 0px 0px 0px 1px #00827c inset !important;
  color: #00827c !important; }

.ui.buttons:not(.vertical) > .basic.teal.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.teal.buttons .button, .ui.inverted.teal.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #6DFFFF inset !important;
  color: #6DFFFF; }

.ui.inverted.teal.buttons .button:hover, .ui.inverted.teal.button:hover,
.ui.inverted.teal.buttons .button:focus, .ui.inverted.teal.button:focus,
.ui.inverted.teal.buttons .button.active, .ui.inverted.teal.button.active,
.ui.inverted.teal.buttons .button:active, .ui.inverted.teal.button:active {
  box-shadow: none !important;
  color: rgba(0, 0, 0, 0.6); }

.ui.inverted.teal.buttons .button:hover, .ui.inverted.teal.button:hover {
  background-color: #54ffff; }

.ui.inverted.teal.buttons .button:focus, .ui.inverted.teal.button:focus {
  background-color: #44ffff; }

.ui.inverted.teal.buttons .active.button, .ui.inverted.teal.active.button {
  background-color: #54ffff; }

.ui.inverted.teal.buttons .button:active, .ui.inverted.teal.button:active {
  background-color: #3affff; }

.ui.inverted.teal.basic.buttons .button,
.ui.inverted.teal.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.teal.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.teal.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #54ffff inset !important;
  color: #6DFFFF !important; }

.ui.inverted.teal.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #54ffff inset !important;
  color: #6DFFFF !important; }

.ui.inverted.teal.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #54ffff inset !important;
  color: #6DFFFF !important; }

.ui.inverted.teal.basic.buttons .button:focus, .ui.inverted.teal.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #44ffff inset !important;
  color: #6DFFFF !important; }

.ui.inverted.teal.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #54ffff inset !important;
  color: #6DFFFF !important; }

.ui.inverted.teal.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #54ffff inset !important;
  color: #6DFFFF !important; }

.ui.inverted.teal.basic.active.button {
  box-shadow: 0px 0px 0px 2px #54ffff inset !important;
  color: #6DFFFF !important; }

.ui.inverted.teal.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #3affff inset !important;
  color: #6DFFFF !important; }

.ui.inverted.teal.buttons .basic.button:active, .ui.inverted.teal.basic.button:active {
  box-shadow: 0px 0px 0px 2px #3affff inset !important;
  color: #6DFFFF !important; }

.ui.olive.buttons .button {
  background-color: #B5CC18;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.olive.button {
  background-color: #B5CC18;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.olive.buttons .button:hover, .ui.olive.button:hover {
  background-color: #a7bd0d;
  color: #FFFFFF;
  text-shadow: none; }

.ui.olive.buttons .button:focus, .ui.olive.button:focus {
  background-color: #a0b605;
  color: #FFFFFF;
  text-shadow: none; }

.ui.olive.buttons .button:active, .ui.olive.button:active {
  background-color: #8d9e13;
  color: #FFFFFF;
  text-shadow: none; }

.ui.olive.buttons .active.button {
  background-color: #aac109;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.olive.buttons .active.button:active {
    background-color: #aac109;
    color: #FFFFFF;
    text-shadow: none; }

.ui.olive.active.button,
.ui.olive.button .active.button:active {
  background-color: #aac109;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.olive.buttons .button, .ui.basic.olive.button {
  box-shadow: 0px 0px 0px 1px #B5CC18 inset !important;
  color: #B5CC18 !important; }

.ui.basic.olive.buttons .button:hover, .ui.basic.olive.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #a7bd0d inset !important;
  color: #a7bd0d !important; }

.ui.basic.olive.buttons .button:focus, .ui.basic.olive.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #a0b605 inset !important;
  color: #a7bd0d !important; }

.ui.basic.olive.buttons .active.button, .ui.basic.olive.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #aac109 inset !important;
  color: #8d9e13 !important; }

.ui.basic.olive.buttons .button:active, .ui.basic.olive.button:active {
  box-shadow: 0px 0px 0px 1px #8d9e13 inset !important;
  color: #8d9e13 !important; }

.ui.buttons:not(.vertical) > .basic.olive.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.olive.buttons .button, .ui.inverted.olive.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #D9E778 inset !important;
  color: #D9E778; }

.ui.inverted.olive.buttons .button:hover, .ui.inverted.olive.button:hover,
.ui.inverted.olive.buttons .button:focus, .ui.inverted.olive.button:focus,
.ui.inverted.olive.buttons .button.active, .ui.inverted.olive.button.active,
.ui.inverted.olive.buttons .button:active, .ui.inverted.olive.button:active {
  box-shadow: none !important;
  color: rgba(0, 0, 0, 0.6); }

.ui.inverted.olive.buttons .button:hover, .ui.inverted.olive.button:hover {
  background-color: #d8ea5c; }

.ui.inverted.olive.buttons .button:focus, .ui.inverted.olive.button:focus {
  background-color: #daef47; }

.ui.inverted.olive.buttons .active.button, .ui.inverted.olive.active.button {
  background-color: #daed59; }

.ui.inverted.olive.buttons .button:active, .ui.inverted.olive.button:active {
  background-color: #cddf4d; }

.ui.inverted.olive.basic.buttons .button,
.ui.inverted.olive.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.olive.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.olive.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #d8ea5c inset !important;
  color: #D9E778 !important; }

.ui.inverted.olive.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #d8ea5c inset !important;
  color: #D9E778 !important; }

.ui.inverted.olive.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #d8ea5c inset !important;
  color: #D9E778 !important; }

.ui.inverted.olive.basic.buttons .button:focus, .ui.inverted.olive.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #daef47 inset !important;
  color: #D9E778 !important; }

.ui.inverted.olive.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #daed59 inset !important;
  color: #D9E778 !important; }

.ui.inverted.olive.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #daed59 inset !important;
  color: #D9E778 !important; }

.ui.inverted.olive.basic.active.button {
  box-shadow: 0px 0px 0px 2px #daed59 inset !important;
  color: #D9E778 !important; }

.ui.inverted.olive.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #cddf4d inset !important;
  color: #D9E778 !important; }

.ui.inverted.olive.buttons .basic.button:active, .ui.inverted.olive.basic.button:active {
  box-shadow: 0px 0px 0px 2px #cddf4d inset !important;
  color: #D9E778 !important; }

.ui.yellow.buttons .button {
  background-color: #FBBD08;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.yellow.button {
  background-color: #FBBD08;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.yellow.buttons .button:hover, .ui.yellow.button:hover {
  background-color: #eaae00;
  color: #FFFFFF;
  text-shadow: none; }

.ui.yellow.buttons .button:focus, .ui.yellow.button:focus {
  background-color: #daa300;
  color: #FFFFFF;
  text-shadow: none; }

.ui.yellow.buttons .button:active, .ui.yellow.button:active {
  background-color: #cd9903;
  color: #FFFFFF;
  text-shadow: none; }

.ui.yellow.buttons .active.button {
  background-color: #eaae00;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.yellow.buttons .active.button:active {
    background-color: #eaae00;
    color: #FFFFFF;
    text-shadow: none; }

.ui.yellow.active.button,
.ui.yellow.button .active.button:active {
  background-color: #eaae00;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.yellow.buttons .button, .ui.basic.yellow.button {
  box-shadow: 0px 0px 0px 1px #FBBD08 inset !important;
  color: #FBBD08 !important; }

.ui.basic.yellow.buttons .button:hover, .ui.basic.yellow.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #eaae00 inset !important;
  color: #eaae00 !important; }

.ui.basic.yellow.buttons .button:focus, .ui.basic.yellow.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #daa300 inset !important;
  color: #eaae00 !important; }

.ui.basic.yellow.buttons .active.button, .ui.basic.yellow.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #eaae00 inset !important;
  color: #cd9903 !important; }

.ui.basic.yellow.buttons .button:active, .ui.basic.yellow.button:active {
  box-shadow: 0px 0px 0px 1px #cd9903 inset !important;
  color: #cd9903 !important; }

.ui.buttons:not(.vertical) > .basic.yellow.button:not(:first-child) {
  margin-left: -1px; }

.ui.inverted.yellow.buttons .button, .ui.inverted.yellow.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px #FFE21F inset !important;
  color: #FFE21F; }

.ui.inverted.yellow.buttons .button:hover, .ui.inverted.yellow.button:hover,
.ui.inverted.yellow.buttons .button:focus, .ui.inverted.yellow.button:focus,
.ui.inverted.yellow.buttons .button.active, .ui.inverted.yellow.button.active,
.ui.inverted.yellow.buttons .button:active, .ui.inverted.yellow.button:active {
  box-shadow: none !important;
  color: rgba(0, 0, 0, 0.6); }

.ui.inverted.yellow.buttons .button:hover, .ui.inverted.yellow.button:hover {
  background-color: #ffdf05; }

.ui.inverted.yellow.buttons .button:focus, .ui.inverted.yellow.button:focus {
  background-color: #f5d500; }

.ui.inverted.yellow.buttons .active.button, .ui.inverted.yellow.active.button {
  background-color: #ffdf05; }

.ui.inverted.yellow.buttons .button:active, .ui.inverted.yellow.button:active {
  background-color: #ebcd00; }

.ui.inverted.yellow.basic.buttons .button,
.ui.inverted.yellow.buttons .basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.yellow.basic.button {
  background-color: transparent;
  box-shadow: 0px 0px 0px 2px rgba(255, 255, 255, 0.5) inset !important;
  color: #FFFFFF !important; }

.ui.inverted.yellow.basic.buttons .button:hover {
  box-shadow: 0px 0px 0px 2px #ffdf05 inset !important;
  color: #FFE21F !important; }

.ui.inverted.yellow.buttons .basic.button:hover {
  box-shadow: 0px 0px 0px 2px #ffdf05 inset !important;
  color: #FFE21F !important; }

.ui.inverted.yellow.basic.button:hover {
  box-shadow: 0px 0px 0px 2px #ffdf05 inset !important;
  color: #FFE21F !important; }

.ui.inverted.yellow.basic.buttons .button:focus, .ui.inverted.yellow.basic.button:focus {
  box-shadow: 0px 0px 0px 2px #f5d500 inset !important;
  color: #FFE21F !important; }

.ui.inverted.yellow.basic.buttons .active.button {
  box-shadow: 0px 0px 0px 2px #ffdf05 inset !important;
  color: #FFE21F !important; }

.ui.inverted.yellow.buttons .basic.active.button {
  box-shadow: 0px 0px 0px 2px #ffdf05 inset !important;
  color: #FFE21F !important; }

.ui.inverted.yellow.basic.active.button {
  box-shadow: 0px 0px 0px 2px #ffdf05 inset !important;
  color: #FFE21F !important; }

.ui.inverted.yellow.basic.buttons .button:active {
  box-shadow: 0px 0px 0px 2px #ebcd00 inset !important;
  color: #FFE21F !important; }

.ui.inverted.yellow.buttons .basic.button:active, .ui.inverted.yellow.basic.button:active {
  box-shadow: 0px 0px 0px 2px #ebcd00 inset !important;
  color: #FFE21F !important; }

.ui.primary.buttons .button {
  background-color: #4c8bd6;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.primary.button {
  background-color: #4c8bd6;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px #rgba 34, 36, 38, 0.15 inset; }

.ui.primary.buttons .button:hover, .ui.primary.button:hover {
  background-color: #1678c2;
  color: #FFFFFF;
  text-shadow: none; }

.ui.primary.buttons .button:focus, .ui.primary.button:focus {
  background-color: #0d71bb;
  color: #FFFFFF;
  text-shadow: none; }

.ui.primary.buttons .button:active, .ui.primary.button:active {
  background-color: #1a69a4;
  color: #FFFFFF;
  text-shadow: none; }

.ui.primary.buttons .active.button {
  background-color: #1279c6;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.primary.buttons .active.button:active {
    background-color: #1279c6;
    color: #FFFFFF;
    text-shadow: none; }

.ui.primary.active.button,
.ui.primary.button .active.button:active {
  background-color: #1279c6;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.primary.buttons .button, .ui.basic.primary.button {
  box-shadow: 0px 0px 0px 1px #2185D0 inset !important;
  color: #2185D0 !important; }

.ui.basic.primary.buttons .button:hover, .ui.basic.primary.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #1279c6 inset !important;
  color: #1a69a4 !important; }

.ui.basic.primary.buttons .button:focus, .ui.basic.primary.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #1678c2 inset !important;
  color: #1678c2 !important; }

.ui.basic.primary.buttons .active.button, .ui.basic.primary.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #0d71bb inset !important;
  color: #1678c2 !important; }

.ui.basic.primary.buttons .button:active, .ui.basic.primary.button:active {
  box-shadow: 0px 0px 0px 1px #1a69a4 inset !important;
  color: #1a69a4 !important; }

.ui.buttons:not(.vertical) > .basic.primary.button:not(:first-child) {
  margin-left: -1px; }

.ui.secondary.buttons .button {
  background-color: #1B1C1D;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.secondary.button {
  background-color: #1B1C1D;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px #rgba 34, 36, 38, 0.15 inset; }

.ui.secondary.buttons .button:hover, .ui.secondary.button:hover {
  background-color: #27292a;
  color: #FFFFFF;
  text-shadow: none; }

.ui.secondary.buttons .button:focus, .ui.secondary.button:focus {
  background-color: #343637;
  color: #FFFFFF;
  text-shadow: none; }

.ui.secondary.buttons .button:active, .ui.secondary.button:active {
  background-color: #27292a;
  color: #FFFFFF;
  text-shadow: none; }

.ui.secondary.buttons .active.button {
  background-color: #2e3032;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.secondary.buttons .active.button:active {
    background-color: #27292a;
    color: #FFFFFF;
    text-shadow: none; }

.ui.secondary.active.button,
.ui.secondary.button .active.button:active {
  background-color: #27292a;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.secondary.buttons .button, .ui.basic.secondary.button {
  box-shadow: 0px 0px 0px 1px #1B1C1D inset !important;
  color: #1B1C1D !important; }

.ui.basic.secondary.buttons .button:hover, .ui.basic.secondary.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #27292a inset !important;
  color: #343637 !important; }

.ui.basic.secondary.buttons .button:focus, .ui.basic.secondary.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #27292a inset !important;
  color: #27292a !important; }

.ui.basic.secondary.buttons .active.button, .ui.basic.secondary.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #2e3032 inset !important;
  color: #27292a !important; }

.ui.basic.secondary.buttons .button:active, .ui.basic.secondary.button:active {
  box-shadow: 0px 0px 0px 1px #343637 inset !important;
  color: #343637 !important; }

.ui.buttons:not(.vertical) > .basic.primary.button:not(:first-child) {
  margin-left: -1px; }

.ui.positive.buttons .button {
  background-color: #21BA45;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.positive.button {
  background-color: #21BA45;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.positive.buttons .button:hover, .ui.positive.button:hover {
  background-color: #16ab39;
  color: #FFFFFF;
  text-shadow: none; }

.ui.positive.buttons .button:focus, .ui.positive.button:focus {
  background-color: #0ea432;
  color: #FFFFFF;
  text-shadow: none; }

.ui.positive.buttons .button:active, .ui.positive.button:active {
  background-color: #198f35;
  color: #FFFFFF;
  text-shadow: none; }

.ui.positive.buttons .active.button {
  background-color: #13ae38;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.positive.buttons .active.button:active {
    background-color: #13ae38;
    color: #FFFFFF;
    text-shadow: none; }

.ui.positive.active.button,
.ui.positive.button .active.button:active {
  background-color: #13ae38;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.positive.buttons .button, .ui.basic.positive.button {
  box-shadow: 0px 0px 0px 1px #21BA45 inset !important;
  color: #21BA45 !important; }

.ui.basic.positive.buttons .button:hover, .ui.basic.positive.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #16ab39 inset !important;
  color: #16ab39 !important; }

.ui.basic.positive.buttons .button:focus, .ui.basic.positive.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #0ea432 inset !important;
  color: #16ab39 !important; }

.ui.basic.positive.buttons .active.button, .ui.basic.positive.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #13ae38 inset !important;
  color: #198f35 !important; }

.ui.basic.positive.buttons .button:active, .ui.basic.positive.button:active {
  box-shadow: 0px 0px 0px 1px #198f35 inset !important;
  color: #198f35 !important; }

.ui.buttons:not(.vertical) > .basic.primary.button:not(:first-child) {
  margin-left: -1px; }

.ui.negative.buttons .button {
  background-color: #DB2828;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none; }

.ui.negative.button {
  background-color: #DB2828;
  color: #FFFFFF;
  text-shadow: none;
  background-image: none;
  box-shadow: 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }

.ui.negative.buttons .button:hover, .ui.negative.button:hover {
  background-color: #d01919;
  color: #FFFFFF;
  text-shadow: none; }

.ui.negative.buttons .button:focus, .ui.negative.button:focus {
  background-color: #ca1010;
  color: #FFFFFF;
  text-shadow: none; }

.ui.negative.buttons .button:active, .ui.negative.button:active {
  background-color: #b21e1e;
  color: #FFFFFF;
  text-shadow: none; }

.ui.negative.buttons .active.button {
  background-color: #d41515;
  color: #FFFFFF;
  text-shadow: none; }
  .ui.negative.buttons .active.button:active {
    background-color: #d41515;
    color: #FFFFFF;
    text-shadow: none; }

.ui.negative.active.button,
.ui.negative.button .active.button:active {
  background-color: #d41515;
  color: #FFFFFF;
  text-shadow: none; }

.ui.basic.negative.buttons .button, .ui.basic.negative.button {
  box-shadow: 0px 0px 0px 1px #DB2828 inset !important;
  color: #DB2828 !important; }

.ui.basic.negative.buttons .button:hover, .ui.basic.negative.button:hover {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #d01919 inset !important;
  color: #d01919 !important; }

.ui.basic.negative.buttons .button:focus, .ui.basic.negative.button:focus {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #ca1010 inset !important;
  color: #d01919 !important; }

.ui.basic.negative.buttons .active.button, .ui.basic.negative.active.button {
  background: transparent !important;
  box-shadow: 0px 0px 0px 1px #d41515 inset !important;
  color: #b21e1e !important; }

.ui.basic.negative.buttons .button:active, .ui.basic.negative.button:active {
  box-shadow: 0px 0px 0px 1px #b21e1e inset !important;
  color: #b21e1e !important; }

.ui.buttons {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -ms-flex-direction: row;
  flex-direction: row;
  font-size: 0em;
  vertical-align: baseline;
  margin: 0em 0.25em 0em 0em; }
  .ui.buttons:not(.vertical) > .basic.primary.button:not(:first-child) {
    margin-left: -1px; }
  .ui.buttons:not(.basic):not(.inverted) {
    box-shadow: none; }
  .ui.buttons:after {
    content: ".";
    display: block;
    height: 0;
    clear: both;
    visibility: hidden; }
  .ui.buttons .button {
    -webkit-box-flex: 1;
    -ms-flex: 1 0 auto;
    flex: 1 0 auto;
    margin: 0em;
    border-radius: 0em;
    margin: 0px 0px 0px 0px; }
  .ui.buttons > .ui.button:not(.basic):not(.inverted),
  .ui.buttons:not(.basic):not(.inverted) > .button {
    box-shadow: 0px 0px 0px 1px transparent inset, 0px 0em 0px 0px rgba(34, 36, 38, 0.15) inset; }
  .ui.buttons .button:first-child {
    border-left: none;
    margin-left: 0em;
    border-top-left-radius: 0.28571429rem;
    border-bottom-left-radius: 0.28571429rem; }
  .ui.buttons .button:last-child {
    border-top-right-radius: 0.28571429rem;
    border-bottom-right-radius: 0.28571429rem; }

.ui.vertical.buttons {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column; }
  .ui.vertical.buttons .button {
    display: block;
    float: none;
    width: 100%;
    margin: 0px 0px 0px 0px;
    box-shadow: none;
    border-radius: 0em; }
    .ui.vertical.buttons .button:first-child {
      border-top-left-radius: 0.28571429rem;
      border-top-right-radius: 0.28571429rem; }
    .ui.vertical.buttons .button:last-child {
      margin-bottom: 0px;
      border-bottom-left-radius: 0.28571429rem;
      border-bottom-right-radius: 0.28571429rem; }
    .ui.vertical.buttons .button:only-child {
      border-radius: 0.28571429rem; }

/*******************************
            States
*******************************/
/*--------------
      Hover
---------------*/
/*--------------
      Focus
---------------*/
/*--------------
      Down
---------------*/
/*--------------
     Active
---------------*/
/*--------------
    Loading
---------------*/
/* Specificity hack */
@-webkit-keyframes button-spin {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

@keyframes button-spin {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

/*!
 * # Semantic UI 2.2.12 - Container
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Container
*******************************/
/* All Sizes */
.ui.container {
  display: block;
  max-width: 100% !important; }

.ui.text.container {
  font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
  max-width: 700px !important;
  line-height: 1.5;
  font-size: 1.14285714rem; }

.ui.fluid.container {
  width: 100%; }

.ui[class*="left aligned"].container {
  text-align: left; }

.ui[class*="center aligned"].container {
  text-align: center; }

.ui[class*="right aligned"].container {
  text-align: right; }

.ui.justified.container {
  text-align: justify;
  -webkit-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto; }

/* Mobile */
@media only screen and (max-width: 767px) {
  .ui.container {
    width: auto !important;
    margin-left: 1em !important;
    margin-right: 1em !important; }
  .ui.grid.container, .ui.relaxed.grid.container, .ui.very.relaxed.grid.container {
    width: auto !important; } }

/* Tablet */
@media only screen and (min-width: 768px) and (max-width: 991px) {
  .ui.container {
    width: 723px;
    margin-left: auto !important;
    margin-right: auto !important; }
  .ui.grid.container {
    width: calc( 723px  +  2rem) !important; }
  .ui.relaxed.grid.container {
    width: calc( 723px  +  3rem) !important; }
  .ui.very.relaxed.grid.container {
    width: calc( 723px  +  5rem) !important; } }

/* Small Monitor */
@media only screen and (min-width: 992px) and (max-width: 1199px) {
  .ui.container {
    width: 933px;
    margin-left: auto !important;
    margin-right: auto !important; }
  .ui.grid.container {
    width: calc( 933px  +  2rem) !important; }
  .ui.relaxed.grid.container {
    width: calc( 933px  +  3rem) !important; }
  .ui.very.relaxed.grid.container {
    width: calc( 933px  +  5rem) !important; } }

/* Large Monitor */
@media only screen and (min-width: 1200px) {
  .ui.container {
    width: 1127px;
    margin-left: auto !important;
    margin-right: auto !important; }
  .ui.grid.container {
    width: calc( 1127px  +  2rem) !important; }
  .ui.relaxed.grid.container {
    width: calc( 1127px  +  3rem) !important; }
  .ui.very.relaxed.grid.container {
    width: calc( 1127px  +  5rem) !important; } }

/*!
 * # Semantic UI 2.2.12 - Divider
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Divider
*******************************/
.ui.divider {
  margin: 1rem 0rem;
  line-height: 1;
  height: 0em;
  font-weight: bold;
  text-transform: uppercase;
  letter-spacing: 0.05em;
  color: rgba(0, 0, 0, 0.85);
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-tap-highlight-color: transparent; }
  .ui.divider:not(.vertical):not(.horizontal) {
    border-top: 1px solid rgba(34, 36, 38, 0.15);
    border-bottom: 1px solid rgba(255, 255, 255, 0.1); }

.ui.grid > .column + .divider, .ui.grid > .row > .column + .divider {
  left: auto; }

.ui.horizontal.divider {
  display: table;
  white-space: nowrap;
  height: auto;
  margin: '';
  line-height: 1;
  text-align: center; }
  .ui.horizontal.divider:before, .ui.horizontal.divider:after {
    content: '';
    display: table-cell;
    position: relative;
    top: 50%;
    width: 50%;
    background-repeat: no-repeat; }
  .ui.horizontal.divider:before {
    background-position: right 1em top 50%; }
  .ui.horizontal.divider:after {
    background-position: left 1em top 50%; }

.ui.vertical.divider {
  position: absolute;
  z-index: 2;
  top: 50%;
  left: 50%;
  margin: 0rem;
  padding: 0em;
  width: auto;
  height: 50%;
  line-height: 0em;
  text-align: center;
  -webkit-transform: translateX(-50%);
  transform: translateX(-50%); }
  .ui.vertical.divider:before, .ui.vertical.divider:after {
    position: absolute;
    left: 50%;
    content: '';
    z-index: 3;
    border-left: 1px solid rgba(34, 36, 38, 0.15);
    border-right: 1px solid rgba(255, 255, 255, 0.1);
    width: 0%;
    height: calc(100% -  1rem); }
  .ui.vertical.divider:before {
    top: -100%; }
  .ui.vertical.divider:after {
    top: auto;
    bottom: 0px; }

.ui.divider > .icon {
  margin: 0rem;
  font-size: 1rem;
  height: 1em;
  vertical-align: middle; }

.ui.hidden.divider {
  border-color: transparent !important; }
  .ui.hidden.divider:before, .ui.hidden.divider:after {
    display: none; }

.ui.divider.inverted, .ui.vertical.inverted.divider, .ui.horizontal.inverted.divider {
  color: #FFFFFF; }

.ui.divider.inverted {
  border-top-color: rgba(34, 36, 38, 0.15) !important;
  border-left-color: rgba(34, 36, 38, 0.15) !important;
  border-bottom-color: rgba(255, 255, 255, 0.15) !important;
  border-right-color: rgba(255, 255, 255, 0.15) !important; }
  .ui.divider.inverted:after, .ui.divider.inverted:before {
    border-top-color: rgba(34, 36, 38, 0.15) !important;
    border-left-color: rgba(34, 36, 38, 0.15) !important;
    border-bottom-color: rgba(255, 255, 255, 0.15) !important;
    border-right-color: rgba(255, 255, 255, 0.15) !important; }

.ui.fitted.divider {
  margin: 0em; }

.ui.clearing.divider {
  clear: both; }

.ui.section.divider {
  margin-top: 2rem;
  margin-bottom: 2rem; }

.ui.divider {
  font-size: 1rem; }

.ui.horizontal.divider:before, .ui.horizontal.divider:after {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABaAAAAACCAYAAACuTHuKAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyFpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChXaW5kb3dzKSIgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo1OThBRDY4OUNDMTYxMUU0OUE3NUVGOEJDMzMzMjE2NyIgeG1wTU06RG9jdW1lbnRJRD0ieG1wLmRpZDo1OThBRDY4QUNDMTYxMUU0OUE3NUVGOEJDMzMzMjE2NyI+IDx4bXBNTTpEZXJpdmVkRnJvbSBzdFJlZjppbnN0YW5jZUlEPSJ4bXAuaWlkOjU5OEFENjg3Q0MxNjExRTQ5QTc1RUY4QkMzMzMyMTY3IiBzdFJlZjpkb2N1bWVudElEPSJ4bXAuZGlkOjU5OEFENjg4Q0MxNjExRTQ5QTc1RUY4QkMzMzMyMTY3Ii8+IDwvcmRmOkRlc2NyaXB0aW9uPiA8L3JkZjpSREY+IDwveDp4bXBtZXRhPiA8P3hwYWNrZXQgZW5kPSJyIj8+VU513gAAADVJREFUeNrs0DENACAQBDBIWLGBJQby/mUcJn5sJXQmOQMAAAAAAJqt+2prAAAAAACg2xdgANk6BEVuJgyMAAAAAElFTkSuQmCC"); }

@media only screen and (max-width: 767px) {
  .ui.stackable.grid .ui.vertical.divider, .ui.grid .stackable.row .ui.vertical.divider {
    display: table;
    white-space: nowrap;
    height: auto;
    margin: '';
    overflow: hidden;
    line-height: 1;
    text-align: center;
    position: static;
    top: 0;
    left: 0;
    -webkit-transform: none;
    transform: none; }
  .ui.stackable.grid .ui.vertical.divider:before, .ui.grid .stackable.row .ui.vertical.divider:before, .ui.stackable.grid .ui.vertical.divider:after, .ui.grid .stackable.row .ui.vertical.divider:after {
    position: static;
    left: 0;
    border-left: none;
    border-right: none;
    content: '';
    display: table-cell;
    position: relative;
    top: 50%;
    width: 50%;
    background-repeat: no-repeat; }
  .ui.stackable.grid .ui.vertical.divider:before, .ui.grid .stackable.row .ui.vertical.divider:before {
    background-position: right 1em top 50%; }
  .ui.stackable.grid .ui.vertical.divider:after, .ui.grid .stackable.row .ui.vertical.divider:after {
    background-position: left 1em top 50%; } }

@media only screen and (max-width: 767px) {
  .ui.stackable.grid .ui.vertical.divider:before, .ui.grid .stackable.row .ui.vertical.divider:before, .ui.stackable.grid .ui.vertical.divider:after, .ui.grid .stackable.row .ui.vertical.divider:after {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABaAAAAACCAYAAACuTHuKAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyFpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuNS1jMDE0IDc5LjE1MTQ4MSwgMjAxMy8wMy8xMy0xMjowOToxNSAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENDIChXaW5kb3dzKSIgeG1wTU06SW5zdGFuY2VJRD0ieG1wLmlpZDo1OThBRDY4OUNDMTYxMUU0OUE3NUVGOEJDMzMzMjE2NyIgeG1wTU06RG9jdW1lbnRJRD0ieG1wLmRpZDo1OThBRDY4QUNDMTYxMUU0OUE3NUVGOEJDMzMzMjE2NyI+IDx4bXBNTTpEZXJpdmVkRnJvbSBzdFJlZjppbnN0YW5jZUlEPSJ4bXAuaWlkOjU5OEFENjg3Q0MxNjExRTQ5QTc1RUY4QkMzMzMyMTY3IiBzdFJlZjpkb2N1bWVudElEPSJ4bXAuZGlkOjU5OEFENjg4Q0MxNjExRTQ5QTc1RUY4QkMzMzMyMTY3Ii8+IDwvcmRmOkRlc2NyaXB0aW9uPiA8L3JkZjpSREY+IDwveDp4bXBtZXRhPiA8P3hwYWNrZXQgZW5kPSJyIj8+VU513gAAADVJREFUeNrs0DENACAQBDBIWLGBJQby/mUcJn5sJXQmOQMAAAAAAJqt+2prAAAAAACg2xdgANk6BEVuJgyMAAAAAElFTkSuQmCC"); } }

/*!
 * # Semantic UI 2.2.12 - Flag
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Flag
*******************************/
i.flag:not(.icon) {
  display: inline-block;
  width: 16px;
  height: 11px;
  line-height: 11px;
  vertical-align: baseline;
  margin: 0em 0.5em 0em 0em;
  text-decoration: inherit;
  speak: none;
  font-smoothing: antialiased;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden; }
  i.flag:not(.icon):before {
    display: inline-block;
    content: '';
    background: url("../../images/flags.png") no-repeat -108px -1976px;
    width: 16px;
    height: 11px; }

i.flag.ad:before, i.flag.andorra:before {
  background-position: 0px 0px; }

i.flag.ae:before, i.flag.united.arab.emirates:before, i.flag.uae:before {
  background-position: 0px -26px; }

i.flag.af:before, i.flag.afghanistan:before {
  background-position: 0px -52px; }

i.flag.ag:before, i.flag.antigua:before {
  background-position: 0px -78px; }

i.flag.ai:before, i.flag.anguilla:before {
  background-position: 0px -104px; }

i.flag.al:before, i.flag.albania:before {
  background-position: 0px -130px; }

i.flag.am:before, i.flag.armenia:before {
  background-position: 0px -156px; }

i.flag.an:before, i.flag.netherlands.antilles:before {
  background-position: 0px -182px; }

i.flag.ao:before, i.flag.angola:before {
  background-position: 0px -208px; }

i.flag.ar:before, i.flag.argentina:before {
  background-position: 0px -234px; }

i.flag.as:before, i.flag.american.samoa:before {
  background-position: 0px -260px; }

i.flag.at:before, i.flag.austria:before {
  background-position: 0px -286px; }

i.flag.au:before, i.flag.australia:before {
  background-position: 0px -312px; }

i.flag.aw:before, i.flag.aruba:before {
  background-position: 0px -338px; }

i.flag.ax:before, i.flag.aland.islands:before {
  background-position: 0px -364px; }

i.flag.az:before, i.flag.azerbaijan:before {
  background-position: 0px -390px; }

i.flag.ba:before, i.flag.bosnia:before {
  background-position: 0px -416px; }

i.flag.bb:before, i.flag.barbados:before {
  background-position: 0px -442px; }

i.flag.bd:before, i.flag.bangladesh:before {
  background-position: 0px -468px; }

i.flag.be:before, i.flag.belgium:before {
  background-position: 0px -494px; }

i.flag.bf:before, i.flag.burkina.faso:before {
  background-position: 0px -520px; }

i.flag.bg:before, i.flag.bulgaria:before {
  background-position: 0px -546px; }

i.flag.bh:before, i.flag.bahrain:before {
  background-position: 0px -572px; }

i.flag.bi:before, i.flag.burundi:before {
  background-position: 0px -598px; }

i.flag.bj:before, i.flag.benin:before {
  background-position: 0px -624px; }

i.flag.bm:before, i.flag.bermuda:before {
  background-position: 0px -650px; }

i.flag.bn:before, i.flag.brunei:before {
  background-position: 0px -676px; }

i.flag.bo:before, i.flag.bolivia:before {
  background-position: 0px -702px; }

i.flag.br:before, i.flag.brazil:before {
  background-position: 0px -728px; }

i.flag.bs:before, i.flag.bahamas:before {
  background-position: 0px -754px; }

i.flag.bt:before, i.flag.bhutan:before {
  background-position: 0px -780px; }

i.flag.bv:before, i.flag.bouvet.island:before {
  background-position: 0px -806px; }

i.flag.bw:before, i.flag.botswana:before {
  background-position: 0px -832px; }

i.flag.by:before, i.flag.belarus:before {
  background-position: 0px -858px; }

i.flag.bz:before, i.flag.belize:before {
  background-position: 0px -884px; }

i.flag.ca:before, i.flag.canada:before {
  background-position: 0px -910px; }

i.flag.cc:before, i.flag.cocos.islands:before {
  background-position: 0px -962px; }

i.flag.cd:before, i.flag.congo:before {
  background-position: 0px -988px; }

i.flag.cf:before, i.flag.central.african.republic:before {
  background-position: 0px -1014px; }

i.flag.cg:before, i.flag.congo.brazzaville:before {
  background-position: 0px -1040px; }

i.flag.ch:before, i.flag.switzerland:before {
  background-position: 0px -1066px; }

i.flag.ci:before, i.flag.cote.divoire:before {
  background-position: 0px -1092px; }

i.flag.ck:before, i.flag.cook.islands:before {
  background-position: 0px -1118px; }

i.flag.cl:before, i.flag.chile:before {
  background-position: 0px -1144px; }

i.flag.cm:before, i.flag.cameroon:before {
  background-position: 0px -1170px; }

i.flag.cn:before, i.flag.china:before {
  background-position: 0px -1196px; }

i.flag.co:before, i.flag.colombia:before {
  background-position: 0px -1222px; }

i.flag.cr:before, i.flag.costa.rica:before {
  background-position: 0px -1248px; }

i.flag.cs:before, i.flag.serbia:before {
  background-position: 0px -1274px; }

i.flag.cu:before, i.flag.cuba:before {
  background-position: 0px -1300px; }

i.flag.cv:before, i.flag.cape.verde:before {
  background-position: 0px -1326px; }

i.flag.cx:before, i.flag.christmas.island:before {
  background-position: 0px -1352px; }

i.flag.cy:before, i.flag.cyprus:before {
  background-position: 0px -1378px; }

i.flag.cz:before, i.flag.czech.republic:before {
  background-position: 0px -1404px; }

i.flag.de:before, i.flag.germany:before {
  background-position: 0px -1430px; }

i.flag.dj:before, i.flag.djibouti:before {
  background-position: 0px -1456px; }

i.flag.dk:before, i.flag.denmark:before {
  background-position: 0px -1482px; }

i.flag.dm:before, i.flag.dominica:before {
  background-position: 0px -1508px; }

i.flag.do:before, i.flag.dominican.republic:before {
  background-position: 0px -1534px; }

i.flag.dz:before, i.flag.algeria:before {
  background-position: 0px -1560px; }

i.flag.ec:before, i.flag.ecuador:before {
  background-position: 0px -1586px; }

i.flag.ee:before, i.flag.estonia:before {
  background-position: 0px -1612px; }

i.flag.eg:before, i.flag.egypt:before {
  background-position: 0px -1638px; }

i.flag.eh:before, i.flag.western.sahara:before {
  background-position: 0px -1664px; }

i.flag.er:before, i.flag.eritrea:before {
  background-position: 0px -1716px; }

i.flag.es:before, i.flag.spain:before {
  background-position: 0px -1742px; }

i.flag.et:before, i.flag.ethiopia:before {
  background-position: 0px -1768px; }

i.flag.eu:before, i.flag.european.union:before {
  background-position: 0px -1794px; }

i.flag.fi:before, i.flag.finland:before {
  background-position: 0px -1846px; }

i.flag.fj:before, i.flag.fiji:before {
  background-position: 0px -1872px; }

i.flag.fk:before, i.flag.falkland.islands:before {
  background-position: 0px -1898px; }

i.flag.fm:before, i.flag.micronesia:before {
  background-position: 0px -1924px; }

i.flag.fo:before, i.flag.faroe.islands:before {
  background-position: 0px -1950px; }

i.flag.fr:before, i.flag.france:before {
  background-position: 0px -1976px; }

i.flag.ga:before, i.flag.gabon:before {
  background-position: -36px 0px; }

i.flag.gb:before, i.flag.united.kingdom:before {
  background-position: -36px -26px; }

i.flag.gd:before, i.flag.grenada:before {
  background-position: -36px -52px; }

i.flag.ge:before, i.flag.georgia:before {
  background-position: -36px -78px; }

i.flag.gf:before, i.flag.french.guiana:before {
  background-position: -36px -104px; }

i.flag.gh:before, i.flag.ghana:before {
  background-position: -36px -130px; }

i.flag.gi:before, i.flag.gibraltar:before {
  background-position: -36px -156px; }

i.flag.gl:before, i.flag.greenland:before {
  background-position: -36px -182px; }

i.flag.gm:before, i.flag.gambia:before {
  background-position: -36px -208px; }

i.flag.gn:before, i.flag.guinea:before {
  background-position: -36px -234px; }

i.flag.gp:before, i.flag.guadeloupe:before {
  background-position: -36px -260px; }

i.flag.gq:before, i.flag.equatorial.guinea:before {
  background-position: -36px -286px; }

i.flag.gr:before, i.flag.greece:before {
  background-position: -36px -312px; }

i.flag.gs:before, i.flag.sandwich.islands:before {
  background-position: -36px -338px; }

i.flag.gt:before, i.flag.guatemala:before {
  background-position: -36px -364px; }

i.flag.gu:before, i.flag.guam:before {
  background-position: -36px -390px; }

i.flag.gw:before, i.flag.guinea-bissau:before {
  background-position: -36px -416px; }

i.flag.gy:before, i.flag.guyana:before {
  background-position: -36px -442px; }

i.flag.hk:before, i.flag.hong.kong:before {
  background-position: -36px -468px; }

i.flag.hm:before, i.flag.heard.island:before {
  background-position: -36px -494px; }

i.flag.hn:before, i.flag.honduras:before {
  background-position: -36px -520px; }

i.flag.hr:before, i.flag.croatia:before {
  background-position: -36px -546px; }

i.flag.ht:before, i.flag.haiti:before {
  background-position: -36px -572px; }

i.flag.hu:before, i.flag.hungary:before {
  background-position: -36px -598px; }

i.flag.id:before, i.flag.indonesia:before {
  background-position: -36px -624px; }

i.flag.ie:before, i.flag.ireland:before {
  background-position: -36px -650px; }

i.flag.il:before, i.flag.israel:before {
  background-position: -36px -676px; }

i.flag.in:before, i.flag.india:before {
  background-position: -36px -702px; }

i.flag.io:before, i.flag.indian.ocean.territory:before {
  background-position: -36px -728px; }

i.flag.iq:before, i.flag.iraq:before {
  background-position: -36px -754px; }

i.flag.ir:before, i.flag.iran:before {
  background-position: -36px -780px; }

i.flag.is:before, i.flag.iceland:before {
  background-position: -36px -806px; }

i.flag.it:before, i.flag.italy:before {
  background-position: -36px -832px; }

i.flag.jm:before, i.flag.jamaica:before {
  background-position: -36px -858px; }

i.flag.jo:before, i.flag.jordan:before {
  background-position: -36px -884px; }

i.flag.jp:before, i.flag.japan:before {
  background-position: -36px -910px; }

i.flag.ke:before, i.flag.kenya:before {
  background-position: -36px -936px; }

i.flag.kg:before, i.flag.kyrgyzstan:before {
  background-position: -36px -962px; }

i.flag.kh:before, i.flag.cambodia:before {
  background-position: -36px -988px; }

i.flag.ki:before, i.flag.kiribati:before {
  background-position: -36px -1014px; }

i.flag.km:before, i.flag.comoros:before {
  background-position: -36px -1040px; }

i.flag.kn:before, i.flag.saint.kitts.and.nevis:before {
  background-position: -36px -1066px; }

i.flag.kp:before, i.flag.north.korea:before {
  background-position: -36px -1092px; }

i.flag.kr:before, i.flag.south.korea:before {
  background-position: -36px -1118px; }

i.flag.kw:before, i.flag.kuwait:before {
  background-position: -36px -1144px; }

i.flag.ky:before, i.flag.cayman.islands:before {
  background-position: -36px -1170px; }

i.flag.kz:before, i.flag.kazakhstan:before {
  background-position: -36px -1196px; }

i.flag.la:before, i.flag.laos:before {
  background-position: -36px -1222px; }

i.flag.lb:before, i.flag.lebanon:before {
  background-position: -36px -1248px; }

i.flag.lc:before, i.flag.saint.lucia:before {
  background-position: -36px -1274px; }

i.flag.li:before, i.flag.liechtenstein:before {
  background-position: -36px -1300px; }

i.flag.lk:before, i.flag.sri.lanka:before {
  background-position: -36px -1326px; }

i.flag.lr:before, i.flag.liberia:before {
  background-position: -36px -1352px; }

i.flag.ls:before, i.flag.lesotho:before {
  background-position: -36px -1378px; }

i.flag.lt:before, i.flag.lithuania:before {
  background-position: -36px -1404px; }

i.flag.lu:before, i.flag.luxembourg:before {
  background-position: -36px -1430px; }

i.flag.lv:before, i.flag.latvia:before {
  background-position: -36px -1456px; }

i.flag.ly:before, i.flag.libya:before {
  background-position: -36px -1482px; }

i.flag.ma:before, i.flag.morocco:before {
  background-position: -36px -1508px; }

i.flag.mc:before, i.flag.monaco:before {
  background-position: -36px -1534px; }

i.flag.md:before, i.flag.moldova:before {
  background-position: -36px -1560px; }

i.flag.me:before, i.flag.montenegro:before {
  background-position: -36px -1586px; }

i.flag.mg:before, i.flag.madagascar:before {
  background-position: -36px -1613px; }

i.flag.mh:before, i.flag.marshall.islands:before {
  background-position: -36px -1639px; }

i.flag.mk:before, i.flag.macedonia:before {
  background-position: -36px -1665px; }

i.flag.ml:before, i.flag.mali:before {
  background-position: -36px -1691px; }

i.flag.mm:before, i.flag.myanmar:before, i.flag.burma:before {
  background-position: -73px -1821px; }

i.flag.mn:before, i.flag.mongolia:before {
  background-position: -36px -1743px; }

i.flag.mo:before, i.flag.macau:before {
  background-position: -36px -1769px; }

i.flag.mp:before, i.flag.northern.mariana.islands:before {
  background-position: -36px -1795px; }

i.flag.mq:before, i.flag.martinique:before {
  background-position: -36px -1821px; }

i.flag.mr:before, i.flag.mauritania:before {
  background-position: -36px -1847px; }

i.flag.ms:before, i.flag.montserrat:before {
  background-position: -36px -1873px; }

i.flag.mt:before, i.flag.malta:before {
  background-position: -36px -1899px; }

i.flag.mu:before, i.flag.mauritius:before {
  background-position: -36px -1925px; }

i.flag.mv:before, i.flag.maldives:before {
  background-position: -36px -1951px; }

i.flag.mw:before, i.flag.malawi:before {
  background-position: -36px -1977px; }

i.flag.mx:before, i.flag.mexico:before {
  background-position: -72px 0px; }

i.flag.my:before, i.flag.malaysia:before {
  background-position: -72px -26px; }

i.flag.mz:before, i.flag.mozambique:before {
  background-position: -72px -52px; }

i.flag.na:before, i.flag.namibia:before {
  background-position: -72px -78px; }

i.flag.nc:before, i.flag.new.caledonia:before {
  background-position: -72px -104px; }

i.flag.ne:before, i.flag.niger:before {
  background-position: -72px -130px; }

i.flag.nf:before, i.flag.norfolk.island:before {
  background-position: -72px -156px; }

i.flag.ng:before, i.flag.nigeria:before {
  background-position: -72px -182px; }

i.flag.ni:before, i.flag.nicaragua:before {
  background-position: -72px -208px; }

i.flag.nl:before, i.flag.netherlands:before {
  background-position: -72px -234px; }

i.flag.no:before, i.flag.norway:before {
  background-position: -72px -260px; }

i.flag.np:before, i.flag.nepal:before {
  background-position: -72px -286px; }

i.flag.nr:before, i.flag.nauru:before {
  background-position: -72px -312px; }

i.flag.nu:before, i.flag.niue:before {
  background-position: -72px -338px; }

i.flag.nz:before, i.flag.new.zealand:before {
  background-position: -72px -364px; }

i.flag.om:before, i.flag.oman:before {
  background-position: -72px -390px; }

i.flag.pa:before, i.flag.panama:before {
  background-position: -72px -416px; }

i.flag.pe:before, i.flag.peru:before {
  background-position: -72px -442px; }

i.flag.pf:before, i.flag.french.polynesia:before {
  background-position: -72px -468px; }

i.flag.pg:before, i.flag.new.guinea:before {
  background-position: -72px -494px; }

i.flag.ph:before, i.flag.philippines:before {
  background-position: -72px -520px; }

i.flag.pk:before, i.flag.pakistan:before {
  background-position: -72px -546px; }

i.flag.pl:before, i.flag.poland:before {
  background-position: -72px -572px; }

i.flag.pm:before, i.flag.saint.pierre:before {
  background-position: -72px -598px; }

i.flag.pn:before, i.flag.pitcairn.islands:before {
  background-position: -72px -624px; }

i.flag.pr:before, i.flag.puerto.rico:before {
  background-position: -72px -650px; }

i.flag.ps:before, i.flag.palestine:before {
  background-position: -72px -676px; }

i.flag.pt:before, i.flag.portugal:before {
  background-position: -72px -702px; }

i.flag.pw:before, i.flag.palau:before {
  background-position: -72px -728px; }

i.flag.py:before, i.flag.paraguay:before {
  background-position: -72px -754px; }

i.flag.qa:before, i.flag.qatar:before {
  background-position: -72px -780px; }

i.flag.re:before, i.flag.reunion:before {
  background-position: -72px -806px; }

i.flag.ro:before, i.flag.romania:before {
  background-position: -72px -832px; }

i.flag.rs:before, i.flag.serbia:before {
  background-position: -72px -858px; }

i.flag.ru:before, i.flag.russia:before {
  background-position: -72px -884px; }

i.flag.rw:before, i.flag.rwanda:before {
  background-position: -72px -910px; }

i.flag.sa:before, i.flag.saudi.arabia:before {
  background-position: -72px -936px; }

i.flag.sb:before, i.flag.solomon.islands:before {
  background-position: -72px -962px; }

i.flag.sc:before, i.flag.seychelles:before {
  background-position: -72px -988px; }

i.flag.gb.sct:before, i.flag.scotland:before {
  background-position: -72px -1014px; }

i.flag.sd:before, i.flag.sudan:before {
  background-position: -72px -1040px; }

i.flag.se:before, i.flag.sweden:before {
  background-position: -72px -1066px; }

i.flag.sg:before, i.flag.singapore:before {
  background-position: -72px -1092px; }

i.flag.sh:before, i.flag.saint.helena:before {
  background-position: -72px -1118px; }

i.flag.si:before, i.flag.slovenia:before {
  background-position: -72px -1144px; }

i.flag.sj:before, i.flag.svalbard:before, i.flag.jan.mayen:before {
  background-position: -72px -1170px; }

i.flag.sk:before, i.flag.slovakia:before {
  background-position: -72px -1196px; }

i.flag.sl:before, i.flag.sierra.leone:before {
  background-position: -72px -1222px; }

i.flag.sm:before, i.flag.san.marino:before {
  background-position: -72px -1248px; }

i.flag.sn:before, i.flag.senegal:before {
  background-position: -72px -1274px; }

i.flag.so:before, i.flag.somalia:before {
  background-position: -72px -1300px; }

i.flag.sr:before, i.flag.suriname:before {
  background-position: -72px -1326px; }

i.flag.st:before, i.flag.sao.tome:before {
  background-position: -72px -1352px; }

i.flag.sv:before, i.flag.el.salvador:before {
  background-position: -72px -1378px; }

i.flag.sy:before, i.flag.syria:before {
  background-position: -72px -1404px; }

i.flag.sz:before, i.flag.swaziland:before {
  background-position: -72px -1430px; }

i.flag.tc:before, i.flag.caicos.islands:before {
  background-position: -72px -1456px; }

i.flag.td:before, i.flag.chad:before {
  background-position: -72px -1482px; }

i.flag.tf:before, i.flag.french.territories:before {
  background-position: -72px -1508px; }

i.flag.tg:before, i.flag.togo:before {
  background-position: -72px -1534px; }

i.flag.th:before, i.flag.thailand:before {
  background-position: -72px -1560px; }

i.flag.tj:before, i.flag.tajikistan:before {
  background-position: -72px -1586px; }

i.flag.tk:before, i.flag.tokelau:before {
  background-position: -72px -1612px; }

i.flag.tl:before, i.flag.timorleste:before {
  background-position: -72px -1638px; }

i.flag.tm:before, i.flag.turkmenistan:before {
  background-position: -72px -1664px; }

i.flag.tn:before, i.flag.tunisia:before {
  background-position: -72px -1690px; }

i.flag.to:before, i.flag.tonga:before {
  background-position: -72px -1716px; }

i.flag.tr:before, i.flag.turkey:before {
  background-position: -72px -1742px; }

i.flag.tt:before, i.flag.trinidad:before {
  background-position: -72px -1768px; }

i.flag.tv:before, i.flag.tuvalu:before {
  background-position: -72px -1794px; }

i.flag.tw:before, i.flag.taiwan:before {
  background-position: -72px -1820px; }

i.flag.tz:before, i.flag.tanzania:before {
  background-position: -72px -1846px; }

i.flag.ua:before, i.flag.ukraine:before {
  background-position: -72px -1872px; }

i.flag.ug:before, i.flag.uganda:before {
  background-position: -72px -1898px; }

i.flag.um:before {
  background-position: -72px -1924px; }

i.flag.us.minor.islands:before {
  background-position: -72px -1924px; }

i.flag.us:before {
  background-position: -72px -1950px; }

i.flag.america:before, i.flag.united.states:before {
  background-position: -72px -1950px; }

i.flag.uy:before, i.flag.uruguay:before {
  background-position: -72px -1976px; }

i.flag.uz:before, i.flag.uzbekistan:before {
  background-position: -108px 0px; }

i.flag.va:before, i.flag.vatican.city:before {
  background-position: -108px -26px; }

i.flag.vc:before, i.flag.saint.vincent:before {
  background-position: -108px -52px; }

i.flag.ve:before, i.flag.venezuela:before {
  background-position: -108px -78px; }

i.flag.vg:before, i.flag.british.virgin.islands:before {
  background-position: -108px -104px; }

i.flag.vi:before, i.flag.us.virgin.islands:before {
  background-position: -108px -130px; }

i.flag.vn:before, i.flag.vietnam:before {
  background-position: -108px -156px; }

i.flag.vu:before, i.flag.vanuatu:before {
  background-position: -108px -182px; }

i.flag.gb.wls:before, i.flag.wales:before {
  background-position: -108px -208px; }

i.flag.wf:before, i.flag.wallis.and.futuna:before {
  background-position: -108px -234px; }

i.flag.ws:before, i.flag.samoa:before {
  background-position: -108px -260px; }

i.flag.ye:before, i.flag.yemen:before {
  background-position: -108px -286px; }

i.flag.yt:before, i.flag.mayotte:before {
  background-position: -108px -312px; }

i.flag.za:before, i.flag.south.africa:before {
  background-position: -108px -338px; }

i.flag.zm:before, i.flag.zambia:before {
  background-position: -108px -364px; }

i.flag.zw:before, i.flag.zimbabwe:before {
  background-position: -108px -390px; }

/* Sprite */
/* Flag Sprite Based On http://www.famfamfam.com/lab/icons/flags/ */
/*******************************
         Theme Overrides
*******************************/
/*******************************
         Site Overrides
*******************************/
/*!
 * # Semantic UI 2.2.12 - Header
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Header
*******************************/
/* Standard */
.ui.header {
  border: none;
  margin: calc(2rem -  0.14285714em) 0em 1rem;
  padding: 0em 0em;
  font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
  font-weight: bold;
  line-height: 1.28571429em;
  text-transform: none;
  color: rgba(0, 0, 0, 0.87); }
  .ui.header:first-child {
    margin-top: -0.14285714em; }
  .ui.header:last-child {
    margin-bottom: 0em; }
  .ui.header .sub.header {
    display: block;
    font-weight: normal;
    padding: 0em;
    margin: 0em;
    font-size: 1rem;
    line-height: 1.2em;
    color: rgba(0, 0, 0, 0.6); }
  .ui.header > .icon {
    display: table-cell;
    opacity: 1;
    font-size: 1.5em;
    padding-top: 0em;
    vertical-align: middle; }
  .ui.header .icon:only-child {
    display: inline-block;
    padding: 0em;
    margin-right: 0.75rem; }
  .ui.header > .image:not(.icon), .ui.header > img {
    display: inline-block;
    margin-top: 0.14285714em;
    width: 2.5em;
    height: auto;
    vertical-align: middle; }
  .ui.header > .image:not(.icon):only-child, .ui.header > img:only-child {
    margin-right: 0.75rem; }
  .ui.header .content {
    display: inline-block;
    vertical-align: top; }
  .ui.header > img + .content, .ui.header > .image + .content {
    padding-left: 0.75rem;
    vertical-align: middle; }
  .ui.header > .icon + .content {
    padding-left: 0.75rem;
    display: table-cell;
    vertical-align: middle; }
  .ui.header .ui.label {
    font-size: '';
    margin-left: 0.5rem;
    vertical-align: middle; }
  .ui.header + p {
    margin-top: 0em; }

/*--------------
   Sub Header
---------------*/
/*--------------
      Icon
---------------*/
/* With Text Node */
/*-------------------
        Image
--------------------*/
/*--------------
     Content
---------------*/
/* After Image */
/* After Icon */
/*--------------
 Loose Coupling
---------------*/
/* Positioning */
/*******************************
            Types
*******************************/
/*--------------
     Page
---------------*/
h1.ui.header {
  font-size: 2rem; }

h2.ui.header {
  font-size: 1.71428571rem; }

h3.ui.header {
  font-size: 1.28571429rem; }

h4.ui.header {
  font-size: 1.07142857rem; }

h5.ui.header {
  font-size: 1rem; }

/* Sub Header */
h1.ui.header .sub.header, h2.ui.header .sub.header {
  font-size: 1.14285714rem; }

h3.ui.header .sub.header, h4.ui.header .sub.header {
  font-size: 1rem; }

h5.ui.header .sub.header {
  font-size: 0.92857143rem; }

/*--------------
 Content Heading
---------------*/
.ui.huge.header {
  min-height: 1em;
  font-size: 2em; }

.ui.large.header {
  font-size: 1.71428571em; }

.ui.medium.header {
  font-size: 1.28571429em; }

.ui.small.header {
  font-size: 1.07142857em; }

.ui.tiny.header {
  font-size: 1em; }

.ui.huge.header .sub.header, .ui.large.header .sub.header {
  font-size: 1.14285714rem; }

.ui.header .sub.header, .ui.small.header .sub.header {
  font-size: 1rem; }

.ui.tiny.header .sub.header {
  font-size: 0.92857143rem; }

.ui.sub.header {
  padding: 0em;
  margin-bottom: 0.14285714rem;
  font-weight: bold;
  font-size: 0.85714286em;
  text-transform: uppercase;
  color: ''; }

.ui.small.sub.header {
  font-size: 0.78571429em; }

.ui.sub.header {
  font-size: 0.85714286em; }

.ui.large.sub.header {
  font-size: 0.92857143em; }

.ui.huge.sub.header {
  font-size: 1em; }

.ui.icon.header {
  display: inline-block;
  text-align: center;
  margin: 2rem 0em 1rem; }
  .ui.icon.header:after {
    content: '';
    display: block;
    height: 0px;
    clear: both;
    visibility: hidden; }
  .ui.icon.header:first-child {
    margin-top: 0em; }
  .ui.icon.header .icon {
    float: none;
    display: block;
    width: auto;
    height: auto;
    line-height: 1;
    padding: 0em;
    font-size: 3em;
    margin: 0em auto 0.5rem;
    opacity: 1; }
  .ui.icon.header .content {
    display: block;
    padding: 0em; }
  .ui.icon.header .circular.icon, .ui.icon.header .square.icon {
    font-size: 2em; }

.ui.block.icon.header .icon {
  margin-bottom: 0em; }

.ui.icon.header.aligned {
  margin-left: auto;
  margin-right: auto;
  display: block; }

.ui.disabled.header {
  opacity: 0.45; }

.ui.inverted.header {
  color: #FFFFFF; }
  .ui.inverted.header .sub.header {
    color: rgba(255, 255, 255, 0.8); }

.ui.inverted.attached.header {
  background: #545454 -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05));
  background: #545454 linear-gradient(transparent, rgba(0, 0, 0, 0.05));
  box-shadow: none;
  border-color: transparent; }

.ui.inverted.block.header {
  background: #545454 -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05));
  background: #545454 linear-gradient(transparent, rgba(0, 0, 0, 0.05));
  box-shadow: none;
  border-bottom: none; }

.ui.red.header {
  color: #DB2828 !important; }

/* Sub Header */
/*--------------
   Sub Heading
---------------*/
/*-------------------
        Icon
--------------------*/
/*******************************
            States
*******************************/
/*******************************
           Variations
*******************************/
/*-------------------
      Inverted
--------------------*/
/*-------------------
       Colors
--------------------*/
/*--- Red ---*/
a.ui.red.header:hover {
  color: #d01919 !important; }

.ui.red.dividing.header {
  border-bottom: 2px solid #DB2828; }

.ui.inverted.red.header {
  color: #FF695E !important; }

/* Inverted */
a.ui.inverted.red.header:hover {
  color: #ff5144 !important; }

/*--- Orange ---*/
.ui.orange.header {
  color: #fc7831 !important; }

a.ui.orange.header:hover {
  color: #f26202 !important; }

.ui.orange.dividing.header {
  border-bottom: 2px solid #fc7831; }

.ui.inverted.orange.header {
  color: #fc7831 !important; }

/* Inverted */
a.ui.inverted.orange.header:hover {
  color: #ff7701 !important; }

/*--- Olive ---*/
.ui.olive.header {
  color: #B5CC18 !important; }

a.ui.olive.header:hover {
  color: #a7bd0d !important; }

.ui.olive.dividing.header {
  border-bottom: 2px solid #B5CC18; }

.ui.inverted.olive.header {
  color: #D9E778 !important; }

/* Inverted */
a.ui.inverted.olive.header:hover {
  color: #d8ea5c !important; }

/*--- Yellow ---*/
.ui.yellow.header {
  color: #FBBD08 !important; }

a.ui.yellow.header:hover {
  color: #eaae00 !important; }

.ui.yellow.dividing.header {
  border-bottom: 2px solid #FBBD08; }

.ui.inverted.yellow.header {
  color: #FFE21F !important; }

/* Inverted */
a.ui.inverted.yellow.header:hover {
  color: #ffdf05 !important; }

/*--- Green ---*/
.ui.green.header {
  color: #21BA45 !important; }

a.ui.green.header:hover {
  color: #16ab39 !important; }

.ui.green.dividing.header {
  border-bottom: 2px solid #21BA45; }

.ui.inverted.green.header {
  color: #2ECC40 !important; }

/* Inverted */
a.ui.inverted.green.header:hover {
  color: #22be34 !important; }

/*--- Teal ---*/
.ui.teal.header {
  color: #00B5AD !important; }

a.ui.teal.header:hover {
  color: #009c95 !important; }

.ui.teal.dividing.header {
  border-bottom: 2px solid #00B5AD; }

.ui.inverted.teal.header {
  color: #6DFFFF !important; }

/* Inverted */
a.ui.inverted.teal.header:hover {
  color: #54ffff !important; }

/*--- Blue ---*/
.ui.blue.header {
  color: #4c8bd6 !important; }

a.ui.blue.header:hover {
  color: #1678c2 !important; }

.ui.blue.dividing.header {
  border-bottom: 2px solid #4c8bd6; }

.ui.inverted.blue.header {
  color: #4c8bd6 !important; }

/* Inverted */
a.ui.inverted.blue.header:hover {
  color: #3ac0ff !important; }

/*--- Violet ---*/
.ui.violet.header {
  color: #6435C9 !important; }

a.ui.violet.header:hover {
  color: #5829bb !important; }

.ui.violet.dividing.header {
  border-bottom: 2px solid #6435C9; }

.ui.inverted.violet.header {
  color: #A291FB !important; }

/* Inverted */
a.ui.inverted.violet.header:hover {
  color: #8a73ff !important; }

/*--- Purple ---*/
.ui.purple.header {
  color: #A333C8 !important; }

a.ui.purple.header:hover {
  color: #9627ba !important; }

.ui.purple.dividing.header {
  border-bottom: 2px solid #A333C8; }

.ui.inverted.purple.header {
  color: #DC73FF !important; }

/* Inverted */
a.ui.inverted.purple.header:hover {
  color: #d65aff !important; }

/*--- Pink ---*/
.ui.pink.header {
  color: #E03997 !important; }

a.ui.pink.header:hover {
  color: #e61a8d !important; }

.ui.pink.dividing.header {
  border-bottom: 2px solid #E03997; }

.ui.inverted.pink.header {
  color: #FF8EDF !important; }

/* Inverted */
a.ui.inverted.pink.header:hover {
  color: #ff74d8 !important; }

/*--- Brown ---*/
.ui.brown.header {
  color: #A5673F !important; }

a.ui.brown.header:hover {
  color: #975b33 !important; }

.ui.brown.dividing.header {
  border-bottom: 2px solid #A5673F; }

.ui.inverted.brown.header {
  color: #D67C1C !important; }

/* Inverted */
a.ui.inverted.brown.header:hover {
  color: #c86f11 !important; }

/*--- Grey ---*/
.ui.grey.header {
  color: #767676 !important; }

a.ui.grey.header:hover {
  color: #838383 !important; }

.ui.grey.dividing.header {
  border-bottom: 2px solid #767676; }

.ui.inverted.grey.header {
  color: #DCDDDE !important; }

/* Inverted */
a.ui.inverted.grey.header:hover {
  color: #cfd0d2 !important; }

/*-------------------
       Aligned
--------------------*/
.ui.left.aligned.header {
  text-align: left; }

.ui.right.aligned.header {
  text-align: right; }

.ui.centered.header, .ui.center.aligned.header {
  text-align: center; }

.ui.justified.header {
  text-align: justify; }
  .ui.justified.header:after {
    display: inline-block;
    content: '';
    width: 100%; }

.ui.floated.header, .ui[class*="left floated"].header {
  float: left;
  margin-top: 0em;
  margin-right: 0.5em; }

.ui[class*="right floated"].header {
  float: right;
  margin-top: 0em;
  margin-left: 0.5em; }

.ui.fitted.header {
  padding: 0em; }

.ui.dividing.header {
  padding-bottom: 0.21428571rem;
  border-bottom: 1px solid rgba(34, 36, 38, 0.15); }
  .ui.dividing.header .sub.header {
    padding-bottom: 0.21428571rem; }
  .ui.dividing.header .icon {
    margin-bottom: 0em; }

.ui.inverted.dividing.header {
  border-bottom-color: rgba(255, 255, 255, 0.1); }

.ui.block.header {
  background: #F3F4F5;
  padding: 0.78571429rem 1rem;
  box-shadow: none;
  border: 1px solid #D4D4D5;
  border-radius: 0.28571429rem; }

.ui.tiny.block.header {
  font-size: 0.85714286rem; }

.ui.small.block.header {
  font-size: 0.92857143rem; }

.ui.block.header:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6) {
  font-size: 1rem; }

.ui.large.block.header {
  font-size: 1.14285714rem; }

.ui.huge.block.header {
  font-size: 1.42857143rem; }

.ui.attached.header {
  background: #FFFFFF;
  padding: 0.78571429rem 1rem;
  margin-left: -1px;
  margin-right: -1px;
  box-shadow: none;
  border: 1px solid #D4D4D5; }

.ui.attached.block.header {
  background: #F3F4F5; }

.ui.attached:not(.top):not(.bottom).header {
  margin-top: 0em;
  margin-bottom: 0em;
  border-top: none;
  border-radius: 0em; }

.ui.top.attached.header {
  margin-bottom: 0em;
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }

.ui.bottom.attached.header {
  margin-top: 0em;
  border-top: none;
  border-radius: 0em 0em 0.28571429rem 0.28571429rem; }

.ui.tiny.attached.header {
  font-size: 0.85714286em; }

.ui.small.attached.header {
  font-size: 0.92857143em; }

.ui.attached.header:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6) {
  font-size: 1em; }

.ui.large.attached.header {
  font-size: 1.14285714em; }

.ui.huge.attached.header {
  font-size: 1.42857143em; }

.ui.header:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6) {
  font-size: 1.28571429em; }

/*!
 * # Semantic UI 2.2.12 - Icon
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Icon
*******************************/
@font-face {
  font-family: 'Icons';
  src: url("../../icons/icons.eot");
  src: url("../../icons/icons.eot?#iefix") format("embedded-opentype"), url("../../icons/icons.woff2") format("woff2"), url("../../icons/icons.woff") format("woff"), url("../../icons/icons.ttf") format("truetype"), url("../../icons/icons.svg#icons") format("svg");
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-decoration: inherit;
  text-transform: none; }

i.icon {
  display: inline-block;
  opacity: 1;
  margin: 0em 0.25rem 0em 0em;
  width: 1.18em;
  height: 1em;
  font-family: 'Icons';
  font-style: normal;
  font-weight: normal;
  text-decoration: inherit;
  text-align: center;
  speak: none;
  font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden; }
  i.icon:before {
    background: none !important; }
  i.icon.loading {
    height: 1em;
    line-height: 1;
    -webkit-animation: icon-loading 2s linear infinite;
    animation: icon-loading 2s linear infinite; }
  i.icon.hover, i.icon.active {
    opacity: 1 !important; }

i.emphasized.icon {
  opacity: 1 !important; }

i.disabled.icon {
  opacity: 0.45 !important; }

i.fitted.icon {
  width: auto;
  margin: 0em; }

i.link.icon, i.link.icons {
  cursor: pointer;
  opacity: 0.8;
  -webkit-transition: opacity 0.1s ease;
  transition: opacity 0.1s ease; }

i.link.icon:hover, i.link.icons:hover {
  opacity: 1 !important; }

i.circular.icon {
  border-radius: 500em !important;
  line-height: 1 !important;
  padding: 0.5em 0.5em !important;
  box-shadow: 0em 0em 0em 0.1em rgba(0, 0, 0, 0.1) inset;
  width: 2em !important;
  height: 2em !important; }

i.circular.inverted.icon {
  border: none;
  box-shadow: none; }

i.flipped.icon, i.horizontally.flipped.icon {
  -webkit-transform: scale(-1, 1);
  transform: scale(-1, 1); }

i.vertically.flipped.icon {
  -webkit-transform: scale(1, -1);
  transform: scale(1, -1); }

i.rotated.icon, i.right.rotated.icon, i.clockwise.rotated.icon {
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg); }

i.left.rotated.icon, i.counterclockwise.rotated.icon {
  -webkit-transform: rotate(-90deg);
  transform: rotate(-90deg); }

i.bordered.icon {
  line-height: 1;
  vertical-align: baseline;
  width: 2em;
  height: 2em;
  padding: 0.5em 0.41em !important;
  box-shadow: 0em 0em 0em 0.1em rgba(0, 0, 0, 0.1) inset; }

i.bordered.inverted.icon {
  border: none;
  box-shadow: none;
  background-color: #1B1C1D !important;
  color: #FFFFFF !important; }

i.inverted.circular.icon {
  background-color: #1B1C1D !important;
  color: #FFFFFF !important; }

i.inverted.icon {
  color: #FFFFFF; }

i.red.icon {
  color: #DB2828 !important; }

i.inverted.red.icon {
  color: #FF695E !important; }

i.inverted.bordered.red.icon, i.inverted.circular.red.icon {
  background-color: #DB2828 !important;
  color: #FFFFFF !important; }

i.orange.icon {
  color: #fc7831 !important; }

i.inverted.orange.icon {
  color: #fc7831 !important; }

i.inverted.bordered.orange.icon, i.inverted.circular.orange.icon {
  background-color: #fc7831 !important;
  color: #FFFFFF !important; }

i.yellow.icon {
  color: #FBBD08 !important; }

i.inverted.yellow.icon {
  color: #FFE21F !important; }

i.inverted.bordered.yellow.icon, i.inverted.circular.yellow.icon {
  background-color: #FBBD08 !important;
  color: #FFFFFF !important; }

i.olive.icon {
  color: #B5CC18 !important; }

i.inverted.olive.icon {
  color: #D9E778 !important; }

i.inverted.bordered.olive.icon, i.inverted.circular.olive.icon {
  background-color: #B5CC18 !important;
  color: #FFFFFF !important; }

i.green.icon {
  color: #21BA45 !important; }

i.inverted.green.icon {
  color: #2ECC40 !important; }

i.inverted.bordered.green.icon, i.inverted.circular.green.icon {
  background-color: #21BA45 !important;
  color: #FFFFFF !important; }

i.teal.icon {
  color: #00B5AD !important; }

i.inverted.teal.icon {
  color: #6DFFFF !important; }

i.inverted.bordered.teal.icon, i.inverted.circular.teal.icon {
  background-color: #00B5AD !important;
  color: #FFFFFF !important; }

i.blue.icon {
  color: #4c8bd6 !important; }

i.inverted.blue.icon {
  color: #4c8bd6 !important; }

i.inverted.bordered.blue.icon, i.inverted.circular.blue.icon {
  background-color: #4c8bd6 !important;
  color: #FFFFFF !important; }

i.violet.icon {
  color: #6435C9 !important; }

i.inverted.violet.icon {
  color: #A291FB !important; }

i.inverted.bordered.violet.icon, i.inverted.circular.violet.icon {
  background-color: #6435C9 !important;
  color: #FFFFFF !important; }

i.purple.icon {
  color: #A333C8 !important; }

i.inverted.purple.icon {
  color: #DC73FF !important; }

i.inverted.bordered.purple.icon, i.inverted.circular.purple.icon {
  background-color: #A333C8 !important;
  color: #FFFFFF !important; }

i.pink.icon {
  color: #E03997 !important; }

i.inverted.pink.icon {
  color: #FF8EDF !important; }

i.inverted.bordered.pink.icon, i.inverted.circular.pink.icon {
  background-color: #E03997 !important;
  color: #FFFFFF !important; }

i.brown.icon {
  color: #A5673F !important; }

i.inverted.brown.icon {
  color: #D67C1C !important; }

i.inverted.bordered.brown.icon, i.inverted.circular.brown.icon {
  background-color: #A5673F !important;
  color: #FFFFFF !important; }

i.grey.icon {
  color: #767676 !important; }

i.inverted.grey.icon {
  color: #DCDDDE !important; }

i.inverted.bordered.grey.icon, i.inverted.circular.grey.icon {
  background-color: #767676 !important;
  color: #FFFFFF !important; }

i.black.icon {
  color: #1B1C1D !important; }

i.inverted.black.icon {
  color: #545454 !important; }

i.inverted.bordered.black.icon, i.inverted.circular.black.icon {
  background-color: #1B1C1D !important;
  color: #FFFFFF !important; }

i.mini.icon, i.mini.icons {
  line-height: 1;
  font-size: 0.4em; }

i.tiny.icon, i.tiny.icons {
  line-height: 1;
  font-size: 0.5em; }

i.small.icon, i.small.icons {
  line-height: 1;
  font-size: 0.75em; }

i.icon, i.icons {
  font-size: 1em; }

i.large.icon, i.large.icons {
  line-height: 1;
  vertical-align: middle;
  font-size: 1.5em; }

i.big.icon, i.big.icons {
  line-height: 1;
  vertical-align: middle;
  font-size: 2em; }

i.huge.icon, i.huge.icons {
  line-height: 1;
  vertical-align: middle;
  font-size: 4em; }

i.massive.icon, i.massive.icons {
  line-height: 1;
  vertical-align: middle;
  font-size: 8em; }

i.icons {
  display: inline-block;
  position: relative;
  line-height: 1; }
  i.icons .icon {
    position: absolute;
    top: 50%;
    left: 50%;
    -webkit-transform: translateX(-50%) translateY(-50%);
    transform: translateX(-50%) translateY(-50%);
    margin: 0em;
    margin: 0; }
    i.icons .icon:first-child {
      position: static;
      width: auto;
      height: auto;
      vertical-align: top;
      -webkit-transform: none;
      transform: none;
      margin-right: 0.25rem; }
  i.icons .corner.icon {
    top: auto;
    left: auto;
    right: 0;
    bottom: 0;
    -webkit-transform: none;
    transform: none;
    font-size: 0.45em;
    text-shadow: -1px -1px 0 #FFFFFF, 1px -1px 0 #FFFFFF, -1px 1px 0 #FFFFFF, 1px 1px 0 #FFFFFF; }
  i.icons .top.right.corner.icon {
    top: 0;
    left: auto;
    right: 0;
    bottom: auto; }
  i.icons .top.left.corner.icon {
    top: 0;
    left: 0;
    right: auto;
    bottom: auto; }
  i.icons .bottom.left.corner.icon {
    top: auto;
    left: 0;
    right: auto;
    bottom: 0; }
  i.icons .bottom.right.corner.icon {
    top: auto;
    left: auto;
    right: 0;
    bottom: 0; }
  i.icons .inverted.corner.icon {
    text-shadow: -1px -1px 0 #1B1C1D, 1px -1px 0 #1B1C1D, -1px 1px 0 #1B1C1D, 1px 1px 0 #1B1C1D; }

i.icon.search:before {
  content: "\f002"; }

i.icon.mail.outline:before {
  content: "\f003"; }

i.icon.signal:before {
  content: "\f012"; }

i.icon.setting:before {
  content: "\f013"; }

i.icon.home:before {
  content: "\f015"; }

i.icon.inbox:before {
  content: "\f01c"; }

i.icon.browser:before {
  content: "\f022"; }

i.icon.tag:before {
  content: "\f02b"; }

i.icon.tags:before {
  content: "\f02c"; }

i.icon.image:before {
  content: "\f03e"; }

i.icon.calendar:before {
  content: "\f073"; }

i.icon.comment:before {
  content: "\f075"; }

i.icon.shop:before {
  content: "\f07a"; }

i.icon.comments:before {
  content: "\f086"; }

i.icon.external:before {
  content: "\f08e"; }

i.icon.privacy:before {
  content: "\f084"; }

i.icon.settings:before {
  content: "\f085"; }

i.icon.comments:before {
  content: "\f086"; }

i.icon.external:before {
  content: "\f08e"; }

i.icon.trophy:before {
  content: "\f091"; }

i.icon.payment:before {
  content: "\f09d"; }

i.icon.feed:before {
  content: "\f09e"; }

i.icon.alarm.outline:before {
  content: "\f0a2"; }

i.icon.tasks:before {
  content: "\f0ae"; }

i.icon.cloud:before {
  content: "\f0c2"; }

i.icon.lab:before {
  content: "\f0c3"; }

i.icon.mail:before {
  content: "\f0e0"; }

i.icon.dashboard:before {
  content: "\f0e4"; }

i.icon.comment.outline:before {
  content: "\f0e5"; }

i.icon.comments.outline:before {
  content: "\f0e6"; }

i.icon.sitemap:before {
  content: "\f0e8"; }

i.icon.idea:before {
  content: "\f0eb"; }

i.icon.alarm:before {
  content: "\f0f3"; }

i.icon.terminal:before {
  content: "\f120"; }

i.icon.code:before {
  content: "\f121"; }

i.icon.protect:before {
  content: "\f132"; }

i.icon.calendar.outline:before {
  content: "\f133"; }

i.icon.ticket:before {
  content: "\f145"; }

i.icon.external.square:before {
  content: "\f14c"; }

i.icon.bug:before {
  content: "\f188"; }

i.icon.mail.square:before {
  content: "\f199"; }

i.icon.history:before {
  content: "\f1da"; }

i.icon.options:before {
  content: "\f1de"; }

i.icon.text.telephone:before {
  content: "\f1e4"; }

i.icon.find:before {
  content: "\f1e5"; }

i.icon.alarm.mute:before {
  content: "\f1f6"; }

i.icon.alarm.mute.outline:before {
  content: "\f1f7"; }

i.icon.copyright:before {
  content: "\f1f9"; }

i.icon.at:before {
  content: "\f1fa"; }

i.icon.eyedropper:before {
  content: "\f1fb"; }

i.icon.paint.brush:before {
  content: "\f1fc"; }

i.icon.heartbeat:before {
  content: "\f21e"; }

i.icon.mouse.pointer:before {
  content: "\f245"; }

i.icon.hourglass.empty:before {
  content: "\f250"; }

i.icon.hourglass.start:before {
  content: "\f251"; }

i.icon.hourglass.half:before {
  content: "\f252"; }

i.icon.hourglass.end:before {
  content: "\f253"; }

i.icon.hourglass.full:before {
  content: "\f254"; }

i.icon.hand.pointer:before {
  content: "\f25a"; }

i.icon.trademark:before {
  content: "\f25c"; }

i.icon.registered:before {
  content: "\f25d"; }

i.icon.creative.commons:before {
  content: "\f25e"; }

i.icon.add.to.calendar:before {
  content: "\f271"; }

i.icon.remove.from.calendar:before {
  content: "\f272"; }

i.icon.delete.calendar:before {
  content: "\f273"; }

i.icon.checked.calendar:before {
  content: "\f274"; }

i.icon.industry:before {
  content: "\f275"; }

i.icon.shopping.bag:before {
  content: "\f290"; }

i.icon.shopping.basket:before {
  content: "\f291"; }

i.icon.hashtag:before {
  content: "\f292"; }

i.icon.percent:before {
  content: "\f295"; }

i.icon.handshake:before {
  content: "\f2b5"; }

i.icon.open.envelope:before {
  content: "\f2b6"; }

i.icon.open.envelope.outline:before {
  content: "\f2b7"; }

i.icon.address.book:before {
  content: "\f2b9"; }

i.icon.address.book.outline:before {
  content: "\f2ba"; }

i.icon.address.card:before {
  content: "\f2bb"; }

i.icon.address.card.outline:before {
  content: "\f2bc"; }

i.icon.id.badge:before {
  content: "\f2c1"; }

i.icon.id.card:before {
  content: "\f2c2"; }

i.icon.id.card.outline:before {
  content: "\f2c3"; }

i.icon.podcast:before {
  content: "\f2ce"; }

i.icon.window.maximize:before {
  content: "\f2d0"; }

i.icon.window.minimize:before {
  content: "\f2d1"; }

i.icon.window.restore:before {
  content: "\f2d2"; }

i.icon.window.close:before {
  content: "\f2d3"; }

i.icon.window.close.outline:before {
  content: "\f2d4"; }

i.icon.wait:before {
  content: "\f017"; }

i.icon.download:before {
  content: "\f019"; }

i.icon.repeat:before {
  content: "\f01e"; }

i.icon.refresh:before {
  content: "\f021"; }

i.icon.lock:before {
  content: "\f023"; }

i.icon.bookmark:before {
  content: "\f02e"; }

i.icon.print:before {
  content: "\f02f"; }

i.icon.write:before {
  content: "\f040"; }

i.icon.adjust:before {
  content: "\f042"; }

i.icon.theme:before {
  content: "\f043"; }

i.icon.edit:before {
  content: "\f044"; }

i.icon.external.share:before {
  content: "\f045"; }

i.icon.ban:before {
  content: "\f05e"; }

i.icon.mail.forward:before, i.icon.share:before {
  content: "\f064"; }

i.icon.expand:before {
  content: "\f065"; }

i.icon.compress:before {
  content: "\f066"; }

i.icon.unhide:before {
  content: "\f06e"; }

i.icon.hide:before {
  content: "\f070"; }

i.icon.random:before {
  content: "\f074"; }

i.icon.retweet:before {
  content: "\f079"; }

i.icon.sign.out:before {
  content: "\f08b"; }

i.icon.pin:before {
  content: "\f08d"; }

i.icon.sign.in:before {
  content: "\f090"; }

i.icon.upload:before {
  content: "\f093"; }

i.icon.call:before {
  content: "\f095"; }

i.icon.remove.bookmark:before {
  content: "\f097"; }

i.icon.call.square:before {
  content: "\f098"; }

i.icon.unlock:before {
  content: "\f09c"; }

i.icon.configure:before {
  content: "\f0ad"; }

i.icon.filter:before {
  content: "\f0b0"; }

i.icon.wizard:before {
  content: "\f0d0"; }

i.icon.undo:before {
  content: "\f0e2"; }

i.icon.exchange:before {
  content: "\f0ec"; }

i.icon.cloud.download:before {
  content: "\f0ed"; }

i.icon.cloud.upload:before {
  content: "\f0ee"; }

i.icon.reply:before {
  content: "\f112"; }

i.icon.reply.all:before {
  content: "\f122"; }

i.icon.erase:before {
  content: "\f12d"; }

i.icon.unlock.alternate:before {
  content: "\f13e"; }

i.icon.write.square:before {
  content: "\f14b"; }

i.icon.share.square:before {
  content: "\f14d"; }

i.icon.archive:before {
  content: "\f187"; }

i.icon.translate:before {
  content: "\f1ab"; }

i.icon.recycle:before {
  content: "\f1b8"; }

i.icon.send:before {
  content: "\f1d8"; }

i.icon.send.outline:before {
  content: "\f1d9"; }

i.icon.share.alternate:before {
  content: "\f1e0"; }

i.icon.share.alternate.square:before {
  content: "\f1e1"; }

i.icon.add.to.cart:before {
  content: "\f217"; }

i.icon.in.cart:before {
  content: "\f218"; }

i.icon.add.user:before {
  content: "\f234"; }

i.icon.remove.user:before {
  content: "\f235"; }

i.icon.object.group:before {
  content: "\f247"; }

i.icon.object.ungroup:before {
  content: "\f248"; }

i.icon.clone:before {
  content: "\f24d"; }

i.icon.talk:before {
  content: "\f27a"; }

i.icon.talk.outline:before {
  content: "\f27b"; }

i.icon.help.circle:before {
  content: "\f059"; }

i.icon.info.circle:before {
  content: "\f05a"; }

i.icon.warning.circle:before {
  content: "\f06a"; }

i.icon.warning.sign:before {
  content: "\f071"; }

i.icon.announcement:before {
  content: "\f0a1"; }

i.icon.help:before {
  content: "\f128"; }

i.icon.info:before {
  content: "\f129"; }

i.icon.warning:before {
  content: "\f12a"; }

i.icon.birthday:before {
  content: "\f1fd"; }

i.icon.help.circle.outline:before {
  content: "\f29c"; }

i.icon.user:before {
  content: "\f007"; }

i.icon.users:before {
  content: "\f0c0"; }

i.icon.doctor:before {
  content: "\f0f0"; }

i.icon.handicap:before {
  content: "\f193"; }

i.icon.student:before {
  content: "\f19d"; }

i.icon.child:before {
  content: "\f1ae"; }

i.icon.spy:before {
  content: "\f21b"; }

i.icon.user.circle:before {
  content: "\f2bd"; }

i.icon.user.circle.outline:before {
  content: "\f2be"; }

i.icon.user.outline:before {
  content: "\f2c0"; }

i.icon.female:before {
  content: "\f182"; }

i.icon.male:before {
  content: "\f183"; }

i.icon.woman:before {
  content: "\f221"; }

i.icon.man:before {
  content: "\f222"; }

i.icon.non.binary.transgender:before {
  content: "\f223"; }

i.icon.intergender:before {
  content: "\f224"; }

i.icon.transgender:before {
  content: "\f225"; }

i.icon.lesbian:before {
  content: "\f226"; }

i.icon.gay:before {
  content: "\f227"; }

i.icon.heterosexual:before {
  content: "\f228"; }

i.icon.other.gender:before {
  content: "\f229"; }

i.icon.other.gender.vertical:before {
  content: "\f22a"; }

i.icon.other.gender.horizontal:before {
  content: "\f22b"; }

i.icon.neuter:before {
  content: "\f22c"; }

i.icon.genderless:before {
  content: "\f22d"; }

i.icon.universal.access:before {
  content: "\f29a"; }

i.icon.wheelchair:before {
  content: "\f29b"; }

i.icon.blind:before {
  content: "\f29d"; }

i.icon.audio.description:before {
  content: "\f29e"; }

i.icon.volume.control.phone:before {
  content: "\f2a0"; }

i.icon.braille:before {
  content: "\f2a1"; }

i.icon.asl:before {
  content: "\f2a3"; }

i.icon.assistive.listening.systems:before {
  content: "\f2a2"; }

i.icon.deafness:before {
  content: "\f2a4"; }

i.icon.sign.language:before {
  content: "\f2a7"; }

i.icon.low.vision:before {
  content: "\f2a8"; }

i.icon.block.layout:before {
  content: "\f009"; }

i.icon.grid.layout:before {
  content: "\f00a"; }

i.icon.list.layout:before {
  content: "\f00b"; }

i.icon.zoom:before {
  content: "\f00e"; }

i.icon.zoom.out:before {
  content: "\f010"; }

i.icon.resize.vertical:before {
  content: "\f07d"; }

i.icon.resize.horizontal:before {
  content: "\f07e"; }

i.icon.maximize:before {
  content: "\f0b2"; }

i.icon.crop:before {
  content: "\f125"; }

i.icon.cocktail:before {
  content: "\f000"; }

i.icon.road:before {
  content: "\f018"; }

i.icon.flag:before {
  content: "\f024"; }

i.icon.book:before {
  content: "\f02d"; }

i.icon.gift:before {
  content: "\f06b"; }

i.icon.leaf:before {
  content: "\f06c"; }

i.icon.fire:before {
  content: "\f06d"; }

i.icon.plane:before {
  content: "\f072"; }

i.icon.magnet:before {
  content: "\f076"; }

i.icon.lemon:before {
  content: "\f094"; }

i.icon.world:before {
  content: "\f0ac"; }

i.icon.travel:before {
  content: "\f0b1"; }

i.icon.shipping:before {
  content: "\f0d1"; }

i.icon.money:before {
  content: "\f0d6"; }

i.icon.legal:before {
  content: "\f0e3"; }

i.icon.lightning:before {
  content: "\f0e7"; }

i.icon.umbrella:before {
  content: "\f0e9"; }

i.icon.treatment:before {
  content: "\f0f1"; }

i.icon.suitcase:before {
  content: "\f0f2"; }

i.icon.bar:before {
  content: "\f0fc"; }

i.icon.flag.outline:before {
  content: "\f11d"; }

i.icon.flag.checkered:before {
  content: "\f11e"; }

i.icon.puzzle:before {
  content: "\f12e"; }

i.icon.fire.extinguisher:before {
  content: "\f134"; }

i.icon.rocket:before {
  content: "\f135"; }

i.icon.anchor:before {
  content: "\f13d"; }

i.icon.bullseye:before {
  content: "\f140"; }

i.icon.sun:before {
  content: "\f185"; }

i.icon.moon:before {
  content: "\f186"; }

i.icon.fax:before {
  content: "\f1ac"; }

i.icon.life.ring:before {
  content: "\f1cd"; }

i.icon.bomb:before {
  content: "\f1e2"; }

i.icon.soccer:before {
  content: "\f1e3"; }

i.icon.calculator:before {
  content: "\f1ec"; }

i.icon.diamond:before {
  content: "\f219"; }

i.icon.sticky.note:before {
  content: "\f249"; }

i.icon.sticky.note.outline:before {
  content: "\f24a"; }

i.icon.law:before {
  content: "\f24e"; }

i.icon.hand.peace:before {
  content: "\f25b"; }

i.icon.hand.rock:before {
  content: "\f255"; }

i.icon.hand.paper:before {
  content: "\f256"; }

i.icon.hand.scissors:before {
  content: "\f257"; }

i.icon.hand.lizard:before {
  content: "\f258"; }

i.icon.hand.spock:before {
  content: "\f259"; }

i.icon.tv:before {
  content: "\f26c"; }

i.icon.thermometer.full:before {
  content: "\f2c7"; }

i.icon.thermometer.three.quarters:before {
  content: "\f2c8"; }

i.icon.thermometer.half:before {
  content: "\f2c9"; }

i.icon.thermometer.quarter:before {
  content: "\f2ca"; }

i.icon.thermometer.empty:before {
  content: "\f2cb"; }

i.icon.shower:before {
  content: "\f2cc"; }

i.icon.bathtub:before {
  content: "\f2cd"; }

i.icon.snowflake:before {
  content: "\f2dc"; }

i.icon.crosshairs:before {
  content: "\f05b"; }

i.icon.asterisk:before {
  content: "\f069"; }

i.icon.square.outline:before {
  content: "\f096"; }

i.icon.certificate:before {
  content: "\f0a3"; }

i.icon.square:before {
  content: "\f0c8"; }

i.icon.quote.left:before {
  content: "\f10d"; }

i.icon.quote.right:before {
  content: "\f10e"; }

i.icon.spinner:before {
  content: "\f110"; }

i.icon.circle:before {
  content: "\f111"; }

i.icon.ellipsis.horizontal:before {
  content: "\f141"; }

i.icon.ellipsis.vertical:before {
  content: "\f142"; }

i.icon.cube:before {
  content: "\f1b2"; }

i.icon.cubes:before {
  content: "\f1b3"; }

i.icon.circle.notched:before {
  content: "\f1ce"; }

i.icon.circle.thin:before {
  content: "\f1db"; }

i.icon.checkmark:before {
  content: "\f00c"; }

i.icon.remove:before {
  content: "\f00d"; }

i.icon.checkmark.box:before {
  content: "\f046"; }

i.icon.move:before {
  content: "\f047"; }

i.icon.add.circle:before {
  content: "\f055"; }

i.icon.minus.circle:before {
  content: "\f056"; }

i.icon.remove.circle:before {
  content: "\f057"; }

i.icon.check.circle:before {
  content: "\f058"; }

i.icon.remove.circle.outline:before {
  content: "\f05c"; }

i.icon.check.circle.outline:before {
  content: "\f05d"; }

i.icon.plus:before {
  content: "\f067"; }

i.icon.minus:before {
  content: "\f068"; }

i.icon.add.square:before {
  content: "\f0fe"; }

i.icon.radio:before {
  content: "\f10c"; }

i.icon.minus.square:before {
  content: "\f146"; }

i.icon.minus.square.outline:before {
  content: "\f147"; }

i.icon.check.square:before {
  content: "\f14a"; }

i.icon.selected.radio:before {
  content: "\f192"; }

i.icon.plus.square.outline:before {
  content: "\f196"; }

i.icon.toggle.off:before {
  content: "\f204"; }

i.icon.toggle.on:before {
  content: "\f205"; }

i.icon.film:before {
  content: "\f008"; }

i.icon.sound:before {
  content: "\f025"; }

i.icon.photo:before {
  content: "\f030"; }

i.icon.bar.chart:before {
  content: "\f080"; }

i.icon.camera.retro:before {
  content: "\f083"; }

i.icon.newspaper:before {
  content: "\f1ea"; }

i.icon.area.chart:before {
  content: "\f1fe"; }

i.icon.pie.chart:before {
  content: "\f200"; }

i.icon.line.chart:before {
  content: "\f201"; }

i.icon.arrow.circle.outline.down:before {
  content: "\f01a"; }

i.icon.arrow.circle.outline.up:before {
  content: "\f01b"; }

i.icon.chevron.left:before {
  content: "\f053"; }

i.icon.chevron.right:before {
  content: "\f054"; }

i.icon.arrow.left:before {
  content: "\f060"; }

i.icon.arrow.right:before {
  content: "\f061"; }

i.icon.arrow.up:before {
  content: "\f062"; }

i.icon.arrow.down:before {
  content: "\f063"; }

i.icon.chevron.up:before {
  content: "\f077"; }

i.icon.chevron.down:before {
  content: "\f078"; }

i.icon.pointing.right:before {
  content: "\f0a4"; }

i.icon.pointing.left:before {
  content: "\f0a5"; }

i.icon.pointing.up:before {
  content: "\f0a6"; }

i.icon.pointing.down:before {
  content: "\f0a7"; }

i.icon.arrow.circle.left:before {
  content: "\f0a8"; }

i.icon.arrow.circle.right:before {
  content: "\f0a9"; }

i.icon.arrow.circle.up:before {
  content: "\f0aa"; }

i.icon.arrow.circle.down:before {
  content: "\f0ab"; }

i.icon.caret.down:before {
  content: "\f0d7"; }

i.icon.caret.up:before {
  content: "\f0d8"; }

i.icon.caret.left:before {
  content: "\f0d9"; }

i.icon.caret.right:before {
  content: "\f0da"; }

i.icon.angle.double.left:before {
  content: "\f100"; }

i.icon.angle.double.right:before {
  content: "\f101"; }

i.icon.angle.double.up:before {
  content: "\f102"; }

i.icon.angle.double.down:before {
  content: "\f103"; }

i.icon.angle.left:before {
  content: "\f104"; }

i.icon.angle.right:before {
  content: "\f105"; }

i.icon.angle.up:before {
  content: "\f106"; }

i.icon.angle.down:before {
  content: "\f107"; }

i.icon.chevron.circle.left:before {
  content: "\f137"; }

i.icon.chevron.circle.right:before {
  content: "\f138"; }

i.icon.chevron.circle.up:before {
  content: "\f139"; }

i.icon.chevron.circle.down:before {
  content: "\f13a"; }

i.icon.toggle.down:before {
  content: "\f150"; }

i.icon.toggle.up:before {
  content: "\f151"; }

i.icon.toggle.right:before {
  content: "\f152"; }

i.icon.long.arrow.down:before {
  content: "\f175"; }

i.icon.long.arrow.up:before {
  content: "\f176"; }

i.icon.long.arrow.left:before {
  content: "\f177"; }

i.icon.long.arrow.right:before {
  content: "\f178"; }

i.icon.arrow.circle.outline.right:before {
  content: "\f18e"; }

i.icon.arrow.circle.outline.left:before {
  content: "\f190"; }

i.icon.toggle.left:before {
  content: "\f191"; }

i.icon.tablet:before {
  content: "\f10a"; }

i.icon.mobile:before {
  content: "\f10b"; }

i.icon.battery.full:before {
  content: "\f240"; }

i.icon.battery.high:before {
  content: "\f241"; }

i.icon.battery.medium:before {
  content: "\f242"; }

i.icon.battery.low:before {
  content: "\f243"; }

i.icon.battery.empty:before {
  content: "\f244"; }

i.icon.power:before {
  content: "\f011"; }

i.icon.trash.outline:before {
  content: "\f014"; }

i.icon.disk.outline:before {
  content: "\f0a0"; }

i.icon.desktop:before {
  content: "\f108"; }

i.icon.laptop:before {
  content: "\f109"; }

i.icon.game:before {
  content: "\f11b"; }

i.icon.keyboard:before {
  content: "\f11c"; }

i.icon.plug:before {
  content: "\f1e6"; }

i.icon.trash:before {
  content: "\f1f8"; }

i.icon.file.outline:before {
  content: "\f016"; }

i.icon.folder:before {
  content: "\f07b"; }

i.icon.folder.open:before {
  content: "\f07c"; }

i.icon.file.text.outline:before {
  content: "\f0f6"; }

i.icon.folder.outline:before {
  content: "\f114"; }

i.icon.folder.open.outline:before {
  content: "\f115"; }

i.icon.level.up:before {
  content: "\f148"; }

i.icon.level.down:before {
  content: "\f149"; }

i.icon.file:before {
  content: "\f15b"; }

i.icon.file.text:before {
  content: "\f15c"; }

i.icon.file.pdf.outline:before {
  content: "\f1c1"; }

i.icon.file.word.outline:before {
  content: "\f1c2"; }

i.icon.file.excel.outline:before {
  content: "\f1c3"; }

i.icon.file.powerpoint.outline:before {
  content: "\f1c4"; }

i.icon.file.image.outline:before {
  content: "\f1c5"; }

i.icon.file.archive.outline:before {
  content: "\f1c6"; }

i.icon.file.audio.outline:before {
  content: "\f1c7"; }

i.icon.file.video.outline:before {
  content: "\f1c8"; }

i.icon.file.code.outline:before {
  content: "\f1c9"; }

i.icon.qrcode:before {
  content: "\f029"; }

i.icon.barcode:before {
  content: "\f02a"; }

i.icon.rss:before {
  content: "\f09e"; }

i.icon.fork:before {
  content: "\f126"; }

i.icon.html5:before {
  content: "\f13b"; }

i.icon.css3:before {
  content: "\f13c"; }

i.icon.rss.square:before {
  content: "\f143"; }

i.icon.openid:before {
  content: "\f19b"; }

i.icon.database:before {
  content: "\f1c0"; }

i.icon.wifi:before {
  content: "\f1eb"; }

i.icon.server:before {
  content: "\f233"; }

i.icon.usb:before {
  content: "\f287"; }

i.icon.bluetooth:before {
  content: "\f293"; }

i.icon.bluetooth.alternative:before {
  content: "\f294"; }

i.icon.microchip:before {
  content: "\f2db"; }

i.icon.heart:before {
  content: "\f004"; }

i.icon.star:before {
  content: "\f005"; }

i.icon.empty.star:before {
  content: "\f006"; }

i.icon.thumbs.outline.up:before {
  content: "\f087"; }

i.icon.thumbs.outline.down:before {
  content: "\f088"; }

i.icon.star.half:before {
  content: "\f089"; }

i.icon.empty.heart:before {
  content: "\f08a"; }

i.icon.smile:before {
  content: "\f118"; }

i.icon.frown:before {
  content: "\f119"; }

i.icon.meh:before {
  content: "\f11a"; }

i.icon.star.half.empty:before {
  content: "\f123"; }

i.icon.thumbs.up:before {
  content: "\f164"; }

i.icon.thumbs.down:before {
  content: "\f165"; }

i.icon.music:before {
  content: "\f001"; }

i.icon.video.play.outline:before {
  content: "\f01d"; }

i.icon.volume.off:before {
  content: "\f026"; }

i.icon.volume.down:before {
  content: "\f027"; }

i.icon.volume.up:before {
  content: "\f028"; }

i.icon.record:before {
  content: "\f03d"; }

i.icon.step.backward:before {
  content: "\f048"; }

i.icon.fast.backward:before {
  content: "\f049"; }

i.icon.backward:before {
  content: "\f04a"; }

i.icon.play:before {
  content: "\f04b"; }

i.icon.pause:before {
  content: "\f04c"; }

i.icon.stop:before {
  content: "\f04d"; }

i.icon.forward:before {
  content: "\f04e"; }

i.icon.fast.forward:before {
  content: "\f050"; }

i.icon.step.forward:before {
  content: "\f051"; }

i.icon.eject:before {
  content: "\f052"; }

i.icon.unmute:before {
  content: "\f130"; }

i.icon.mute:before {
  content: "\f131"; }

i.icon.video.play:before {
  content: "\f144"; }

i.icon.closed.captioning:before {
  content: "\f20a"; }

i.icon.pause.circle:before {
  content: "\f28b"; }

i.icon.pause.circle.outline:before {
  content: "\f28c"; }

i.icon.stop.circle:before {
  content: "\f28d"; }

i.icon.stop.circle.outline:before {
  content: "\f28e"; }

i.icon.marker:before {
  content: "\f041"; }

i.icon.coffee:before {
  content: "\f0f4"; }

i.icon.food:before {
  content: "\f0f5"; }

i.icon.building.outline:before {
  content: "\f0f7"; }

i.icon.hospital:before {
  content: "\f0f8"; }

i.icon.emergency:before {
  content: "\f0f9"; }

i.icon.first.aid:before {
  content: "\f0fa"; }

i.icon.military:before {
  content: "\f0fb"; }

i.icon.h:before {
  content: "\f0fd"; }

i.icon.location.arrow:before {
  content: "\f124"; }

i.icon.compass:before {
  content: "\f14e"; }

i.icon.space.shuttle:before {
  content: "\f197"; }

i.icon.university:before {
  content: "\f19c"; }

i.icon.building:before {
  content: "\f1ad"; }

i.icon.paw:before {
  content: "\f1b0"; }

i.icon.spoon:before {
  content: "\f1b1"; }

i.icon.car:before {
  content: "\f1b9"; }

i.icon.taxi:before {
  content: "\f1ba"; }

i.icon.tree:before {
  content: "\f1bb"; }

i.icon.bicycle:before {
  content: "\f206"; }

i.icon.bus:before {
  content: "\f207"; }

i.icon.ship:before {
  content: "\f21a"; }

i.icon.motorcycle:before {
  content: "\f21c"; }

i.icon.street.view:before {
  content: "\f21d"; }

i.icon.hotel:before {
  content: "\f236"; }

i.icon.train:before {
  content: "\f238"; }

i.icon.subway:before {
  content: "\f239"; }

i.icon.map.pin:before {
  content: "\f276"; }

i.icon.map.signs:before {
  content: "\f277"; }

i.icon.map.outline:before {
  content: "\f278"; }

i.icon.map:before {
  content: "\f279"; }

i.icon.table:before {
  content: "\f0ce"; }

i.icon.columns:before {
  content: "\f0db"; }

i.icon.sort:before {
  content: "\f0dc"; }

i.icon.sort.descending:before {
  content: "\f0dd"; }

i.icon.sort.ascending:before {
  content: "\f0de"; }

i.icon.sort.alphabet.ascending:before {
  content: "\f15d"; }

i.icon.sort.alphabet.descending:before {
  content: "\f15e"; }

i.icon.sort.content.ascending:before {
  content: "\f160"; }

i.icon.sort.content.descending:before {
  content: "\f161"; }

i.icon.sort.numeric.ascending:before {
  content: "\f162"; }

i.icon.sort.numeric.descending:before {
  content: "\f163"; }

i.icon.font:before {
  content: "\f031"; }

i.icon.bold:before {
  content: "\f032"; }

i.icon.italic:before {
  content: "\f033"; }

i.icon.text.height:before {
  content: "\f034"; }

i.icon.text.width:before {
  content: "\f035"; }

i.icon.align.left:before {
  content: "\f036"; }

i.icon.align.center:before {
  content: "\f037"; }

i.icon.align.right:before {
  content: "\f038"; }

i.icon.align.justify:before {
  content: "\f039"; }

i.icon.list:before {
  content: "\f03a"; }

i.icon.outdent:before {
  content: "\f03b"; }

i.icon.indent:before {
  content: "\f03c"; }

i.icon.linkify:before {
  content: "\f0c1"; }

i.icon.cut:before {
  content: "\f0c4"; }

i.icon.copy:before {
  content: "\f0c5"; }

i.icon.attach:before {
  content: "\f0c6"; }

i.icon.save:before {
  content: "\f0c7"; }

i.icon.content:before {
  content: "\f0c9"; }

i.icon.unordered.list:before {
  content: "\f0ca"; }

i.icon.ordered.list:before {
  content: "\f0cb"; }

i.icon.strikethrough:before {
  content: "\f0cc"; }

i.icon.underline:before {
  content: "\f0cd"; }

i.icon.paste:before {
  content: "\f0ea"; }

i.icon.unlinkify:before {
  content: "\f127"; }

i.icon.superscript:before {
  content: "\f12b"; }

i.icon.subscript:before {
  content: "\f12c"; }

i.icon.header:before {
  content: "\f1dc"; }

i.icon.paragraph:before {
  content: "\f1dd"; }

i.icon.text.cursor:before {
  content: "\f246"; }

i.icon.euro:before {
  content: "\f153"; }

i.icon.pound:before {
  content: "\f154"; }

i.icon.dollar:before {
  content: "\f155"; }

i.icon.rupee:before {
  content: "\f156"; }

i.icon.yen:before {
  content: "\f157"; }

i.icon.ruble:before {
  content: "\f158"; }

i.icon.won:before {
  content: "\f159"; }

i.icon.bitcoin:before {
  content: "\f15a"; }

i.icon.lira:before {
  content: "\f195"; }

i.icon.shekel:before {
  content: "\f20b"; }

i.icon.paypal:before {
  content: "\f1ed"; }

i.icon.google.wallet:before {
  content: "\f1ee"; }

i.icon.visa:before {
  content: "\f1f0"; }

i.icon.mastercard:before {
  content: "\f1f1"; }

i.icon.discover:before {
  content: "\f1f2"; }

i.icon.american.express:before {
  content: "\f1f3"; }

i.icon.paypal.card:before {
  content: "\f1f4"; }

i.icon.stripe:before {
  content: "\f1f5"; }

i.icon.japan.credit.bureau:before {
  content: "\f24b"; }

i.icon.diners.club:before {
  content: "\f24c"; }

i.icon.credit.card.alternative:before {
  content: "\f283"; }

i.icon.twitter.square:before {
  content: "\f081"; }

i.icon.facebook.square:before {
  content: "\f082"; }

i.icon.linkedin.square:before {
  content: "\f08c"; }

i.icon.github.square:before {
  content: "\f092"; }

i.icon.twitter:before {
  content: "\f099"; }

i.icon.facebook.f:before {
  content: "\f09a"; }

i.icon.github:before {
  content: "\f09b"; }

i.icon.pinterest:before {
  content: "\f0d2"; }

i.icon.pinterest.square:before {
  content: "\f0d3"; }

i.icon.google.plus.square:before {
  content: "\f0d4"; }

i.icon.google.plus:before {
  content: "\f0d5"; }

i.icon.linkedin:before {
  content: "\f0e1"; }

i.icon.github.alternate:before {
  content: "\f113"; }

i.icon.maxcdn:before {
  content: "\f136"; }

i.icon.youtube.square:before {
  content: "\f166"; }

i.icon.youtube:before {
  content: "\f167"; }

i.icon.xing:before {
  content: "\f168"; }

i.icon.xing.square:before {
  content: "\f169"; }

i.icon.youtube.play:before {
  content: "\f16a"; }

i.icon.dropbox:before {
  content: "\f16b"; }

i.icon.stack.overflow:before {
  content: "\f16c"; }

i.icon.instagram:before {
  content: "\f16d"; }

i.icon.flickr:before {
  content: "\f16e"; }

i.icon.adn:before {
  content: "\f170"; }

i.icon.bitbucket:before {
  content: "\f171"; }

i.icon.bitbucket.square:before {
  content: "\f172"; }

i.icon.tumblr:before {
  content: "\f173"; }

i.icon.tumblr.square:before {
  content: "\f174"; }

i.icon.apple:before {
  content: "\f179"; }

i.icon.windows:before {
  content: "\f17a"; }

i.icon.android:before {
  content: "\f17b"; }

i.icon.linux:before {
  content: "\f17c"; }

i.icon.dribble:before {
  content: "\f17d"; }

i.icon.skype:before {
  content: "\f17e"; }

i.icon.foursquare:before {
  content: "\f180"; }

i.icon.trello:before {
  content: "\f181"; }

i.icon.gittip:before {
  content: "\f184"; }

i.icon.vk:before {
  content: "\f189"; }

i.icon.weibo:before {
  content: "\f18a"; }

i.icon.renren:before {
  content: "\f18b"; }

i.icon.pagelines:before {
  content: "\f18c"; }

i.icon.stack.exchange:before {
  content: "\f18d"; }

i.icon.vimeo.square:before {
  content: "\f194"; }

i.icon.slack:before {
  content: "\f198"; }

i.icon.wordpress:before {
  content: "\f19a"; }

i.icon.yahoo:before {
  content: "\f19e"; }

i.icon.google:before {
  content: "\f1a0"; }

i.icon.reddit:before {
  content: "\f1a1"; }

i.icon.reddit.square:before {
  content: "\f1a2"; }

i.icon.stumbleupon.circle:before {
  content: "\f1a3"; }

i.icon.stumbleupon:before {
  content: "\f1a4"; }

i.icon.delicious:before {
  content: "\f1a5"; }

i.icon.digg:before {
  content: "\f1a6"; }

i.icon.pied.piper:before {
  content: "\f1a7"; }

i.icon.pied.piper.alternate:before {
  content: "\f1a8"; }

i.icon.drupal:before {
  content: "\f1a9"; }

i.icon.joomla:before {
  content: "\f1aa"; }

i.icon.behance:before {
  content: "\f1b4"; }

i.icon.behance.square:before {
  content: "\f1b5"; }

i.icon.steam:before {
  content: "\f1b6"; }

i.icon.steam.square:before {
  content: "\f1b7"; }

i.icon.spotify:before {
  content: "\f1bc"; }

i.icon.deviantart:before {
  content: "\f1bd"; }

i.icon.soundcloud:before {
  content: "\f1be"; }

i.icon.vine:before {
  content: "\f1ca"; }

i.icon.codepen:before {
  content: "\f1cb"; }

i.icon.jsfiddle:before {
  content: "\f1cc"; }

i.icon.rebel:before {
  content: "\f1d0"; }

i.icon.empire:before {
  content: "\f1d1"; }

i.icon.git.square:before {
  content: "\f1d2"; }

i.icon.git:before {
  content: "\f1d3"; }

i.icon.hacker.news:before {
  content: "\f1d4"; }

i.icon.tencent.weibo:before {
  content: "\f1d5"; }

i.icon.qq:before {
  content: "\f1d6"; }

i.icon.wechat:before {
  content: "\f1d7"; }

i.icon.slideshare:before {
  content: "\f1e7"; }

i.icon.twitch:before {
  content: "\f1e8"; }

i.icon.yelp:before {
  content: "\f1e9"; }

i.icon.lastfm:before {
  content: "\f202"; }

i.icon.lastfm.square:before {
  content: "\f203"; }

i.icon.ioxhost:before {
  content: "\f208"; }

i.icon.angellist:before {
  content: "\f209"; }

i.icon.meanpath:before {
  content: "\f20c"; }

i.icon.buysellads:before {
  content: "\f20d"; }

i.icon.connectdevelop:before {
  content: "\f20e"; }

i.icon.dashcube:before {
  content: "\f210"; }

i.icon.forumbee:before {
  content: "\f211"; }

i.icon.leanpub:before {
  content: "\f212"; }

i.icon.sellsy:before {
  content: "\f213"; }

i.icon.shirtsinbulk:before {
  content: "\f214"; }

i.icon.simplybuilt:before {
  content: "\f215"; }

i.icon.skyatlas:before {
  content: "\f216"; }

i.icon.facebook:before {
  content: "\f230"; }

i.icon.pinterest:before {
  content: "\f231"; }

i.icon.whatsapp:before {
  content: "\f232"; }

i.icon.viacoin:before {
  content: "\f237"; }

i.icon.medium:before {
  content: "\f23a"; }

i.icon.y.combinator:before {
  content: "\f23b"; }

i.icon.optinmonster:before {
  content: "\f23c"; }

i.icon.opencart:before {
  content: "\f23d"; }

i.icon.expeditedssl:before {
  content: "\f23e"; }

i.icon.gg:before {
  content: "\f260"; }

i.icon.gg.circle:before {
  content: "\f261"; }

i.icon.tripadvisor:before {
  content: "\f262"; }

i.icon.odnoklassniki:before {
  content: "\f263"; }

i.icon.odnoklassniki.square:before {
  content: "\f264"; }

i.icon.pocket:before {
  content: "\f265"; }

i.icon.wikipedia:before {
  content: "\f266"; }

i.icon.safari:before {
  content: "\f267"; }

i.icon.chrome:before {
  content: "\f268"; }

i.icon.firefox:before {
  content: "\f269"; }

i.icon.opera:before {
  content: "\f26a"; }

i.icon.internet.explorer:before {
  content: "\f26b"; }

i.icon.contao:before {
  content: "\f26d"; }

i.icon.500px:before {
  content: "\f26e"; }

i.icon.amazon:before {
  content: "\f270"; }

i.icon.houzz:before {
  content: "\f27c"; }

i.icon.vimeo:before {
  content: "\f27d"; }

i.icon.black.tie:before {
  content: "\f27e"; }

i.icon.fonticons:before {
  content: "\f280"; }

i.icon.reddit.alien:before {
  content: "\f281"; }

i.icon.microsoft.edge:before {
  content: "\f282"; }

i.icon.codiepie:before {
  content: "\f284"; }

i.icon.modx:before {
  content: "\f285"; }

i.icon.fort.awesome:before {
  content: "\f286"; }

i.icon.product.hunt:before {
  content: "\f288"; }

i.icon.mixcloud:before {
  content: "\f289"; }

i.icon.scribd:before {
  content: "\f28a"; }

i.icon.gitlab:before {
  content: "\f296"; }

i.icon.wpbeginner:before {
  content: "\f297"; }

i.icon.wpforms:before {
  content: "\f298"; }

i.icon.envira.gallery:before {
  content: "\f299"; }

i.icon.glide:before {
  content: "\f2a5"; }

i.icon.glide.g:before {
  content: "\f2a6"; }

i.icon.viadeo:before {
  content: "\f2a9"; }

i.icon.viadeo.square:before {
  content: "\f2aa"; }

i.icon.snapchat:before {
  content: "\f2ab"; }

i.icon.snapchat.ghost:before {
  content: "\f2ac"; }

i.icon.snapchat.square:before {
  content: "\f2ad"; }

i.icon.pied.piper.hat:before {
  content: "\f2ae"; }

i.icon.first.order:before {
  content: "\f2b0"; }

i.icon.yoast:before {
  content: "\f2b1"; }

i.icon.themeisle:before {
  content: "\f2b2"; }

i.icon.google.plus.circle:before {
  content: "\f2b3"; }

i.icon.font.awesome:before {
  content: "\f2b4"; }

i.icon.linode:before {
  content: "\f2b8"; }

i.icon.quora:before {
  content: "\f2c4"; }

i.icon.free.code.camp:before {
  content: "\f2c5"; }

i.icon.telegram:before {
  content: "\f2c6"; }

i.icon.bandcamp:before {
  content: "\f2d5"; }

i.icon.grav:before {
  content: "\f2d6"; }

i.icon.etsy:before {
  content: "\f2d7"; }

i.icon.imdb:before {
  content: "\f2d8"; }

i.icon.ravelry:before {
  content: "\f2d9"; }

i.icon.eercast:before {
  content: "\f2da"; }

i.icon.superpowers:before {
  content: "\f2dd"; }

i.icon.wpexplorer:before {
  content: "\f2de"; }

i.icon.meetup:before {
  content: "\f2e0"; }

i.icon.like:before {
  content: "\f004"; }

i.icon.favorite:before {
  content: "\f005"; }

i.icon.video:before {
  content: "\f008"; }

i.icon.check:before {
  content: "\f00c"; }

i.icon.close:before, i.icon.cancel:before, i.icon.delete:before, i.icon.x:before {
  content: "\f00d"; }

i.icon.zoom.in:before, i.icon.magnify:before {
  content: "\f00e"; }

i.icon.shutdown:before {
  content: "\f011"; }

i.icon.clock:before, i.icon.time:before {
  content: "\f017"; }

i.icon.play.circle.outline:before {
  content: "\f01d"; }

i.icon.headphone:before {
  content: "\f025"; }

i.icon.camera:before {
  content: "\f030"; }

i.icon.video.camera:before {
  content: "\f03d"; }

i.icon.picture:before {
  content: "\f03e"; }

i.icon.pencil:before, i.icon.compose:before {
  content: "\f040"; }

i.icon.point:before {
  content: "\f041"; }

i.icon.tint:before {
  content: "\f043"; }

i.icon.signup:before {
  content: "\f044"; }

i.icon.plus.circle:before {
  content: "\f055"; }

i.icon.question.circle:before {
  content: "\f059"; }

i.icon.dont:before {
  content: "\f05e"; }

i.icon.minimize:before {
  content: "\f066"; }

i.icon.add:before {
  content: "\f067"; }

i.icon.exclamation.circle:before, i.icon.attention:before {
  content: "\f06a"; }

i.icon.eye:before {
  content: "\f06e"; }

i.icon.exclamation.triangle:before {
  content: "\f071"; }

i.icon.shuffle:before {
  content: "\f074"; }

i.icon.chat:before {
  content: "\f075"; }

i.icon.cart:before, i.icon.shopping.cart:before {
  content: "\f07a"; }

i.icon.bar.graph:before {
  content: "\f080"; }

i.icon.key:before {
  content: "\f084"; }

i.icon.cogs:before {
  content: "\f085"; }

i.icon.discussions:before {
  content: "\f086"; }

i.icon.like.outline:before {
  content: "\f087"; }

i.icon.dislike.outline:before {
  content: "\f088"; }

i.icon.heart.outline:before {
  content: "\f08a"; }

i.icon.log.out:before {
  content: "\f08b"; }

i.icon.thumb.tack:before {
  content: "\f08d"; }

i.icon.winner:before {
  content: "\f091"; }

i.icon.phone:before {
  content: "\f095"; }

i.icon.bookmark.outline:before {
  content: "\f097"; }

i.icon.phone.square:before {
  content: "\f098"; }

i.icon.credit.card:before {
  content: "\f09d"; }

i.icon.hdd.outline:before {
  content: "\f0a0"; }

i.icon.bullhorn:before {
  content: "\f0a1"; }

i.icon.bell.outline:before {
  content: "\f0a2"; }

i.icon.hand.outline.right:before {
  content: "\f0a4"; }

i.icon.hand.outline.left:before {
  content: "\f0a5"; }

i.icon.hand.outline.up:before {
  content: "\f0a6"; }

i.icon.hand.outline.down:before {
  content: "\f0a7"; }

i.icon.globe:before {
  content: "\f0ac"; }

i.icon.wrench:before {
  content: "\f0ad"; }

i.icon.briefcase:before {
  content: "\f0b1"; }

i.icon.group:before {
  content: "\f0c0"; }

i.icon.linkify:before, i.icon.chain:before {
  content: "\f0c1"; }

i.icon.flask:before {
  content: "\f0c3"; }

i.icon.sidebar:before, i.icon.bars:before {
  content: "\f0c9"; }

i.icon.list.ul:before {
  content: "\f0ca"; }

i.icon.list.ol:before {
  content: "\f0cb"; }

i.icon.numbered.list:before {
  content: "\f0cb"; }

i.icon.magic:before {
  content: "\f0d0"; }

i.icon.truck:before {
  content: "\f0d1"; }

i.icon.currency:before {
  content: "\f0d6"; }

i.icon.triangle.down:before, i.icon.dropdown:before {
  content: "\f0d7"; }

i.icon.triangle.up:before {
  content: "\f0d8"; }

i.icon.triangle.left:before {
  content: "\f0d9"; }

i.icon.triangle.right:before {
  content: "\f0da"; }

i.icon.envelope:before {
  content: "\f0e0"; }

i.icon.conversation:before {
  content: "\f0e6"; }

i.icon.rain:before {
  content: "\f0e9"; }

i.icon.clipboard:before {
  content: "\f0ea"; }

i.icon.lightbulb:before {
  content: "\f0eb"; }

i.icon.bell:before {
  content: "\f0f3"; }

i.icon.ambulance:before {
  content: "\f0f9"; }

i.icon.medkit:before {
  content: "\f0fa"; }

i.icon.fighter.jet:before {
  content: "\f0fb"; }

i.icon.beer:before {
  content: "\f0fc"; }

i.icon.plus.square:before {
  content: "\f0fe"; }

i.icon.computer:before {
  content: "\f108"; }

i.icon.circle.outline:before {
  content: "\f10c"; }

i.icon.gamepad:before {
  content: "\f11b"; }

i.icon.star.half.full:before {
  content: "\f123"; }

i.icon.broken.chain:before {
  content: "\f127"; }

i.icon.question:before {
  content: "\f128"; }

i.icon.exclamation:before {
  content: "\f12a"; }

i.icon.eraser:before {
  content: "\f12d"; }

i.icon.microphone:before {
  content: "\f130"; }

i.icon.microphone.slash:before {
  content: "\f131"; }

i.icon.shield:before {
  content: "\f132"; }

i.icon.target:before {
  content: "\f140"; }

i.icon.play.circle:before {
  content: "\f144"; }

i.icon.pencil.square:before {
  content: "\f14b"; }

i.icon.eur:before {
  content: "\f153"; }

i.icon.gbp:before {
  content: "\f154"; }

i.icon.usd:before {
  content: "\f155"; }

i.icon.inr:before {
  content: "\f156"; }

i.icon.cny:before, i.icon.rmb:before, i.icon.jpy:before {
  content: "\f157"; }

i.icon.rouble:before, i.icon.rub:before {
  content: "\f158"; }

i.icon.krw:before {
  content: "\f159"; }

i.icon.btc:before {
  content: "\f15a"; }

i.icon.gratipay:before {
  content: "\f184"; }

i.icon.zip:before {
  content: "\f187"; }

i.icon.dot.circle.outline:before {
  content: "\f192"; }

i.icon.try:before {
  content: "\f195"; }

i.icon.graduation:before {
  content: "\f19d"; }

i.icon.circle.outline:before {
  content: "\f1db"; }

i.icon.sliders:before {
  content: "\f1de"; }

i.icon.weixin:before {
  content: "\f1d7"; }

i.icon.tty:before, i.icon.teletype:before {
  content: "\f1e4"; }

i.icon.binoculars:before {
  content: "\f1e5"; }

i.icon.power.cord:before {
  content: "\f1e6"; }

i.icon.wi-fi:before {
  content: "\f1eb"; }

i.icon.visa.card:before {
  content: "\f1f0"; }

i.icon.mastercard.card:before {
  content: "\f1f1"; }

i.icon.discover.card:before {
  content: "\f1f2"; }

i.icon.amex:before, i.icon.american.express.card:before {
  content: "\f1f3"; }

i.icon.stripe.card:before {
  content: "\f1f5"; }

i.icon.bell.slash:before {
  content: "\f1f6"; }

i.icon.bell.slash.outline:before {
  content: "\f1f7"; }

i.icon.area.graph:before {
  content: "\f1fe"; }

i.icon.pie.graph:before {
  content: "\f200"; }

i.icon.line.graph:before {
  content: "\f201"; }

i.icon.cc:before {
  content: "\f20a"; }

i.icon.sheqel:before, i.icon.ils:before {
  content: "\f20b"; }

i.icon.plus.cart:before {
  content: "\f217"; }

i.icon.arrow.down.cart:before {
  content: "\f218"; }

i.icon.detective:before {
  content: "\f21b"; }

i.icon.venus:before {
  content: "\f221"; }

i.icon.mars:before {
  content: "\f222"; }

i.icon.mercury:before {
  content: "\f223"; }

i.icon.intersex:before {
  content: "\f224"; }

i.icon.venus.double:before, i.icon.female.homosexual:before {
  content: "\f226"; }

i.icon.mars.double:before, i.icon.male.homosexual:before {
  content: "\f227"; }

i.icon.venus.mars:before {
  content: "\f228"; }

i.icon.mars.stroke:before, i.icon.mars.alternate:before {
  content: "\f229"; }

i.icon.mars.vertical:before, i.icon.mars.stroke.vertical:before {
  content: "\f22a"; }

i.icon.mars.horizontal:before, i.icon.mars.stroke.horizontal:before {
  content: "\f22b"; }

i.icon.asexual:before {
  content: "\f22d"; }

i.icon.facebook.official:before {
  content: "\f230"; }

i.icon.user.plus:before {
  content: "\f234"; }

i.icon.user.times:before, i.icon.user.close:before, i.icon.user.cancel:before, i.icon.user.delete:before, i.icon.user.x:before {
  content: "\f235"; }

i.icon.bed:before {
  content: "\f236"; }

i.icon.yc:before, i.icon.ycombinator:before {
  content: "\f23b"; }

i.icon.battery.four:before {
  content: "\f240"; }

i.icon.battery.three:before, i.icon.battery.three.quarters:before {
  content: "\f241"; }

i.icon.battery.two:before, i.icon.battery.half:before {
  content: "\f242"; }

i.icon.battery.one:before, i.icon.battery.quarter:before {
  content: "\f243"; }

i.icon.battery.zero:before {
  content: "\f244"; }

i.icon.i.cursor:before {
  content: "\f246"; }

i.icon.jcb:before, i.icon.japan.credit.bureau.card:before {
  content: "\f24b"; }

i.icon.diners.club.card:before {
  content: "\f24c"; }

i.icon.balance:before {
  content: "\f24e"; }

i.icon.hourglass.outline:before, i.icon.hourglass.zero:before {
  content: "\f250"; }

i.icon.hourglass.one:before {
  content: "\f251"; }

i.icon.hourglass.two:before {
  content: "\f252"; }

i.icon.hourglass.three:before {
  content: "\f253"; }

i.icon.hourglass.four:before {
  content: "\f254"; }

i.icon.grab:before {
  content: "\f255"; }

i.icon.hand.victory:before {
  content: "\f25b"; }

i.icon.tm:before {
  content: "\f25c"; }

i.icon.r.circle:before {
  content: "\f25d"; }

i.icon.television:before {
  content: "\f26c"; }

i.icon.five.hundred.pixels:before {
  content: "\f26e"; }

i.icon.calendar.plus:before {
  content: "\f271"; }

i.icon.calendar.minus:before {
  content: "\f272"; }

i.icon.calendar.times:before {
  content: "\f273"; }

i.icon.calendar.check:before {
  content: "\f274"; }

i.icon.factory:before {
  content: "\f275"; }

i.icon.commenting:before {
  content: "\f27a"; }

i.icon.commenting.outline:before {
  content: "\f27b"; }

i.icon.edge:before, i.icon.ms.edge:before {
  content: "\f282"; }

i.icon.wordpress.beginner:before {
  content: "\f297"; }

i.icon.wordpress.forms:before {
  content: "\f298"; }

i.icon.envira:before {
  content: "\f299"; }

i.icon.question.circle.outline:before {
  content: "\f29c"; }

i.icon.assistive.listening.devices:before, i.icon.als:before, i.icon.ald:before {
  content: "\f2a2"; }

i.icon.asl.interpreting:before {
  content: "\f2a3"; }

i.icon.deaf:before {
  content: "\f2a4"; }

i.icon.american.sign.language.interpreting:before {
  content: "\f2a3"; }

i.icon.hard.of.hearing:before {
  content: "\f2a4"; }

i.icon.signing:before {
  content: "\f2a7"; }

i.icon.new.pied.piper:before {
  content: "\f2ae"; }

i.icon.theme.isle:before {
  content: "\f2b2"; }

i.icon.google.plus.official:before {
  content: "\f2b3"; }

i.icon.fa:before {
  content: "\f2b4"; }

i.icon.vcard:before {
  content: "\f2bb"; }

i.icon.vcard.outline:before {
  content: "\f2bc"; }

i.icon.drivers.license:before {
  content: "\f2c2"; }

i.icon.drivers.license.outline:before {
  content: "\f2c3"; }

i.icon.thermometer:before {
  content: "\f2c7"; }

i.icon.s15:before, i.icon.bath:before {
  content: "\f2cd"; }

i.icon.times.rectangle:before {
  content: "\f2d3"; }

i.icon.times.rectangle.outline:before {
  content: "\f2d4"; }

/*******************************
             Types
*******************************/
/*--------------
    Loading
---------------*/
@-webkit-keyframes icon-loading {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

@keyframes icon-loading {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

/*******************************
             States
*******************************/
/*******************************
           Variations
*******************************/
/*-------------------
        Fitted
--------------------*/
/*-------------------
         Link
--------------------*/
/*-------------------
      Circular
--------------------*/
/*-------------------
      Flipped
--------------------*/
/*-------------------
      Rotated
--------------------*/
/*-------------------
      Bordered
--------------------*/
/*-------------------
      Inverted
--------------------*/
/* Inverted Shapes */
/*-------------------
       Colors
--------------------*/
/* Red */
/* Orange */
/* Yellow */
/* Olive */
/* Green */
/* Teal */
/* Blue */
/* Violet */
/* Purple */
/* Pink */
/* Brown */
/* Grey */
/* Black */
/*-------------------
        Sizes
--------------------*/
/*******************************
            Groups
*******************************/
/* Corner Icon */
/*
 * Font Awesome 4.7.0 by @davegandy - http://fontawesome.io - @fontawesome
 * License - http://fontawesome.io/license (Font: SIL OFL 1.1, CSS: MIT License)
 */
/*******************************

Semantic-UI integration of font-awesome :

///class names are separated
i.icon.circle => i.icon.circle
i.icon.circle-o => i.icon.circle.outline

//abbreviation are replaced by full letters:
i.icon.ellipsis-h => i.icon.ellipsis.horizontal
i.icon.ellipsis-v => i.icon.ellipsis.vertical
.alpha => .i.icon.alphabet
.asc => .i.icon.ascending
.desc => .i.icon.descending
.alt =>.alternate

ASCII order is conserved for easier maintenance.

Icons that only have one style 'outline', 'square' etc do not require this class
for instance `lemon icon` not `lemon outline icon` since there is only one lemon

*******************************/
/*******************************
            Icons
*******************************/
/* Web Content */
/* User Actions */
/* Messages */
/* Users */
/* Gender & Sexuality */
/* Accessibility */
/* View Adjustment */
/* Literal Objects */
/* Shapes */
/* Item Selection */
/* Media */
/* Pointers */
/* Mobile */
/* Computer */
/* File System */
/* Technologies */
/* Rating */
/* Audio */
/* Map, Locations, & Transportation */
/* Tables */
/* Text Editor */
/* Currency */
/* Payment Options */
/* Networks and Websites*/
/*******************************
            Aliases
*******************************/
/*******************************
         Site Overrides
*******************************/
/*!
 * # Semantic UI 2.2.12 - Image
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Image
*******************************/
.ui.image {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  max-width: 100%;
  background-color: transparent; }

img.ui.image {
  display: block; }

.ui.image svg, .ui.image img {
  display: block;
  max-width: 100%;
  height: auto; }

.ui.hidden.images, .ui.hidden.image {
  display: none; }

.ui.hidden.transition.images, .ui.hidden.transition.image {
  display: block;
  visibility: hidden; }

.ui.disabled.images, .ui.disabled.image {
  cursor: default;
  opacity: 0.45; }

.ui.inline.image {
  display: inline-block; }
  .ui.inline.image svg, .ui.inline.image img {
    display: inline-block; }

.ui.top.aligned.images .image {
  display: inline-block;
  vertical-align: top; }

.ui.top.aligned.image {
  display: inline-block;
  vertical-align: top; }
  .ui.top.aligned.image svg, .ui.top.aligned.image img {
    display: inline-block;
    vertical-align: top; }

.ui.middle.aligned.images .image {
  display: inline-block;
  vertical-align: middle; }

.ui.middle.aligned.image {
  display: inline-block;
  vertical-align: middle; }
  .ui.middle.aligned.image svg, .ui.middle.aligned.image img {
    display: inline-block;
    vertical-align: middle; }

.ui.bottom.aligned.images .image {
  display: inline-block;
  vertical-align: bottom; }

.ui.bottom.aligned.image {
  display: inline-block;
  vertical-align: bottom; }
  .ui.bottom.aligned.image svg, .ui.bottom.aligned.image img {
    display: inline-block;
    vertical-align: bottom; }

.ui.rounded.images .image, .ui.rounded.image, .ui.rounded.images .image > *, .ui.rounded.image > * {
  border-radius: 0.3125em; }

.ui.bordered.images .image, .ui.bordered.images img, .ui.bordered.images svg {
  border: 1px solid rgba(0, 0, 0, 0.1); }

.ui.bordered.image img, .ui.bordered.image svg {
  border: 1px solid rgba(0, 0, 0, 0.1); }

/*******************************
            States
*******************************/
/*******************************
          Variations
*******************************/
/*--------------
     Inline
---------------*/
/*------------------
  Vertical Aligned
-------------------*/
/*--------------
     Rounded
---------------*/
/*--------------
    Bordered
---------------*/
img.ui.bordered.image {
  border: 1px solid rgba(0, 0, 0, 0.1); }

/*--------------
    Circular
---------------*/
.ui.circular.images, .ui.circular.image {
  overflow: hidden; }

.ui.circular.images .image, .ui.circular.image, .ui.circular.images .image > *, .ui.circular.image > * {
  border-radius: 500rem; }

.ui.fluid.images, .ui.fluid.image {
  display: block;
  width: 100%;
  height: auto; }

.ui.fluid.images img, .ui.fluid.images svg {
  display: block;
  width: 100%;
  height: auto; }

.ui.fluid.image svg, .ui.fluid.image img {
  display: block;
  width: 100%;
  height: auto; }

.ui.avatar.images .image, .ui.avatar.images img, .ui.avatar.images svg {
  margin-right: 0.25em;
  display: inline-block;
  width: 2em;
  height: 2em;
  border-radius: 500rem; }

.ui.avatar.image {
  margin-right: 0.25em;
  display: inline-block;
  width: 2em;
  height: 2em;
  border-radius: 500rem; }
  .ui.avatar.image img, .ui.avatar.image svg {
    margin-right: 0.25em;
    display: inline-block;
    width: 2em;
    height: 2em;
    border-radius: 500rem; }

.ui.spaced.image {
  display: inline-block !important;
  margin-left: 0.5em;
  margin-right: 0.5em; }

.ui[class*="left spaced"].image {
  margin-left: 0.5em;
  margin-right: 0em; }

.ui[class*="right spaced"].image {
  margin-left: 0em;
  margin-right: 0.5em; }

.ui.floated.image, .ui.floated.images {
  float: left;
  margin-right: 1em;
  margin-bottom: 1em; }

.ui.right.floated.images, .ui.right.floated.image {
  float: right;
  margin-right: 0em;
  margin-bottom: 1em;
  margin-left: 1em; }

.ui.floated.images:last-child, .ui.floated.image:last-child {
  margin-bottom: 0em; }

.ui.centered.images, .ui.centered.image {
  margin-left: auto;
  margin-right: auto; }

.ui.mini.images .image, .ui.mini.images img, .ui.mini.images svg {
  width: 35px;
  height: auto;
  font-size: 0.78571429rem; }

.ui.mini.image {
  width: 35px;
  height: auto;
  font-size: 0.78571429rem; }

.ui.tiny.images .image, .ui.tiny.images img, .ui.tiny.images svg {
  width: 80px;
  height: auto;
  font-size: 0.85714286rem; }

.ui.tiny.image {
  width: 80px;
  height: auto;
  font-size: 0.85714286rem; }

.ui.small.images .image, .ui.small.images img, .ui.small.images svg {
  width: 150px;
  height: auto;
  font-size: 0.92857143rem; }

.ui.small.image {
  width: 150px;
  height: auto;
  font-size: 0.92857143rem; }

.ui.medium.images .image, .ui.medium.images img, .ui.medium.images svg {
  width: 300px;
  height: auto;
  font-size: 1rem; }

.ui.medium.image {
  width: 300px;
  height: auto;
  font-size: 1rem; }

.ui.large.images .image, .ui.large.images img, .ui.large.images svg {
  width: 450px;
  height: auto;
  font-size: 1.14285714rem; }

.ui.large.image {
  width: 450px;
  height: auto;
  font-size: 1.14285714rem; }

.ui.big.images .image, .ui.big.images img, .ui.big.images svg {
  width: 600px;
  height: auto;
  font-size: 1.28571429rem; }

.ui.big.image {
  width: 600px;
  height: auto;
  font-size: 1.28571429rem; }

.ui.huge.images .image, .ui.huge.images img, .ui.huge.images svg {
  width: 800px;
  height: auto;
  font-size: 1.42857143rem; }

.ui.huge.image {
  width: 800px;
  height: auto;
  font-size: 1.42857143rem; }

.ui.massive.images .image, .ui.massive.images img, .ui.massive.images svg {
  width: 960px;
  height: auto;
  font-size: 1.71428571rem; }

.ui.massive.image {
  width: 960px;
  height: auto;
  font-size: 1.71428571rem; }

.ui.images {
  font-size: 0em;
  margin: 0em -0.25rem 0rem; }
  .ui.images .image, .ui.images img, .ui.images svg {
    display: inline-block;
    margin: 0em 0.25rem 0.5rem; }

/*!
 * # Semantic UI 2.2.12 - Input
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
           Standard
*******************************/
/*--------------------
        Inputs
---------------------*/
.ui.input {
  position: relative;
  font-weight: normal;
  font-style: normal;
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  color: rgba(0, 0, 0, 0.87); }
  .ui.input input {
    margin: 0em;
    max-width: 100%;
    -webkit-box-flex: 1;
    -ms-flex: 1 0 auto;
    flex: 1 0 auto;
    outline: none;
    -webkit-tap-highlight-color: rgba(255, 255, 255, 0);
    text-align: left;
    line-height: 1.21428571em;
    font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
    padding: 0.67857143em 1em;
    background: #FFFFFF;
    border: 1px solid rgba(34, 36, 38, 0.15);
    color: rgba(0, 0, 0, 0.87);
    border-radius: 0.28571429rem;
    -webkit-transition: box-shadow 0.1s ease, border-color 0.1s ease;
    transition: box-shadow 0.1s ease, border-color 0.1s ease;
    box-shadow: none; }
    .ui.input input::-webkit-input-placeholder, .ui.input input::-moz-placeholder, .ui.input input:-ms-input-placeholder {
      color: rgba(191, 191, 191, 0.87); }

.ui.disabled.input, .ui.input:not(.disabled) input[disabled] {
  opacity: 0.45; }

.ui.disabled.input input {
  pointer-events: none; }

.ui.input:not(.disabled) input[disabled] {
  pointer-events: none; }

.ui.input input:active, .ui.input.down input {
  border-color: rgba(0, 0, 0, 0.3);
  background: #FAFAFA;
  color: rgba(0, 0, 0, 0.87);
  box-shadow: none; }

.ui.loading.loading.input > i.icon:before {
  position: absolute;
  content: '';
  top: 50%;
  left: 50%;
  margin: -0.64285714em 0em 0em -0.64285714em;
  width: 1.28571429em;
  height: 1.28571429em;
  border-radius: 500rem;
  border: 0.2em solid rgba(0, 0, 0, 0.1); }

.ui.loading.loading.input > i.icon:after {
  position: absolute;
  content: '';
  top: 50%;
  left: 50%;
  margin: -0.64285714em 0em 0em -0.64285714em;
  width: 1.28571429em;
  height: 1.28571429em;
  -webkit-animation: button-spin 0.6s linear;
  animation: button-spin 0.6s linear;
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite;
  border-radius: 500rem;
  border-color: #767676 transparent transparent;
  border-style: solid;
  border-width: 0.2em;
  box-shadow: 0px 0px 0px 1px transparent; }

.ui.input.focus input, .ui.input input:focus {
  border-color: #85B7D9;
  background: #FFFFFF;
  color: rgba(0, 0, 0, 0.8);
  box-shadow: none; }

.ui.input.focus input::-webkit-input-placeholder, .ui.input input:focus::-webkit-input-placeholder, .ui.input.focus input::-moz-placeholder, .ui.input input:focus::-moz-placeholder, .ui.input.focus input:-ms-input-placeholder, .ui.input input:focus:-ms-input-placeholder {
  color: rgba(115, 115, 115, 0.87); }

.ui.input.error input {
  background-color: #FFF6F6;
  border-color: #E0B4B4;
  color: #9F3A38;
  box-shadow: none; }
  .ui.input.error input::-webkit-input-placeholder, .ui.input.error input::-moz-placeholder {
    color: #e7bdbc; }
  .ui.input.error input:-ms-input-placeholder {
    color: #e7bdbc !important; }
  .ui.input.error input:focus::-webkit-input-placeholder, .ui.input.error input:focus::-moz-placeholder {
    color: #da9796; }
  .ui.input.error input:focus:-ms-input-placeholder {
    color: #da9796 !important; }

.ui.transparent.input input {
  border-color: transparent !important;
  background-color: transparent !important;
  padding: 0em !important;
  box-shadow: none !important;
  border-radius: 0px !important; }

.ui.transparent.icon.input > i.icon {
  width: 1.1em; }

.ui.transparent.icon.input > input {
  padding-left: 0em !important;
  padding-right: 2em !important; }

.ui.transparent[class*="left icon"].input > input {
  padding-left: 2em !important;
  padding-right: 0em !important; }

.ui.transparent.inverted.input {
  color: #FFFFFF; }
  .ui.transparent.inverted.input input {
    color: inherit; }
    .ui.transparent.inverted.input input::-webkit-input-placeholder, .ui.transparent.inverted.input input::-moz-placeholder, .ui.transparent.inverted.input input:-ms-input-placeholder {
      color: rgba(255, 255, 255, 0.5); }

.ui.icon.input > i.icon {
  cursor: default;
  position: absolute;
  line-height: 1;
  text-align: center;
  top: 0px;
  right: 0px;
  margin: 0em;
  height: 100%;
  width: 2.67142857em;
  opacity: 0.5;
  border-radius: 0em 0.28571429rem 0.28571429rem 0em;
  -webkit-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease; }
  .ui.icon.input > i.icon:not(.link) {
    pointer-events: none; }

.ui.icon.input input {
  padding-right: 2.67142857em !important; }

.ui.icon.input > i.icon:before, .ui.icon.input > i.icon:after {
  left: 0;
  position: absolute;
  text-align: center;
  top: 50%;
  width: 100%;
  margin-top: -0.5em; }

.ui.icon.input > i.link.icon {
  cursor: pointer; }

.ui.icon.input > i.circular.icon {
  top: 0.35em;
  right: 0.5em; }

.ui[class*="left icon"].input > i.icon {
  right: auto;
  left: 1px;
  border-radius: 0.28571429rem 0em 0em 0.28571429rem; }

.ui[class*="left icon"].input > i.circular.icon {
  right: auto;
  left: 0.5em; }

.ui[class*="left icon"].input > input {
  padding-left: 2.67142857em !important;
  padding-right: 1em !important; }

.ui.icon.input > input:focus ~ i.icon {
  opacity: 1; }

.ui.labeled.input > .label {
  -webkit-box-flex: 0;
  -ms-flex: 0 0 auto;
  flex: 0 0 auto;
  margin: 0;
  font-size: 1em; }
  .ui.labeled.input > .label:not(.corner) {
    padding-top: 0.78571429em;
    padding-bottom: 0.78571429em; }

.ui.labeled.input:not([class*="corner labeled"]) .label:first-child {
  border-top-right-radius: 0px;
  border-bottom-right-radius: 0px; }
  .ui.labeled.input:not([class*="corner labeled"]) .label:first-child + input {
    border-top-left-radius: 0px;
    border-bottom-left-radius: 0px;
    border-left-color: transparent; }
    .ui.labeled.input:not([class*="corner labeled"]) .label:first-child + input:focus {
      border-left-color: #85B7D9; }

.ui[class*="right labeled"].input input {
  border-top-right-radius: 0px !important;
  border-bottom-right-radius: 0px !important;
  border-right-color: transparent !important; }
  .ui[class*="right labeled"].input input + .label {
    border-top-left-radius: 0px;
    border-bottom-left-radius: 0px; }
  .ui[class*="right labeled"].input input:focus {
    border-right-color: #85B7D9 !important; }

.ui.labeled.input .corner.label {
  top: 1px;
  right: 1px;
  font-size: 0.64285714em;
  border-radius: 0em 0.28571429rem 0em 0em; }

.ui[class*="corner labeled"]:not([class*="left corner labeled"]).labeled.input input {
  padding-right: 2.5em !important; }

.ui[class*="corner labeled"].icon.input:not([class*="left corner labeled"]) > input {
  padding-right: 3.25em !important; }

.ui[class*="corner labeled"].icon.input:not([class*="left corner labeled"]) > .icon {
  margin-right: 1.25em; }

.ui[class*="left corner labeled"].labeled.input input {
  padding-left: 2.5em !important; }

.ui[class*="left corner labeled"].icon.input > input {
  padding-left: 3.25em !important; }

.ui[class*="left corner labeled"].icon.input > .icon {
  margin-left: 1.25em; }

.ui.input > .ui.corner.label {
  top: 1px;
  right: 1px; }

.ui.input > .ui.left.corner.label {
  right: auto;
  left: 1px; }

.ui.action.input > .button, .ui.action.input > .buttons {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-flex: 0;
  -ms-flex: 0 0 auto;
  flex: 0 0 auto; }

.ui.action.input > .button, .ui.action.input > .buttons > .button {
  padding-top: 0.78571429em;
  padding-bottom: 0.78571429em;
  margin: 0; }

.ui.action.input:not([class*="left action"]) > input {
  border-top-right-radius: 0px !important;
  border-bottom-right-radius: 0px !important;
  border-right-color: transparent !important; }

.ui.action.input:not([class*="left action"]) > .dropdown:not(:first-child), .ui.action.input:not([class*="left action"]) > .button:not(:first-child), .ui.action.input:not([class*="left action"]) > .buttons:not(:first-child) > .button {
  border-radius: 0px; }

.ui.action.input:not([class*="left action"]) > .dropdown:last-child, .ui.action.input:not([class*="left action"]) > .button:last-child, .ui.action.input:not([class*="left action"]) > .buttons:last-child > .button {
  border-radius: 0px 0.28571429rem 0.28571429rem 0px; }

.ui.action.input:not([class*="left action"]) input:focus {
  border-right-color: #85B7D9 !important; }

.ui[class*="left action"].input > input {
  border-top-left-radius: 0px !important;
  border-bottom-left-radius: 0px !important;
  border-left-color: transparent !important; }

.ui[class*="left action"].input > .dropdown, .ui[class*="left action"].input > .button, .ui[class*="left action"].input > .buttons > .button {
  border-radius: 0px; }

.ui[class*="left action"].input > .dropdown:first-child, .ui[class*="left action"].input > .button:first-child, .ui[class*="left action"].input > .buttons:first-child > .button {
  border-radius: 0.28571429rem 0px 0px 0.28571429rem; }

.ui[class*="left action"].input > input:focus {
  border-left-color: #85B7D9 !important; }

.ui.inverted.input input {
  border: none; }

.ui.fluid.input {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }
  .ui.fluid.input > input {
    width: 0px !important; }

.ui.mini.input {
  font-size: 0.78571429em; }

.ui.small.input {
  font-size: 0.92857143em; }

.ui.input {
  font-size: 1em; }

.ui.large.input {
  font-size: 1.14285714em; }

.ui.big.input {
  font-size: 1.28571429em; }

.ui.huge.input {
  font-size: 1.42857143em; }

.ui.massive.input {
  font-size: 1.71428571em; }

/*!
 * # Semantic UI 2.2.12 - Label
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Label
*******************************/
.ui.label {
  display: inline-block;
  line-height: 1;
  vertical-align: baseline;
  margin: 0em 0.14285714em;
  background-color: #E8E8E8;
  background-image: none;
  padding: 0.5833em 0.833em;
  color: rgba(0, 0, 0, 0.6);
  text-transform: none;
  font-weight: bold;
  border: 0px solid transparent;
  border-radius: 0.28571429rem;
  -webkit-transition: background 0.1s ease;
  transition: background 0.1s ease; }
  .ui.label:first-child {
    margin-left: 0em; }
  .ui.label:last-child {
    margin-right: 0em; }

/* Link */
a.ui.label {
  cursor: pointer; }

/* Inside Link */
.ui.label > a {
  cursor: pointer;
  color: inherit;
  opacity: 0.5;
  -webkit-transition: 0.1s opacity ease;
  transition: 0.1s opacity ease; }
  .ui.label > a:hover {
    opacity: 1; }

.ui.label > img {
  width: auto !important;
  vertical-align: middle;
  height: 2.1666em !important; }

.ui.label > .icon {
  width: auto;
  margin: 0em 0.75em 0em 0em; }

.ui.label > .detail {
  display: inline-block;
  vertical-align: top;
  font-weight: bold;
  margin-left: 1em;
  opacity: 0.8; }
  .ui.label > .detail .icon {
    margin: 0em 0.25em 0em 0em; }

.ui.label > .close.icon {
  cursor: pointer;
  margin-right: 0em;
  margin-left: 0.5em;
  font-size: 0.92857143em;
  opacity: 0.5;
  -webkit-transition: background 0.1s ease;
  transition: background 0.1s ease; }

.ui.label > .delete.icon {
  cursor: pointer;
  margin-right: 0em;
  margin-left: 0.5em;
  font-size: 0.92857143em;
  opacity: 0.5;
  -webkit-transition: background 0.1s ease;
  transition: background 0.1s ease; }
  .ui.label > .delete.icon:hover {
    opacity: 1; }

.ui.labels > .label {
  margin: 0em 0.5em 0.5em 0em; }

.ui.header > .ui.label {
  margin-top: -0.29165em; }

.ui.attached.segment > .ui.top.left.attached.label, .ui.bottom.attached.segment > .ui.top.left.attached.label {
  border-top-left-radius: 0; }

.ui.attached.segment > .ui.top.right.attached.label, .ui.bottom.attached.segment > .ui.top.right.attached.label {
  border-top-right-radius: 0; }

.ui.top.attached.segment > .ui.bottom.left.attached.label {
  border-bottom-left-radius: 0; }

.ui.top.attached.segment > .ui.bottom.right.attached.label {
  border-bottom-right-radius: 0; }

.ui.top.attached.label:first-child + :not(.attached), .ui.top.attached.label + [class*="right floated"] + * {
  margin-top: 2rem !important; }

.ui.bottom.attached.label:first-child ~ :last-child:not(.attached) {
  margin-top: 0em;
  margin-bottom: 2rem !important; }

.ui.image.label {
  width: auto !important;
  margin-top: 0em;
  margin-bottom: 0em;
  max-width: 9999px;
  vertical-align: baseline;
  text-transform: none;
  background: #E8E8E8;
  padding: 0.5833em 0.833em 0.5833em 0.5em;
  border-radius: 0.28571429rem;
  box-shadow: none; }
  .ui.image.label img {
    display: inline-block;
    vertical-align: top;
    height: 2.1666em;
    margin: -0.5833em 0.5em -0.5833em -0.5em;
    border-radius: 0.28571429rem 0em 0em 0.28571429rem; }
  .ui.image.label .detail {
    background: rgba(0, 0, 0, 0.1);
    margin: -0.5833em -0.833em -0.5833em 0.5em;
    padding: 0.5833em 0.833em;
    border-radius: 0em 0.28571429rem 0.28571429rem 0em; }

.ui.tag.labels .label, .ui.tag.label {
  margin-left: 1em;
  position: relative;
  padding-left: 1.5em;
  padding-right: 1.5em;
  border-radius: 0em 0.28571429rem 0.28571429rem 0em;
  -webkit-transition: none;
  transition: none; }

.ui.tag.labels .label:before, .ui.tag.label:before {
  position: absolute;
  -webkit-transform: translateY(-50%) translateX(50%) rotate(-45deg);
  transform: translateY(-50%) translateX(50%) rotate(-45deg);
  top: 50%;
  right: 100%;
  content: '';
  background-color: inherit;
  background-image: none;
  width: 1.56em;
  height: 1.56em;
  -webkit-transition: none;
  transition: none; }

.ui.tag.labels .label:after, .ui.tag.label:after {
  position: absolute;
  content: '';
  top: 50%;
  left: -0.25em;
  margin-top: -0.25em;
  background-color: #FFFFFF !important;
  width: 0.5em;
  height: 0.5em;
  box-shadow: 0 -1px 1px 0 rgba(0, 0, 0, 0.3);
  border-radius: 500rem; }

.ui.corner.label {
  position: absolute;
  top: 0em;
  right: 0em;
  margin: 0em;
  padding: 0em;
  text-align: center;
  border-color: #E8E8E8;
  width: 4em;
  height: 4em;
  z-index: 1;
  -webkit-transition: border-color 0.1s ease;
  transition: border-color 0.1s ease;
  background-color: transparent !important; }
  .ui.corner.label:after {
    position: absolute;
    content: "";
    right: 0em;
    top: 0em;
    z-index: -1;
    width: 0em;
    height: 0em;
    background-color: transparent !important;
    border-top: 0em solid transparent;
    border-right: 4em solid transparent;
    border-bottom: 4em solid transparent;
    border-left: 0em solid transparent;
    border-right-color: inherit;
    -webkit-transition: border-color 0.1s ease;
    transition: border-color 0.1s ease; }
  .ui.corner.label .icon {
    cursor: default;
    position: relative;
    top: 0.64285714em;
    left: 0.78571429em;
    font-size: 1.14285714em;
    margin: 0em; }

.ui.left.corner.label {
  right: auto;
  left: 0em; }
  .ui.left.corner.label:after {
    right: auto;
    left: 0em;
    border-top: 4em solid transparent;
    border-right: 4em solid transparent;
    border-bottom: 0em solid transparent;
    border-left: 0em solid transparent;
    border-top-color: inherit; }
  .ui.left.corner.label .icon {
    left: -0.78571429em; }

.ui.segment > .ui.corner.label {
  top: -1px;
  right: -1px; }

.ui.segment > .ui.left.corner.label {
  right: auto;
  left: -1px; }

.ui.ribbon.label {
  position: relative;
  margin: 0em;
  min-width: -webkit-max-content;
  min-width: -moz-max-content;
  min-width: max-content;
  border-radius: 0em 0.28571429rem 0.28571429rem 0em;
  border-color: rgba(0, 0, 0, 0.15);
  left: calc( -1rem  -  1.2em);
  margin-right: -1.2em;
  padding-left: calc( 1rem  +  1.2em);
  padding-right: 1.2em; }
  .ui.ribbon.label:after {
    position: absolute;
    content: '';
    top: 100%;
    left: 0%;
    background-color: transparent !important;
    border-style: solid;
    border-width: 0em 1.2em 1.2em 0em;
    border-color: transparent;
    border-right-color: inherit;
    width: 0em;
    height: 0em; }

.ui[class*="right ribbon"].label {
  left: calc(100% +  1rem  +  1.2em);
  padding-left: 1.2em;
  padding-right: calc( 1rem  +  1.2em);
  text-align: left;
  -webkit-transform: translateX(-100%);
  transform: translateX(-100%);
  border-radius: 0.28571429rem 0em 0em 0.28571429rem; }
  .ui[class*="right ribbon"].label:after {
    left: auto;
    right: 0%;
    border-style: solid;
    border-width: 1.2em 1.2em 0em 0em;
    border-color: transparent;
    border-top-color: inherit; }

.ui.image > .ribbon.label {
  position: absolute;
  top: 1rem; }

.ui.card .image > .ribbon.label {
  position: absolute;
  top: 1rem; }

.ui.card .image > .ui.ribbon.label {
  left: calc( 0.05rem  -  1.2em); }

.ui.image > .ui.ribbon.label {
  left: calc( 0.05rem  -  1.2em); }

.ui.card .image > .ui[class*="right ribbon"].label, .ui.image > .ui[class*="right ribbon"].label {
  left: calc(100% +  -0.05rem  +  1.2em);
  padding-left: 0.833em; }

.ui.table td > .ui.ribbon.label {
  left: calc( -0.78571429em  -  1.2em); }

.ui.table td > .ui[class*="right ribbon"].label {
  left: calc(100% +  0.78571429em  +  1.2em);
  padding-left: 0.833em; }

.ui[class*="top attached"].label, .ui.attached.label {
  width: 100%;
  position: absolute;
  margin: 0em;
  top: 0em;
  left: 0em;
  padding: 0.75em 1em;
  border-radius: 0.21428571rem 0.21428571rem 0em 0em; }

.ui[class*="bottom attached"].label {
  top: auto;
  bottom: 0em;
  border-radius: 0em 0em 0.21428571rem 0.21428571rem; }

.ui[class*="top left attached"].label {
  width: auto;
  margin-top: 0em !important;
  border-radius: 0.21428571rem 0em 0.28571429rem 0em; }

.ui[class*="top right attached"].label {
  width: auto;
  left: auto;
  right: 0em;
  border-radius: 0em 0.21428571rem 0em 0.28571429rem; }

.ui[class*="bottom left attached"].label {
  width: auto;
  top: auto;
  bottom: 0em;
  border-radius: 0em 0.28571429rem 0em 0.21428571rem; }

.ui[class*="bottom right attached"].label {
  top: auto;
  bottom: 0em;
  left: auto;
  right: 0em;
  width: auto;
  border-radius: 0.28571429rem 0em 0.21428571rem 0em; }

.ui.label.disabled {
  opacity: 0.5; }

/* Image */
/* Icon */
/* Detail */
/* Removable label */
/*-------------------
       Group
--------------------*/
/*-------------------
       Coupling
--------------------*/
/* Remove border radius on attached segment */
/* Padding on next content after a label */
/*******************************
             Types
*******************************/
/*-------------------
         Tag
--------------------*/
/*-------------------
    Corner Label
--------------------*/
/* Icon Label */
/* Left Corner */
/* Segment */
/*-------------------
       Ribbon
--------------------*/
/* Positioning */
/* Right Ribbon */
/* Inside Table */
/* Inside Table */
/*-------------------
      Attached
--------------------*/
/*******************************
             States
*******************************/
/*-------------------
      Disabled
--------------------*/
/*-------------------
        Hover
--------------------*/
a.ui.labels .label:hover, a.ui.label:hover {
  background-color: #E0E0E0;
  border-color: #E0E0E0;
  background-image: none;
  color: rgba(0, 0, 0, 0.8); }

.ui.labels a.label:hover:before, a.ui.label:hover:before {
  color: rgba(0, 0, 0, 0.8); }

/*-------------------
        Active
--------------------*/
.ui.active.label {
  background-color: #D0D0D0;
  border-color: #D0D0D0;
  background-image: none;
  color: rgba(0, 0, 0, 0.95); }
  .ui.active.label:before {
    background-color: #D0D0D0;
    background-image: none;
    color: rgba(0, 0, 0, 0.95); }

/*-------------------
     Active Hover
--------------------*/
a.ui.labels .active.label:hover, a.ui.active.label:hover {
  background-color: #C8C8C8;
  border-color: #C8C8C8;
  background-image: none;
  color: rgba(0, 0, 0, 0.95); }

.ui.labels a.active.label:ActiveHover:before, a.ui.active.label:ActiveHover:before {
  background-color: #C8C8C8;
  background-image: none;
  color: rgba(0, 0, 0, 0.95); }

/*-------------------
      Visible
--------------------*/
.ui.labels.visible .label, .ui.label.visible:not(.dropdown) {
  display: inline-block !important; }

.ui.labels.hidden .label, .ui.label.hidden {
  display: none !important; }

.ui.red.labels .label, .ui.red.label {
  background-color: #DB2828 !important;
  border-color: #DB2828 !important;
  color: #FFFFFF !important; }

.ui.red.labels .label:hover {
  background-color: #d01919 !important;
  border-color: #d01919 !important;
  color: #FFFFFF !important; }

/*-------------------
      Hidden
--------------------*/
/*******************************
           Variations
*******************************/
/*-------------------
       Colors
--------------------*/
/*--- Red ---*/
/* Link */
a.ui.red.label:hover {
  background-color: #d01919 !important;
  border-color: #d01919 !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.red.corner.label {
  background-color: transparent !important; }
  .ui.red.corner.label:hover {
    background-color: transparent !important; }

.ui.red.ribbon.label {
  border-color: #b21e1e !important; }

.ui.basic.red.label {
  background-color: #FFFFFF !important;
  color: #DB2828 !important;
  border-color: #DB2828 !important; }

.ui.basic.red.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #d01919 !important;
  border-color: #d01919 !important; }

/* Ribbon */
/* Basic */
a.ui.basic.red.label:hover {
  background-color: #FFFFFF !important;
  color: #d01919 !important;
  border-color: #d01919 !important; }

/*--- Orange ---*/
.ui.orange.labels .label, .ui.orange.label {
  background-color: #fc7831 !important;
  border-color: #fc7831 !important;
  color: #FFFFFF !important; }

.ui.orange.labels .label:hover {
  background-color: #f26202 !important;
  border-color: #f26202 !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.orange.label:hover {
  background-color: #f26202 !important;
  border-color: #f26202 !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.orange.corner.label {
  background-color: transparent !important; }
  .ui.orange.corner.label:hover {
    background-color: transparent !important; }

.ui.orange.ribbon.label {
  border-color: #cf590c !important; }

.ui.basic.orange.label {
  background-color: #FFFFFF !important;
  color: #fc7831 !important;
  border-color: #fc7831 !important; }

.ui.basic.orange.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #f26202 !important;
  border-color: #f26202 !important; }

/* Ribbon */
/* Basic */
a.ui.basic.orange.label:hover {
  background-color: #FFFFFF !important;
  color: #f26202 !important;
  border-color: #f26202 !important; }

/*--- Yellow ---*/
.ui.yellow.labels .label, .ui.yellow.label {
  background-color: #FBBD08 !important;
  border-color: #FBBD08 !important;
  color: #FFFFFF !important; }

.ui.yellow.labels .label:hover {
  background-color: #eaae00 !important;
  border-color: #eaae00 !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.yellow.label:hover {
  background-color: #eaae00 !important;
  border-color: #eaae00 !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.yellow.corner.label {
  background-color: transparent !important; }
  .ui.yellow.corner.label:hover {
    background-color: transparent !important; }

.ui.yellow.ribbon.label {
  border-color: #cd9903 !important; }

.ui.basic.yellow.label {
  background-color: #FFFFFF !important;
  color: #FBBD08 !important;
  border-color: #FBBD08 !important; }

.ui.basic.yellow.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #eaae00 !important;
  border-color: #eaae00 !important; }

/* Ribbon */
/* Basic */
a.ui.basic.yellow.label:hover {
  background-color: #FFFFFF !important;
  color: #eaae00 !important;
  border-color: #eaae00 !important; }

/*--- Olive ---*/
.ui.olive.labels .label, .ui.olive.label {
  background-color: #B5CC18 !important;
  border-color: #B5CC18 !important;
  color: #FFFFFF !important; }

.ui.olive.labels .label:hover {
  background-color: #a7bd0d !important;
  border-color: #a7bd0d !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.olive.label:hover {
  background-color: #a7bd0d !important;
  border-color: #a7bd0d !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.olive.corner.label {
  background-color: transparent !important; }
  .ui.olive.corner.label:hover {
    background-color: transparent !important; }

.ui.olive.ribbon.label {
  border-color: #198f35 !important; }

.ui.basic.olive.label {
  background-color: #FFFFFF !important;
  color: #B5CC18 !important;
  border-color: #B5CC18 !important; }

.ui.basic.olive.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #a7bd0d !important;
  border-color: #a7bd0d !important; }

/* Ribbon */
/* Basic */
a.ui.basic.olive.label:hover {
  background-color: #FFFFFF !important;
  color: #a7bd0d !important;
  border-color: #a7bd0d !important; }

/*--- Green ---*/
.ui.green.labels .label, .ui.green.label {
  background-color: #21BA45 !important;
  border-color: #21BA45 !important;
  color: #FFFFFF !important; }

.ui.green.labels .label:hover {
  background-color: #16ab39 !important;
  border-color: #16ab39 !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.green.label:hover {
  background-color: #16ab39 !important;
  border-color: #16ab39 !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.green.corner.label {
  background-color: transparent !important; }
  .ui.green.corner.label:hover {
    background-color: transparent !important; }

.ui.green.ribbon.label {
  border-color: #198f35 !important; }

.ui.basic.green.label {
  background-color: #FFFFFF !important;
  color: #21BA45 !important;
  border-color: #21BA45 !important; }

.ui.basic.green.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #16ab39 !important;
  border-color: #16ab39 !important; }

/* Ribbon */
/* Basic */
a.ui.basic.green.label:hover {
  background-color: #FFFFFF !important;
  color: #16ab39 !important;
  border-color: #16ab39 !important; }

/*--- Teal ---*/
.ui.teal.labels .label, .ui.teal.label {
  background-color: #00B5AD !important;
  border-color: #00B5AD !important;
  color: #FFFFFF !important; }

.ui.teal.labels .label:hover {
  background-color: #009c95 !important;
  border-color: #009c95 !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.teal.label:hover {
  background-color: #009c95 !important;
  border-color: #009c95 !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.teal.corner.label {
  background-color: transparent !important; }
  .ui.teal.corner.label:hover {
    background-color: transparent !important; }

.ui.teal.ribbon.label {
  border-color: #00827c !important; }

.ui.basic.teal.label {
  background-color: #FFFFFF !important;
  color: #00B5AD !important;
  border-color: #00B5AD !important; }

.ui.basic.teal.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #009c95 !important;
  border-color: #009c95 !important; }

/* Ribbon */
/* Basic */
a.ui.basic.teal.label:hover {
  background-color: #FFFFFF !important;
  color: #009c95 !important;
  border-color: #009c95 !important; }

/*--- Blue ---*/
.ui.blue.labels .label, .ui.blue.label {
  background-color: #4c8bd6 !important;
  border-color: #4c8bd6 !important;
  color: #FFFFFF !important; }

.ui.blue.labels .label:hover {
  background-color: #1678c2 !important;
  border-color: #1678c2 !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.blue.label:hover {
  background-color: #1678c2 !important;
  border-color: #1678c2 !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.blue.corner.label {
  background-color: transparent !important; }
  .ui.blue.corner.label:hover {
    background-color: transparent !important; }

.ui.blue.ribbon.label {
  border-color: #1a69a4 !important; }

.ui.basic.blue.label {
  background-color: #FFFFFF !important;
  color: #4c8bd6 !important;
  border-color: #4c8bd6 !important; }

.ui.basic.blue.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #1678c2 !important;
  border-color: #1678c2 !important; }

/* Ribbon */
/* Basic */
a.ui.basic.blue.label:hover {
  background-color: #FFFFFF !important;
  color: #1678c2 !important;
  border-color: #1678c2 !important; }

/*--- Violet ---*/
.ui.violet.labels .label, .ui.violet.label {
  background-color: #6435C9 !important;
  border-color: #6435C9 !important;
  color: #FFFFFF !important; }

.ui.violet.labels .label:hover {
  background-color: #5829bb !important;
  border-color: #5829bb !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.violet.label:hover {
  background-color: #5829bb !important;
  border-color: #5829bb !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.violet.corner.label {
  background-color: transparent !important; }
  .ui.violet.corner.label:hover {
    background-color: transparent !important; }

.ui.violet.ribbon.label {
  border-color: #502aa1 !important; }

.ui.basic.violet.label {
  background-color: #FFFFFF !important;
  color: #6435C9 !important;
  border-color: #6435C9 !important; }

.ui.basic.violet.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #5829bb !important;
  border-color: #5829bb !important; }

/* Ribbon */
/* Basic */
a.ui.basic.violet.label:hover {
  background-color: #FFFFFF !important;
  color: #5829bb !important;
  border-color: #5829bb !important; }

/*--- Purple ---*/
.ui.purple.labels .label, .ui.purple.label {
  background-color: #A333C8 !important;
  border-color: #A333C8 !important;
  color: #FFFFFF !important; }

.ui.purple.labels .label:hover {
  background-color: #9627ba !important;
  border-color: #9627ba !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.purple.label:hover {
  background-color: #9627ba !important;
  border-color: #9627ba !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.purple.corner.label {
  background-color: transparent !important; }
  .ui.purple.corner.label:hover {
    background-color: transparent !important; }

.ui.purple.ribbon.label {
  border-color: #82299f !important; }

.ui.basic.purple.label {
  background-color: #FFFFFF !important;
  color: #A333C8 !important;
  border-color: #A333C8 !important; }

.ui.basic.purple.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #9627ba !important;
  border-color: #9627ba !important; }

/* Ribbon */
/* Basic */
a.ui.basic.purple.label:hover {
  background-color: #FFFFFF !important;
  color: #9627ba !important;
  border-color: #9627ba !important; }

/*--- Pink ---*/
.ui.pink.labels .label, .ui.pink.label {
  background-color: #E03997 !important;
  border-color: #E03997 !important;
  color: #FFFFFF !important; }

.ui.pink.labels .label:hover {
  background-color: #e61a8d !important;
  border-color: #e61a8d !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.pink.label:hover {
  background-color: #e61a8d !important;
  border-color: #e61a8d !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.pink.corner.label {
  background-color: transparent !important; }
  .ui.pink.corner.label:hover {
    background-color: transparent !important; }

.ui.pink.ribbon.label {
  border-color: #c71f7e !important; }

.ui.basic.pink.label {
  background-color: #FFFFFF !important;
  color: #E03997 !important;
  border-color: #E03997 !important; }

.ui.basic.pink.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #e61a8d !important;
  border-color: #e61a8d !important; }

/* Ribbon */
/* Basic */
a.ui.basic.pink.label:hover {
  background-color: #FFFFFF !important;
  color: #e61a8d !important;
  border-color: #e61a8d !important; }

/*--- Brown ---*/
.ui.brown.labels .label, .ui.brown.label {
  background-color: #A5673F !important;
  border-color: #A5673F !important;
  color: #FFFFFF !important; }

.ui.brown.labels .label:hover {
  background-color: #975b33 !important;
  border-color: #975b33 !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.brown.label:hover {
  background-color: #975b33 !important;
  border-color: #975b33 !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.brown.corner.label {
  background-color: transparent !important; }
  .ui.brown.corner.label:hover {
    background-color: transparent !important; }

.ui.brown.ribbon.label {
  border-color: #805031 !important; }

.ui.basic.brown.label {
  background-color: #FFFFFF !important;
  color: #A5673F !important;
  border-color: #A5673F !important; }

.ui.basic.brown.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #975b33 !important;
  border-color: #975b33 !important; }

/* Ribbon */
/* Basic */
a.ui.basic.brown.label:hover {
  background-color: #FFFFFF !important;
  color: #975b33 !important;
  border-color: #975b33 !important; }

/*--- Grey ---*/
.ui.grey.labels .label, .ui.grey.label {
  background-color: #767676 !important;
  border-color: #767676 !important;
  color: #FFFFFF !important; }

.ui.grey.labels .label:hover {
  background-color: #838383 !important;
  border-color: #838383 !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.grey.label:hover {
  background-color: #838383 !important;
  border-color: #838383 !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.grey.corner.label {
  background-color: transparent !important; }
  .ui.grey.corner.label:hover {
    background-color: transparent !important; }

.ui.grey.ribbon.label {
  border-color: #805031 !important; }

.ui.basic.grey.label {
  background-color: #FFFFFF !important;
  color: #767676 !important;
  border-color: #767676 !important; }

.ui.basic.grey.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #838383 !important;
  border-color: #838383 !important; }

/* Ribbon */
/* Basic */
a.ui.basic.grey.label:hover {
  background-color: #FFFFFF !important;
  color: #838383 !important;
  border-color: #838383 !important; }

/*--- Black ---*/
.ui.black.labels .label, .ui.black.label {
  background-color: #1B1C1D !important;
  border-color: #1B1C1D !important;
  color: #FFFFFF !important; }

.ui.black.labels .label:hover {
  background-color: #27292a !important;
  border-color: #27292a !important;
  color: #FFFFFF !important; }

/* Link */
a.ui.black.label:hover {
  background-color: #27292a !important;
  border-color: #27292a !important;
  color: #FFFFFF !important; }

/* Corner */
.ui.black.corner.label {
  background-color: transparent !important; }
  .ui.black.corner.label:hover {
    background-color: transparent !important; }

.ui.black.ribbon.label {
  border-color: #805031 !important; }

.ui.basic.black.label {
  background-color: #FFFFFF !important;
  color: #1B1C1D !important;
  border-color: #1B1C1D !important; }

.ui.basic.black.labels a.label:hover {
  background-color: #FFFFFF !important;
  color: #27292a !important;
  border-color: #27292a !important; }

/* Ribbon */
/* Basic */
a.ui.basic.black.label:hover {
  background-color: #FFFFFF !important;
  color: #27292a !important;
  border-color: #27292a !important; }

/*-------------------
        Basic
--------------------*/
.ui.basic.label {
  background: none #FFFFFF;
  border: 1px solid rgba(34, 36, 38, 0.15);
  color: rgba(0, 0, 0, 0.87);
  box-shadow: none; }

/* Link */
a.ui.basic.label:hover {
  text-decoration: none;
  background: none #FFFFFF;
  color: #4679b7;
  box-shadow: 1px solid rgba(34, 36, 38, 0.15);
  box-shadow: none; }

/* Pointing */
.ui.basic.pointing.label:before {
  border-color: inherit; }

.ui.label.fluid, .ui.fluid.labels > .label {
  width: 100%;
  box-sizing: border-box; }

.ui.inverted.labels .label, .ui.inverted.label {
  color: rgba(255, 255, 255, 0.9) !important; }

.ui.horizontal.labels .label, .ui.horizontal.label {
  margin: 0em 0.5em 0em 0em;
  padding: 0.4em 0.833em;
  min-width: 3em;
  text-align: center; }

.ui.circular.labels .label, .ui.circular.label {
  min-width: 2em;
  min-height: 2em;
  padding: 0.5em !important;
  line-height: 1em;
  text-align: center;
  border-radius: 500rem; }

.ui.empty.circular.labels .label, .ui.empty.circular.label {
  min-width: 0em;
  min-height: 0em;
  overflow: hidden;
  width: 0.5em;
  height: 0.5em;
  vertical-align: baseline; }

.ui.pointing.label {
  position: relative; }

.ui.attached.pointing.label {
  position: absolute; }

.ui.pointing.label {
  margin-top: 1em; }
  .ui.pointing.label:before {
    background-color: inherit;
    background-image: inherit;
    border-width: none;
    border-style: solid;
    border-color: inherit;
    position: absolute;
    content: '';
    -webkit-transform: rotate(45deg);
    transform: rotate(45deg);
    background-image: none;
    z-index: 2;
    width: 0.6666em;
    height: 0.6666em;
    -webkit-transition: background 0.1s ease;
    transition: background 0.1s ease; }

.ui[class*="pointing above"].label {
  margin-top: 1em; }

.ui.pointing.label:before, .ui[class*="pointing above"].label:before {
  border-width: 1px 0px 0px 1px;
  -webkit-transform: translateX(-50%) translateY(-50%) rotate(45deg);
  transform: translateX(-50%) translateY(-50%) rotate(45deg);
  top: 0%;
  left: 50%; }

.ui[class*="bottom pointing"].label, .ui[class*="pointing below"].label {
  margin-top: 0em;
  margin-bottom: 1em; }

.ui[class*="bottom pointing"].label:before, .ui[class*="pointing below"].label:before {
  border-width: 0px 1px 1px 0px;
  top: auto;
  right: auto;
  -webkit-transform: translateX(-50%) translateY(-50%) rotate(45deg);
  transform: translateX(-50%) translateY(-50%) rotate(45deg);
  top: 100%;
  left: 50%; }

.ui[class*="left pointing"].label {
  margin-top: 0em;
  margin-left: 0.6666em; }
  .ui[class*="left pointing"].label:before {
    border-width: 0px 0px 1px 1px;
    -webkit-transform: translateX(-50%) translateY(-50%) rotate(45deg);
    transform: translateX(-50%) translateY(-50%) rotate(45deg);
    bottom: auto;
    right: auto;
    top: 50%;
    left: 0em; }

.ui[class*="right pointing"].label {
  margin-top: 0em;
  margin-right: 0.6666em; }
  .ui[class*="right pointing"].label:before {
    border-width: 1px 1px 0px 0px;
    -webkit-transform: translateX(50%) translateY(-50%) rotate(45deg);
    transform: translateX(50%) translateY(-50%) rotate(45deg);
    top: 50%;
    right: 0%;
    bottom: auto;
    left: auto; }

.ui.basic.pointing.label:before, .ui.basic[class*="pointing above"].label:before {
  margin-top: -1px; }

.ui.basic[class*="bottom pointing"].label:before, .ui.basic[class*="pointing below"].label:before {
  bottom: auto;
  top: 100%;
  margin-top: 1px; }

.ui.basic[class*="left pointing"].label:before {
  top: 50%;
  left: -1px; }

.ui.basic[class*="right pointing"].label:before {
  top: 50%;
  right: -1px; }

.ui.floating.label {
  position: absolute;
  z-index: 100;
  top: -1em;
  left: 100%;
  margin: 0em 0em 0em -1.5em !important; }

.ui.mini.labels .label, .ui.mini.label {
  font-size: 0.64285714rem; }

.ui.tiny.labels .label, .ui.tiny.label {
  font-size: 0.71428571rem; }

.ui.small.labels .label, .ui.small.label {
  font-size: 0.78571429rem; }

.ui.labels .label, .ui.label {
  font-size: 0.85714286rem; }

.ui.large.labels .label, .ui.large.label {
  font-size: 1rem; }

.ui.big.labels .label, .ui.big.label {
  font-size: 1.28571429rem; }

.ui.huge.labels .label, .ui.huge.label {
  font-size: 1.42857143rem; }

.ui.massive.labels .label, .ui.massive.label {
  font-size: 1.71428571rem; }

/*!
 * # Semantic UI 2.2.12 - List
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            List
*******************************/
ul.ui.list, ol.ui.list, .ui.list {
  list-style-type: none;
  margin: 1em 0em;
  padding: 0em 0em; }

ul.ui.list:first-child, ol.ui.list:first-child, .ui.list:first-child {
  margin-top: 0em;
  padding-top: 0em; }

ul.ui.list:last-child, ol.ui.list:last-child, .ui.list:last-child {
  margin-bottom: 0em;
  padding-bottom: 0em; }

/*******************************
            Content
*******************************/
/* List Item */
ul.ui.list li, ol.ui.list li {
  display: list-item;
  table-layout: fixed;
  list-style-type: none;
  list-style-position: outside;
  padding: 0.21428571em 0em;
  line-height: 1.14285714em; }

.ui.list > .item, .ui.list .list > .item {
  display: list-item;
  table-layout: fixed;
  list-style-type: none;
  list-style-position: outside;
  padding: 0.21428571em 0em;
  line-height: 1.14285714em; }

ul.ui.list > li:first-child:after, ol.ui.list > li:first-child:after {
  content: '';
  display: block;
  height: 0;
  clear: both;
  visibility: hidden; }

.ui.list > .list > .item, .ui.list > .item:after {
  content: '';
  display: block;
  height: 0;
  clear: both;
  visibility: hidden; }

ul.ui.list li:first-child, ol.ui.list li:first-child {
  padding-top: 0em; }

.ui.list .list > .item:first-child, .ui.list > .item:first-child {
  padding-top: 0em; }

ul.ui.list li:last-child, ol.ui.list li:last-child {
  padding-bottom: 0em; }

.ui.list .list > .item:last-child, .ui.list > .item:last-child {
  padding-bottom: 0em; }

/* Child List */
ul.ui.list ul, ol.ui.list ol, .ui.list .list {
  clear: both;
  margin: 0em;
  padding: 0.75em 0em 0.25em 0.5em; }

/* Child Item */
ul.ui.list ul li, ol.ui.list ol li {
  padding: 0.14285714em 0em;
  line-height: inherit; }

.ui.list .list > .item {
  padding: 0.14285714em 0em;
  line-height: inherit; }
  .ui.list .list > .item > i.icon {
    display: table-cell;
    margin: 0em;
    padding-top: 0em;
    padding-right: 0.28571429em;
    vertical-align: top;
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease; }

.ui.list .list > .item > i.icon:only-child {
  display: inline-block;
  vertical-align: top; }

.ui.list .list > .item > .image {
  display: table-cell;
  background-color: transparent;
  margin: 0em;
  vertical-align: top; }

.ui.list .list > .item > .image:not(:only-child):not(img) {
  padding-right: 0.5em; }

.ui.list .list > .item > .image img {
  vertical-align: top; }

.ui.list .list > .item > img.image, .ui.list .list > .item > .image:only-child {
  display: inline-block; }

.ui.list .list > .item > .content {
  line-height: 1.14285714em; }

.ui.list .list > .item > .image + .content, .ui.list .list > .item > .icon + .content {
  display: table-cell;
  padding: 0em 0em 0em 0.5em;
  vertical-align: top; }

.ui.list .list > .item > img.image + .content {
  display: inline-block; }

.ui.list .list > .item > .content > .list {
  margin-left: 0em;
  padding-left: 0em; }

.ui.list .list > .item .header {
  display: block;
  margin: 0em;
  font-family: 'Lato', 'Helvetica Neue', Arial, Helvetica, sans-serif;
  font-weight: bold;
  color: rgba(0, 0, 0, 0.87); }

.ui.list .list > .item .description {
  display: block;
  color: rgba(0, 0, 0, 0.7); }

.ui.list .list > .item a {
  cursor: pointer; }

.ui.list .list > a.item {
  cursor: pointer;
  color: #4c8bd6; }

.ui.list .list > a.item:hover {
  color: #4679b7; }

.ui.list .list > a.item i.icon {
  color: rgba(0, 0, 0, 0.4); }

.ui.list .list > .item a.header {
  cursor: pointer;
  color: #4c8bd6 !important; }

.ui.list .list > .item a.header:hover {
  color: #4679b7 !important; }

.ui.list > .item > i.icon {
  display: table-cell;
  margin: 0em;
  padding-top: 0em;
  padding-right: 0.28571429em;
  vertical-align: top;
  -webkit-transition: color 0.1s ease;
  transition: color 0.1s ease; }

.ui.list > .item > i.icon:only-child {
  display: inline-block;
  vertical-align: top; }

.ui.list > .item > .image {
  display: table-cell;
  background-color: transparent;
  margin: 0em;
  vertical-align: top; }

.ui.list > .item > .image:not(:only-child):not(img) {
  padding-right: 0.5em; }

.ui.list > .item > .image img {
  vertical-align: top; }

.ui.list > .item > img.image, .ui.list > .item > .image:only-child {
  display: inline-block; }

.ui.list > .item > .content {
  line-height: 1.14285714em; }

.ui.list > .item > .image + .content, .ui.list > .item > .icon + .content {
  display: table-cell;
  padding: 0em 0em 0em 0.5em;
  vertical-align: top; }

.ui.list > .item > img.image + .content {
  display: inline-block; }

.ui.list > .item > .content > .list {
  margin-left: 0em;
  padding-left: 0em; }

.ui.list > .item .header {
  display: block;
  margin: 0em;
  font-family: 'Lato', 'Helvetica Neue', Arial, Helvetica, sans-serif;
  font-weight: bold;
  color: rgba(0, 0, 0, 0.87); }

.ui.list > .item .description {
  display: block;
  color: rgba(0, 0, 0, 0.7); }

.ui.list > .item a {
  cursor: pointer; }

.ui.list > a.item {
  cursor: pointer;
  color: #4c8bd6; }

.ui.list > a.item:hover {
  color: #4679b7; }

.ui.list > a.item i.icon {
  color: rgba(0, 0, 0, 0.4); }

.ui.list > .item a.header {
  cursor: pointer;
  color: #4c8bd6 !important; }

.ui.list > .item a.header:hover {
  color: #4679b7 !important; }

.ui[class*="left floated"].list {
  float: left; }

.ui[class*="right floated"].list {
  float: right; }

.ui.list .list > .item [class*="left floated"] {
  float: left;
  margin: 0em 1em 0em 0em; }

.ui.list .list > .item [class*="right floated"] {
  float: right;
  margin: 0em 0em 0em 1em; }

.ui.list > .item [class*="left floated"] {
  float: left;
  margin: 0em 1em 0em 0em; }

.ui.list > .item [class*="right floated"] {
  float: right;
  margin: 0em 0em 0em 1em; }

.ui.menu .ui.list > .item {
  display: list-item;
  table-layout: fixed;
  background-color: transparent;
  list-style-type: none;
  list-style-position: outside;
  padding: 0.21428571em 0em;
  line-height: 1.14285714em; }

.ui.menu .ui.list .list > .item {
  display: list-item;
  table-layout: fixed;
  background-color: transparent;
  list-style-type: none;
  list-style-position: outside;
  padding: 0.21428571em 0em;
  line-height: 1.14285714em; }
  .ui.menu .ui.list .list > .item:before {
    border: none;
    background: none; }

.ui.menu .ui.list .list > .item:first-child {
  padding-top: 0em; }

.ui.menu .ui.list .list > .item:last-child {
  padding-bottom: 0em; }

.ui.menu .ui.list > .item:before {
  border: none;
  background: none; }

.ui.menu .ui.list > .item:first-child {
  padding-top: 0em; }

.ui.menu .ui.list > .item:last-child {
  padding-bottom: 0em; }

.ui.horizontal.list {
  display: inline-block;
  font-size: 0em; }
  .ui.horizontal.list > .item {
    display: inline-block;
    margin-left: 1em;
    font-size: 1rem; }
  .ui.horizontal.list:not(.celled) > .item:first-child {
    margin-left: 0em !important;
    padding-left: 0em !important; }
  .ui.horizontal.list .list {
    padding-left: 0em;
    padding-bottom: 0em; }
    .ui.horizontal.list .list > .item > .image, .ui.horizontal.list .list > .item > .icon, .ui.horizontal.list .list > .item > .content {
      vertical-align: middle; }
  .ui.horizontal.list > .item > .image, .ui.horizontal.list > .item > .icon, .ui.horizontal.list > .item > .content {
    vertical-align: middle; }
  .ui.horizontal.list > .item:first-child, .ui.horizontal.list > .item:last-child {
    padding-top: 0.21428571em;
    padding-bottom: 0.21428571em; }
  .ui.horizontal.list > .item > i.icon {
    margin: 0em;
    padding: 0em 0.25em 0em 0em; }
  .ui.horizontal.list > .item > .icon {
    float: none;
    display: inline-block; }
    .ui.horizontal.list > .item > .icon + .content {
      float: none;
      display: inline-block; }

.ui.list .list > .disabled.item, .ui.list > .disabled.item {
  pointer-events: none;
  color: rgba(40, 40, 40, 0.3) !important; }

.ui.inverted.list .list > .disabled.item, .ui.inverted.list > .disabled.item {
  color: rgba(225, 225, 225, 0.3) !important; }

.ui.list .list > a.item:hover .icon, .ui.list > a.item:hover .icon {
  color: rgba(0, 0, 0, 0.87); }

.ui.inverted.list .list > a.item > .icon {
  color: rgba(255, 255, 255, 0.7); }

.ui.inverted.list .list > .item .header {
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.list .list > .item .description {
  color: rgba(255, 255, 255, 0.7); }

.ui.inverted.list .list > a.item {
  cursor: pointer;
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.list .list > a.item:hover {
  color: #4679b7; }

.ui.inverted.list > a.item > .icon {
  color: rgba(255, 255, 255, 0.7); }

.ui.inverted.list > .item .header {
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.list > .item .description {
  color: rgba(255, 255, 255, 0.7); }

.ui.inverted.list > a.item {
  cursor: pointer;
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.list > a.item:hover {
  color: #4679b7; }

.ui.inverted.list .item a:not(.ui) {
  color: rgba(255, 255, 255, 0.9) !important; }
  .ui.inverted.list .item a:not(.ui):hover {
    color: #4679b7 !important; }

.ui.list[class*="top aligned"] .image, .ui.list[class*="top aligned"] .content {
  vertical-align: top !important; }

.ui.list [class*="top aligned"] {
  vertical-align: top !important; }

.ui.list[class*="middle aligned"] .image, .ui.list[class*="middle aligned"] .content {
  vertical-align: middle !important; }

.ui.list [class*="middle aligned"] {
  vertical-align: middle !important; }

.ui.list[class*="bottom aligned"] .image, .ui.list[class*="bottom aligned"] .content {
  vertical-align: bottom !important; }

.ui.list [class*="bottom aligned"] {
  vertical-align: bottom !important; }

.ui.link.list .item, .ui.link.list a.item, .ui.link.list .item a:not(.ui) {
  color: rgba(0, 0, 0, 0.4);
  -webkit-transition: 0.1s color ease;
  transition: 0.1s color ease; }

.ui.link.list a.item:hover, .ui.link.list .item a:not(.ui):hover {
  color: rgba(0, 0, 0, 0.8); }

.ui.link.list a.item:active, .ui.link.list .item a:not(.ui):active {
  color: rgba(0, 0, 0, 0.9); }

.ui.link.list .active.item {
  color: rgba(0, 0, 0, 0.95); }
  .ui.link.list .active.item a:not(.ui) {
    color: rgba(0, 0, 0, 0.95); }

.ui.inverted.link.list .item, .ui.inverted.link.list a.item, .ui.inverted.link.list .item a:not(.ui) {
  color: rgba(255, 255, 255, 0.5); }

.ui.inverted.link.list a.item:hover, .ui.inverted.link.list .item a:not(.ui):hover, .ui.inverted.link.list a.item:active, .ui.inverted.link.list .item a:not(.ui):active, .ui.inverted.link.list a.active.item, .ui.inverted.link.list .active.item a:not(.ui) {
  color: #FFFFFF; }

.ui.selection.list .list > .item {
  cursor: pointer;
  background: transparent;
  padding: 0.5em 0.5em;
  margin: 0em;
  color: rgba(0, 0, 0, 0.4);
  border-radius: 0.5em;
  -webkit-transition: 0.1s color ease, 0.1s padding-left ease, 0.1s background-color ease;
  transition: 0.1s color ease, 0.1s padding-left ease, 0.1s background-color ease; }

.ui.selection.list .list > .item:last-child {
  margin-bottom: 0em; }

.ui.selection.list .list > .item:active {
  background: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.9); }

.ui.selection.list .list > .item.active {
  background: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.95); }

.ui.selection.list > .item {
  cursor: pointer;
  background: transparent;
  padding: 0.5em 0.5em;
  margin: 0em;
  color: rgba(0, 0, 0, 0.4);
  border-radius: 0.5em;
  -webkit-transition: 0.1s color ease, 0.1s padding-left ease, 0.1s background-color ease;
  transition: 0.1s color ease, 0.1s padding-left ease, 0.1s background-color ease; }

.ui.selection.list > .item:last-child {
  margin-bottom: 0em; }

.ui.selection.list > .item:hover {
  background: rgba(0, 0, 0, 0.03);
  color: rgba(0, 0, 0, 0.8); }

.ui.selection.list > .item:active {
  background: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.9); }

.ui.selection.list > .item.active {
  background: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.95); }

.ui.inverted.selection.list > .item {
  background: transparent;
  color: rgba(255, 255, 255, 0.5); }
  .ui.inverted.selection.list > .item:hover {
    background: rgba(255, 255, 255, 0.02);
    color: #FFFFFF; }
  .ui.inverted.selection.list > .item:active, .ui.inverted.selection.list > .item.active {
    background: rgba(255, 255, 255, 0.08);
    color: #FFFFFF; }

.ui.celled.selection.list .list > .item, .ui.divided.selection.list .list > .item, .ui.celled.selection.list > .item, .ui.divided.selection.list > .item {
  border-radius: 0em; }

.ui.animated.list > .item {
  -webkit-transition: 0.25s color ease 0.1s, 0.25s padding-left ease 0.1s, 0.25s background-color ease 0.1s;
  transition: 0.25s color ease 0.1s, 0.25s padding-left ease 0.1s, 0.25s background-color ease 0.1s; }

.ui.animated.list:not(.horizontal) > .item:hover {
  padding-left: 1em; }

.ui.fitted.list:not(.selection) .list > .item, .ui.fitted.list:not(.selection) > .item {
  padding-left: 0em;
  padding-right: 0em; }

.ui.fitted.selection.list .list > .item, .ui.fitted.selection.list > .item {
  margin-left: -0.5em;
  margin-right: -0.5em; }

/* Icon */
/* Image */
/* Content */
/* Header */
/* Description */
/* Child Link */
/* Linking Item */
/* Linked Item Icons */
/* Header Link */
/* Floated Content */
/*******************************
            Coupling
*******************************/
/*******************************
            Types
*******************************/
/*-------------------
      Horizontal
--------------------*/
/* Padding on all elements */
/* Horizontal List */
/*******************************
             States
*******************************/
/*-------------------
       Disabled
--------------------*/
/*-------------------
        Hover
--------------------*/
/*******************************
           Variations
*******************************/
/*-------------------
       Inverted
--------------------*/
/* Item Link */
/* Linking Content */
/*-------------------
       Aligned
--------------------*/
/*-------------------
       Link
--------------------*/
/* Inverted */
/*-------------------
      Selection
--------------------*/
/* Inverted */
/* Celled / Divided Selection List */
/*-------------------
       Animated
--------------------*/
/*-------------------
       Fitted
--------------------*/
/*-------------------
      Bulleted
--------------------*/
ul.ui.list, .ui.bulleted.list {
  margin-left: 1.25rem; }

ul.ui.list li {
  position: relative; }

.ui.bulleted.list .list > .item, .ui.bulleted.list > .item {
  position: relative; }

ul.ui.list li:before {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  pointer-events: none;
  position: absolute;
  top: auto;
  left: auto;
  font-weight: normal;
  margin-left: -1.25rem;
  content: '•';
  opacity: 1;
  color: inherit;
  vertical-align: top; }

.ui.bulleted.list .list > .item:before, .ui.bulleted.list > .item:before {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  pointer-events: none;
  position: absolute;
  top: auto;
  left: auto;
  font-weight: normal;
  margin-left: -1.25rem;
  content: '•';
  opacity: 1;
  color: inherit;
  vertical-align: top; }

ul.ui.list li:before {
  color: rgba(0, 0, 0, 0.87); }

.ui.bulleted.list .list > a.item:before, .ui.bulleted.list > a.item:before {
  color: rgba(0, 0, 0, 0.87); }

ul.ui.list ul, .ui.bulleted.list .list {
  padding-left: 1.25rem; }

/* Horizontal Bulleted */
ul.ui.horizontal.bulleted.list, .ui.horizontal.bulleted.list {
  margin-left: 0em; }

ul.ui.horizontal.bulleted.list li, .ui.horizontal.bulleted.list > .item {
  margin-left: 1.75rem; }

ul.ui.horizontal.bulleted.list li:first-child, .ui.horizontal.bulleted.list > .item:first-child {
  margin-left: 0em; }

ul.ui.horizontal.bulleted.list li::before, .ui.horizontal.bulleted.list > .item::before {
  color: rgba(0, 0, 0, 0.87); }

ul.ui.horizontal.bulleted.list li:first-child::before, .ui.horizontal.bulleted.list > .item:first-child::before {
  display: none; }

/*-------------------
       Ordered
--------------------*/
ol.ui.list {
  counter-reset: ordered;
  margin-left: 1.25rem;
  list-style-type: none; }

.ui.ordered.list {
  counter-reset: ordered;
  margin-left: 1.25rem;
  list-style-type: none; }
  .ui.ordered.list .list {
    counter-reset: ordered;
    margin-left: 1.25rem;
    list-style-type: none; }

ol.ui.list ol {
  counter-reset: ordered;
  margin-left: 1.25rem;
  list-style-type: none; }

ol.ui.list li {
  list-style-type: none;
  position: relative; }

.ui.ordered.list .list > .item, .ui.ordered.list > .item {
  list-style-type: none;
  position: relative; }

ol.ui.list li:before {
  position: absolute;
  top: auto;
  left: auto;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  pointer-events: none;
  margin-left: -1.25rem;
  counter-increment: ordered;
  content: counters(ordered, ".") " ";
  text-align: right;
  color: rgba(0, 0, 0, 0.87);
  vertical-align: middle;
  opacity: 0.8; }

.ui.ordered.list .list > .item:before, .ui.ordered.list > .item:before {
  position: absolute;
  top: auto;
  left: auto;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  pointer-events: none;
  margin-left: -1.25rem;
  counter-increment: ordered;
  content: counters(ordered, ".") " ";
  text-align: right;
  color: rgba(0, 0, 0, 0.87);
  vertical-align: middle;
  opacity: 0.8; }

ol.ui.inverted.list li:before {
  color: rgba(255, 255, 255, 0.7); }

.ui.ordered.inverted.list .list > .item:before, .ui.ordered.inverted.list > .item:before {
  color: rgba(255, 255, 255, 0.7); }

.ui.ordered.list > .list > .item[data-value], .ui.ordered.list > .item[data-value] {
  content: attr(data-value); }

/* Value */
ol.ui.list li[value]:before {
  content: attr(value); }

ol.ui.list ol {
  margin-left: 1em; }

/* Child Lists */
.ui.ordered.list .list {
  margin-left: 1em; }

ol.ui.list ol li:before, .ui.ordered.list .list > .item:before {
  margin-left: -2em; }

/* Horizontal Ordered */
ol.ui.horizontal.list, .ui.ordered.horizontal.list {
  margin-left: 0em; }

ol.ui.horizontal.list li:before {
  position: static;
  margin: 0em 0.5em 0em 0em; }

.ui.ordered.horizontal.list .list > .item:before, .ui.ordered.horizontal.list > .item:before {
  position: static;
  margin: 0em 0.5em 0em 0em; }

.ui.divided.list > .item {
  border-top: 1px solid rgba(34, 36, 38, 0.15); }

.ui.divided.list .list > .item, .ui.divided.list .item .list > .item, .ui.divided.list .list > .item:first-child, .ui.divided.list > .item:first-child {
  border-top: none; }

.ui.divided.list:not(.horizontal) .list > .item:first-child {
  border-top-width: 1px; }

.ui.divided.bulleted.list:not(.horizontal), .ui.divided.bulleted.list .list {
  margin-left: 0em;
  padding-left: 0em; }

.ui.divided.bulleted.list > .item:not(.horizontal) {
  padding-left: 1.25rem; }

.ui.divided.ordered.list {
  margin-left: 0em; }
  .ui.divided.ordered.list .list > .item, .ui.divided.ordered.list > .item {
    padding-left: 1.25rem; }
  .ui.divided.ordered.list .item .list {
    margin-left: 0em;
    margin-right: 0em;
    padding-bottom: 0.21428571em; }
    .ui.divided.ordered.list .item .list > .item {
      padding-left: 1em; }

.ui.divided.selection.list .list > .item, .ui.divided.selection.list > .item {
  margin: 0em;
  border-radius: 0em; }

.ui.divided.horizontal.list {
  margin-left: 0em; }
  .ui.divided.horizontal.list > .item {
    border-top: none;
    border-left: 1px solid rgba(34, 36, 38, 0.15);
    margin: 0em;
    line-height: 0.6; }
    .ui.divided.horizontal.list > .item:not(:first-child) {
      padding-left: 0.5em; }
    .ui.divided.horizontal.list > .item:not(:last-child) {
      padding-right: 0.5em; }
    .ui.divided.horizontal.list > .item:first-child {
      border-left: none; }

.ui.divided.inverted.list > .item, .ui.divided.inverted.list > .list {
  border-color: rgba(255, 255, 255, 0.1); }

.ui.divided.inverted.horizontal.list > .item {
  border-color: rgba(255, 255, 255, 0.1); }

.ui.celled.list > .item, .ui.celled.list > .list {
  border-top: 1px solid rgba(34, 36, 38, 0.15);
  padding-left: 0.5em;
  padding-right: 0.5em; }

.ui.celled.list > .item:last-child {
  border-bottom: 1px solid rgba(34, 36, 38, 0.15); }

.ui.celled.list > .item:first-child, .ui.celled.list > .item:last-child {
  padding-top: 0.21428571em;
  padding-bottom: 0.21428571em; }

.ui.celled.list .item .list > .item {
  border-width: 0px; }

.ui.celled.list .list > .item:first-child {
  border-top-width: 0px; }

.ui.celled.bulleted.list {
  margin-left: 0em; }
  .ui.celled.bulleted.list .list > .item, .ui.celled.bulleted.list > .item {
    padding-left: 1.25rem; }
  .ui.celled.bulleted.list .item .list {
    margin-left: -1.25rem;
    margin-right: -1.25rem;
    padding-bottom: 0.21428571em; }

.ui.celled.ordered.list {
  margin-left: 0em; }
  .ui.celled.ordered.list .list > .item, .ui.celled.ordered.list > .item {
    padding-left: 1.25rem; }
  .ui.celled.ordered.list .item .list {
    margin-left: 0em;
    margin-right: 0em;
    padding-bottom: 0.21428571em; }
  .ui.celled.ordered.list .list > .item {
    padding-left: 1em; }

.ui.horizontal.celled.list {
  margin-left: 0em; }
  .ui.horizontal.celled.list .list > .item {
    border-top: none;
    border-left: 1px solid rgba(34, 36, 38, 0.15);
    margin: 0em;
    padding-left: 0.5em;
    padding-right: 0.5em;
    line-height: 0.6; }
  .ui.horizontal.celled.list .list > .item:last-child {
    border-bottom: none;
    border-right: 1px solid rgba(34, 36, 38, 0.15); }
  .ui.horizontal.celled.list > .item {
    border-top: none;
    border-left: 1px solid rgba(34, 36, 38, 0.15);
    margin: 0em;
    padding-left: 0.5em;
    padding-right: 0.5em;
    line-height: 0.6; }
  .ui.horizontal.celled.list > .item:last-child {
    border-bottom: none;
    border-right: 1px solid rgba(34, 36, 38, 0.15); }

.ui.celled.inverted.list > .item, .ui.celled.inverted.list > .list {
  border-color: 1px solid rgba(255, 255, 255, 0.1); }

.ui.celled.inverted.horizontal.list .list > .item, .ui.celled.inverted.horizontal.list > .item {
  border-color: 1px solid rgba(255, 255, 255, 0.1); }

.ui.relaxed.list:not(.horizontal) > .item:not(:first-child) {
  padding-top: 0.42857143em; }

.ui.relaxed.list:not(.horizontal) > .item:not(:last-child) {
  padding-bottom: 0.42857143em; }

.ui.horizontal.relaxed.list .list > .item:not(:first-child) {
  padding-left: 1rem; }

.ui.horizontal.relaxed.list .list > .item:not(:last-child) {
  padding-right: 1rem; }

.ui.horizontal.relaxed.list > .item:not(:first-child) {
  padding-left: 1rem; }

.ui.horizontal.relaxed.list > .item:not(:last-child) {
  padding-right: 1rem; }

.ui[class*="very relaxed"].list:not(.horizontal) > .item:not(:first-child) {
  padding-top: 0.85714286em; }

.ui[class*="very relaxed"].list:not(.horizontal) > .item:not(:last-child) {
  padding-bottom: 0.85714286em; }

.ui.horizontal[class*="very relaxed"].list .list > .item:not(:first-child) {
  padding-left: 1.5rem; }

.ui.horizontal[class*="very relaxed"].list .list > .item:not(:last-child) {
  padding-right: 1.5rem; }

.ui.horizontal[class*="very relaxed"].list > .item:not(:first-child) {
  padding-left: 1.5rem; }

.ui.horizontal[class*="very relaxed"].list > .item:not(:last-child) {
  padding-right: 1.5rem; }

.ui.mini.list {
  font-size: 0.78571429em; }

.ui.tiny.list {
  font-size: 0.85714286em; }

.ui.small.list {
  font-size: 0.92857143em; }

.ui.list {
  font-size: 1em; }

.ui.large.list {
  font-size: 1.14285714em; }

.ui.big.list {
  font-size: 1.28571429em; }

.ui.huge.list {
  font-size: 1.42857143em; }

.ui.massive.list {
  font-size: 1.71428571em; }

.ui.mini.horizontal.list .list > .item, .ui.mini.horizontal.list > .item {
  font-size: 0.78571429rem; }

.ui.tiny.horizontal.list .list > .item, .ui.tiny.horizontal.list > .item {
  font-size: 0.85714286rem; }

.ui.small.horizontal.list .list > .item, .ui.small.horizontal.list > .item {
  font-size: 0.92857143rem; }

.ui.horizontal.list .list > .item, .ui.horizontal.list > .item {
  font-size: 1rem; }

.ui.large.horizontal.list .list > .item, .ui.large.horizontal.list > .item {
  font-size: 1.14285714rem; }

.ui.big.horizontal.list .list > .item, .ui.big.horizontal.list > .item {
  font-size: 1.28571429rem; }

.ui.huge.horizontal.list .list > .item, .ui.huge.horizontal.list > .item {
  font-size: 1.42857143rem; }

.ui.massive.horizontal.list .list > .item, .ui.massive.horizontal.list > .item {
  font-size: 1.71428571rem; }

/*!
 * # Semantic UI 2.2.12 - Loader
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Loader
*******************************/
/* Standard Size */
.ui.loader {
  display: none;
  position: absolute;
  top: 50%;
  left: 50%;
  margin: 0px;
  text-align: center;
  z-index: 1000;
  -webkit-transform: translateX(-50%) translateY(-50%);
  transform: translateX(-50%) translateY(-50%); }
  .ui.loader:before {
    position: absolute;
    content: '';
    top: 0%;
    left: 50%;
    width: 100%;
    height: 100%;
    border-radius: 500rem;
    border: 0.2em solid rgba(0, 0, 0, 0.1); }
  .ui.loader:after {
    position: absolute;
    content: '';
    top: 0%;
    left: 50%;
    width: 100%;
    height: 100%;
    -webkit-animation: loader 0.6s linear;
    animation: loader 0.6s linear;
    -webkit-animation-iteration-count: infinite;
    animation-iteration-count: infinite;
    border-radius: 500rem;
    border-color: #767676 transparent transparent;
    border-style: solid;
    border-width: 0.2em;
    box-shadow: 0px 0px 0px 1px transparent; }

.ui.mini.loader:before, .ui.mini.loader:after {
  width: 1rem;
  height: 1rem;
  margin: 0em 0em 0em -0.5rem; }

.ui.tiny.loader:before, .ui.tiny.loader:after {
  width: 1.14285714rem;
  height: 1.14285714rem;
  margin: 0em 0em 0em -0.57142857rem; }

.ui.small.loader:before, .ui.small.loader:after {
  width: 1.71428571rem;
  height: 1.71428571rem;
  margin: 0em 0em 0em -0.85714286rem; }

.ui.loader:before, .ui.loader:after {
  width: 2.28571429rem;
  height: 2.28571429rem;
  margin: 0em 0em 0em -1.14285714rem; }

.ui.large.loader:before, .ui.large.loader:after {
  width: 3.42857143rem;
  height: 3.42857143rem;
  margin: 0em 0em 0em -1.71428571rem; }

.ui.big.loader:before, .ui.big.loader:after {
  width: 3.71428571rem;
  height: 3.71428571rem;
  margin: 0em 0em 0em -1.85714286rem; }

.ui.huge.loader:before, .ui.huge.loader:after {
  width: 4.14285714rem;
  height: 4.14285714rem;
  margin: 0em 0em 0em -2.07142857rem; }

.ui.massive.loader:before, .ui.massive.loader:after {
  width: 4.57142857rem;
  height: 4.57142857rem;
  margin: 0em 0em 0em -2.28571429rem; }

.ui.dimmer .loader {
  display: block; }

.ui.dimmer .ui.loader {
  color: rgba(255, 255, 255, 0.9); }
  .ui.dimmer .ui.loader:before {
    border-color: rgba(255, 255, 255, 0.15); }
  .ui.dimmer .ui.loader:after {
    border-color: #FFFFFF transparent transparent; }

.ui.inverted.dimmer .ui.loader {
  color: rgba(0, 0, 0, 0.87); }
  .ui.inverted.dimmer .ui.loader:before {
    border-color: rgba(0, 0, 0, 0.1); }
  .ui.inverted.dimmer .ui.loader:after {
    border-color: #767676 transparent transparent; }

.ui.text.loader {
  width: auto !important;
  height: auto !important;
  text-align: center;
  font-style: normal; }

.ui.indeterminate.loader:after {
  -webkit-animation-direction: reverse;
  animation-direction: reverse;
  -webkit-animation-duration: 1.2s;
  animation-duration: 1.2s; }

.ui.loader.active, .ui.loader.visible {
  display: block; }

.ui.loader.disabled, .ui.loader.hidden {
  display: none; }

.ui.inverted.dimmer .ui.mini.loader, .ui.mini.loader {
  width: 1rem;
  height: 1rem;
  font-size: 0.78571429em; }

.ui.inverted.dimmer .ui.tiny.loader, .ui.tiny.loader {
  width: 1.14285714rem;
  height: 1.14285714rem;
  font-size: 0.85714286em; }

.ui.inverted.dimmer .ui.small.loader, .ui.small.loader {
  width: 1.71428571rem;
  height: 1.71428571rem;
  font-size: 0.92857143em; }

.ui.inverted.dimmer .ui.loader, .ui.loader {
  width: 2.28571429rem;
  height: 2.28571429rem;
  font-size: 1em; }

.ui.inverted.dimmer .ui.large.loader, .ui.large.loader {
  width: 3.42857143rem;
  height: 3.42857143rem;
  font-size: 1.14285714em; }

.ui.inverted.dimmer .ui.big.loader, .ui.big.loader {
  width: 3.71428571rem;
  height: 3.71428571rem;
  font-size: 1.28571429em; }

.ui.inverted.dimmer .ui.huge.loader, .ui.huge.loader {
  width: 4.14285714rem;
  height: 4.14285714rem;
  font-size: 1.42857143em; }

.ui.inverted.dimmer .ui.massive.loader, .ui.massive.loader {
  width: 4.57142857rem;
  height: 4.57142857rem;
  font-size: 1.71428571em; }

.ui.mini.text.loader {
  min-width: 1rem;
  padding-top: 1.78571429rem; }

.ui.tiny.text.loader {
  min-width: 1.14285714rem;
  padding-top: 1.92857143rem; }

.ui.small.text.loader {
  min-width: 1.71428571rem;
  padding-top: 2.5rem; }

.ui.text.loader {
  min-width: 2.28571429rem;
  padding-top: 3.07142857rem; }

.ui.large.text.loader {
  min-width: 3.42857143rem;
  padding-top: 4.21428571rem; }

.ui.big.text.loader {
  min-width: 3.71428571rem;
  padding-top: 4.5rem; }

.ui.huge.text.loader {
  min-width: 4.14285714rem;
  padding-top: 4.92857143rem; }

.ui.massive.text.loader {
  min-width: 4.57142857rem;
  padding-top: 5.35714286rem; }

.ui.inverted.loader {
  color: rgba(255, 255, 255, 0.9); }
  .ui.inverted.loader:before {
    border-color: rgba(255, 255, 255, 0.15); }
  .ui.inverted.loader:after {
    border-top-color: #FFFFFF; }

.ui.inline.loader {
  position: relative;
  vertical-align: middle;
  margin: 0em;
  left: 0em;
  top: 0em;
  -webkit-transform: none;
  transform: none; }
  .ui.inline.loader.active, .ui.inline.loader.visible {
    display: inline-block; }

.ui.centered.inline.loader.active, .ui.centered.inline.loader.visible {
  display: block;
  margin-left: auto;
  margin-right: auto; }

/* Static Shape */
/* Active Shape */
/* Active Animation */
@-webkit-keyframes loader {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

@keyframes loader {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

/*!
 * # Semantic UI 2.2.12 - Rail
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Rails
*******************************/
.ui.rail {
  position: absolute;
  top: 0%;
  width: 300px;
  height: 100%; }

.ui.left.rail {
  left: auto;
  right: 100%;
  padding: 0em 2rem 0em 0em;
  margin: 0em 2rem 0em 0em; }

.ui.right.rail {
  left: 100%;
  right: auto;
  padding: 0em 0em 0em 2rem;
  margin: 0em 0em 0em 2rem; }

.ui.left.internal.rail {
  left: 0%;
  right: auto;
  padding: 0em 0em 0em 2rem;
  margin: 0em 0em 0em 2rem; }

.ui.right.internal.rail {
  left: auto;
  right: 0%;
  padding: 0em 2rem 0em 0em;
  margin: 0em 2rem 0em 0em; }

.ui.dividing.rail {
  width: 302.5px; }

.ui.left.dividing.rail {
  padding: 0em 2.5rem 0em 0em;
  margin: 0em 2.5rem 0em 0em;
  border-right: 1px solid rgba(34, 36, 38, 0.15); }

.ui.right.dividing.rail {
  border-left: 1px solid rgba(34, 36, 38, 0.15);
  padding: 0em 0em 0em 2.5rem;
  margin: 0em 0em 0em 2.5rem; }

.ui.close.rail {
  width: calc( 300px  +  1em); }

.ui.close.left.rail {
  padding: 0em 1em 0em 0em;
  margin: 0em 1em 0em 0em; }

.ui.close.right.rail {
  padding: 0em 0em 0em 1em;
  margin: 0em 0em 0em 1em; }

.ui.very.close.rail {
  width: calc( 300px  +  0.5em); }

.ui.very.close.left.rail {
  padding: 0em 0.5em 0em 0em;
  margin: 0em 0.5em 0em 0em; }

.ui.very.close.right.rail {
  padding: 0em 0em 0em 0.5em;
  margin: 0em 0em 0em 0.5em; }

.ui.attached.left.rail, .ui.attached.right.rail {
  padding: 0em;
  margin: 0em; }

.ui.mini.rail {
  font-size: 0.78571429rem; }

.ui.tiny.rail {
  font-size: 0.85714286rem; }

.ui.small.rail {
  font-size: 0.92857143rem; }

.ui.rail {
  font-size: 1rem; }

.ui.large.rail {
  font-size: 1.14285714rem; }

.ui.big.rail {
  font-size: 1.28571429rem; }

.ui.huge.rail {
  font-size: 1.42857143rem; }

.ui.massive.rail {
  font-size: 1.71428571rem; }

/*!
 * # Semantic UI 2.2.12 - Reveal
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Reveal
*******************************/
.ui.reveal {
  display: inherit;
  position: relative !important;
  font-size: 0em !important; }
  .ui.reveal > .visible.content {
    position: absolute !important;
    top: 0em !important;
    left: 0em !important;
    z-index: 3 !important;
    -webkit-transition: all 0.5s ease 0.1s;
    transition: all 0.5s ease 0.1s; }
  .ui.reveal > .hidden.content {
    position: relative !important;
    z-index: 2 !important; }

.ui.active.reveal .visible.content, .ui.reveal:hover .visible.content {
  z-index: 4 !important; }

.ui.slide.reveal {
  position: relative !important;
  overflow: hidden !important;
  white-space: nowrap; }
  .ui.slide.reveal > .content {
    display: block;
    width: 100%;
    float: left;
    margin: 0em;
    -webkit-transition: -webkit-transform 0.5s ease 0.1s;
    transition: -webkit-transform 0.5s ease 0.1s;
    transition: transform 0.5s ease 0.1s;
    transition: transform 0.5s ease 0.1s, -webkit-transform 0.5s ease 0.1s; }
  .ui.slide.reveal > .visible.content {
    position: relative !important; }
  .ui.slide.reveal > .hidden.content {
    position: absolute !important;
    left: 0% !important;
    width: 100% !important;
    -webkit-transform: translateX(100%) !important;
    transform: translateX(100%) !important; }

.ui.slide.active.reveal > .visible.content, .ui.slide.reveal:hover > .visible.content {
  -webkit-transform: translateX(-100%) !important;
  transform: translateX(-100%) !important; }

.ui.slide.active.reveal > .hidden.content, .ui.slide.reveal:hover > .hidden.content {
  -webkit-transform: translateX(0%) !important;
  transform: translateX(0%) !important; }

.ui.slide.right.reveal > .visible.content {
  -webkit-transform: translateX(0%) !important;
  transform: translateX(0%) !important; }

.ui.slide.right.reveal > .hidden.content {
  -webkit-transform: translateX(-100%) !important;
  transform: translateX(-100%) !important; }

.ui.slide.right.active.reveal > .visible.content, .ui.slide.right.reveal:hover > .visible.content {
  -webkit-transform: translateX(100%) !important;
  transform: translateX(100%) !important; }

.ui.slide.right.active.reveal > .hidden.content, .ui.slide.right.reveal:hover > .hidden.content {
  -webkit-transform: translateX(0%) !important;
  transform: translateX(0%) !important; }

.ui.slide.up.reveal > .hidden.content {
  -webkit-transform: translateY(100%) !important;
  transform: translateY(100%) !important; }

.ui.slide.up.active.reveal > .visible.content, .ui.slide.up.reveal:hover > .visible.content {
  -webkit-transform: translateY(-100%) !important;
  transform: translateY(-100%) !important; }

.ui.slide.up.active.reveal > .hidden.content, .ui.slide.up.reveal:hover > .hidden.content {
  -webkit-transform: translateY(0%) !important;
  transform: translateY(0%) !important; }

.ui.slide.down.reveal > .hidden.content {
  -webkit-transform: translateY(-100%) !important;
  transform: translateY(-100%) !important; }

.ui.slide.down.active.reveal > .visible.content, .ui.slide.down.reveal:hover > .visible.content {
  -webkit-transform: translateY(100%) !important;
  transform: translateY(100%) !important; }

.ui.slide.down.active.reveal > .hidden.content, .ui.slide.down.reveal:hover > .hidden.content {
  -webkit-transform: translateY(0%) !important;
  transform: translateY(0%) !important; }

.ui.fade.reveal > .visible.content {
  opacity: 1; }

.ui.fade.active.reveal > .visible.content, .ui.fade.reveal:hover > .visible.content {
  opacity: 0; }

.ui.move.reveal {
  position: relative !important;
  overflow: hidden !important;
  white-space: nowrap; }
  .ui.move.reveal > .content {
    display: block;
    float: left;
    margin: 0em;
    -webkit-transition: -webkit-transform 0.5s cubic-bezier(0.175, 0.885, 0.32, 1) 0.1s;
    transition: -webkit-transform 0.5s cubic-bezier(0.175, 0.885, 0.32, 1) 0.1s;
    transition: transform 0.5s cubic-bezier(0.175, 0.885, 0.32, 1) 0.1s;
    transition: transform 0.5s cubic-bezier(0.175, 0.885, 0.32, 1) 0.1s, -webkit-transform 0.5s cubic-bezier(0.175, 0.885, 0.32, 1) 0.1s; }
  .ui.move.reveal > .visible.content {
    position: relative !important; }
  .ui.move.reveal > .hidden.content {
    position: absolute !important;
    left: 0% !important;
    width: 100% !important; }

.ui.move.active.reveal > .visible.content, .ui.move.reveal:hover > .visible.content {
  -webkit-transform: translateX(-100%) !important;
  transform: translateX(-100%) !important; }

.ui.move.right.active.reveal > .visible.content, .ui.move.right.reveal:hover > .visible.content {
  -webkit-transform: translateX(100%) !important;
  transform: translateX(100%) !important; }

.ui.move.up.active.reveal > .visible.content, .ui.move.up.reveal:hover > .visible.content {
  -webkit-transform: translateY(-100%) !important;
  transform: translateY(-100%) !important; }

.ui.move.down.active.reveal > .visible.content, .ui.move.down.reveal:hover > .visible.content {
  -webkit-transform: translateY(100%) !important;
  transform: translateY(100%) !important; }

.ui.rotate.reveal > .visible.content {
  -webkit-transition-duration: 0.5s;
  transition-duration: 0.5s;
  -webkit-transform: rotate(0deg);
  transform: rotate(0deg);
  -webkit-transform-origin: bottom right;
  transform-origin: bottom right; }

.ui.rotate.right.reveal > .visible.content {
  -webkit-transform-origin: bottom right;
  transform-origin: bottom right; }

.ui.rotate.active.reveal > .visible.content, .ui.rotate.reveal:hover > .visible.content {
  -webkit-transform: rotate(110deg);
  transform: rotate(110deg); }

.ui.rotate.right.active.reveal > .visible.content, .ui.rotate.right.reveal:hover > .visible.content {
  -webkit-transform: rotate(110deg);
  transform: rotate(110deg); }

.ui.rotate.left.reveal > .visible.content {
  -webkit-transform-origin: bottom left;
  transform-origin: bottom left; }

.ui.rotate.left.active.reveal > .visible.content, .ui.rotate.left.reveal:hover > .visible.content {
  -webkit-transform: rotate(-110deg);
  transform: rotate(-110deg); }

.ui.disabled.reveal:hover > .visible.visible.content {
  position: static !important;
  display: block !important;
  opacity: 1 !important;
  top: 0 !important;
  left: 0 !important;
  right: auto !important;
  bottom: auto !important;
  -webkit-transform: none !important;
  transform: none !important; }

.ui.disabled.reveal:hover > .hidden.hidden.content {
  display: none !important; }

.ui.visible.reveal {
  overflow: visible; }

.ui.instant.reveal > .content {
  -webkit-transition-delay: 0s !important;
  transition-delay: 0s !important; }

.ui.reveal > .content {
  font-size: 1rem !important; }

/*!
 * # Semantic UI 2.2.12 - Segment
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Segment
*******************************/
.ui.segment {
  position: relative;
  background: #FFFFFF;
  box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15);
  margin: 1rem 0em;
  padding: 1em 1em;
  border-radius: 0.28571429rem;
  border: 1px solid rgba(34, 36, 38, 0.15); }
  .ui.segment:first-child {
    margin-top: 0em; }
  .ui.segment:last-child {
    margin-bottom: 0em; }

.ui.vertical.segment {
  margin: 0em;
  padding-left: 0em;
  padding-right: 0em;
  background: none transparent;
  border-radius: 0px;
  box-shadow: none;
  border: none;
  border-bottom: 1px solid rgba(34, 36, 38, 0.15); }
  .ui.vertical.segment:last-child {
    border-bottom: none; }

.ui.inverted.segment > .ui.header {
  color: #FFFFFF; }

.ui[class*="bottom attached"].segment > [class*="top attached"].label {
  border-top-left-radius: 0em;
  border-top-right-radius: 0em; }

.ui[class*="top attached"].segment > [class*="bottom attached"].label {
  border-bottom-left-radius: 0em;
  border-bottom-right-radius: 0em; }

.ui.attached.segment:not(.top):not(.bottom) > [class*="top attached"].label {
  border-top-left-radius: 0em;
  border-top-right-radius: 0em; }

.ui.attached.segment:not(.top):not(.bottom) > [class*="bottom attached"].label {
  border-bottom-left-radius: 0em;
  border-bottom-right-radius: 0em; }

.ui.page.grid.segment {
  padding-top: 2em;
  padding-bottom: 2em; }

.ui.grid > .row > .ui.segment.column, .ui.grid > .ui.segment.column {
  padding-top: 2em;
  padding-bottom: 2em; }

.ui.grid.segment {
  margin: 1rem 0em;
  border-radius: 0.28571429rem; }

.ui.basic.table.segment {
  background: #FFFFFF;
  border: 1px solid rgba(34, 36, 38, 0.15);
  box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15); }

.ui[class*="very basic"].table.segment {
  padding: 1em 1em; }

.ui.piled.segments {
  margin: 3em 0em;
  box-shadow: '';
  z-index: auto; }

.ui.piled.segment {
  margin: 3em 0em;
  box-shadow: '';
  z-index: auto; }
  .ui.piled.segment:first-child {
    margin-top: 0em; }
  .ui.piled.segment:last-child {
    margin-bottom: 0em; }

.ui.piled.segments:after, .ui.piled.segments:before {
  background-color: #FFFFFF;
  visibility: visible;
  content: '';
  display: block;
  height: 100%;
  left: 0px;
  position: absolute;
  width: 100%;
  border: 1px solid rgba(34, 36, 38, 0.15);
  box-shadow: ''; }

.ui.piled.segment:after, .ui.piled.segment:before {
  background-color: #FFFFFF;
  visibility: visible;
  content: '';
  display: block;
  height: 100%;
  left: 0px;
  position: absolute;
  width: 100%;
  border: 1px solid rgba(34, 36, 38, 0.15);
  box-shadow: ''; }

.ui.piled.segments:before, .ui.piled.segment:before {
  -webkit-transform: rotate(-1.2deg);
  transform: rotate(-1.2deg);
  top: 0;
  z-index: -2; }

.ui.piled.segments:after, .ui.piled.segment:after {
  -webkit-transform: rotate(1.2deg);
  transform: rotate(1.2deg);
  top: 0;
  z-index: -1; }

.ui[class*="top attached"].piled.segment {
  margin-top: 3em;
  margin-bottom: 0em; }

.ui.piled.segment[class*="top attached"]:first-child {
  margin-top: 0em; }

.ui.piled.segment[class*="bottom attached"] {
  margin-top: 0em;
  margin-bottom: 3em; }
  .ui.piled.segment[class*="bottom attached"]:last-child {
    margin-bottom: 0em; }

.ui.stacked.segment {
  padding-bottom: 1.4em; }

.ui.stacked.segments:before, .ui.stacked.segments:after {
  content: '';
  position: absolute;
  bottom: -3px;
  left: 0%;
  border-top: 1px solid rgba(34, 36, 38, 0.15);
  background: rgba(0, 0, 0, 0.03);
  width: 100%;
  height: 6px;
  visibility: visible; }

.ui.stacked.segment:before, .ui.stacked.segment:after {
  content: '';
  position: absolute;
  bottom: -3px;
  left: 0%;
  border-top: 1px solid rgba(34, 36, 38, 0.15);
  background: rgba(0, 0, 0, 0.03);
  width: 100%;
  height: 6px;
  visibility: visible; }

.ui.stacked.segments:before, .ui.stacked.segment:before {
  display: none; }

.ui.tall.stacked.segments:before, .ui.tall.stacked.segment:before {
  display: block;
  bottom: 0px; }

.ui.stacked.inverted.segments:before, .ui.stacked.inverted.segments:after {
  background-color: rgba(0, 0, 0, 0.03);
  border-top: 1px solid rgba(34, 36, 38, 0.35); }

.ui.stacked.inverted.segment:before, .ui.stacked.inverted.segment:after {
  background-color: rgba(0, 0, 0, 0.03);
  border-top: 1px solid rgba(34, 36, 38, 0.35); }

.ui.padded.segment {
  padding: 1.5em; }

.ui[class*="very padded"].segment {
  padding: 3em; }

.ui.padded.segment.vertical.segment, .ui[class*="very padded"].vertical.segment {
  padding-left: 0px;
  padding-right: 0px; }

.ui.compact.segment {
  display: table; }

.ui.compact.segments {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex; }
  .ui.compact.segments .segment {
    display: block;
    -webkit-box-flex: 0;
    -ms-flex: 0 1 auto;
    flex: 0 1 auto; }

.ui.segments .compact.segment {
  display: block;
  -webkit-box-flex: 0;
  -ms-flex: 0 1 auto;
  flex: 0 1 auto; }

.ui.circular.segment {
  display: table-cell;
  padding: 2em;
  text-align: center;
  vertical-align: middle;
  border-radius: 500em; }

.ui.raised.segments, .ui.raised.segment {
  box-shadow: 0px 2px 4px 0px rgba(34, 36, 38, 0.12), 0px 2px 10px 0px rgba(34, 36, 38, 0.15); }

.ui.segments {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  position: relative;
  margin: 1rem 0em;
  border: 1px solid rgba(34, 36, 38, 0.15);
  box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15);
  border-radius: 0.28571429rem; }
  .ui.segments:first-child {
    margin-top: 0em; }
  .ui.segments:last-child {
    margin-bottom: 0em; }
  .ui.segments > .segment {
    top: 0px;
    bottom: 0px;
    border-radius: 0px;
    margin: 0em;
    width: auto;
    box-shadow: none;
    border: none;
    border-top: 1px solid rgba(34, 36, 38, 0.15); }
  .ui.segments:not(.horizontal) > .segment:first-child {
    border-top: none;
    margin-top: 0em;
    bottom: 0px;
    margin-bottom: 0em;
    top: 0px;
    border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
  .ui.segments:not(.horizontal) > .segment:last-child {
    top: 0px;
    bottom: 0px;
    margin-top: 0em;
    margin-bottom: 0em;
    box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15), none;
    border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
  .ui.segments:not(.horizontal) > .segment:only-child {
    border-radius: 0.28571429rem; }
  .ui.segments > .ui.segments {
    border-top: 1px solid rgba(34, 36, 38, 0.15);
    margin: 1rem 1rem; }
  .ui.segments > .segments:first-child {
    border-top: none; }
  .ui.segments > .segment + .segments:not(.horizontal) {
    margin-top: 0em; }

.ui.horizontal.segments {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -ms-flex-direction: row;
  flex-direction: row;
  background-color: transparent;
  border-radius: 0px;
  padding: 0em;
  background-color: #FFFFFF;
  box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15);
  margin: 1rem 0em;
  border-radius: 0.28571429rem;
  border: 1px solid rgba(34, 36, 38, 0.15); }

.ui.segments > .horizontal.segments {
  margin: 0em;
  background-color: transparent;
  border-radius: 0px;
  border: none;
  box-shadow: none;
  border-top: 1px solid rgba(34, 36, 38, 0.15); }

.ui.horizontal.segments > .segment {
  -webkit-box-flex: 1;
  flex: 1 1 auto;
  -ms-flex: 1 1 0px;
  /* Solves #2550 MS Flex */
  margin: 0em;
  min-width: 0px;
  background-color: transparent;
  border-radius: 0px;
  border: none;
  box-shadow: none;
  border-left: 1px solid rgba(34, 36, 38, 0.15); }

.ui.segments > .horizontal.segments:first-child {
  border-top: none; }

.ui.horizontal.segments > .segment:first-child {
  border-left: none; }

.ui.disabled.segment {
  opacity: 0.45;
  color: rgba(40, 40, 40, 0.3); }

.ui.loading.segment {
  position: relative;
  cursor: default;
  pointer-events: none;
  text-shadow: none !important;
  color: transparent !important;
  -webkit-transition: all 0s linear;
  transition: all 0s linear; }
  .ui.loading.segment:before {
    position: absolute;
    content: '';
    top: 0%;
    left: 0%;
    background: rgba(255, 255, 255, 0.8);
    width: 100%;
    height: 100%;
    border-radius: 0.28571429rem;
    z-index: 100; }
  .ui.loading.segment:after {
    position: absolute;
    content: '';
    top: 50%;
    left: 50%;
    margin: -1.5em 0em 0em -1.5em;
    width: 3em;
    height: 3em;
    -webkit-animation: segment-spin 0.6s linear;
    animation: segment-spin 0.6s linear;
    -webkit-animation-iteration-count: infinite;
    animation-iteration-count: infinite;
    border-radius: 500rem;
    border-color: #767676 rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1);
    border-style: solid;
    border-width: 0.2em;
    box-shadow: 0px 0px 0px 1px transparent;
    visibility: visible;
    z-index: 101; }

.ui.basic.segment {
  background: none transparent;
  box-shadow: none;
  border: none;
  border-radius: 0px; }

.ui.clearing.segment:after {
  content: ".";
  display: block;
  height: 0;
  clear: both;
  visibility: hidden; }

.ui.red.segment:not(.inverted) {
  border-top: 2px solid #DB2828 !important; }

.ui.inverted.red.segment {
  background-color: #DB2828 !important;
  color: #FFFFFF !important; }

.ui.orange.segment:not(.inverted) {
  border-top: 2px solid #fc7831 !important; }

.ui.inverted.orange.segment {
  background-color: #fc7831 !important;
  color: #FFFFFF !important; }

.ui.yellow.segment:not(.inverted) {
  border-top: 2px solid #FBBD08 !important; }

.ui.inverted.yellow.segment {
  background-color: #FBBD08 !important;
  color: #FFFFFF !important; }

.ui.olive.segment:not(.inverted) {
  border-top: 2px solid #B5CC18 !important; }

.ui.inverted.olive.segment {
  background-color: #B5CC18 !important;
  color: #FFFFFF !important; }

.ui.green.segment:not(.inverted) {
  border-top: 2px solid #21BA45 !important; }

.ui.inverted.green.segment {
  background-color: #21BA45 !important;
  color: #FFFFFF !important; }

.ui.teal.segment:not(.inverted) {
  border-top: 2px solid #00B5AD !important; }

.ui.inverted.teal.segment {
  background-color: #00B5AD !important;
  color: #FFFFFF !important; }

.ui.blue.segment:not(.inverted) {
  border-top: 2px solid #4c8bd6 !important; }

.ui.inverted.blue.segment {
  background-color: #4c8bd6 !important;
  color: #FFFFFF !important; }

.ui.violet.segment:not(.inverted) {
  border-top: 2px solid #6435C9 !important; }

.ui.inverted.violet.segment {
  background-color: #6435C9 !important;
  color: #FFFFFF !important; }

.ui.purple.segment:not(.inverted) {
  border-top: 2px solid #A333C8 !important; }

.ui.inverted.purple.segment {
  background-color: #A333C8 !important;
  color: #FFFFFF !important; }

.ui.pink.segment:not(.inverted) {
  border-top: 2px solid #E03997 !important; }

.ui.inverted.pink.segment {
  background-color: #E03997 !important;
  color: #FFFFFF !important; }

.ui.brown.segment:not(.inverted) {
  border-top: 2px solid #A5673F !important; }

.ui.inverted.brown.segment {
  background-color: #A5673F !important;
  color: #FFFFFF !important; }

.ui.grey.segment:not(.inverted) {
  border-top: 2px solid #767676 !important; }

.ui.inverted.grey.segment {
  background-color: #767676 !important;
  color: #FFFFFF !important; }

.ui.black.segment:not(.inverted) {
  border-top: 2px solid #1B1C1D !important; }

.ui.inverted.black.segment {
  background-color: #1B1C1D !important;
  color: #FFFFFF !important; }

.ui[class*="left aligned"].segment {
  text-align: left; }

.ui[class*="right aligned"].segment {
  text-align: right; }

.ui[class*="center aligned"].segment {
  text-align: center; }

.ui.floated.segment, .ui[class*="left floated"].segment {
  float: left;
  margin-right: 1em; }

.ui[class*="right floated"].segment {
  float: right;
  margin-left: 1em; }

.ui.inverted.segment {
  border: none;
  box-shadow: none;
  background: #1B1C1D;
  color: rgba(255, 255, 255, 0.9); }

.ui.primary.inverted.segment {
  background: #1B1C1D;
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.segment .segment {
  color: rgba(0, 0, 0, 0.87); }

.ui.inverted.segment .inverted.segment {
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.attached.segment {
  border-color: #555555; }

.ui.secondary.segment {
  background: #F3F4F5;
  color: rgba(0, 0, 0, 0.6); }

.ui.secondary.inverted.segment {
  background: #4c4f52 -webkit-linear-gradient(rgba(255, 255, 255, 0.2) 0%, rgba(255, 255, 255, 0.2) 100%);
  background: #4c4f52 linear-gradient(rgba(255, 255, 255, 0.2) 0%, rgba(255, 255, 255, 0.2) 100%);
  color: rgba(255, 255, 255, 0.8); }

.ui.tertiary.segment {
  background: #DCDDDE;
  color: rgba(0, 0, 0, 0.6); }

.ui.tertiary.inverted.segment {
  background: #717579 -webkit-linear-gradient(rgba(255, 255, 255, 0.35) 0%, rgba(255, 255, 255, 0.35) 100%);
  background: #717579 linear-gradient(rgba(255, 255, 255, 0.35) 0%, rgba(255, 255, 255, 0.35) 100%);
  color: rgba(255, 255, 255, 0.8); }

.ui.attached.segment {
  top: 0px;
  bottom: 0px;
  border-radius: 0px;
  margin: 0em -1px;
  width: calc(100% +  2px);
  max-width: calc(100% +  2px);
  box-shadow: none;
  border: 1px solid #D4D4D5; }

.ui.attached:not(.message) + .ui.attached.segment:not(.top) {
  border-top: none; }

.ui[class*="top attached"].segment {
  bottom: 0px;
  margin-bottom: 0em;
  top: 0px;
  margin-top: 1rem;
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }

.ui.segment[class*="top attached"]:first-child {
  margin-top: 0em; }

.ui.segment[class*="bottom attached"] {
  bottom: 0px;
  margin-top: 0em;
  top: 0px;
  margin-bottom: 1rem;
  box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15), none;
  border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
  .ui.segment[class*="bottom attached"]:last-child {
    margin-bottom: 0em; }

.ui.mini.segments .segment, .ui.mini.segment {
  font-size: 0.78571429rem; }

.ui.tiny.segments .segment, .ui.tiny.segment {
  font-size: 0.85714286rem; }

.ui.small.segments .segment, .ui.small.segment {
  font-size: 0.92857143rem; }

.ui.segments .segment, .ui.segment {
  font-size: 1rem; }

.ui.large.segments .segment, .ui.large.segment {
  font-size: 1.14285714rem; }

.ui.big.segments .segment, .ui.big.segment {
  font-size: 1.28571429rem; }

.ui.huge.segments .segment, .ui.huge.segment {
  font-size: 1.42857143rem; }

.ui.massive.segments .segment, .ui.massive.segment {
  font-size: 1.71428571rem; }

@-webkit-keyframes segment-spin {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

@keyframes segment-spin {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

/*!
 * # Semantic UI 2.2.12 - Step
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Plural
*******************************/
.ui.steps {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-box-align: stretch;
  -ms-flex-align: stretch;
  align-items: stretch;
  margin: 1em 0em;
  background: '';
  box-shadow: none;
  line-height: 1.14285714em;
  border-radius: 0.28571429rem;
  border: 1px solid rgba(34, 36, 38, 0.15); }
  .ui.steps:first-child {
    margin-top: 0em; }
  .ui.steps:last-child {
    margin-bottom: 0em; }
  .ui.steps .step {
    position: relative;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-flex: 1;
    -ms-flex: 1 0 auto;
    flex: 1 0 auto;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row;
    vertical-align: middle;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
    margin: 0em 0em;
    padding: 1.14285714em 2em;
    background: #FFFFFF;
    color: rgba(0, 0, 0, 0.87);
    box-shadow: none;
    border-radius: 0em;
    border: none;
    border-right: 1px solid rgba(34, 36, 38, 0.15);
    -webkit-transition: background-color 0.1s ease, opacity 0.1s ease, color 0.1s ease, box-shadow 0.1s ease;
    transition: background-color 0.1s ease, opacity 0.1s ease, color 0.1s ease, box-shadow 0.1s ease; }
    .ui.steps .step:after {
      display: none;
      position: absolute;
      z-index: 2;
      content: '';
      top: 50%;
      right: 0%;
      border: medium none;
      background-color: #FFFFFF;
      width: 1.14285714em;
      height: 1.14285714em;
      border-style: solid;
      border-color: rgba(34, 36, 38, 0.15);
      border-width: 0px 1px 1px 0px;
      -webkit-transition: background-color 0.1s ease, opacity 0.1s ease, color 0.1s ease, box-shadow 0.1s ease;
      transition: background-color 0.1s ease, opacity 0.1s ease, color 0.1s ease, box-shadow 0.1s ease;
      -webkit-transform: translateY(-50%) translateX(50%) rotate(-45deg);
      transform: translateY(-50%) translateX(50%) rotate(-45deg); }
    .ui.steps .step:first-child {
      padding-left: 2em;
      border-radius: 0.28571429rem 0em 0em 0.28571429rem; }
    .ui.steps .step:last-child {
      border-radius: 0em 0.28571429rem 0.28571429rem 0em;
      border-right: none;
      margin-right: 0em; }
    .ui.steps .step:only-child {
      border-radius: 0.28571429rem; }
    .ui.steps .step .title {
      font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
      font-size: 1.14285714em;
      font-weight: bold; }
    .ui.steps .step > .title {
      width: 100%; }
    .ui.steps .step .description {
      font-weight: normal;
      font-size: 0.92857143em;
      color: rgba(0, 0, 0, 0.87); }
    .ui.steps .step > .description {
      width: 100%; }
    .ui.steps .step .title ~ .description {
      margin-top: 0.25em; }
    .ui.steps .step > .icon {
      line-height: 1;
      font-size: 2.5em;
      margin: 0em 1rem 0em 0em;
      display: block;
      -webkit-box-flex: 0;
      -ms-flex: 0 1 auto;
      flex: 0 1 auto;
      -ms-flex-item-align: middle;
      -ms-grid-row-align: middle;
      align-self: middle; }
      .ui.steps .step > .icon ~ .content {
        display: block;
        -webkit-box-flex: 0;
        -ms-flex: 0 1 auto;
        flex: 0 1 auto;
        -ms-flex-item-align: middle;
        -ms-grid-row-align: middle;
        align-self: middle;
        -webkit-box-flex: 1 0 auto;
        -ms-flex-positive: 1 0 auto;
        flex-grow: 1 0 auto; }
  .ui.steps:not(.vertical) .step > .icon {
    width: auto; }
  .ui.steps .link.step, .ui.steps a.step {
    cursor: pointer; }

.ui.ordered.steps {
  counter-reset: ordered; }
  .ui.ordered.steps .step:before {
    display: block;
    position: static;
    text-align: center;
    content: counters(ordered, ".");
    -ms-flex-item-align: middle;
    -ms-grid-row-align: middle;
    align-self: middle;
    margin-right: 1rem;
    font-size: 2.5em;
    counter-increment: ordered;
    font-family: inherit;
    font-weight: bold; }
  .ui.ordered.steps .step > * {
    display: block;
    -ms-flex-item-align: middle;
    -ms-grid-row-align: middle;
    align-self: middle; }

.ui.vertical.steps {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  overflow: visible; }
  .ui.vertical.steps .step {
    -webkit-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start;
    border-radius: 0em;
    padding: 1.14285714em 2em;
    border-right: none;
    border-bottom: 1px solid rgba(34, 36, 38, 0.15); }
    .ui.vertical.steps .step:first-child {
      padding: 1.14285714em 2em;
      border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
    .ui.vertical.steps .step:last-child {
      border-bottom: none;
      border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
    .ui.vertical.steps .step:only-child {
      border-radius: 0.28571429rem; }
    .ui.vertical.steps .step:after {
      display: none;
      top: 50%;
      right: 0%;
      border-width: 0px 1px 1px 0px;
      display: none; }
  .ui.vertical.steps .active.step:after {
    display: block; }
  .ui.vertical.steps .step:last-child:after {
    display: none; }
  .ui.vertical.steps .active.step:last-child:after {
    display: block; }

.ui.steps .link.step:hover, .ui.steps a.step:hover {
  background: #F9FAFB;
  color: rgba(0, 0, 0, 0.8); }
  .ui.steps .link.step:hover::after, .ui.steps a.step:hover::after {
    background: #F9FAFB;
    color: rgba(0, 0, 0, 0.8); }

.ui.steps .link.step:active, .ui.steps a.step:active {
  background: #F3F4F5;
  color: rgba(0, 0, 0, 0.9); }
  .ui.steps .link.step:active::after, .ui.steps a.step:active::after {
    background: #F3F4F5;
    color: rgba(0, 0, 0, 0.9); }

.ui.steps .step.active {
  cursor: auto;
  background: #F3F4F5; }
  .ui.steps .step.active:after {
    background: #F3F4F5; }
  .ui.steps .step.active .title {
    color: #4c8bd6; }

.ui.ordered.steps .step.active:before {
  color: rgba(0, 0, 0, 0.85); }

.ui.steps .active.step .icon {
  color: rgba(0, 0, 0, 0.85); }

.ui.steps .step:after, .ui.steps .active.step:after {
  display: block; }

.ui.steps .step:last-child:after, .ui.steps .active.step:last-child:after {
  display: none; }

.ui.steps .link.active.step:hover, .ui.steps a.active.step:hover {
  cursor: pointer;
  background: #DCDDDE;
  color: rgba(0, 0, 0, 0.87); }
  .ui.steps .link.active.step:hover::after, .ui.steps a.active.step:hover::after {
    cursor: pointer;
    background: #DCDDDE;
    color: rgba(0, 0, 0, 0.87); }

.ui.steps .step.completed > .icon:before {
  color: #21BA45; }

.ui.ordered.steps .step.completed:before {
  color: #21BA45; }

.ui.steps .disabled.step {
  cursor: auto;
  background: #FFFFFF;
  pointer-events: none;
  color: rgba(40, 40, 40, 0.3); }
  .ui.steps .disabled.step .title, .ui.steps .disabled.step .description {
    color: rgba(40, 40, 40, 0.3); }
  .ui.steps .disabled.step:after {
    background: #FFFFFF; }

.ui.fluid.steps {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  width: 100%; }

.ui.attached.steps {
  width: calc(100% +  2px) !important;
  margin: 0em -1px 0;
  max-width: calc(100% +  2px);
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
  .ui.attached.steps .step:first-child {
    border-radius: 0.28571429rem 0em 0em 0em; }
  .ui.attached.steps .step:last-child {
    border-radius: 0em 0.28571429rem 0em 0em; }

.ui.bottom.attached.steps {
  margin: 0 -1px 0em;
  border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
  .ui.bottom.attached.steps .step:first-child {
    border-radius: 0em 0em 0em 0.28571429rem; }
  .ui.bottom.attached.steps .step:last-child {
    border-radius: 0em 0em 0.28571429rem 0em; }

.ui.one.steps, .ui.two.steps, .ui.three.steps, .ui.four.steps, .ui.five.steps, .ui.six.steps, .ui.seven.steps, .ui.eight.steps {
  width: 100%; }

.ui.one.steps > .step, .ui.two.steps > .step, .ui.three.steps > .step, .ui.four.steps > .step, .ui.five.steps > .step, .ui.six.steps > .step, .ui.seven.steps > .step, .ui.eight.steps > .step {
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap; }

.ui.one.steps > .step {
  width: 100%; }

.ui.two.steps > .step {
  width: 50%; }

.ui.three.steps > .step {
  width: 33.333%; }

.ui.four.steps > .step {
  width: 25%; }

.ui.five.steps > .step {
  width: 20%; }

.ui.six.steps > .step {
  width: 16.666%; }

.ui.seven.steps > .step {
  width: 14.285%; }

.ui.eight.steps > .step {
  width: 12.500%; }

.ui.mini.steps .step, .ui.mini.step {
  font-size: 0.78571429rem; }

.ui.tiny.steps .step, .ui.tiny.step {
  font-size: 0.85714286rem; }

.ui.small.steps .step, .ui.small.step {
  font-size: 0.92857143rem; }

.ui.steps .step, .ui.step {
  font-size: 1rem; }

.ui.large.steps .step, .ui.large.step {
  font-size: 1.14285714rem; }

.ui.big.steps .step, .ui.big.step {
  font-size: 1.28571429rem; }

.ui.huge.steps .step, .ui.huge.step {
  font-size: 1.42857143rem; }

.ui.massive.steps .step, .ui.massive.step {
  font-size: 1.71428571rem; }

.ui.steps .step.completed > .icon:before, .ui.ordered.steps .step.completed:before {
  font-family: 'Step';
  content: '\e800'; }

@media only screen and (max-width: 767px) {
  .ui.steps:not(.unstackable) {
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    overflow: visible;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column; }
    .ui.steps:not(.unstackable) .step {
      width: 100% !important;
      -webkit-box-orient: vertical;
      -webkit-box-direction: normal;
      -ms-flex-direction: column;
      flex-direction: column;
      border-radius: 0em;
      padding: 1.14285714em 2em; }
      .ui.steps:not(.unstackable) .step:first-child {
        padding: 1.14285714em 2em;
        border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
      .ui.steps:not(.unstackable) .step:last-child {
        border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
      .ui.steps:not(.unstackable) .step:after {
        display: none !important; }
      .ui.steps:not(.unstackable) .step .content {
        text-align: center; }
      .ui.steps:not(.unstackable) .step > .icon {
        margin: 0em 0em 1rem 0em; }
  .ui.ordered.steps:not(.unstackable) .step:before {
    margin: 0em 0em 1rem 0em; } }

@media only screen and (max-width: 991px) {
  .ui[class*="tablet stackable"].steps {
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    overflow: visible;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column; }
    .ui[class*="tablet stackable"].steps .step {
      -webkit-box-orient: vertical;
      -webkit-box-direction: normal;
      -ms-flex-direction: column;
      flex-direction: column;
      border-radius: 0em;
      padding: 1.14285714em 2em; }
      .ui[class*="tablet stackable"].steps .step:first-child {
        padding: 1.14285714em 2em;
        border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
      .ui[class*="tablet stackable"].steps .step:last-child {
        border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
      .ui[class*="tablet stackable"].steps .step:after {
        display: none !important; }
      .ui[class*="tablet stackable"].steps .step .content {
        text-align: center; }
      .ui[class*="tablet stackable"].steps .step > .icon {
        margin: 0em 0em 1rem 0em; }
  .ui[class*="tablet stackable"].ordered.steps .step:before {
    margin: 0em 0em 1rem 0em; } }

@font-face {
  font-family: 'Step';
  src: url(data:application/x-font-ttf;charset=utf-8;;base64, ) format("truetype"), url(data:application/font-woff;charset=utf-8;base64,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) format("woff"); }

/*!
 * # Semantic UI 2.2.12 - Breadcrumb
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
           Breadcrumb
*******************************/
.ui.breadcrumb {
  line-height: 1;
  display: inline-block;
  margin: 0 0;
  vertical-align: middle; }
  .ui.breadcrumb:first-child {
    margin-top: 0; }
  .ui.breadcrumb:last-child {
    margin-bottom: 0; }
  .ui.breadcrumb .divider {
    display: inline-block;
    opacity: 0.7;
    margin: 0em 0.21428571rem 0em;
    font-size: 0.92857143em;
    color: rgba(0, 0, 0, 0.4);
    vertical-align: baseline; }
  .ui.breadcrumb a {
    color: #4c8bd6; }
    .ui.breadcrumb a:hover {
      color: #4679b7; }
  .ui.breadcrumb .icon.divider {
    font-size: 0.85714286em;
    vertical-align: baseline; }
  .ui.breadcrumb a.section {
    cursor: pointer; }
  .ui.breadcrumb .section {
    display: inline-block;
    margin: 0;
    padding: 0; }
  .ui.breadcrumb.segment {
    display: inline-block;
    padding: 0.78571429em 1em; }
  .ui.breadcrumb .active.section {
    font-weight: bold; }

.ui.mini.breadcrumb {
  font-size: 0.78571429rem; }

.ui.tiny.breadcrumb {
  font-size: 0.85714286rem; }

.ui.small.breadcrumb {
  font-size: 0.92857143rem; }

.ui.breadcrumb {
  font-size: 1rem; }

.ui.large.breadcrumb {
  font-size: 1.14285714rem; }

.ui.big.breadcrumb {
  font-size: 1.28571429rem; }

.ui.huge.breadcrumb {
  font-size: 1.42857143rem; }

.ui.massive.breadcrumb {
  font-size: 1.71428571rem; }

/*!
 * # Semantic UI 2.2.12 - Form
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Elements
*******************************/
/*--------------------
        Form
---------------------*/
.ui.form {
  position: relative;
  max-width: 100%; }
  .ui.form > p {
    margin: 1em 0em; }
  .ui.form .field {
    clear: both;
    margin: 0em 0em 1em; }
    .ui.form .field:last-child {
      margin-bottom: 0em; }
  .ui.form .fields:last-child .field {
    margin-bottom: 0em; }
  .ui.form .fields .field {
    clear: both;
    margin: 0em; }
  .ui.form .field > label {
    display: block;
    margin: 0em 0em 0.28571429rem 0em;
    color: rgba(0, 0, 0, 0.87);
    font-size: 0.92857143em;
    font-weight: bold;
    text-transform: none; }
  .ui.form textarea {
    width: 100%;
    vertical-align: top; }
  .ui.form input:not([type]), .ui.form input[type="date"], .ui.form input[type="datetime-local"], .ui.form input[type="email"], .ui.form input[type="number"], .ui.form input[type="password"], .ui.form input[type="search"], .ui.form input[type="tel"], .ui.form input[type="time"], .ui.form input[type="text"], .ui.form input[type="file"], .ui.form input[type="url"] {
    width: 100%;
    vertical-align: top; }
  .ui.form ::-webkit-datetime-edit, .ui.form ::-webkit-inner-spin-button {
    height: 1.21428571em; }
  .ui.form input:not([type]), .ui.form input[type="date"], .ui.form input[type="datetime-local"], .ui.form input[type="email"], .ui.form input[type="number"], .ui.form input[type="password"], .ui.form input[type="search"], .ui.form input[type="tel"], .ui.form input[type="time"], .ui.form input[type="text"], .ui.form input[type="file"], .ui.form input[type="url"] {
    font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
    margin: 0em;
    outline: none;
    tap-highlight-color: rgba(255, 255, 255, 0);
    line-height: 1.21428571em;
    padding: 0.67857143em 1em;
    font-size: 1em;
    background: #FFFFFF;
    border: 1px solid rgba(34, 36, 38, 0.15);
    color: rgba(0, 0, 0, 0.87);
    border-radius: 0.28571429rem;
    box-shadow: 0em 0em 0em 0em transparent inset;
    transition: color 0.1s ease, border-color 0.1s ease; }
  .ui.form textarea {
    margin: 0em;
    tap-highlight-color: rgba(255, 255, 255, 0);
    padding: 0.78571429em 1em;
    background: #FFFFFF;
    border: 1px solid rgba(34, 36, 38, 0.15);
    outline: none;
    color: rgba(0, 0, 0, 0.87);
    border-radius: 0.28571429rem;
    box-shadow: 0em 0em 0em 0em transparent inset;
    transition: color 0.1s ease, border-color 0.1s ease;
    font-size: 1em;
    line-height: 1.2857;
    resize: vertical;
    vertical-align: top; }
    .ui.form textarea:not([rows]) {
      height: 12em;
      min-height: 8em;
      max-height: 24em; }
  .ui.form input[type="checkbox"] {
    vertical-align: top; }
  .ui.form input.attached {
    width: auto; }
  .ui.form select {
    display: block;
    height: auto;
    width: 100%;
    background: #FFFFFF;
    border: 1px solid rgba(34, 36, 38, 0.15);
    border-radius: 0.28571429rem;
    box-shadow: 0em 0em 0em 0em transparent inset;
    padding: 0.62em 1em;
    color: rgba(0, 0, 0, 0.87);
    transition: color 0.1s ease, border-color 0.1s ease; }
  .ui.form .field > .selection.dropdown {
    width: 100%; }
    .ui.form .field > .selection.dropdown > .dropdown.icon {
      float: right; }
  .ui.form .inline.fields .field > .selection.dropdown, .ui.form .inline.field > .selection.dropdown {
    width: auto; }
  .ui.form .inline.fields .field > .selection.dropdown > .dropdown.icon, .ui.form .inline.field > .selection.dropdown > .dropdown.icon {
    float: none; }
  .ui.form .field .ui.input, .ui.form .fields .field .ui.input, .ui.form .wide.field .ui.input {
    width: 100%; }
  .ui.form .inline.fields .field:not(.wide) .ui.input, .ui.form .inline.field:not(.wide) .ui.input {
    width: auto;
    vertical-align: middle; }
  .ui.form .fields .field .ui.input input, .ui.form .field .ui.input input {
    width: auto; }
  .ui.form .ten.fields .ui.input input, .ui.form .nine.fields .ui.input input, .ui.form .eight.fields .ui.input input, .ui.form .seven.fields .ui.input input, .ui.form .six.fields .ui.input input, .ui.form .five.fields .ui.input input, .ui.form .four.fields .ui.input input, .ui.form .three.fields .ui.input input, .ui.form .two.fields .ui.input input, .ui.form .wide.field .ui.input input {
    flex: 1 0 auto;
    width: 0px; }
  .ui.form .success.message, .ui.form .warning.message, .ui.form .error.message {
    display: none; }
  .ui.form .message:first-child {
    margin-top: 0px; }
  .ui.form .field .prompt.label {
    white-space: normal;
    background: #FFFFFF !important;
    border: 1px solid #E0B4B4 !important;
    color: #9F3A38 !important; }
  .ui.form .inline.fields .field .prompt, .ui.form .inline.field .prompt {
    vertical-align: top;
    margin: -0.25em 0em -0.5em 0.5em; }
  .ui.form .inline.fields .field .prompt:before, .ui.form .inline.field .prompt:before {
    border-width: 0px 0px 1px 1px;
    bottom: auto;
    right: auto;
    top: 50%;
    left: 0em; }
  .ui.form .field.field input:-webkit-autofill {
    box-shadow: 0px 0px 0px 100px #FFFFF0 inset !important;
    border-color: #E5DFA1 !important; }
    .ui.form .field.field input:-webkit-autofill:focus {
      box-shadow: 0px 0px 0px 100px #FFFFF0 inset !important;
      border-color: #D5C315 !important; }
  .ui.form .error.error input:-webkit-autofill {
    box-shadow: 0px 0px 0px 100px #FFFAF0 inset !important;
    border-color: #E0B4B4 !important; }
  .ui.form ::-webkit-input-placeholder, .ui.form :-ms-input-placeholder, .ui.form ::-moz-placeholder {
    color: rgba(191, 191, 191, 0.87); }
  .ui.form :focus::-webkit-input-placeholder, .ui.form :focus:-ms-input-placeholder, .ui.form :focus::-moz-placeholder {
    color: rgba(115, 115, 115, 0.87); }
  .ui.form .error ::-webkit-input-placeholder {
    color: #e7bdbc; }
  .ui.form .error :-ms-input-placeholder {
    color: #e7bdbc !important; }
  .ui.form .error ::-moz-placeholder {
    color: #e7bdbc; }
  .ui.form .error :focus::-webkit-input-placeholder {
    color: #da9796; }
  .ui.form .error :focus:-ms-input-placeholder {
    color: #da9796 !important; }
  .ui.form .error :focus::-moz-placeholder {
    color: #da9796; }
  .ui.form input:not([type]):focus, .ui.form input[type="date"]:focus, .ui.form input[type="datetime-local"]:focus, .ui.form input[type="email"]:focus, .ui.form input[type="number"]:focus, .ui.form input[type="password"]:focus, .ui.form input[type="search"]:focus, .ui.form input[type="tel"]:focus, .ui.form input[type="time"]:focus, .ui.form input[type="text"]:focus, .ui.form input[type="file"]:focus, .ui.form input[type="url"]:focus {
    color: rgba(0, 0, 0, 0.95);
    border-color: #85B7D9;
    border-radius: 0.28571429rem;
    background: #FFFFFF;
    box-shadow: 0px 0em 0em 0em rgba(34, 36, 38, 0.35) inset; }
  .ui.form textarea:focus {
    color: rgba(0, 0, 0, 0.95);
    border-color: #85B7D9;
    border-radius: 0.28571429rem;
    background: #FFFFFF;
    box-shadow: 0px 0em 0em 0em rgba(34, 36, 38, 0.35) inset; }
  .ui.form.success .success.message:not(:empty) {
    display: block; }
  .ui.form.success .compact.success.message:not(:empty) {
    display: inline-block; }
  .ui.form.success .icon.success.message:not(:empty) {
    display: flex; }
  .ui.form.warning .warning.message:not(:empty) {
    display: block; }
  .ui.form.warning .compact.warning.message:not(:empty) {
    display: inline-block; }
  .ui.form.warning .icon.warning.message:not(:empty) {
    display: flex; }
  .ui.form.error .error.message:not(:empty) {
    display: block; }
  .ui.form.error .compact.error.message:not(:empty) {
    display: inline-block; }
  .ui.form.error .icon.error.message:not(:empty) {
    display: flex; }
  .ui.form .fields.error .field label, .ui.form .field.error label, .ui.form .fields.error .field .input, .ui.form .field.error .input {
    color: #9F3A38; }
  .ui.form .fields.error .field .corner.label, .ui.form .field.error .corner.label {
    border-color: #9F3A38;
    color: #FFFFFF; }
  .ui.form .fields.error .field textarea, .ui.form .fields.error .field select {
    background: #FFF6F6;
    border-color: #E0B4B4;
    color: #9F3A38;
    border-radius: '';
    box-shadow: none; }
  .ui.form .fields.error .field input:not([type]), .ui.form .fields.error .field input[type="date"], .ui.form .fields.error .field input[type="datetime-local"], .ui.form .fields.error .field input[type="email"], .ui.form .fields.error .field input[type="number"], .ui.form .fields.error .field input[type="password"], .ui.form .fields.error .field input[type="search"], .ui.form .fields.error .field input[type="tel"], .ui.form .fields.error .field input[type="time"], .ui.form .fields.error .field input[type="text"], .ui.form .fields.error .field input[type="file"], .ui.form .fields.error .field input[type="url"] {
    background: #FFF6F6;
    border-color: #E0B4B4;
    color: #9F3A38;
    border-radius: '';
    box-shadow: none; }
  .ui.form .field.error textarea, .ui.form .field.error select {
    background: #FFF6F6;
    border-color: #E0B4B4;
    color: #9F3A38;
    border-radius: '';
    box-shadow: none; }
  .ui.form .field.error input:not([type]), .ui.form .field.error input[type="date"], .ui.form .field.error input[type="datetime-local"], .ui.form .field.error input[type="email"], .ui.form .field.error input[type="number"], .ui.form .field.error input[type="password"], .ui.form .field.error input[type="search"], .ui.form .field.error input[type="tel"], .ui.form .field.error input[type="time"], .ui.form .field.error input[type="text"], .ui.form .field.error input[type="file"], .ui.form .field.error input[type="url"] {
    background: #FFF6F6;
    border-color: #E0B4B4;
    color: #9F3A38;
    border-radius: '';
    box-shadow: none; }
  .ui.form .field.error textarea:focus, .ui.form .field.error select:focus {
    background: #FFF6F6;
    border-color: #E0B4B4;
    color: #9F3A38;
    -webkit-appearance: none;
    box-shadow: none; }
  .ui.form .field.error input:not([type]):focus, .ui.form .field.error input[type="date"]:focus, .ui.form .field.error input[type="datetime-local"]:focus, .ui.form .field.error input[type="email"]:focus, .ui.form .field.error input[type="number"]:focus, .ui.form .field.error input[type="password"]:focus, .ui.form .field.error input[type="search"]:focus, .ui.form .field.error input[type="tel"]:focus, .ui.form .field.error input[type="time"]:focus, .ui.form .field.error input[type="text"]:focus, .ui.form .field.error input[type="file"]:focus, .ui.form .field.error input[type="url"]:focus {
    background: #FFF6F6;
    border-color: #E0B4B4;
    color: #9F3A38;
    -webkit-appearance: none;
    box-shadow: none; }
  .ui.form .field.error select {
    -webkit-appearance: menulist-button; }
  .ui.form .fields.error .field .ui.dropdown {
    background: #FFF6F6;
    color: #9F3A38; }
    .ui.form .fields.error .field .ui.dropdown .item {
      background: #FFF6F6;
      color: #9F3A38; }
  .ui.form .field.error .ui.dropdown {
    background: #FFF6F6;
    color: #9F3A38; }
    .ui.form .field.error .ui.dropdown .text, .ui.form .field.error .ui.dropdown .item {
      background: #FFF6F6;
      color: #9F3A38; }
  .ui.form .fields.error .field .ui.dropdown, .ui.form .field.error .ui.dropdown, .ui.form .fields.error .field .ui.dropdown:hover, .ui.form .field.error .ui.dropdown:hover {
    border-color: #E0B4B4 !important; }
  .ui.form .fields.error .field .ui.dropdown:hover .menu, .ui.form .field.error .ui.dropdown:hover .menu {
    border-color: #E0B4B4; }
  .ui.form .fields.error .field .ui.multiple.selection.dropdown > .label, .ui.form .field.error .ui.multiple.selection.dropdown > .label {
    background-color: #EACBCB;
    color: #9F3A38; }
  .ui.form .fields.error .field .ui.dropdown .menu .item:hover, .ui.form .field.error .ui.dropdown .menu .item:hover, .ui.form .fields.error .field .ui.dropdown .menu .selected.item, .ui.form .field.error .ui.dropdown .menu .selected.item {
    background-color: #FBE7E7; }
  .ui.form .fields.error .field .ui.dropdown .menu .active.item, .ui.form .field.error .ui.dropdown .menu .active.item {
    background-color: #FDCFCF !important; }
  .ui.form .fields.error .field .checkbox:not(.toggle):not(.slider) label, .ui.form .field.error .checkbox:not(.toggle):not(.slider) label, .ui.form .fields.error .field .checkbox:not(.toggle):not(.slider) .box, .ui.form .field.error .checkbox:not(.toggle):not(.slider) .box {
    color: #9F3A38; }
  .ui.form .fields.error .field .checkbox:not(.toggle):not(.slider) label:before, .ui.form .field.error .checkbox:not(.toggle):not(.slider) label:before, .ui.form .fields.error .field .checkbox:not(.toggle):not(.slider) .box:before, .ui.form .field.error .checkbox:not(.toggle):not(.slider) .box:before {
    background: #FFF6F6;
    border-color: #E0B4B4; }
  .ui.form .fields.error .field .checkbox label:after, .ui.form .field.error .checkbox label:after, .ui.form .fields.error .field .checkbox .box:after, .ui.form .field.error .checkbox .box:after {
    color: #9F3A38; }
  .ui.form .disabled.fields .field, .ui.form .disabled.field {
    pointer-events: none;
    opacity: 0.45; }
  .ui.form .field :disabled {
    pointer-events: none;
    opacity: 0.45; }
  .ui.form .field.disabled > label {
    opacity: 0.45; }
  .ui.form .fields.disabled > label {
    opacity: 0.45; }
  .ui.form .field.disabled :disabled {
    opacity: 1; }

.ui.loading.form {
  position: relative;
  cursor: default;
  pointer-events: none; }
  .ui.loading.form:before {
    position: absolute;
    content: '';
    top: 0%;
    left: 0%;
    background: rgba(255, 255, 255, 0.8);
    width: 100%;
    height: 100%;
    z-index: 100; }
  .ui.loading.form:after {
    position: absolute;
    content: '';
    top: 50%;
    left: 50%;
    margin: -1.5em 0em 0em -1.5em;
    width: 3em;
    height: 3em;
    -webkit-animation: form-spin 0.6s linear;
    animation: form-spin 0.6s linear;
    -webkit-animation-iteration-count: infinite;
    animation-iteration-count: infinite;
    border-radius: 500rem;
    border-color: #767676 rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1);
    border-style: solid;
    border-width: 0.2em;
    box-shadow: 0px 0px 0px 1px transparent;
    visibility: visible;
    z-index: 101; }

.ui.form .required.fields:not(.grouped) > .field > label:after, .ui.form .required.fields.grouped > label:after {
  margin: -0.2em 0em 0em 0.2em;
  content: '*';
  color: #DB2828; }

.ui.form .required.field > label:after, .ui.form .required.fields:not(.grouped) > .field > .checkbox:after, .ui.form .required.field > .checkbox:after {
  margin: -0.2em 0em 0em 0.2em;
  content: '*';
  color: #DB2828; }

.ui.form .required.fields:not(.grouped) > .field > label:after, .ui.form .required.fields.grouped > label:after {
  display: inline-block;
  vertical-align: top; }

.ui.form .required.field > label:after {
  display: inline-block;
  vertical-align: top; }

.ui.form .required.fields:not(.grouped) > .field > .checkbox:after, .ui.form .required.field > .checkbox:after {
  position: absolute;
  top: 0%;
  left: 100%; }

.ui.inverted.form label {
  color: rgba(255, 255, 255, 0.9); }

.ui.form .inverted.segment label {
  color: rgba(255, 255, 255, 0.9); }

.ui.form .inverted.segment .ui.checkbox label, .ui.form .inverted.segment .ui.checkbox .box {
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.form .ui.checkbox label, .ui.inverted.form .ui.checkbox .box {
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.form .inline.fields > label {
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.form .inline.fields .field > label, .ui.inverted.form .inline.fields .field > p {
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.form .inline.field > label, .ui.inverted.form .inline.field > p {
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.form input:not([type]), .ui.inverted.form input[type="date"], .ui.inverted.form input[type="datetime-local"], .ui.inverted.form input[type="email"], .ui.inverted.form input[type="number"], .ui.inverted.form input[type="password"], .ui.inverted.form input[type="search"], .ui.inverted.form input[type="tel"], .ui.inverted.form input[type="time"], .ui.inverted.form input[type="text"], .ui.inverted.form input[type="file"], .ui.inverted.form input[type="url"] {
  background: #FFFFFF;
  border-color: rgba(255, 255, 255, 0.1);
  color: rgba(0, 0, 0, 0.87);
  box-shadow: none; }

.ui.form .grouped.fields {
  display: block;
  margin: 0em 0em 1em; }
  .ui.form .grouped.fields:last-child {
    margin-bottom: 0em; }
  .ui.form .grouped.fields > label {
    margin: 0em 0em 0.28571429rem 0em;
    color: rgba(0, 0, 0, 0.87);
    font-size: 0.92857143em;
    font-weight: bold;
    text-transform: none; }
  .ui.form .grouped.fields .field {
    display: block;
    margin: 0.5em 0em;
    padding: 0em; }

.ui.form .grouped.inline.fields .field {
  display: block;
  margin: 0.5em 0em;
  padding: 0em; }

.ui.form .fields {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -ms-flex-direction: row;
  flex-direction: row;
  margin: 0em -0.5em 1em; }
  .ui.form .fields > .field {
    -webkit-box-flex: 0;
    -ms-flex: 0 1 auto;
    flex: 0 1 auto;
    padding-left: 0.5em;
    padding-right: 0.5em; }
    .ui.form .fields > .field:first-child {
      border-left: none;
      box-shadow: none; }

.ui.form .two.fields > .fields, .ui.form .two.fields > .field {
  width: 50%; }

.ui.form .three.fields > .fields, .ui.form .three.fields > .field {
  width: 33.33333333%; }

.ui.form .four.fields > .fields, .ui.form .four.fields > .field {
  width: 25%; }

.ui.form .five.fields > .fields, .ui.form .five.fields > .field {
  width: 20%; }

.ui.form .six.fields > .fields, .ui.form .six.fields > .field {
  width: 16.66666667%; }

.ui.form .seven.fields > .fields, .ui.form .seven.fields > .field {
  width: 14.28571429%; }

.ui.form .eight.fields > .fields, .ui.form .eight.fields > .field {
  width: 12.5%; }

.ui.form .nine.fields > .fields, .ui.form .nine.fields > .field {
  width: 11.11111111%; }

.ui.form .ten.fields > .fields, .ui.form .ten.fields > .field {
  width: 10%; }

.ui.form .fields .wide.field {
  width: 6.25%;
  padding-left: 0.5em;
  padding-right: 0.5em; }

.ui.form .one.wide.field {
  width: 6.25% !important; }

.ui.form .two.wide.field {
  width: 12.5% !important; }

.ui.form .three.wide.field {
  width: 18.75% !important; }

.ui.form .four.wide.field {
  width: 25% !important; }

.ui.form .five.wide.field {
  width: 31.25% !important; }

.ui.form .six.wide.field {
  width: 37.5% !important; }

.ui.form .seven.wide.field {
  width: 43.75% !important; }

.ui.form .eight.wide.field {
  width: 50% !important; }

.ui.form .nine.wide.field {
  width: 56.25% !important; }

.ui.form .ten.wide.field {
  width: 62.5% !important; }

.ui.form .eleven.wide.field {
  width: 68.75% !important; }

.ui.form .twelve.wide.field {
  width: 75% !important; }

.ui.form .thirteen.wide.field {
  width: 81.25% !important; }

.ui.form .fourteen.wide.field {
  width: 87.5% !important; }

.ui.form .fifteen.wide.field {
  width: 93.75% !important; }

.ui.form .sixteen.wide.field {
  width: 100% !important; }

.ui[class*="equal width"].form .fields > .field {
  width: 100%;
  -webkit-box-flex: 1;
  -ms-flex: 1 1 auto;
  flex: 1 1 auto; }

.ui.form [class*="equal width"].fields > .field {
  width: 100%;
  -webkit-box-flex: 1;
  -ms-flex: 1 1 auto;
  flex: 1 1 auto; }

.ui.form .inline.fields {
  margin: 0em 0em 1em;
  -webkit-box-align: center;
  -ms-flex-align: center;
  align-items: center; }
  .ui.form .inline.fields .field {
    margin: 0em;
    padding: 0em 1em 0em 0em; }
    .ui.form .inline.fields .field > label, .ui.form .inline.fields .field > p {
      display: inline-block;
      width: auto;
      margin-top: 0em;
      margin-bottom: 0em;
      vertical-align: baseline;
      font-size: 0.92857143em;
      font-weight: bold;
      color: rgba(0, 0, 0, 0.87);
      text-transform: none; }
  .ui.form .inline.fields > label {
    display: inline-block;
    width: auto;
    margin-top: 0em;
    margin-bottom: 0em;
    vertical-align: baseline;
    font-size: 0.92857143em;
    font-weight: bold;
    color: rgba(0, 0, 0, 0.87);
    text-transform: none; }

.ui.form .inline.field > label, .ui.form .inline.field > p {
  display: inline-block;
  width: auto;
  margin-top: 0em;
  margin-bottom: 0em;
  vertical-align: baseline;
  font-size: 0.92857143em;
  font-weight: bold;
  color: rgba(0, 0, 0, 0.87);
  text-transform: none; }

.ui.form .inline.fields > label {
  margin: 0.035714em 1em 0em 0em; }

.ui.form .inline.fields .field > input, .ui.form .inline.fields .field > select {
  display: inline-block;
  width: auto;
  margin-top: 0em;
  margin-bottom: 0em;
  vertical-align: middle;
  font-size: 1em; }

.ui.form .inline.field > input, .ui.form .inline.field > select {
  display: inline-block;
  width: auto;
  margin-top: 0em;
  margin-bottom: 0em;
  vertical-align: middle;
  font-size: 1em; }

.ui.form .inline.fields .field > :first-child, .ui.form .inline.field > :first-child {
  margin: 0em 0.85714286em 0em 0em; }

.ui.form .inline.fields .field > :only-child, .ui.form .inline.field > :only-child {
  margin: 0em; }

.ui.form .inline.fields .wide.field {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -ms-flex-align: center;
  align-items: center; }
  .ui.form .inline.fields .wide.field > input, .ui.form .inline.fields .wide.field > select {
    width: 100%; }

.ui.mini.form {
  font-size: 0.78571429rem; }

.ui.tiny.form {
  font-size: 0.85714286rem; }

.ui.small.form {
  font-size: 0.92857143rem; }

.ui.form {
  font-size: 1rem; }

.ui.large.form {
  font-size: 1.14285714rem; }

.ui.big.form {
  font-size: 1.28571429rem; }

.ui.huge.form {
  font-size: 1.42857143rem; }

.ui.massive.form {
  font-size: 1.71428571rem; }

/*--------------
    Loading
---------------*/
@-webkit-keyframes form-spin {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

@keyframes form-spin {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

/* Swap to full width on mobile */
@media only screen and (max-width: 767px) {
  .ui.form .fields {
    -ms-flex-wrap: wrap;
    flex-wrap: wrap; }
  .ui[class*="equal width"].form:not(.unstackable) .fields > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) [class*="equal width"].fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) .two.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .two.fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) .three.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .three.fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) .four.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .four.fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) .five.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .five.fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) .six.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .six.fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) .seven.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .seven.fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) .eight.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .eight.fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) .nine.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .nine.fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; }
  .ui.form:not(.unstackable) .ten.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .ten.fields:not(.unstackable) > .field {
    width: 100% !important;
    margin: 0em 0em 1em; } }

/* Swap to full width on mobile */
@media only screen and (max-width: 767px) {
  .ui.form:not(.unstackable) .two.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .two.fields:not(.unstackable) > .field {
    width: 100% !important; }
  .ui.form:not(.unstackable) .three.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .three.fields:not(.unstackable) > .field {
    width: 100% !important; }
  .ui.form:not(.unstackable) .four.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .four.fields:not(.unstackable) > .field {
    width: 100% !important; }
  .ui.form:not(.unstackable) .five.fields:not(.unstackable) > .fields, .ui.form:not(.unstackable) .five.fields:not(.unstackable) > .field {
    width: 100% !important; }
  .ui.form:not(.unstackable) .fields:not(.unstackable) > .two.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .three.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .four.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .five.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .six.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .seven.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .eight.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .nine.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .ten.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .eleven.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .twelve.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .thirteen.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .fourteen.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .fifteen.wide.field, .ui.form:not(.unstackable) .fields:not(.unstackable) > .sixteen.wide.field {
    width: 100% !important; }
  .ui.form .fields {
    margin-bottom: 0em; } }

/*!
 * # Semantic UI 2.2.12 - Grid
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Standard
*******************************/
.ui.grid {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -ms-flex-direction: row;
  flex-direction: row;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  -webkit-box-align: stretch;
  -ms-flex-align: stretch;
  align-items: stretch;
  padding: 0em;
  margin-top: -1rem;
  margin-bottom: -1rem;
  margin-left: -1rem;
  margin-right: -1rem; }

.ui.relaxed.grid {
  margin-left: -1.5rem;
  margin-right: -1.5rem; }

.ui[class*="very relaxed"].grid {
  margin-left: -2.5rem;
  margin-right: -2.5rem; }

.ui.grid + .grid {
  margin-top: 1rem; }

.ui.grid > .column:not(.row), .ui.grid > .row > .column {
  position: relative;
  display: inline-block;
  width: 6.25%;
  padding-left: 1rem;
  padding-right: 1rem;
  vertical-align: top; }

.ui.grid > * {
  padding-left: 1rem;
  padding-right: 1rem; }

.ui.grid > .row {
  position: relative;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -ms-flex-direction: row;
  flex-direction: row;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  -webkit-box-pack: inherit;
  -ms-flex-pack: inherit;
  justify-content: inherit;
  -webkit-box-align: stretch;
  -ms-flex-align: stretch;
  align-items: stretch;
  width: 100% !important;
  padding: 0rem;
  padding-top: 1rem;
  padding-bottom: 1rem; }

.ui.grid > .column:not(.row) {
  padding-top: 1rem;
  padding-bottom: 1rem; }

.ui.grid > .row > .column {
  margin-top: 0em;
  margin-bottom: 0em; }

.ui.grid > .row > img, .ui.grid > .row > .column > img {
  max-width: 100%; }

.ui.grid > .ui.grid:first-child {
  margin-top: 0em; }

.ui.grid > .ui.grid:last-child {
  margin-bottom: 0em; }

.ui.grid .aligned.row > .column > .segment:not(.compact):not(.attached) {
  width: 100%; }

.ui.aligned.grid .column > .segment:not(.compact):not(.attached) {
  width: 100%; }

.ui.grid .row + .ui.divider {
  -webkit-box-flex: 1;
  -ms-flex-positive: 1;
  flex-grow: 1;
  margin: 1rem 1rem; }

.ui.grid .column + .ui.vertical.divider {
  height: calc(50% -  1rem); }

.ui.grid > .row > .column:last-child > .horizontal.segment {
  box-shadow: none; }

.ui.grid > .column:last-child > .horizontal.segment {
  box-shadow: none; }

.ui.grid > .column:only-child {
  width: 100%; }

.ui.grid > .row > .column:only-child {
  width: 100%; }

.ui[class*="one column"].grid > .row > .column, .ui[class*="one column"].grid > .column:not(.row) {
  width: 100%; }

.ui[class*="two column"].grid > .row > .column, .ui[class*="two column"].grid > .column:not(.row) {
  width: 50%; }

.ui[class*="three column"].grid > .row > .column, .ui[class*="three column"].grid > .column:not(.row) {
  width: 33.33333333%; }

.ui[class*="four column"].grid > .row > .column, .ui[class*="four column"].grid > .column:not(.row) {
  width: 25%; }

.ui[class*="five column"].grid > .row > .column, .ui[class*="five column"].grid > .column:not(.row) {
  width: 20%; }

.ui[class*="six column"].grid > .row > .column, .ui[class*="six column"].grid > .column:not(.row) {
  width: 16.66666667%; }

.ui[class*="seven column"].grid > .row > .column, .ui[class*="seven column"].grid > .column:not(.row) {
  width: 14.28571429%; }

.ui[class*="eight column"].grid > .row > .column, .ui[class*="eight column"].grid > .column:not(.row) {
  width: 12.5%; }

.ui[class*="nine column"].grid > .row > .column, .ui[class*="nine column"].grid > .column:not(.row) {
  width: 11.11111111%; }

.ui[class*="ten column"].grid > .row > .column, .ui[class*="ten column"].grid > .column:not(.row) {
  width: 10%; }

.ui[class*="eleven column"].grid > .row > .column, .ui[class*="eleven column"].grid > .column:not(.row) {
  width: 9.09090909%; }

.ui[class*="twelve column"].grid > .row > .column, .ui[class*="twelve column"].grid > .column:not(.row) {
  width: 8.33333333%; }

.ui[class*="thirteen column"].grid > .row > .column, .ui[class*="thirteen column"].grid > .column:not(.row) {
  width: 7.69230769%; }

.ui[class*="fourteen column"].grid > .row > .column, .ui[class*="fourteen column"].grid > .column:not(.row) {
  width: 7.14285714%; }

.ui[class*="fifteen column"].grid > .row > .column, .ui[class*="fifteen column"].grid > .column:not(.row) {
  width: 6.66666667%; }

.ui[class*="sixteen column"].grid > .row > .column, .ui[class*="sixteen column"].grid > .column:not(.row) {
  width: 6.25%; }

.ui.grid > [class*="one column"].row > .column {
  width: 100% !important; }

.ui.grid > [class*="two column"].row > .column {
  width: 50% !important; }

.ui.grid > [class*="three column"].row > .column {
  width: 33.33333333% !important; }

.ui.grid > [class*="four column"].row > .column {
  width: 25% !important; }

.ui.grid > [class*="five column"].row > .column {
  width: 20% !important; }

.ui.grid > [class*="six column"].row > .column {
  width: 16.66666667% !important; }

.ui.grid > [class*="seven column"].row > .column {
  width: 14.28571429% !important; }

.ui.grid > [class*="eight column"].row > .column {
  width: 12.5% !important; }

.ui.grid > [class*="nine column"].row > .column {
  width: 11.11111111% !important; }

.ui.grid > [class*="ten column"].row > .column {
  width: 10% !important; }

.ui.grid > [class*="eleven column"].row > .column {
  width: 9.09090909% !important; }

.ui.grid > [class*="twelve column"].row > .column {
  width: 8.33333333% !important; }

.ui.grid > [class*="thirteen column"].row > .column {
  width: 7.69230769% !important; }

.ui.grid > [class*="fourteen column"].row > .column {
  width: 7.14285714% !important; }

.ui.grid > [class*="fifteen column"].row > .column {
  width: 6.66666667% !important; }

.ui.grid > [class*="sixteen column"].row > .column {
  width: 6.25% !important; }

.ui.celled.page.grid {
  box-shadow: none; }

.ui.grid > .row > [class*="one wide"].column, .ui.grid > .column.row > [class*="one wide"].column, .ui.grid > [class*="one wide"].column {
  width: 6.25% !important; }

.ui.column.grid > [class*="one wide"].column {
  width: 6.25% !important; }

.ui.grid > .row > [class*="two wide"].column, .ui.grid > .column.row > [class*="two wide"].column, .ui.grid > [class*="two wide"].column {
  width: 12.5% !important; }

.ui.column.grid > [class*="two wide"].column {
  width: 12.5% !important; }

.ui.grid > .row > [class*="three wide"].column, .ui.grid > .column.row > [class*="three wide"].column, .ui.grid > [class*="three wide"].column {
  width: 18.75% !important; }

.ui.column.grid > [class*="three wide"].column {
  width: 18.75% !important; }

.ui.grid > .row > [class*="four wide"].column, .ui.grid > .column.row > [class*="four wide"].column, .ui.grid > [class*="four wide"].column {
  width: 25% !important; }

.ui.column.grid > [class*="four wide"].column {
  width: 25% !important; }

.ui.grid > .row > [class*="five wide"].column, .ui.grid > .column.row > [class*="five wide"].column, .ui.grid > [class*="five wide"].column {
  width: 31.25% !important; }

.ui.column.grid > [class*="five wide"].column {
  width: 31.25% !important; }

.ui.grid > .row > [class*="six wide"].column, .ui.grid > .column.row > [class*="six wide"].column, .ui.grid > [class*="six wide"].column {
  width: 37.5% !important; }

.ui.column.grid > [class*="six wide"].column {
  width: 37.5% !important; }

.ui.grid > .row > [class*="seven wide"].column, .ui.grid > .column.row > [class*="seven wide"].column, .ui.grid > [class*="seven wide"].column {
  width: 43.75% !important; }

.ui.column.grid > [class*="seven wide"].column {
  width: 43.75% !important; }

.ui.grid > .row > [class*="eight wide"].column, .ui.grid > .column.row > [class*="eight wide"].column, .ui.grid > [class*="eight wide"].column {
  width: 50% !important; }

.ui.column.grid > [class*="eight wide"].column {
  width: 50% !important; }

.ui.grid > .row > [class*="nine wide"].column, .ui.grid > .column.row > [class*="nine wide"].column, .ui.grid > [class*="nine wide"].column {
  width: 56.25% !important; }

.ui.column.grid > [class*="nine wide"].column {
  width: 56.25% !important; }

.ui.grid > .row > [class*="ten wide"].column, .ui.grid > .column.row > [class*="ten wide"].column, .ui.grid > [class*="ten wide"].column {
  width: 62.5% !important; }

.ui.column.grid > [class*="ten wide"].column {
  width: 62.5% !important; }

.ui.grid > .row > [class*="eleven wide"].column, .ui.grid > .column.row > [class*="eleven wide"].column, .ui.grid > [class*="eleven wide"].column {
  width: 68.75% !important; }

.ui.column.grid > [class*="eleven wide"].column {
  width: 68.75% !important; }

.ui.grid > .row > [class*="twelve wide"].column, .ui.grid > .column.row > [class*="twelve wide"].column, .ui.grid > [class*="twelve wide"].column {
  width: 75% !important; }

.ui.column.grid > [class*="twelve wide"].column {
  width: 75% !important; }

.ui.grid > .row > [class*="thirteen wide"].column, .ui.grid > .column.row > [class*="thirteen wide"].column, .ui.grid > [class*="thirteen wide"].column {
  width: 81.25% !important; }

.ui.column.grid > [class*="thirteen wide"].column {
  width: 81.25% !important; }

.ui.grid > .row > [class*="fourteen wide"].column, .ui.grid > .column.row > [class*="fourteen wide"].column, .ui.grid > [class*="fourteen wide"].column {
  width: 87.5% !important; }

.ui.column.grid > [class*="fourteen wide"].column {
  width: 87.5% !important; }

.ui.grid > .row > [class*="fifteen wide"].column, .ui.grid > .column.row > [class*="fifteen wide"].column, .ui.grid > [class*="fifteen wide"].column {
  width: 93.75% !important; }

.ui.column.grid > [class*="fifteen wide"].column {
  width: 93.75% !important; }

.ui.grid > .row > [class*="sixteen wide"].column, .ui.grid > .column.row > [class*="sixteen wide"].column, .ui.grid > [class*="sixteen wide"].column {
  width: 100% !important; }

.ui.column.grid > [class*="sixteen wide"].column {
  width: 100% !important; }

.ui.centered.grid {
  text-align: center;
  -webkit-box-pack: center;
  -ms-flex-pack: center;
  justify-content: center; }
  .ui.centered.grid > .row {
    text-align: center;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center; }

.ui.grid > .centered.row {
  text-align: center;
  -webkit-box-pack: center;
  -ms-flex-pack: center;
  justify-content: center; }

.ui.centered.grid > .column:not(.aligned):not(.justified):not(.row), .ui.centered.grid > .row > .column:not(.aligned):not(.justified) {
  text-align: left; }

.ui.grid .centered.row > .column:not(.aligned):not(.justified) {
  text-align: left; }

.ui.grid > .centered.column, .ui.grid > .row > .centered.column {
  display: block;
  margin-left: auto;
  margin-right: auto; }

.ui.relaxed.grid > .column:not(.row), .ui.relaxed.grid > .row > .column {
  padding-left: 1.5rem;
  padding-right: 1.5rem; }

.ui.grid > .relaxed.row > .column {
  padding-left: 1.5rem;
  padding-right: 1.5rem; }

.ui[class*="very relaxed"].grid > .column:not(.row), .ui[class*="very relaxed"].grid > .row > .column {
  padding-left: 2.5rem;
  padding-right: 2.5rem; }

.ui.grid > [class*="very relaxed"].row > .column {
  padding-left: 2.5rem;
  padding-right: 2.5rem; }

.ui.relaxed.grid .row + .ui.divider, .ui.grid .relaxed.row + .ui.divider {
  margin-left: 1.5rem;
  margin-right: 1.5rem; }

.ui[class*="very relaxed"].grid .row + .ui.divider, .ui.grid [class*="very relaxed"].row + .ui.divider {
  margin-left: 2.5rem;
  margin-right: 2.5rem; }

.ui.padded.grid:not(.vertically):not(.horizontally) {
  margin: 0em !important; }

/*----------------------
      Remove Gutters
-----------------------*/
/* Preserve Rows Spacing on Consecutive Grids */
/*-------------------
       Columns
--------------------*/
/* Standard 16 column */
/*-------------------
        Rows
--------------------*/
/*-------------------
       Columns
--------------------*/
/* Vertical padding when no rows */
/*-------------------
      Content
--------------------*/
/*-------------------
    Loose Coupling
--------------------*/
/* Collapse Margin on Consecutive Grid */
/* Segment inside Aligned Grid */
/* Align Dividers with Gutter */
/* Remove Border on Last Horizontal Segment */
/*******************************
           Variations
*******************************/
/*-----------------------
       Page Grid
-------------------------*/
@media only screen and (max-width: 767px) {
  .ui.page.grid {
    width: auto;
    padding-left: 0em;
    padding-right: 0em;
    margin-left: 0em;
    margin-right: 0em; } }

@media only screen and (min-width: 768px) and (max-width: 991px) {
  .ui.page.grid {
    width: auto;
    margin-left: 0em;
    margin-right: 0em;
    padding-left: 2em;
    padding-right: 2em; } }

@media only screen and (min-width: 992px) and (max-width: 1199px) {
  .ui.page.grid {
    width: auto;
    margin-left: 0em;
    margin-right: 0em;
    padding-left: 3%;
    padding-right: 3%; } }

@media only screen and (min-width: 1200px) and (max-width: 1919px) {
  .ui.page.grid {
    width: auto;
    margin-left: 0em;
    margin-right: 0em;
    padding-left: 15%;
    padding-right: 15%; } }

@media only screen and (min-width: 1920px) {
  .ui.page.grid {
    width: auto;
    margin-left: 0em;
    margin-right: 0em;
    padding-left: 23%;
    padding-right: 23%; } }

/*-------------------
     Column Count
--------------------*/
/* Assume full width with one column */
/* Grid Based */
/* Row Based Overrides */
/* Celled Page */
/*-------------------
    Column Width
--------------------*/
/* Sizing Combinations */
/*----------------------
    Width per Device
-----------------------*/
/* Mobile Sizing Combinations */
@media only screen and (min-width: 320px) and (max-width: 767px) {
  .ui.grid > .row > [class*="one wide mobile"].column, .ui.grid > .column.row > [class*="one wide mobile"].column, .ui.grid > [class*="one wide mobile"].column {
    width: 6.25% !important; }
  .ui.column.grid > [class*="one wide mobile"].column {
    width: 6.25% !important; }
  .ui.grid > .row > [class*="two wide mobile"].column, .ui.grid > .column.row > [class*="two wide mobile"].column, .ui.grid > [class*="two wide mobile"].column {
    width: 12.5% !important; }
  .ui.column.grid > [class*="two wide mobile"].column {
    width: 12.5% !important; }
  .ui.grid > .row > [class*="three wide mobile"].column, .ui.grid > .column.row > [class*="three wide mobile"].column, .ui.grid > [class*="three wide mobile"].column {
    width: 18.75% !important; }
  .ui.column.grid > [class*="three wide mobile"].column {
    width: 18.75% !important; }
  .ui.grid > .row > [class*="four wide mobile"].column, .ui.grid > .column.row > [class*="four wide mobile"].column, .ui.grid > [class*="four wide mobile"].column {
    width: 25% !important; }
  .ui.column.grid > [class*="four wide mobile"].column {
    width: 25% !important; }
  .ui.grid > .row > [class*="five wide mobile"].column, .ui.grid > .column.row > [class*="five wide mobile"].column, .ui.grid > [class*="five wide mobile"].column {
    width: 31.25% !important; }
  .ui.column.grid > [class*="five wide mobile"].column {
    width: 31.25% !important; }
  .ui.grid > .row > [class*="six wide mobile"].column, .ui.grid > .column.row > [class*="six wide mobile"].column, .ui.grid > [class*="six wide mobile"].column {
    width: 37.5% !important; }
  .ui.column.grid > [class*="six wide mobile"].column {
    width: 37.5% !important; }
  .ui.grid > .row > [class*="seven wide mobile"].column, .ui.grid > .column.row > [class*="seven wide mobile"].column, .ui.grid > [class*="seven wide mobile"].column {
    width: 43.75% !important; }
  .ui.column.grid > [class*="seven wide mobile"].column {
    width: 43.75% !important; }
  .ui.grid > .row > [class*="eight wide mobile"].column, .ui.grid > .column.row > [class*="eight wide mobile"].column, .ui.grid > [class*="eight wide mobile"].column {
    width: 50% !important; }
  .ui.column.grid > [class*="eight wide mobile"].column {
    width: 50% !important; }
  .ui.grid > .row > [class*="nine wide mobile"].column, .ui.grid > .column.row > [class*="nine wide mobile"].column, .ui.grid > [class*="nine wide mobile"].column {
    width: 56.25% !important; }
  .ui.column.grid > [class*="nine wide mobile"].column {
    width: 56.25% !important; }
  .ui.grid > .row > [class*="ten wide mobile"].column, .ui.grid > .column.row > [class*="ten wide mobile"].column, .ui.grid > [class*="ten wide mobile"].column {
    width: 62.5% !important; }
  .ui.column.grid > [class*="ten wide mobile"].column {
    width: 62.5% !important; }
  .ui.grid > .row > [class*="eleven wide mobile"].column, .ui.grid > .column.row > [class*="eleven wide mobile"].column, .ui.grid > [class*="eleven wide mobile"].column {
    width: 68.75% !important; }
  .ui.column.grid > [class*="eleven wide mobile"].column {
    width: 68.75% !important; }
  .ui.grid > .row > [class*="twelve wide mobile"].column, .ui.grid > .column.row > [class*="twelve wide mobile"].column, .ui.grid > [class*="twelve wide mobile"].column {
    width: 75% !important; }
  .ui.column.grid > [class*="twelve wide mobile"].column {
    width: 75% !important; }
  .ui.grid > .row > [class*="thirteen wide mobile"].column, .ui.grid > .column.row > [class*="thirteen wide mobile"].column, .ui.grid > [class*="thirteen wide mobile"].column {
    width: 81.25% !important; }
  .ui.column.grid > [class*="thirteen wide mobile"].column {
    width: 81.25% !important; }
  .ui.grid > .row > [class*="fourteen wide mobile"].column, .ui.grid > .column.row > [class*="fourteen wide mobile"].column, .ui.grid > [class*="fourteen wide mobile"].column {
    width: 87.5% !important; }
  .ui.column.grid > [class*="fourteen wide mobile"].column {
    width: 87.5% !important; }
  .ui.grid > .row > [class*="fifteen wide mobile"].column, .ui.grid > .column.row > [class*="fifteen wide mobile"].column, .ui.grid > [class*="fifteen wide mobile"].column {
    width: 93.75% !important; }
  .ui.column.grid > [class*="fifteen wide mobile"].column {
    width: 93.75% !important; }
  .ui.grid > .row > [class*="sixteen wide mobile"].column, .ui.grid > .column.row > [class*="sixteen wide mobile"].column, .ui.grid > [class*="sixteen wide mobile"].column {
    width: 100% !important; }
  .ui.column.grid > [class*="sixteen wide mobile"].column {
    width: 100% !important; } }

/* Tablet Sizing Combinations */
@media only screen and (min-width: 768px) and (max-width: 991px) {
  .ui.grid > .row > [class*="one wide tablet"].column, .ui.grid > .column.row > [class*="one wide tablet"].column, .ui.grid > [class*="one wide tablet"].column {
    width: 6.25% !important; }
  .ui.column.grid > [class*="one wide tablet"].column {
    width: 6.25% !important; }
  .ui.grid > .row > [class*="two wide tablet"].column, .ui.grid > .column.row > [class*="two wide tablet"].column, .ui.grid > [class*="two wide tablet"].column {
    width: 12.5% !important; }
  .ui.column.grid > [class*="two wide tablet"].column {
    width: 12.5% !important; }
  .ui.grid > .row > [class*="three wide tablet"].column, .ui.grid > .column.row > [class*="three wide tablet"].column, .ui.grid > [class*="three wide tablet"].column {
    width: 18.75% !important; }
  .ui.column.grid > [class*="three wide tablet"].column {
    width: 18.75% !important; }
  .ui.grid > .row > [class*="four wide tablet"].column, .ui.grid > .column.row > [class*="four wide tablet"].column, .ui.grid > [class*="four wide tablet"].column {
    width: 25% !important; }
  .ui.column.grid > [class*="four wide tablet"].column {
    width: 25% !important; }
  .ui.grid > .row > [class*="five wide tablet"].column, .ui.grid > .column.row > [class*="five wide tablet"].column, .ui.grid > [class*="five wide tablet"].column {
    width: 31.25% !important; }
  .ui.column.grid > [class*="five wide tablet"].column {
    width: 31.25% !important; }
  .ui.grid > .row > [class*="six wide tablet"].column, .ui.grid > .column.row > [class*="six wide tablet"].column, .ui.grid > [class*="six wide tablet"].column {
    width: 37.5% !important; }
  .ui.column.grid > [class*="six wide tablet"].column {
    width: 37.5% !important; }
  .ui.grid > .row > [class*="seven wide tablet"].column, .ui.grid > .column.row > [class*="seven wide tablet"].column, .ui.grid > [class*="seven wide tablet"].column {
    width: 43.75% !important; }
  .ui.column.grid > [class*="seven wide tablet"].column {
    width: 43.75% !important; }
  .ui.grid > .row > [class*="eight wide tablet"].column, .ui.grid > .column.row > [class*="eight wide tablet"].column, .ui.grid > [class*="eight wide tablet"].column {
    width: 50% !important; }
  .ui.column.grid > [class*="eight wide tablet"].column {
    width: 50% !important; }
  .ui.grid > .row > [class*="nine wide tablet"].column, .ui.grid > .column.row > [class*="nine wide tablet"].column, .ui.grid > [class*="nine wide tablet"].column {
    width: 56.25% !important; }
  .ui.column.grid > [class*="nine wide tablet"].column {
    width: 56.25% !important; }
  .ui.grid > .row > [class*="ten wide tablet"].column, .ui.grid > .column.row > [class*="ten wide tablet"].column, .ui.grid > [class*="ten wide tablet"].column {
    width: 62.5% !important; }
  .ui.column.grid > [class*="ten wide tablet"].column {
    width: 62.5% !important; }
  .ui.grid > .row > [class*="eleven wide tablet"].column, .ui.grid > .column.row > [class*="eleven wide tablet"].column, .ui.grid > [class*="eleven wide tablet"].column {
    width: 68.75% !important; }
  .ui.column.grid > [class*="eleven wide tablet"].column {
    width: 68.75% !important; }
  .ui.grid > .row > [class*="twelve wide tablet"].column, .ui.grid > .column.row > [class*="twelve wide tablet"].column, .ui.grid > [class*="twelve wide tablet"].column {
    width: 75% !important; }
  .ui.column.grid > [class*="twelve wide tablet"].column {
    width: 75% !important; }
  .ui.grid > .row > [class*="thirteen wide tablet"].column, .ui.grid > .column.row > [class*="thirteen wide tablet"].column, .ui.grid > [class*="thirteen wide tablet"].column {
    width: 81.25% !important; }
  .ui.column.grid > [class*="thirteen wide tablet"].column {
    width: 81.25% !important; }
  .ui.grid > .row > [class*="fourteen wide tablet"].column, .ui.grid > .column.row > [class*="fourteen wide tablet"].column, .ui.grid > [class*="fourteen wide tablet"].column {
    width: 87.5% !important; }
  .ui.column.grid > [class*="fourteen wide tablet"].column {
    width: 87.5% !important; }
  .ui.grid > .row > [class*="fifteen wide tablet"].column, .ui.grid > .column.row > [class*="fifteen wide tablet"].column, .ui.grid > [class*="fifteen wide tablet"].column {
    width: 93.75% !important; }
  .ui.column.grid > [class*="fifteen wide tablet"].column {
    width: 93.75% !important; }
  .ui.grid > .row > [class*="sixteen wide tablet"].column, .ui.grid > .column.row > [class*="sixteen wide tablet"].column, .ui.grid > [class*="sixteen wide tablet"].column {
    width: 100% !important; }
  .ui.column.grid > [class*="sixteen wide tablet"].column {
    width: 100% !important; } }

/* Computer/Desktop Sizing Combinations */
@media only screen and (min-width: 992px) {
  .ui.grid > .row > [class*="one wide computer"].column, .ui.grid > .column.row > [class*="one wide computer"].column, .ui.grid > [class*="one wide computer"].column {
    width: 6.25% !important; }
  .ui.column.grid > [class*="one wide computer"].column {
    width: 6.25% !important; }
  .ui.grid > .row > [class*="two wide computer"].column, .ui.grid > .column.row > [class*="two wide computer"].column, .ui.grid > [class*="two wide computer"].column {
    width: 12.5% !important; }
  .ui.column.grid > [class*="two wide computer"].column {
    width: 12.5% !important; }
  .ui.grid > .row > [class*="three wide computer"].column, .ui.grid > .column.row > [class*="three wide computer"].column, .ui.grid > [class*="three wide computer"].column {
    width: 18.75% !important; }
  .ui.column.grid > [class*="three wide computer"].column {
    width: 18.75% !important; }
  .ui.grid > .row > [class*="four wide computer"].column, .ui.grid > .column.row > [class*="four wide computer"].column, .ui.grid > [class*="four wide computer"].column {
    width: 25% !important; }
  .ui.column.grid > [class*="four wide computer"].column {
    width: 25% !important; }
  .ui.grid > .row > [class*="five wide computer"].column, .ui.grid > .column.row > [class*="five wide computer"].column, .ui.grid > [class*="five wide computer"].column {
    width: 31.25% !important; }
  .ui.column.grid > [class*="five wide computer"].column {
    width: 31.25% !important; }
  .ui.grid > .row > [class*="six wide computer"].column, .ui.grid > .column.row > [class*="six wide computer"].column, .ui.grid > [class*="six wide computer"].column {
    width: 37.5% !important; }
  .ui.column.grid > [class*="six wide computer"].column {
    width: 37.5% !important; }
  .ui.grid > .row > [class*="seven wide computer"].column, .ui.grid > .column.row > [class*="seven wide computer"].column, .ui.grid > [class*="seven wide computer"].column {
    width: 43.75% !important; }
  .ui.column.grid > [class*="seven wide computer"].column {
    width: 43.75% !important; }
  .ui.grid > .row > [class*="eight wide computer"].column, .ui.grid > .column.row > [class*="eight wide computer"].column, .ui.grid > [class*="eight wide computer"].column {
    width: 50% !important; }
  .ui.column.grid > [class*="eight wide computer"].column {
    width: 50% !important; }
  .ui.grid > .row > [class*="nine wide computer"].column, .ui.grid > .column.row > [class*="nine wide computer"].column, .ui.grid > [class*="nine wide computer"].column {
    width: 56.25% !important; }
  .ui.column.grid > [class*="nine wide computer"].column {
    width: 56.25% !important; }
  .ui.grid > .row > [class*="ten wide computer"].column, .ui.grid > .column.row > [class*="ten wide computer"].column, .ui.grid > [class*="ten wide computer"].column {
    width: 62.5% !important; }
  .ui.column.grid > [class*="ten wide computer"].column {
    width: 62.5% !important; }
  .ui.grid > .row > [class*="eleven wide computer"].column, .ui.grid > .column.row > [class*="eleven wide computer"].column, .ui.grid > [class*="eleven wide computer"].column {
    width: 68.75% !important; }
  .ui.column.grid > [class*="eleven wide computer"].column {
    width: 68.75% !important; }
  .ui.grid > .row > [class*="twelve wide computer"].column, .ui.grid > .column.row > [class*="twelve wide computer"].column, .ui.grid > [class*="twelve wide computer"].column {
    width: 75% !important; }
  .ui.column.grid > [class*="twelve wide computer"].column {
    width: 75% !important; }
  .ui.grid > .row > [class*="thirteen wide computer"].column, .ui.grid > .column.row > [class*="thirteen wide computer"].column, .ui.grid > [class*="thirteen wide computer"].column {
    width: 81.25% !important; }
  .ui.column.grid > [class*="thirteen wide computer"].column {
    width: 81.25% !important; }
  .ui.grid > .row > [class*="fourteen wide computer"].column, .ui.grid > .column.row > [class*="fourteen wide computer"].column, .ui.grid > [class*="fourteen wide computer"].column {
    width: 87.5% !important; }
  .ui.column.grid > [class*="fourteen wide computer"].column {
    width: 87.5% !important; }
  .ui.grid > .row > [class*="fifteen wide computer"].column, .ui.grid > .column.row > [class*="fifteen wide computer"].column, .ui.grid > [class*="fifteen wide computer"].column {
    width: 93.75% !important; }
  .ui.column.grid > [class*="fifteen wide computer"].column {
    width: 93.75% !important; }
  .ui.grid > .row > [class*="sixteen wide computer"].column, .ui.grid > .column.row > [class*="sixteen wide computer"].column, .ui.grid > [class*="sixteen wide computer"].column {
    width: 100% !important; }
  .ui.column.grid > [class*="sixteen wide computer"].column {
    width: 100% !important; } }

/* Large Monitor Sizing Combinations */
@media only screen and (min-width: 1200px) and (max-width: 1919px) {
  .ui.grid > .row > [class*="one wide large screen"].column, .ui.grid > .column.row > [class*="one wide large screen"].column, .ui.grid > [class*="one wide large screen"].column {
    width: 6.25% !important; }
  .ui.column.grid > [class*="one wide large screen"].column {
    width: 6.25% !important; }
  .ui.grid > .row > [class*="two wide large screen"].column, .ui.grid > .column.row > [class*="two wide large screen"].column, .ui.grid > [class*="two wide large screen"].column {
    width: 12.5% !important; }
  .ui.column.grid > [class*="two wide large screen"].column {
    width: 12.5% !important; }
  .ui.grid > .row > [class*="three wide large screen"].column, .ui.grid > .column.row > [class*="three wide large screen"].column, .ui.grid > [class*="three wide large screen"].column {
    width: 18.75% !important; }
  .ui.column.grid > [class*="three wide large screen"].column {
    width: 18.75% !important; }
  .ui.grid > .row > [class*="four wide large screen"].column, .ui.grid > .column.row > [class*="four wide large screen"].column, .ui.grid > [class*="four wide large screen"].column {
    width: 25% !important; }
  .ui.column.grid > [class*="four wide large screen"].column {
    width: 25% !important; }
  .ui.grid > .row > [class*="five wide large screen"].column, .ui.grid > .column.row > [class*="five wide large screen"].column, .ui.grid > [class*="five wide large screen"].column {
    width: 31.25% !important; }
  .ui.column.grid > [class*="five wide large screen"].column {
    width: 31.25% !important; }
  .ui.grid > .row > [class*="six wide large screen"].column, .ui.grid > .column.row > [class*="six wide large screen"].column, .ui.grid > [class*="six wide large screen"].column {
    width: 37.5% !important; }
  .ui.column.grid > [class*="six wide large screen"].column {
    width: 37.5% !important; }
  .ui.grid > .row > [class*="seven wide large screen"].column, .ui.grid > .column.row > [class*="seven wide large screen"].column, .ui.grid > [class*="seven wide large screen"].column {
    width: 43.75% !important; }
  .ui.column.grid > [class*="seven wide large screen"].column {
    width: 43.75% !important; }
  .ui.grid > .row > [class*="eight wide large screen"].column, .ui.grid > .column.row > [class*="eight wide large screen"].column, .ui.grid > [class*="eight wide large screen"].column {
    width: 50% !important; }
  .ui.column.grid > [class*="eight wide large screen"].column {
    width: 50% !important; }
  .ui.grid > .row > [class*="nine wide large screen"].column, .ui.grid > .column.row > [class*="nine wide large screen"].column, .ui.grid > [class*="nine wide large screen"].column {
    width: 56.25% !important; }
  .ui.column.grid > [class*="nine wide large screen"].column {
    width: 56.25% !important; }
  .ui.grid > .row > [class*="ten wide large screen"].column, .ui.grid > .column.row > [class*="ten wide large screen"].column, .ui.grid > [class*="ten wide large screen"].column {
    width: 62.5% !important; }
  .ui.column.grid > [class*="ten wide large screen"].column {
    width: 62.5% !important; }
  .ui.grid > .row > [class*="eleven wide large screen"].column, .ui.grid > .column.row > [class*="eleven wide large screen"].column, .ui.grid > [class*="eleven wide large screen"].column {
    width: 68.75% !important; }
  .ui.column.grid > [class*="eleven wide large screen"].column {
    width: 68.75% !important; }
  .ui.grid > .row > [class*="twelve wide large screen"].column, .ui.grid > .column.row > [class*="twelve wide large screen"].column, .ui.grid > [class*="twelve wide large screen"].column {
    width: 75% !important; }
  .ui.column.grid > [class*="twelve wide large screen"].column {
    width: 75% !important; }
  .ui.grid > .row > [class*="thirteen wide large screen"].column, .ui.grid > .column.row > [class*="thirteen wide large screen"].column, .ui.grid > [class*="thirteen wide large screen"].column {
    width: 81.25% !important; }
  .ui.column.grid > [class*="thirteen wide large screen"].column {
    width: 81.25% !important; }
  .ui.grid > .row > [class*="fourteen wide large screen"].column, .ui.grid > .column.row > [class*="fourteen wide large screen"].column, .ui.grid > [class*="fourteen wide large screen"].column {
    width: 87.5% !important; }
  .ui.column.grid > [class*="fourteen wide large screen"].column {
    width: 87.5% !important; }
  .ui.grid > .row > [class*="fifteen wide large screen"].column, .ui.grid > .column.row > [class*="fifteen wide large screen"].column, .ui.grid > [class*="fifteen wide large screen"].column {
    width: 93.75% !important; }
  .ui.column.grid > [class*="fifteen wide large screen"].column {
    width: 93.75% !important; }
  .ui.grid > .row > [class*="sixteen wide large screen"].column, .ui.grid > .column.row > [class*="sixteen wide large screen"].column, .ui.grid > [class*="sixteen wide large screen"].column {
    width: 100% !important; }
  .ui.column.grid > [class*="sixteen wide large screen"].column {
    width: 100% !important; } }

/* Widescreen Sizing Combinations */
@media only screen and (min-width: 1920px) {
  .ui.grid > .row > [class*="one wide widescreen"].column, .ui.grid > .column.row > [class*="one wide widescreen"].column, .ui.grid > [class*="one wide widescreen"].column {
    width: 6.25% !important; }
  .ui.column.grid > [class*="one wide widescreen"].column {
    width: 6.25% !important; }
  .ui.grid > .row > [class*="two wide widescreen"].column, .ui.grid > .column.row > [class*="two wide widescreen"].column, .ui.grid > [class*="two wide widescreen"].column {
    width: 12.5% !important; }
  .ui.column.grid > [class*="two wide widescreen"].column {
    width: 12.5% !important; }
  .ui.grid > .row > [class*="three wide widescreen"].column, .ui.grid > .column.row > [class*="three wide widescreen"].column, .ui.grid > [class*="three wide widescreen"].column {
    width: 18.75% !important; }
  .ui.column.grid > [class*="three wide widescreen"].column {
    width: 18.75% !important; }
  .ui.grid > .row > [class*="four wide widescreen"].column, .ui.grid > .column.row > [class*="four wide widescreen"].column, .ui.grid > [class*="four wide widescreen"].column {
    width: 25% !important; }
  .ui.column.grid > [class*="four wide widescreen"].column {
    width: 25% !important; }
  .ui.grid > .row > [class*="five wide widescreen"].column, .ui.grid > .column.row > [class*="five wide widescreen"].column, .ui.grid > [class*="five wide widescreen"].column {
    width: 31.25% !important; }
  .ui.column.grid > [class*="five wide widescreen"].column {
    width: 31.25% !important; }
  .ui.grid > .row > [class*="six wide widescreen"].column, .ui.grid > .column.row > [class*="six wide widescreen"].column, .ui.grid > [class*="six wide widescreen"].column {
    width: 37.5% !important; }
  .ui.column.grid > [class*="six wide widescreen"].column {
    width: 37.5% !important; }
  .ui.grid > .row > [class*="seven wide widescreen"].column, .ui.grid > .column.row > [class*="seven wide widescreen"].column, .ui.grid > [class*="seven wide widescreen"].column {
    width: 43.75% !important; }
  .ui.column.grid > [class*="seven wide widescreen"].column {
    width: 43.75% !important; }
  .ui.grid > .row > [class*="eight wide widescreen"].column, .ui.grid > .column.row > [class*="eight wide widescreen"].column, .ui.grid > [class*="eight wide widescreen"].column {
    width: 50% !important; }
  .ui.column.grid > [class*="eight wide widescreen"].column {
    width: 50% !important; }
  .ui.grid > .row > [class*="nine wide widescreen"].column, .ui.grid > .column.row > [class*="nine wide widescreen"].column, .ui.grid > [class*="nine wide widescreen"].column {
    width: 56.25% !important; }
  .ui.column.grid > [class*="nine wide widescreen"].column {
    width: 56.25% !important; }
  .ui.grid > .row > [class*="ten wide widescreen"].column, .ui.grid > .column.row > [class*="ten wide widescreen"].column, .ui.grid > [class*="ten wide widescreen"].column {
    width: 62.5% !important; }
  .ui.column.grid > [class*="ten wide widescreen"].column {
    width: 62.5% !important; }
  .ui.grid > .row > [class*="eleven wide widescreen"].column, .ui.grid > .column.row > [class*="eleven wide widescreen"].column, .ui.grid > [class*="eleven wide widescreen"].column {
    width: 68.75% !important; }
  .ui.column.grid > [class*="eleven wide widescreen"].column {
    width: 68.75% !important; }
  .ui.grid > .row > [class*="twelve wide widescreen"].column, .ui.grid > .column.row > [class*="twelve wide widescreen"].column, .ui.grid > [class*="twelve wide widescreen"].column {
    width: 75% !important; }
  .ui.column.grid > [class*="twelve wide widescreen"].column {
    width: 75% !important; }
  .ui.grid > .row > [class*="thirteen wide widescreen"].column, .ui.grid > .column.row > [class*="thirteen wide widescreen"].column, .ui.grid > [class*="thirteen wide widescreen"].column {
    width: 81.25% !important; }
  .ui.column.grid > [class*="thirteen wide widescreen"].column {
    width: 81.25% !important; }
  .ui.grid > .row > [class*="fourteen wide widescreen"].column, .ui.grid > .column.row > [class*="fourteen wide widescreen"].column, .ui.grid > [class*="fourteen wide widescreen"].column {
    width: 87.5% !important; }
  .ui.column.grid > [class*="fourteen wide widescreen"].column {
    width: 87.5% !important; }
  .ui.grid > .row > [class*="fifteen wide widescreen"].column, .ui.grid > .column.row > [class*="fifteen wide widescreen"].column, .ui.grid > [class*="fifteen wide widescreen"].column {
    width: 93.75% !important; }
  .ui.column.grid > [class*="fifteen wide widescreen"].column {
    width: 93.75% !important; }
  .ui.grid > .row > [class*="sixteen wide widescreen"].column, .ui.grid > .column.row > [class*="sixteen wide widescreen"].column, .ui.grid > [class*="sixteen wide widescreen"].column {
    width: 100% !important; }
  .ui.column.grid > [class*="sixteen wide widescreen"].column {
    width: 100% !important; } }

/*----------------------
        Centered
-----------------------*/
/*----------------------
        Relaxed
-----------------------*/
/* Coupling with UI Divider */
/*----------------------
        Padded
-----------------------*/
[class*="horizontally padded"].ui.grid {
  margin-left: 0em !important;
  margin-right: 0em !important; }

[class*="vertically padded"].ui.grid {
  margin-top: 0em !important;
  margin-bottom: 0em !important; }

/*----------------------
       "Floated"
-----------------------*/
.ui.grid [class*="left floated"].column {
  margin-right: auto; }

.ui.grid [class*="right floated"].column {
  margin-left: auto; }

.ui.divided.grid:not([class*="vertically divided"]) > .column:not(.row), .ui.divided.grid:not([class*="vertically divided"]) > .row > .column {
  box-shadow: -1px 0px 0px 0px rgba(34, 36, 38, 0.15); }

.ui[class*="vertically divided"].grid > .column:not(.row) {
  margin-top: 1rem;
  margin-bottom: 1rem;
  padding-top: 0rem;
  padding-bottom: 0rem; }

.ui[class*="vertically divided"].grid > .row {
  margin-top: 0em;
  margin-bottom: 0em; }
  .ui[class*="vertically divided"].grid > .row > .column {
    margin-top: 1rem;
    margin-bottom: 1rem;
    padding-top: 0rem;
    padding-bottom: 0rem; }

.ui.divided.grid:not([class*="vertically divided"]) > .column:first-child, .ui.divided.grid:not([class*="vertically divided"]) > .row > .column:first-child {
  box-shadow: none; }

.ui[class*="vertically divided"].grid > .row:first-child > .column {
  margin-top: 0em; }

.ui.grid > .divided.row > .column {
  box-shadow: -1px 0px 0px 0px rgba(34, 36, 38, 0.15); }
  .ui.grid > .divided.row > .column:first-child {
    box-shadow: none; }

.ui[class*="vertically divided"].grid > .row {
  position: relative; }
  .ui[class*="vertically divided"].grid > .row:before {
    position: absolute;
    content: "";
    top: 0em;
    left: 0px;
    width: calc(100% -  2rem);
    height: 1px;
    margin: 0% 1rem;
    box-shadow: 0px -1px 0px 0px rgba(34, 36, 38, 0.15); }

/*----------------------
        Divided
-----------------------*/
/* Swap from padding to margin on columns to have dividers align */
/* No divider on first column on row */
/* No space on top of first row */
/* Divided Row */
/* Vertically Divided */
/* Padded Horizontally Divided */
[class*="horizontally padded"].ui.divided.grid {
  width: 100%; }

.ui.padded.divided.grid:not(.vertically):not(.horizontally) {
  width: 100%; }

.ui[class*="vertically divided"].grid > .row:first-child:before {
  box-shadow: none; }

.ui.inverted.divided.grid:not([class*="vertically divided"]) > .column:not(.row), .ui.inverted.divided.grid:not([class*="vertically divided"]) > .row > .column {
  box-shadow: -1px 0px 0px 0px rgba(255, 255, 255, 0.1); }

.ui.inverted.divided.grid:not([class*="vertically divided"]) > .column:not(.row):first-child, .ui.inverted.divided.grid:not([class*="vertically divided"]) > .row > .column:first-child {
  box-shadow: none; }

.ui.inverted[class*="vertically divided"].grid > .row:before {
  box-shadow: 0px -1px 0px 0px rgba(255, 255, 255, 0.1); }

.ui.relaxed[class*="vertically divided"].grid > .row:before {
  margin-left: 1.5rem;
  margin-right: 1.5rem;
  width: calc(100% -  3rem); }

.ui[class*="very relaxed"][class*="vertically divided"].grid > .row:before {
  margin-left: 5rem;
  margin-right: 5rem;
  width: calc(100% -  5rem); }

.ui.celled.grid {
  width: 100%;
  margin: 1em 0em;
  box-shadow: 0px 0px 0px 1px #D4D4D5; }
  .ui.celled.grid > .row {
    width: 100% !important;
    margin: 0em;
    padding: 0em;
    box-shadow: 0px -1px 0px 0px #D4D4D5; }
  .ui.celled.grid > .column:not(.row), .ui.celled.grid > .row > .column {
    box-shadow: -1px 0px 0px 0px #D4D4D5; }
  .ui.celled.grid > .column:first-child, .ui.celled.grid > .row > .column:first-child {
    box-shadow: none; }
  .ui.celled.grid > .column:not(.row), .ui.celled.grid > .row > .column {
    padding: 1em; }

.ui.relaxed.celled.grid > .column:not(.row), .ui.relaxed.celled.grid > .row > .column {
  padding: 1.5em; }

.ui[class*="very relaxed"].celled.grid > .column:not(.row), .ui[class*="very relaxed"].celled.grid > .row > .column {
  padding: 2em; }

.ui[class*="internally celled"].grid {
  box-shadow: none;
  margin: 0em; }
  .ui[class*="internally celled"].grid > .row:first-child, .ui[class*="internally celled"].grid > .row > .column:first-child {
    box-shadow: none; }

.ui[class*="top aligned"].grid > .column:not(.row), .ui[class*="top aligned"].grid > .row > .column {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  vertical-align: top;
  -ms-flex-item-align: start !important;
  align-self: flex-start !important; }

.ui.grid > [class*="top aligned"].row > .column, .ui.grid > [class*="top aligned"].column:not(.row) {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  vertical-align: top;
  -ms-flex-item-align: start !important;
  align-self: flex-start !important; }

.ui.grid > .row > [class*="top aligned"].column {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  vertical-align: top;
  -ms-flex-item-align: start !important;
  align-self: flex-start !important; }

.ui[class*="middle aligned"].grid > .column:not(.row), .ui[class*="middle aligned"].grid > .row > .column {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  vertical-align: middle;
  -ms-flex-item-align: center !important;
  -ms-grid-row-align: center !important;
  align-self: center !important; }

.ui.grid > [class*="middle aligned"].row > .column, .ui.grid > [class*="middle aligned"].column:not(.row) {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  vertical-align: middle;
  -ms-flex-item-align: center !important;
  -ms-grid-row-align: center !important;
  align-self: center !important; }

.ui.grid > .row > [class*="middle aligned"].column {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  vertical-align: middle;
  -ms-flex-item-align: center !important;
  -ms-grid-row-align: center !important;
  align-self: center !important; }

.ui[class*="bottom aligned"].grid > .column:not(.row), .ui[class*="bottom aligned"].grid > .row > .column {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  vertical-align: bottom;
  -ms-flex-item-align: end !important;
  align-self: flex-end !important; }

.ui.grid > [class*="bottom aligned"].row > .column, .ui.grid > [class*="bottom aligned"].column:not(.row) {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  vertical-align: bottom;
  -ms-flex-item-align: end !important;
  align-self: flex-end !important; }

.ui.grid > .row > [class*="bottom aligned"].column {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  vertical-align: bottom;
  -ms-flex-item-align: end !important;
  align-self: flex-end !important; }

.ui.stretched.grid > .row > .column, .ui.stretched.grid > .column {
  display: -webkit-inline-box !important;
  display: -ms-inline-flexbox !important;
  display: inline-flex !important;
  -ms-flex-item-align: stretch;
  align-self: stretch;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column; }

.ui.grid > .stretched.row > .column, .ui.grid > .stretched.column:not(.row) {
  display: -webkit-inline-box !important;
  display: -ms-inline-flexbox !important;
  display: inline-flex !important;
  -ms-flex-item-align: stretch;
  align-self: stretch;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column; }

.ui.grid > .row > .stretched.column {
  display: -webkit-inline-box !important;
  display: -ms-inline-flexbox !important;
  display: inline-flex !important;
  -ms-flex-item-align: stretch;
  align-self: stretch;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column; }

.ui.stretched.grid > .row > .column > *, .ui.stretched.grid > .column > * {
  -webkit-box-flex: 1;
  -ms-flex-positive: 1;
  flex-grow: 1; }

.ui.grid > .stretched.row > .column > *, .ui.grid > .stretched.column:not(.row) > * {
  -webkit-box-flex: 1;
  -ms-flex-positive: 1;
  flex-grow: 1; }

.ui.grid > .row > .stretched.column > * {
  -webkit-box-flex: 1;
  -ms-flex-positive: 1;
  flex-grow: 1; }

.ui[class*="left aligned"].grid > .column, .ui[class*="left aligned"].grid > .row > .column {
  text-align: left;
  -ms-flex-item-align: inherit;
  -ms-grid-row-align: inherit;
  align-self: inherit; }

.ui.grid > [class*="left aligned"].row > .column, .ui.grid > [class*="left aligned"].column.column {
  text-align: left;
  -ms-flex-item-align: inherit;
  -ms-grid-row-align: inherit;
  align-self: inherit; }

.ui.grid > .row > [class*="left aligned"].column.column {
  text-align: left;
  -ms-flex-item-align: inherit;
  -ms-grid-row-align: inherit;
  align-self: inherit; }

.ui[class*="center aligned"].grid > .column, .ui[class*="center aligned"].grid > .row > .column {
  text-align: center;
  -ms-flex-item-align: inherit;
  -ms-grid-row-align: inherit;
  align-self: inherit; }

.ui.grid > [class*="center aligned"].row > .column, .ui.grid > [class*="center aligned"].column.column {
  text-align: center;
  -ms-flex-item-align: inherit;
  -ms-grid-row-align: inherit;
  align-self: inherit; }

.ui.grid > .row > [class*="center aligned"].column.column {
  text-align: center;
  -ms-flex-item-align: inherit;
  -ms-grid-row-align: inherit;
  align-self: inherit; }

.ui[class*="center aligned"].grid {
  -webkit-box-pack: center;
  -ms-flex-pack: center;
  justify-content: center; }

.ui[class*="right aligned"].grid > .column, .ui[class*="right aligned"].grid > .row > .column {
  text-align: right;
  -ms-flex-item-align: inherit;
  -ms-grid-row-align: inherit;
  align-self: inherit; }

.ui.grid > [class*="right aligned"].row > .column, .ui.grid > [class*="right aligned"].column.column {
  text-align: right;
  -ms-flex-item-align: inherit;
  -ms-grid-row-align: inherit;
  align-self: inherit; }

.ui.grid > .row > [class*="right aligned"].column.column {
  text-align: right;
  -ms-flex-item-align: inherit;
  -ms-grid-row-align: inherit;
  align-self: inherit; }

.ui.justified.grid > .column, .ui.justified.grid > .row > .column {
  text-align: justify;
  -webkit-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto; }

.ui.grid > .justified.row > .column, .ui.grid > .justified.column.column {
  text-align: justify;
  -webkit-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto; }

.ui.grid > .row > .justified.column.column {
  text-align: justify;
  -webkit-hyphens: auto;
  -ms-hyphens: auto;
  hyphens: auto; }

.ui.grid > .row > .red.column, .ui.grid > .row > .orange.column, .ui.grid > .row > .yellow.column, .ui.grid > .row > .olive.column, .ui.grid > .row > .green.column, .ui.grid > .row > .teal.column, .ui.grid > .row > .blue.column, .ui.grid > .row > .violet.column, .ui.grid > .row > .purple.column, .ui.grid > .row > .pink.column, .ui.grid > .row > .brown.column, .ui.grid > .row > .grey.column, .ui.grid > .row > .black.column {
  margin-top: -1rem;
  margin-bottom: -1rem;
  padding-top: 1rem;
  padding-bottom: 1rem; }

.ui.grid > .red.row, .ui.grid > .red.column {
  background-color: #DB2828 !important;
  color: #FFFFFF; }

.ui.grid > .row > .red.column {
  background-color: #DB2828 !important;
  color: #FFFFFF; }

.ui.grid > .orange.row, .ui.grid > .orange.column {
  background-color: #fc7831 !important;
  color: #FFFFFF; }

.ui.grid > .row > .orange.column {
  background-color: #fc7831 !important;
  color: #FFFFFF; }

.ui.grid > .yellow.row, .ui.grid > .yellow.column {
  background-color: #FBBD08 !important;
  color: #FFFFFF; }

.ui.grid > .row > .yellow.column {
  background-color: #FBBD08 !important;
  color: #FFFFFF; }

.ui.grid > .olive.row, .ui.grid > .olive.column {
  background-color: #B5CC18 !important;
  color: #FFFFFF; }

.ui.grid > .row > .olive.column {
  background-color: #B5CC18 !important;
  color: #FFFFFF; }

.ui.grid > .green.row, .ui.grid > .green.column {
  background-color: #21BA45 !important;
  color: #FFFFFF; }

.ui.grid > .row > .green.column {
  background-color: #21BA45 !important;
  color: #FFFFFF; }

.ui.grid > .teal.row, .ui.grid > .teal.column {
  background-color: #00B5AD !important;
  color: #FFFFFF; }

.ui.grid > .row > .teal.column {
  background-color: #00B5AD !important;
  color: #FFFFFF; }

.ui.grid > .blue.row, .ui.grid > .blue.column {
  background-color: #4c8bd6 !important;
  color: #FFFFFF; }

.ui.grid > .row > .blue.column {
  background-color: #4c8bd6 !important;
  color: #FFFFFF; }

.ui.grid > .violet.row, .ui.grid > .violet.column {
  background-color: #6435C9 !important;
  color: #FFFFFF; }

.ui.grid > .row > .violet.column {
  background-color: #6435C9 !important;
  color: #FFFFFF; }

.ui.grid > .purple.row, .ui.grid > .purple.column {
  background-color: #A333C8 !important;
  color: #FFFFFF; }

.ui.grid > .row > .purple.column {
  background-color: #A333C8 !important;
  color: #FFFFFF; }

.ui.grid > .pink.row, .ui.grid > .pink.column {
  background-color: #E03997 !important;
  color: #FFFFFF; }

.ui.grid > .row > .pink.column {
  background-color: #E03997 !important;
  color: #FFFFFF; }

.ui.grid > .brown.row, .ui.grid > .brown.column {
  background-color: #A5673F !important;
  color: #FFFFFF; }

.ui.grid > .row > .brown.column {
  background-color: #A5673F !important;
  color: #FFFFFF; }

.ui.grid > .grey.row, .ui.grid > .grey.column {
  background-color: #767676 !important;
  color: #FFFFFF; }

.ui.grid > .row > .grey.column {
  background-color: #767676 !important;
  color: #FFFFFF; }

.ui.grid > .black.row, .ui.grid > .black.column {
  background-color: #1B1C1D !important;
  color: #FFFFFF; }

.ui.grid > .row > .black.column {
  background-color: #1B1C1D !important;
  color: #FFFFFF; }

.ui[class*="equal width"].grid > .column:not(.row), .ui[class*="equal width"].grid > .row > .column {
  display: inline-block;
  -webkit-box-flex: 1;
  -ms-flex-positive: 1;
  flex-grow: 1; }

.ui.grid > [class*="equal width"].row > .column {
  display: inline-block;
  -webkit-box-flex: 1;
  -ms-flex-positive: 1;
  flex-grow: 1; }

.ui[class*="equal width"].grid > .wide.column, .ui[class*="equal width"].grid > .row > .wide.column {
  -webkit-box-flex: 0;
  -ms-flex-positive: 0;
  flex-grow: 0; }

.ui.grid > [class*="equal width"].row > .wide.column {
  -webkit-box-flex: 0;
  -ms-flex-positive: 0;
  flex-grow: 0; }

/* First Row Vertically Divided */
/* Inverted Divided */
/* Relaxed */
/*----------------------
         Celled
-----------------------*/
/* Internally Celled */
/*----------------------
   Vertically Aligned
-----------------------*/
/* Top Aligned */
/* Middle Aligned */
/* Bottom Aligned */
/* Stretched */
/*----------------------
  Horizontally Centered
-----------------------*/
/* Left Aligned */
/* Center Aligned */
/* Right Aligned */
/* Justified */
/*----------------------
         Colored
-----------------------*/
/* Red */
/* Orange */
/* Yellow */
/* Olive */
/* Green */
/* Teal */
/* Blue */
/* Violet */
/* Purple */
/* Pink */
/* Brown */
/* Grey */
/* Black */
/*----------------------
      Equal Width
-----------------------*/
/*----------------------
        Reverse
-----------------------*/
/* Mobile */
@media only screen and (max-width: 767px) {
  .ui[class*="mobile reversed"].grid {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: reverse;
    -ms-flex-direction: row-reverse;
    flex-direction: row-reverse; }
    .ui[class*="mobile reversed"].grid > .row {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: reverse;
      -ms-flex-direction: row-reverse;
      flex-direction: row-reverse; }
  .ui.grid > [class*="mobile reversed"].row {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: reverse;
    -ms-flex-direction: row-reverse;
    flex-direction: row-reverse; }
  .ui[class*="mobile vertically reversed"].grid, .ui.stackable[class*="mobile reversed"] {
    -webkit-box-orient: vertical;
    -webkit-box-direction: reverse;
    -ms-flex-direction: column-reverse;
    flex-direction: column-reverse; }
  .ui[class*="mobile reversed"].divided.grid:not([class*="vertically divided"]) > .column:first-child, .ui[class*="mobile reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:first-child {
    box-shadow: -1px 0px 0px 0px rgba(34, 36, 38, 0.15); }
  .ui[class*="mobile reversed"].divided.grid:not([class*="vertically divided"]) > .column:last-child, .ui[class*="mobile reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:last-child {
    box-shadow: none; }
  .ui.grid[class*="vertically divided"][class*="mobile vertically reversed"] > .row:first-child:before {
    box-shadow: 0px -1px 0px 0px rgba(34, 36, 38, 0.15); }
  .ui.grid[class*="vertically divided"][class*="mobile vertically reversed"] > .row:last-child:before {
    box-shadow: none; }
  .ui[class*="mobile reversed"].celled.grid > .row > .column:first-child {
    box-shadow: -1px 0px 0px 0px #D4D4D5; }
  .ui[class*="mobile reversed"].celled.grid > .row > .column:last-child {
    box-shadow: none; }
  /* Divided Reversed */
  /* Vertically Divided Reversed */
  /* Celled Reversed */ }

/* Tablet */
@media only screen and (min-width: 768px) and (max-width: 991px) {
  .ui[class*="tablet reversed"].grid {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: reverse;
    -ms-flex-direction: row-reverse;
    flex-direction: row-reverse; }
    .ui[class*="tablet reversed"].grid > .row {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: reverse;
      -ms-flex-direction: row-reverse;
      flex-direction: row-reverse; }
  .ui.grid > [class*="tablet reversed"].row {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: reverse;
    -ms-flex-direction: row-reverse;
    flex-direction: row-reverse; }
  .ui[class*="tablet vertically reversed"].grid {
    -webkit-box-orient: vertical;
    -webkit-box-direction: reverse;
    -ms-flex-direction: column-reverse;
    flex-direction: column-reverse; }
  .ui[class*="tablet reversed"].divided.grid:not([class*="vertically divided"]) > .column:first-child, .ui[class*="tablet reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:first-child {
    box-shadow: -1px 0px 0px 0px rgba(34, 36, 38, 0.15); }
  .ui[class*="tablet reversed"].divided.grid:not([class*="vertically divided"]) > .column:last-child, .ui[class*="tablet reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:last-child {
    box-shadow: none; }
  .ui.grid[class*="vertically divided"][class*="tablet vertically reversed"] > .row:first-child:before {
    box-shadow: 0px -1px 0px 0px rgba(34, 36, 38, 0.15); }
  .ui.grid[class*="vertically divided"][class*="tablet vertically reversed"] > .row:last-child:before {
    box-shadow: none; }
  .ui[class*="tablet reversed"].celled.grid > .row > .column:first-child {
    box-shadow: -1px 0px 0px 0px #D4D4D5; }
  .ui[class*="tablet reversed"].celled.grid > .row > .column:last-child {
    box-shadow: none; }
  /* Divided Reversed */
  /* Vertically Divided Reversed */
  /* Celled Reversed */ }

/* Computer */
@media only screen and (min-width: 992px) {
  .ui[class*="computer reversed"].grid {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: reverse;
    -ms-flex-direction: row-reverse;
    flex-direction: row-reverse; }
    .ui[class*="computer reversed"].grid > .row {
      -webkit-box-orient: horizontal;
      -webkit-box-direction: reverse;
      -ms-flex-direction: row-reverse;
      flex-direction: row-reverse; }
  .ui.grid > [class*="computer reversed"].row {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: reverse;
    -ms-flex-direction: row-reverse;
    flex-direction: row-reverse; }
  .ui[class*="computer vertically reversed"].grid {
    -webkit-box-orient: vertical;
    -webkit-box-direction: reverse;
    -ms-flex-direction: column-reverse;
    flex-direction: column-reverse; }
  .ui[class*="computer reversed"].divided.grid:not([class*="vertically divided"]) > .column:first-child, .ui[class*="computer reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:first-child {
    box-shadow: -1px 0px 0px 0px rgba(34, 36, 38, 0.15); }
  .ui[class*="computer reversed"].divided.grid:not([class*="vertically divided"]) > .column:last-child, .ui[class*="computer reversed"].divided.grid:not([class*="vertically divided"]) > .row > .column:last-child {
    box-shadow: none; }
  .ui.grid[class*="vertically divided"][class*="computer vertically reversed"] > .row:first-child:before {
    box-shadow: 0px -1px 0px 0px rgba(34, 36, 38, 0.15); }
  .ui.grid[class*="vertically divided"][class*="computer vertically reversed"] > .row:last-child:before {
    box-shadow: none; }
  .ui[class*="computer reversed"].celled.grid > .row > .column:first-child {
    box-shadow: -1px 0px 0px 0px #D4D4D5; }
  .ui[class*="computer reversed"].celled.grid > .row > .column:last-child {
    box-shadow: none; }
  /* Divided Reversed */
  /* Vertically Divided Reversed */
  /* Celled Reversed */ }

/*-------------------
      Doubling
--------------------*/
/* Tablet Only */
@media only screen and (min-width: 768px) and (max-width: 991px) {
  .ui.doubling.grid {
    width: auto; }
  .ui.grid > .doubling.row, .ui.doubling.grid > .row {
    margin: 0em !important;
    padding: 0em !important; }
  .ui.grid > .doubling.row > .column, .ui.doubling.grid > .row > .column {
    display: inline-block !important;
    padding-top: 1rem !important;
    padding-bottom: 1rem !important;
    box-shadow: none !important;
    margin: 0em; }
  .ui[class*="two column"].doubling.grid > .row > .column, .ui[class*="two column"].doubling.grid > .column:not(.row) {
    width: 100% !important; }
  .ui.grid > [class*="two column"].doubling.row.row > .column {
    width: 100% !important; }
  .ui[class*="three column"].doubling.grid > .row > .column, .ui[class*="three column"].doubling.grid > .column:not(.row) {
    width: 50% !important; }
  .ui.grid > [class*="three column"].doubling.row.row > .column {
    width: 50% !important; }
  .ui[class*="four column"].doubling.grid > .row > .column, .ui[class*="four column"].doubling.grid > .column:not(.row) {
    width: 50% !important; }
  .ui.grid > [class*="four column"].doubling.row.row > .column {
    width: 50% !important; }
  .ui[class*="five column"].doubling.grid > .row > .column, .ui[class*="five column"].doubling.grid > .column:not(.row) {
    width: 33.33333333% !important; }
  .ui.grid > [class*="five column"].doubling.row.row > .column {
    width: 33.33333333% !important; }
  .ui[class*="six column"].doubling.grid > .row > .column, .ui[class*="six column"].doubling.grid > .column:not(.row) {
    width: 33.33333333% !important; }
  .ui.grid > [class*="six column"].doubling.row.row > .column {
    width: 33.33333333% !important; }
  .ui[class*="seven column"].doubling.grid > .row > .column, .ui[class*="seven column"].doubling.grid > .column:not(.row) {
    width: 33.33333333% !important; }
  .ui.grid > [class*="seven column"].doubling.row.row > .column {
    width: 33.33333333% !important; }
  .ui[class*="eight column"].doubling.grid > .row > .column, .ui[class*="eight column"].doubling.grid > .column:not(.row) {
    width: 25% !important; }
  .ui.grid > [class*="eight column"].doubling.row.row > .column {
    width: 25% !important; }
  .ui[class*="nine column"].doubling.grid > .row > .column, .ui[class*="nine column"].doubling.grid > .column:not(.row) {
    width: 25% !important; }
  .ui.grid > [class*="nine column"].doubling.row.row > .column {
    width: 25% !important; }
  .ui[class*="ten column"].doubling.grid > .row > .column, .ui[class*="ten column"].doubling.grid > .column:not(.row) {
    width: 20% !important; }
  .ui.grid > [class*="ten column"].doubling.row.row > .column {
    width: 20% !important; }
  .ui[class*="eleven column"].doubling.grid > .row > .column, .ui[class*="eleven column"].doubling.grid > .column:not(.row) {
    width: 20% !important; }
  .ui.grid > [class*="eleven column"].doubling.row.row > .column {
    width: 20% !important; }
  .ui[class*="twelve column"].doubling.grid > .row > .column, .ui[class*="twelve column"].doubling.grid > .column:not(.row) {
    width: 16.66666667% !important; }
  .ui.grid > [class*="twelve column"].doubling.row.row > .column {
    width: 16.66666667% !important; }
  .ui[class*="thirteen column"].doubling.grid > .row > .column, .ui[class*="thirteen column"].doubling.grid > .column:not(.row) {
    width: 16.66666667% !important; }
  .ui.grid > [class*="thirteen column"].doubling.row.row > .column {
    width: 16.66666667% !important; }
  .ui[class*="fourteen column"].doubling.grid > .row > .column, .ui[class*="fourteen column"].doubling.grid > .column:not(.row) {
    width: 14.28571429% !important; }
  .ui.grid > [class*="fourteen column"].doubling.row.row > .column {
    width: 14.28571429% !important; }
  .ui[class*="fifteen column"].doubling.grid > .row > .column, .ui[class*="fifteen column"].doubling.grid > .column:not(.row) {
    width: 14.28571429% !important; }
  .ui.grid > [class*="fifteen column"].doubling.row.row > .column {
    width: 14.28571429% !important; }
  .ui[class*="sixteen column"].doubling.grid > .row > .column, .ui[class*="sixteen column"].doubling.grid > .column:not(.row) {
    width: 12.5% !important; }
  .ui.grid > [class*="sixteen column"].doubling.row.row > .column {
    width: 12.5% !important; } }

/* Mobile Only */
@media only screen and (max-width: 767px) {
  .ui.grid > .doubling.row, .ui.doubling.grid > .row {
    margin: 0em !important;
    padding: 0em !important; }
  .ui.grid > .doubling.row > .column, .ui.doubling.grid > .row > .column {
    padding-top: 1rem !important;
    padding-bottom: 1rem !important;
    margin: 0em !important;
    box-shadow: none !important; }
  .ui[class*="two column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="two column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 100% !important; }
  .ui.grid > [class*="two column"].doubling:not(.stackable).row.row > .column {
    width: 100% !important; }
  .ui[class*="three column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="three column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 50% !important; }
  .ui.grid > [class*="three column"].doubling:not(.stackable).row.row > .column {
    width: 50% !important; }
  .ui[class*="four column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="four column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 50% !important; }
  .ui.grid > [class*="four column"].doubling:not(.stackable).row.row > .column {
    width: 50% !important; }
  .ui[class*="five column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="five column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 50% !important; }
  .ui.grid > [class*="five column"].doubling:not(.stackable).row.row > .column {
    width: 50% !important; }
  .ui[class*="six column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="six column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 50% !important; }
  .ui.grid > [class*="six column"].doubling:not(.stackable).row.row > .column {
    width: 50% !important; }
  .ui[class*="seven column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="seven column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 50% !important; }
  .ui.grid > [class*="seven column"].doubling:not(.stackable).row.row > .column {
    width: 50% !important; }
  .ui[class*="eight column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="eight column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 50% !important; }
  .ui.grid > [class*="eight column"].doubling:not(.stackable).row.row > .column {
    width: 50% !important; }
  .ui[class*="nine column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="nine column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 33.33333333% !important; }
  .ui.grid > [class*="nine column"].doubling:not(.stackable).row.row > .column {
    width: 33.33333333% !important; }
  .ui[class*="ten column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="ten column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 33.33333333% !important; }
  .ui.grid > [class*="ten column"].doubling:not(.stackable).row.row > .column {
    width: 33.33333333% !important; }
  .ui[class*="eleven column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="eleven column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 33.33333333% !important; }
  .ui.grid > [class*="eleven column"].doubling:not(.stackable).row.row > .column {
    width: 33.33333333% !important; }
  .ui[class*="twelve column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="twelve column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 33.33333333% !important; }
  .ui.grid > [class*="twelve column"].doubling:not(.stackable).row.row > .column {
    width: 33.33333333% !important; }
  .ui[class*="thirteen column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="thirteen column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 33.33333333% !important; }
  .ui.grid > [class*="thirteen column"].doubling:not(.stackable).row.row > .column {
    width: 33.33333333% !important; }
  .ui[class*="fourteen column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="fourteen column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 25% !important; }
  .ui.grid > [class*="fourteen column"].doubling:not(.stackable).row.row > .column {
    width: 25% !important; }
  .ui[class*="fifteen column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="fifteen column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 25% !important; }
  .ui.grid > [class*="fifteen column"].doubling:not(.stackable).row.row > .column {
    width: 25% !important; }
  .ui[class*="sixteen column"].doubling:not(.stackable).grid > .row > .column, .ui[class*="sixteen column"].doubling:not(.stackable).grid > .column:not(.row) {
    width: 25% !important; }
  .ui.grid > [class*="sixteen column"].doubling:not(.stackable).row.row > .column {
    width: 25% !important; } }

/*-------------------
      Stackable
--------------------*/
@media only screen and (max-width: 767px) {
  .ui.stackable.grid {
    width: auto;
    margin-left: 0em !important;
    margin-right: 0em !important; }
    .ui.stackable.grid > .row > .wide.column, .ui.stackable.grid > .wide.column {
      width: 100% !important;
      margin: 0em 0em !important;
      box-shadow: none !important;
      padding: 1rem 1rem !important; }
    .ui.stackable.grid > .column.grid > .column, .ui.stackable.grid > .column.row > .column {
      width: 100% !important;
      margin: 0em 0em !important;
      box-shadow: none !important;
      padding: 1rem 1rem !important; }
    .ui.stackable.grid > .row > .column, .ui.stackable.grid > .column:not(.row) {
      width: 100% !important;
      margin: 0em 0em !important;
      box-shadow: none !important;
      padding: 1rem 1rem !important; }
  .ui.grid > .stackable.stackable.row > .column {
    width: 100% !important;
    margin: 0em 0em !important;
    box-shadow: none !important;
    padding: 1rem 1rem !important; }
  .ui.stackable.grid:not(.vertically) > .row {
    margin: 0em;
    padding: 0em; }
  .ui.container > .ui.stackable.grid > .column, .ui.container > .ui.stackable.grid > .row > .column {
    padding-left: 0em !important;
    padding-right: 0em !important; }
  .ui.grid .ui.stackable.grid, .ui.segment:not(.vertical) .ui.stackable.page.grid {
    margin-left: -1rem !important;
    margin-right: -1rem !important; }
  .ui.stackable.divided.grid > .row:first-child > .column:first-child, .ui.stackable.celled.grid > .row:first-child > .column:first-child, .ui.stackable.divided.grid > .column:not(.row):first-child, .ui.stackable.celled.grid > .column:not(.row):first-child {
    border-top: none !important; }
  .ui.inverted.stackable.celled.grid > .column:not(.row), .ui.inverted.stackable.divided.grid > .column:not(.row), .ui.inverted.stackable.celled.grid > .row > .column, .ui.inverted.stackable.divided.grid > .row > .column {
    border-top: 1px solid rgba(255, 255, 255, 0.1); }
  .ui.stackable.celled.grid > .column:not(.row), .ui.stackable.divided:not(.vertically).grid > .column:not(.row), .ui.stackable.celled.grid > .row > .column, .ui.stackable.divided:not(.vertically).grid > .row > .column {
    border-top: 1px solid rgba(34, 36, 38, 0.15);
    box-shadow: none !important;
    padding-top: 2rem !important;
    padding-bottom: 2rem !important; }
  .ui.stackable.celled.grid > .row {
    box-shadow: none !important; }
  .ui.stackable.divided:not(.vertically).grid > .column:not(.row), .ui.stackable.divided:not(.vertically).grid > .row > .column {
    padding-left: 0em !important;
    padding-right: 0em !important; }
  /* Coupling */
  /* Don't pad inside segment or nested grid */
  /* Divided Stackable */ }

/*----------------------
     Only (Device)
-----------------------*/
/* These include arbitrary class repetitions for forced specificity */
/* Mobile Only Hide */
@media only screen and (max-width: 767px) {
  .ui[class*="tablet only"].grid.grid.grid:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="tablet only"].row:not(.mobile), .ui.grid.grid.grid > [class*="tablet only"].column:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="tablet only"].column:not(.mobile) {
    display: none !important; }
  .ui[class*="computer only"].grid.grid.grid:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="computer only"].row:not(.mobile), .ui.grid.grid.grid > [class*="computer only"].column:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="computer only"].column:not(.mobile) {
    display: none !important; }
  .ui[class*="large screen only"].grid.grid.grid:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="large screen only"].row:not(.mobile), .ui.grid.grid.grid > [class*="large screen only"].column:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="large screen only"].column:not(.mobile) {
    display: none !important; }
  .ui[class*="widescreen only"].grid.grid.grid:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="widescreen only"].row:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].column:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="widescreen only"].column:not(.mobile) {
    display: none !important; } }

/* Tablet Only Hide */
@media only screen and (min-width: 768px) and (max-width: 991px) {
  .ui[class*="mobile only"].grid.grid.grid:not(.tablet) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="mobile only"].row:not(.tablet), .ui.grid.grid.grid > [class*="mobile only"].column:not(.tablet) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="mobile only"].column:not(.tablet) {
    display: none !important; }
  .ui[class*="computer only"].grid.grid.grid:not(.tablet) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="computer only"].row:not(.tablet), .ui.grid.grid.grid > [class*="computer only"].column:not(.tablet) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="computer only"].column:not(.tablet) {
    display: none !important; }
  .ui[class*="large screen only"].grid.grid.grid:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="large screen only"].row:not(.mobile), .ui.grid.grid.grid > [class*="large screen only"].column:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="large screen only"].column:not(.mobile) {
    display: none !important; }
  .ui[class*="widescreen only"].grid.grid.grid:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="widescreen only"].row:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].column:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="widescreen only"].column:not(.mobile) {
    display: none !important; } }

/* Computer Only Hide */
@media only screen and (min-width: 992px) and (max-width: 1199px) {
  .ui[class*="mobile only"].grid.grid.grid:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="mobile only"].row:not(.computer), .ui.grid.grid.grid > [class*="mobile only"].column:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="mobile only"].column:not(.computer) {
    display: none !important; }
  .ui[class*="tablet only"].grid.grid.grid:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="tablet only"].row:not(.computer), .ui.grid.grid.grid > [class*="tablet only"].column:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="tablet only"].column:not(.computer) {
    display: none !important; }
  .ui[class*="large screen only"].grid.grid.grid:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="large screen only"].row:not(.mobile), .ui.grid.grid.grid > [class*="large screen only"].column:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="large screen only"].column:not(.mobile) {
    display: none !important; }
  .ui[class*="widescreen only"].grid.grid.grid:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="widescreen only"].row:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].column:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="widescreen only"].column:not(.mobile) {
    display: none !important; } }

/* Large Screen Only Hide */
@media only screen and (min-width: 1200px) and (max-width: 1919px) {
  .ui[class*="mobile only"].grid.grid.grid:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="mobile only"].row:not(.computer), .ui.grid.grid.grid > [class*="mobile only"].column:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="mobile only"].column:not(.computer) {
    display: none !important; }
  .ui[class*="tablet only"].grid.grid.grid:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="tablet only"].row:not(.computer), .ui.grid.grid.grid > [class*="tablet only"].column:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="tablet only"].column:not(.computer) {
    display: none !important; }
  .ui[class*="widescreen only"].grid.grid.grid:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="widescreen only"].row:not(.mobile), .ui.grid.grid.grid > [class*="widescreen only"].column:not(.mobile) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="widescreen only"].column:not(.mobile) {
    display: none !important; } }

/* Widescreen Only Hide */
@media only screen and (min-width: 1920px) {
  .ui[class*="mobile only"].grid.grid.grid:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="mobile only"].row:not(.computer), .ui.grid.grid.grid > [class*="mobile only"].column:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="mobile only"].column:not(.computer) {
    display: none !important; }
  .ui[class*="tablet only"].grid.grid.grid:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > [class*="tablet only"].row:not(.computer), .ui.grid.grid.grid > [class*="tablet only"].column:not(.computer) {
    display: none !important; }
  .ui.grid.grid.grid > .row > [class*="tablet only"].column:not(.computer) {
    display: none !important; } }

/*******************************
         Theme Overrides
*******************************/
/*******************************
         Site Overrides
*******************************/
/*
 * # Semantic - Menu
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Copyright 2015 Contributor
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Standard
*******************************/
/*--------------
      Menu
---------------*/
.ui.menu {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  margin: 1rem 0em;
  font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
  background: #FFFFFF;
  font-weight: normal;
  border: 1px solid rgba(34, 36, 38, 0.15);
  box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15);
  border-radius: 0.28571429rem;
  min-height: 2.85714286em; }
  .ui.menu:after {
    content: '';
    display: block;
    height: 0px;
    clear: both;
    visibility: hidden; }
  .ui.menu:first-child {
    margin-top: 0rem; }
  .ui.menu:last-child {
    margin-bottom: 0rem; }
  .ui.menu .menu {
    margin: 0em; }
  .ui.menu:not(.vertical) > .menu {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex; }
  .ui.menu:not(.vertical) .item {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center; }
  .ui.menu .item {
    position: relative;
    vertical-align: middle;
    line-height: 1;
    text-decoration: none;
    -webkit-tap-highlight-color: transparent;
    -webkit-box-flex: 0;
    -ms-flex: 0 0 auto;
    flex: 0 0 auto;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    background: none;
    padding: 0.92857143em 1.14285714em;
    text-transform: none;
    color: rgba(0, 0, 0, 0.87);
    font-weight: normal;
    -webkit-transition: background 0.1s ease, box-shadow 0.1s ease, color 0.1s ease;
    transition: background 0.1s ease, box-shadow 0.1s ease, color 0.1s ease; }
    .ui.menu .item:before {
      position: absolute;
      content: '';
      top: 0%;
      right: 0px;
      height: 100%;
      width: 1px;
      background: rgba(34, 36, 38, 0.1); }
  .ui.menu > .item:first-child {
    border-radius: 0.28571429rem 0px 0px 0.28571429rem; }
  .ui.menu .text.item > * {
    -webkit-user-select: text;
    -moz-user-select: text;
    -ms-user-select: text;
    user-select: text;
    line-height: 1.3; }
  .ui.menu .item > a:not(.ui) {
    -webkit-user-select: text;
    -moz-user-select: text;
    -ms-user-select: text;
    user-select: text;
    line-height: 1.3; }
  .ui.menu .item > p:only-child {
    -webkit-user-select: text;
    -moz-user-select: text;
    -ms-user-select: text;
    user-select: text;
    line-height: 1.3; }
  .ui.menu .item > p:first-child {
    margin-top: 0; }
  .ui.menu .item > p:last-child {
    margin-bottom: 0; }
  .ui.menu .item > i.icon {
    opacity: 0.9;
    float: none;
    margin: 0em 0.35714286em 0em 0em; }
  .ui.menu:not(.vertical) .item > .button {
    position: relative;
    top: 0em;
    margin: -0.5em 0em;
    padding-bottom: 0.78571429em;
    padding-top: 0.78571429em;
    font-size: 1em; }
  .ui.menu > .grid, .ui.menu > .container {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: inherit;
    -ms-flex-align: inherit;
    align-items: inherit;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: inherit;
    flex-direction: inherit; }
  .ui.menu .item > .input {
    width: 100%; }
  .ui.menu:not(.vertical) .item > .input {
    position: relative;
    top: 0em;
    margin: -0.5em 0em; }
  .ui.menu .item > .input input {
    font-size: 1em;
    padding-top: 0.57142857em;
    padding-bottom: 0.57142857em; }
  .ui.menu .header.item {
    margin: 0em;
    background: '';
    text-transform: normal;
    font-weight: bold; }

.ui.vertical.menu .header.item {
  margin: 0em;
  background: '';
  text-transform: normal;
  font-weight: bold; }

.ui.vertical.menu .item > .header:not(.ui) {
  margin: 0em 0em 0.5em;
  font-size: 1em;
  font-weight: bold; }

.ui.menu .item > i.dropdown.icon {
  padding: 0em;
  float: right;
  margin: 0em 0em 0em 1em; }

.ui.menu .dropdown.item .menu {
  min-width: calc(100% - 1px);
  border-radius: 0em 0em 0.28571429rem 0.28571429rem;
  background: #FFFFFF;
  margin: 0em 0px 0px;
  box-shadow: 0px 1px 3px 0px rgba(0, 0, 0, 0.08);
  -webkit-box-orient: vertical !important;
  -webkit-box-direction: normal !important;
  -ms-flex-direction: column !important;
  flex-direction: column !important; }

.ui.menu .ui.dropdown .menu > .item {
  margin: 0;
  text-align: left;
  font-size: 1em !important;
  padding: 0.78571429em 1.14285714em !important;
  background: transparent !important;
  color: rgba(0, 0, 0, 0.87) !important;
  text-transform: none !important;
  font-weight: normal !important;
  box-shadow: none !important;
  -webkit-transition: none !important;
  transition: none !important; }
  .ui.menu .ui.dropdown .menu > .item:hover {
    background: rgba(0, 0, 0, 0.05) !important;
    color: rgba(0, 0, 0, 0.95) !important; }

.ui.menu .ui.dropdown .menu > .selected.item {
  background: rgba(0, 0, 0, 0.05) !important;
  color: rgba(0, 0, 0, 0.95) !important; }

.ui.menu .ui.dropdown .menu > .active.item {
  background: rgba(0, 0, 0, 0.03) !important;
  font-weight: bold !important;
  color: rgba(0, 0, 0, 0.95) !important; }

.ui.menu .ui.dropdown.item .menu .item:not(.filtered) {
  display: block; }

.ui.menu .ui.dropdown .menu > .item .icon:not(.dropdown) {
  display: inline-block;
  font-size: 1em !important;
  float: none;
  margin: 0em 0.75em 0em 0em; }

.ui.secondary.menu .dropdown.item > .menu, .ui.text.menu .dropdown.item > .menu {
  border-radius: 0.28571429rem;
  margin-top: 0.35714286em; }

.ui.menu .pointing.dropdown.item .menu {
  margin-top: 0.75em; }

.ui.inverted.menu .search.dropdown.item > .search, .ui.inverted.menu .search.dropdown.item > .text {
  color: rgba(255, 255, 255, 0.9); }

.ui.vertical.menu .dropdown.item > .icon {
  float: right;
  content: "\f0da";
  margin-left: 1em; }

.ui.vertical.menu .dropdown.item .menu {
  left: 100%;
  min-width: 0;
  margin: 0em 0em 0em 0em;
  box-shadow: 0 1px 3px 0px rgba(0, 0, 0, 0.08);
  border-radius: 0em 0.28571429rem 0.28571429rem 0.28571429rem; }

.ui.vertical.menu .dropdown.item.upward .menu {
  bottom: 0; }

.ui.vertical.menu .dropdown.item:not(.upward) .menu {
  top: 0; }

.ui.vertical.menu .active.dropdown.item {
  border-top-right-radius: 0em;
  border-bottom-right-radius: 0em;
  box-shadow: none; }

.ui.item.menu .dropdown .menu .item {
  width: 100%; }

.ui.menu .item > .label {
  background: #999999;
  color: #FFFFFF;
  margin-left: 1em;
  padding: 0.3em 0.78571429em; }

.ui.vertical.menu .item > .label {
  background: #999999;
  color: #FFFFFF;
  margin-top: -0.15em;
  margin-bottom: -0.15em;
  padding: 0.3em 0.78571429em; }

.ui.menu .item > .floating.label {
  padding: 0.3em 0.78571429em; }

.ui.menu .item > img:not(.ui) {
  display: inline-block;
  vertical-align: middle;
  margin: -0.3em 0em;
  width: 2.5em; }

.ui.vertical.menu .item > img:not(.ui):only-child {
  display: block;
  max-width: 100%;
  width: auto; }

.ui.vertical.sidebar.menu > .item:first-child:before {
  display: block !important; }

.ui.vertical.sidebar.menu > .item::before {
  top: auto;
  bottom: 0px; }

.ui.link.menu .item:hover {
  cursor: pointer;
  background: rgba(0, 0, 0, 0.03);
  color: rgba(0, 0, 0, 0.95); }

.ui.menu .dropdown.item:hover, .ui.menu .link.item:hover, .ui.menu a.item:hover {
  cursor: pointer;
  background: rgba(0, 0, 0, 0.03);
  color: rgba(0, 0, 0, 0.95); }

.ui.link.menu .item:active {
  background: rgba(0, 0, 0, 0.03);
  color: rgba(0, 0, 0, 0.95); }

.ui.menu .link.item:active, .ui.menu a.item:active {
  background: rgba(0, 0, 0, 0.03);
  color: rgba(0, 0, 0, 0.95); }

.ui.menu .active.item {
  background: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.95);
  font-weight: normal;
  box-shadow: none; }
  .ui.menu .active.item > i.icon {
    opacity: 1; }
  .ui.menu .active.item:hover {
    background-color: rgba(0, 0, 0, 0.05);
    color: rgba(0, 0, 0, 0.95); }

.ui.vertical.menu .active.item:hover {
  background-color: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.95); }

.ui.menu .item.disabled {
  cursor: default;
  background-color: transparent !important;
  color: rgba(40, 40, 40, 0.3); }
  .ui.menu .item.disabled:hover {
    cursor: default;
    background-color: transparent !important;
    color: rgba(40, 40, 40, 0.3); }

.ui.menu:not(.vertical) .left.item, .ui.menu:not(.vertical) .left.menu {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  margin-right: auto !important; }

.ui.menu:not(.vertical) .right.item, .ui.menu:not(.vertical) .right.menu {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  margin-left: auto !important; }

.ui.menu .right.item::before, .ui.menu .right.menu > .item::before {
  right: auto;
  left: 0; }

.ui.vertical.menu {
  display: block;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  background: #FFFFFF;
  box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15); }
  .ui.vertical.menu .item {
    display: block;
    background: none;
    border-top: none;
    border-right: none; }
    .ui.vertical.menu .item > .label {
      float: right;
      text-align: center; }
    .ui.vertical.menu .item > i.icon {
      width: 1.18em;
      float: right;
      margin: 0em 0em 0em 0.5em; }
    .ui.vertical.menu .item > .label + i.icon {
      float: none;
      margin: 0em 0.5em 0em 0em; }
    .ui.vertical.menu .item:before {
      position: absolute;
      content: '';
      top: 0%;
      left: 0px;
      width: 100%;
      height: 1px;
      background: rgba(34, 36, 38, 0.1); }
    .ui.vertical.menu .item:first-child:before {
      display: none !important; }
    .ui.vertical.menu .item > .menu {
      margin: 0.5em -1.14285714em 0em; }
  .ui.vertical.menu > .item:first-child {
    border-radius: 0.28571429rem 0.28571429rem 0px 0px; }
  .ui.vertical.menu > .item:last-child {
    border-radius: 0px 0px 0.28571429rem 0.28571429rem; }
  .ui.vertical.menu .menu .item {
    background: none;
    padding: 0.5em 1.33333333em;
    font-size: 0.85714286em;
    color: rgba(0, 0, 0, 0.5); }
  .ui.vertical.menu .item .menu a.item:hover, .ui.vertical.menu .item .menu .link.item:hover {
    color: rgba(0, 0, 0, 0.85); }
  .ui.vertical.menu .menu .item:before {
    display: none; }
  .ui.vertical.menu .active.item {
    background: rgba(0, 0, 0, 0.05);
    border-radius: 0em;
    box-shadow: none; }
    .ui.vertical.menu .active.item .menu .active.item {
      border-left: none; }
  .ui.vertical.menu > .active.item:first-child {
    border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
  .ui.vertical.menu > .active.item:last-child {
    border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
  .ui.vertical.menu > .active.item:only-child {
    border-radius: 0.28571429rem; }
  .ui.vertical.menu .item .menu .active.item {
    background-color: transparent;
    font-weight: bold;
    color: rgba(0, 0, 0, 0.95); }

.ui.tabular.menu {
  border-radius: 0em;
  box-shadow: none !important;
  border: none;
  background: none transparent;
  border-bottom: 1px solid #D4D4D5; }

.ui.tabular.fluid.menu {
  width: calc(100% +  2px) !important; }

.ui.tabular.menu .item {
  background: transparent;
  border-bottom: none;
  border-left: 1px solid transparent;
  border-right: 1px solid transparent;
  border-top: 2px solid transparent;
  padding: 0.92857143em 1.42857143em;
  color: rgba(0, 0, 0, 0.87); }
  .ui.tabular.menu .item:before {
    display: none; }
  .ui.tabular.menu .item:hover {
    background-color: transparent;
    color: rgba(0, 0, 0, 0.8); }

.ui.tabular.menu .active.item {
  background: none #FFFFFF;
  color: rgba(0, 0, 0, 0.95);
  border-top-width: 1px;
  border-color: #D4D4D5;
  font-weight: bold;
  margin-bottom: -1px;
  box-shadow: none;
  border-radius: 0.28571429rem 0.28571429rem 0px 0px !important; }

.ui.tabular.menu + .attached:not(.top).segment {
  border-top: none;
  margin-left: 0px;
  margin-top: 0px;
  margin-right: 0px;
  width: 100%; }
  .ui.tabular.menu + .attached:not(.top).segment + .attached:not(.top).segment {
    border-top: none;
    margin-left: 0px;
    margin-top: 0px;
    margin-right: 0px;
    width: 100%; }

@media only screen and (max-width: 767px) {
  .ui.menu > .ui.container {
    width: 100% !important;
    margin-left: 0em !important;
    margin-right: 0em !important; } }

@media only screen and (min-width: 768px) {
  .ui.menu:not(.secondary):not(.text):not(.tabular):not(.borderless) > .container > .item:not(.right):not(.borderless):first-child {
    border-left: 1px solid rgba(34, 36, 38, 0.1); } }

.top.attached.segment + .ui.bottom.tabular.menu {
  position: relative;
  width: calc(100% +  2px);
  left: -1px; }

/* Bottom Vertical Tabular */
.ui.bottom.tabular.menu {
  background: none transparent;
  border-radius: 0em;
  box-shadow: none !important;
  border-bottom: none;
  border-top: 1px solid #D4D4D5; }
  .ui.bottom.tabular.menu .item {
    background: none;
    border-left: 1px solid transparent;
    border-right: 1px solid transparent;
    border-bottom: 1px solid transparent;
    border-top: none; }
  .ui.bottom.tabular.menu .active.item {
    background: none #FFFFFF;
    color: rgba(0, 0, 0, 0.95);
    border-color: #D4D4D5;
    margin: -1px 0px 0px 0px;
    border-radius: 0px 0px 0.28571429rem 0.28571429rem !important; }

.ui.vertical.tabular.menu {
  background: none transparent;
  border-radius: 0em;
  box-shadow: none !important;
  border-bottom: none;
  border-right: 1px solid #D4D4D5; }
  .ui.vertical.tabular.menu .item {
    background: none;
    border-left: 1px solid transparent;
    border-bottom: 1px solid transparent;
    border-top: 1px solid transparent;
    border-right: none; }
  .ui.vertical.tabular.menu .active.item {
    background: none #FFFFFF;
    color: rgba(0, 0, 0, 0.95);
    border-color: #D4D4D5;
    margin: 0px -1px 0px 0px;
    border-radius: 0.28571429rem 0px 0px 0.28571429rem !important; }

.ui.vertical.right.tabular.menu {
  background: none transparent;
  border-radius: 0em;
  box-shadow: none !important;
  border-bottom: none;
  border-right: none;
  border-left: 1px solid #D4D4D5; }
  .ui.vertical.right.tabular.menu .item {
    background: none;
    border-right: 1px solid transparent;
    border-bottom: 1px solid transparent;
    border-top: 1px solid transparent;
    border-left: none; }
  .ui.vertical.right.tabular.menu .active.item {
    background: none #FFFFFF;
    color: rgba(0, 0, 0, 0.95);
    border-color: #D4D4D5;
    margin: 0px 0px 0px -1px;
    border-radius: 0px 0.28571429rem 0.28571429rem 0px !important; }

.ui.tabular.menu .active.dropdown.item {
  margin-bottom: 0px;
  border-left: 1px solid transparent;
  border-right: 1px solid transparent;
  border-top: 2px solid transparent;
  border-bottom: none; }

.ui.pagination.menu {
  margin: 0em;
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  vertical-align: middle; }
  .ui.pagination.menu .item:last-child {
    border-radius: 0em 0.28571429rem 0.28571429rem 0em; }

.ui.compact.menu .item:last-child {
  border-radius: 0em 0.28571429rem 0.28571429rem 0em; }

.ui.pagination.menu .item {
  min-width: 3em;
  text-align: center; }
  .ui.pagination.menu .item:last-child:before {
    display: none; }

.ui.pagination.menu .icon.item i.icon {
  vertical-align: top; }

.ui.pagination.menu .active.item {
  border-top: none;
  padding-top: 0.92857143em;
  background-color: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.95);
  box-shadow: none; }

.ui.secondary.menu {
  background: none;
  margin-left: -0.35714286em;
  margin-right: -0.35714286em;
  border-radius: 0em;
  border: none;
  box-shadow: none; }
  .ui.secondary.menu .item {
    -ms-flex-item-align: center;
    -ms-grid-row-align: center;
    align-self: center;
    box-shadow: none;
    border: none;
    padding: 0.78571429em 0.92857143em;
    margin: 0em 0.35714286em;
    background: none;
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease;
    border-radius: 0.28571429rem; }
    .ui.secondary.menu .item:before {
      display: none !important; }
  .ui.secondary.menu .header.item {
    border-radius: 0em;
    border-right: none;
    background: none transparent; }
  .ui.secondary.menu .item > img:not(.ui) {
    margin: 0em; }
  .ui.secondary.menu .dropdown.item:hover, .ui.secondary.menu .link.item:hover, .ui.secondary.menu a.item:hover {
    background: rgba(0, 0, 0, 0.05);
    color: rgba(0, 0, 0, 0.95); }
  .ui.secondary.menu .active.item {
    box-shadow: none;
    background: rgba(0, 0, 0, 0.05);
    color: rgba(0, 0, 0, 0.95);
    border-radius: 0.28571429rem; }
    .ui.secondary.menu .active.item:hover {
      box-shadow: none;
      background: rgba(0, 0, 0, 0.05);
      color: rgba(0, 0, 0, 0.95); }

.ui.secondary.inverted.menu .link.item, .ui.secondary.inverted.menu a.item {
  color: rgba(255, 255, 255, 0.7) !important; }

.ui.secondary.inverted.menu .dropdown.item:hover, .ui.secondary.inverted.menu .link.item:hover, .ui.secondary.inverted.menu a.item:hover {
  background: rgba(255, 255, 255, 0.08);
  color: #FFFFFF !important; }

.ui.secondary.inverted.menu .active.item {
  background: rgba(255, 255, 255, 0.15);
  color: #FFFFFF !important; }

.ui.secondary.item.menu {
  margin-left: 0em;
  margin-right: 0em; }
  .ui.secondary.item.menu .item:last-child {
    margin-right: 0em; }

.ui.secondary.attached.menu {
  box-shadow: none; }

.ui.vertical.secondary.menu .item:not(.dropdown) > .menu {
  margin: 0em -0.92857143em; }
  .ui.vertical.secondary.menu .item:not(.dropdown) > .menu > .item {
    margin: 0em;
    padding: 0.5em 1.33333333em; }

.ui.vertical.secondary.menu .item > .menu .item {
  background-color: transparent; }

.ui.vertical.secondary.menu > .item {
  border: none;
  margin: 0em 0em 0.35714286em;
  border-radius: 0.28571429rem !important; }

.ui.vertical.secondary.menu > .header.item {
  border-radius: 0em; }

.ui.secondary.inverted.menu {
  background-color: transparent; }

.ui.secondary.pointing.menu {
  margin-left: 0em;
  margin-right: 0em;
  border-bottom: 2px solid rgba(34, 36, 38, 0.15); }
  .ui.secondary.pointing.menu .item {
    border-bottom-color: transparent;
    border-bottom-style: solid;
    border-radius: 0em;
    -ms-flex-item-align: end;
    align-self: flex-end;
    margin: 0em 0em -2px;
    padding: 0.85714286em 1.14285714em;
    border-bottom-width: 2px;
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease; }
  .ui.secondary.pointing.menu .header.item {
    color: rgba(0, 0, 0, 0.85) !important; }
  .ui.secondary.pointing.menu .text.item {
    box-shadow: none !important; }
  .ui.secondary.pointing.menu .item:after {
    display: none; }
  .ui.secondary.pointing.menu .dropdown.item:hover, .ui.secondary.pointing.menu .link.item:hover, .ui.secondary.pointing.menu a.item:hover {
    background-color: transparent;
    color: rgba(0, 0, 0, 0.87); }
  .ui.secondary.pointing.menu .dropdown.item:active, .ui.secondary.pointing.menu .link.item:active, .ui.secondary.pointing.menu a.item:active {
    background-color: transparent;
    border-color: rgba(34, 36, 38, 0.15); }
  .ui.secondary.pointing.menu .active.item {
    background-color: transparent;
    box-shadow: none;
    border-color: #1B1C1D;
    font-weight: bold;
    color: rgba(0, 0, 0, 0.95); }
    .ui.secondary.pointing.menu .active.item:hover {
      border-color: #1B1C1D;
      color: rgba(0, 0, 0, 0.95); }
  .ui.secondary.pointing.menu .active.dropdown.item {
    border-color: transparent; }

.ui.secondary.vertical.pointing.menu {
  border-bottom-width: 0px;
  border-right-width: 2px;
  border-right-style: solid;
  border-right-color: rgba(34, 36, 38, 0.15); }
  .ui.secondary.vertical.pointing.menu .item {
    border-bottom: none;
    border-right-style: solid;
    border-right-color: transparent;
    border-radius: 0em !important;
    margin: 0em -2px 0em 0em;
    border-right-width: 2px; }
  .ui.secondary.vertical.pointing.menu .active.item {
    border-color: #1B1C1D; }

.ui.secondary.inverted.pointing.menu {
  border-color: rgba(255, 255, 255, 0.1);
  border-width: 2px;
  border-color: rgba(34, 36, 38, 0.15); }
  .ui.secondary.inverted.pointing.menu .item {
    color: rgba(255, 255, 255, 0.9); }
  .ui.secondary.inverted.pointing.menu .header.item {
    color: #FFFFFF !important; }
  .ui.secondary.inverted.pointing.menu .link.item:hover, .ui.secondary.inverted.pointing.menu a.item:hover {
    color: rgba(0, 0, 0, 0.95); }
  .ui.secondary.inverted.pointing.menu .active.item {
    border-color: #FFFFFF;
    color: #FFFFFF; }

.ui.text.menu {
  background: none transparent;
  border-radius: 0px;
  box-shadow: none;
  border: none;
  margin: 1em -0.5em; }
  .ui.text.menu .item {
    border-radius: 0px;
    box-shadow: none;
    -ms-flex-item-align: center;
    -ms-grid-row-align: center;
    align-self: center;
    margin: 0em 0em;
    padding: 0.35714286em 0.5em;
    font-weight: normal;
    color: rgba(0, 0, 0, 0.6);
    -webkit-transition: opacity 0.1s ease;
    transition: opacity 0.1s ease; }
    .ui.text.menu .item:before {
      display: none !important; }
  .ui.text.menu .menu .item:before {
    display: none !important; }
  .ui.text.menu .header.item {
    background-color: transparent;
    opacity: 1;
    color: rgba(0, 0, 0, 0.85);
    font-size: 0.92857143em;
    text-transform: uppercase;
    font-weight: bold; }
  .ui.text.menu .item > img:not(.ui) {
    margin: 0em; }

.ui.text.item.menu .item {
  margin: 0em; }

.ui.vertical.text.menu {
  margin: 1em 0em; }
  .ui.vertical.text.menu:first-child {
    margin-top: 0rem; }
  .ui.vertical.text.menu:last-child {
    margin-bottom: 0rem; }
  .ui.vertical.text.menu .item {
    margin: 0.57142857em 0em;
    padding-left: 0em;
    padding-right: 0em; }
    .ui.vertical.text.menu .item > i.icon {
      float: none;
      margin: 0em 0.35714286em 0em 0em; }
  .ui.vertical.text.menu .header.item {
    margin: 0.57142857em 0em 0.71428571em; }
  .ui.vertical.text.menu .item:not(.dropdown) > .menu {
    margin: 0em; }
    .ui.vertical.text.menu .item:not(.dropdown) > .menu > .item {
      margin: 0em;
      padding: 0.5em 0em; }

.ui.text.menu .item:hover {
  opacity: 1;
  background-color: transparent; }

.ui.text.menu .active.item {
  background-color: transparent;
  border: none;
  box-shadow: none;
  font-weight: normal;
  color: rgba(0, 0, 0, 0.95); }
  .ui.text.menu .active.item:hover {
    background-color: transparent; }

.ui.text.pointing.menu .active.item:after, .ui.text.attached.menu {
  box-shadow: none; }

.ui.inverted.text.menu {
  background-color: transparent !important; }
  .ui.inverted.text.menu .item {
    background-color: transparent !important; }
    .ui.inverted.text.menu .item:hover {
      background-color: transparent !important; }
  .ui.inverted.text.menu .active.item {
    background-color: transparent !important; }

.ui.fluid.text.menu {
  margin-left: 0em;
  margin-right: 0em; }

.ui.vertical.icon.menu {
  display: inline-block;
  width: auto; }

.ui.icon.menu .item {
  height: auto;
  text-align: center;
  color: #1B1C1D; }
  .ui.icon.menu .item > .icon:not(.dropdown) {
    margin: 0;
    opacity: 1; }

.ui.icon.menu .icon:before {
  opacity: 1; }

.ui.menu .icon.item > .icon {
  width: auto;
  margin: 0em auto; }

.ui.vertical.icon.menu .item > .icon:not(.dropdown) {
  display: block;
  opacity: 1;
  margin: 0em auto;
  float: none; }

.ui.inverted.icon.menu .item {
  color: #FFFFFF; }

.ui.labeled.icon.menu {
  text-align: center; }
  .ui.labeled.icon.menu .item {
    min-width: 6em;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column; }
    .ui.labeled.icon.menu .item > .icon:not(.dropdown) {
      height: 1em;
      display: block;
      font-size: 1.71428571em !important;
      margin: 0em auto 0.5rem !important; }

.ui.fluid.labeled.icon.menu > .item {
  min-width: 0em; }

.ui.menu .red.active.item, .ui.red.menu .active.item {
  border-color: #DB2828 !important;
  color: #DB2828 !important; }

.ui.menu .orange.active.item, .ui.orange.menu .active.item {
  border-color: #fc7831 !important;
  color: #fc7831 !important; }

.ui.menu .yellow.active.item, .ui.yellow.menu .active.item {
  border-color: #FBBD08 !important;
  color: #FBBD08 !important; }

.ui.menu .olive.active.item, .ui.olive.menu .active.item {
  border-color: #B5CC18 !important;
  color: #B5CC18 !important; }

.ui.menu .green.active.item, .ui.green.menu .active.item {
  border-color: #21BA45 !important;
  color: #21BA45 !important; }

.ui.menu .teal.active.item, .ui.teal.menu .active.item {
  border-color: #00B5AD !important;
  color: #00B5AD !important; }

.ui.menu .blue.active.item, .ui.blue.menu .active.item {
  border-color: #4c8bd6 !important;
  color: #4c8bd6 !important; }

.ui.menu .violet.active.item, .ui.violet.menu .active.item {
  border-color: #6435C9 !important;
  color: #6435C9 !important; }

.ui.menu .purple.active.item, .ui.purple.menu .active.item {
  border-color: #A333C8 !important;
  color: #A333C8 !important; }

.ui.menu .pink.active.item, .ui.pink.menu .active.item {
  border-color: #E03997 !important;
  color: #E03997 !important; }

.ui.menu .brown.active.item, .ui.brown.menu .active.item {
  border-color: #A5673F !important;
  color: #A5673F !important; }

.ui.menu .grey.active.item, .ui.grey.menu .active.item {
  border-color: #767676 !important;
  color: #767676 !important; }

.ui.inverted.menu {
  border: 0px solid transparent;
  background: #1B1C1D;
  box-shadow: none; }
  .ui.inverted.menu .item {
    background: transparent;
    color: rgba(255, 255, 255, 0.9); }
    .ui.inverted.menu .item > a:not(.ui) {
      background: transparent;
      color: rgba(255, 255, 255, 0.9); }
    .ui.inverted.menu .item.menu {
      background: transparent; }
    .ui.inverted.menu .item:before {
      background: rgba(255, 255, 255, 0.08); }

.ui.vertical.inverted.menu .item:before {
  background: rgba(255, 255, 255, 0.08); }

.ui.vertical.inverted.menu .menu .item {
  color: rgba(255, 255, 255, 0.5); }
  .ui.vertical.inverted.menu .menu .item a:not(.ui) {
    color: rgba(255, 255, 255, 0.5); }

.ui.inverted.menu .header.item {
  margin: 0em;
  background: transparent;
  box-shadow: none; }

.ui.inverted.menu .item.disabled {
  color: rgba(225, 225, 225, 0.3); }
  .ui.inverted.menu .item.disabled:hover {
    color: rgba(225, 225, 225, 0.3); }

.ui.link.inverted.menu .item:hover {
  background: rgba(255, 255, 255, 0.08);
  color: #FFFFFF; }

.ui.inverted.menu .dropdown.item:hover, .ui.inverted.menu .link.item:hover, .ui.inverted.menu a.item:hover {
  background: rgba(255, 255, 255, 0.08);
  color: #FFFFFF; }

.ui.vertical.inverted.menu .item .menu a.item:hover, .ui.vertical.inverted.menu .item .menu .link.item:hover {
  background: transparent;
  color: #FFFFFF; }

.ui.inverted.menu a.item:active, .ui.inverted.menu .link.item:active {
  background: rgba(255, 255, 255, 0.08);
  color: #FFFFFF; }

.ui.inverted.menu .active.item {
  background: rgba(255, 255, 255, 0.15);
  color: #FFFFFF !important; }

.ui.inverted.vertical.menu .item .menu .active.item {
  background: transparent;
  color: #FFFFFF; }

.ui.inverted.pointing.menu .active.item:after {
  background: #3D3E3F !important;
  margin: 0em !important;
  box-shadow: none !important;
  border: none !important; }

.ui.inverted.menu .active.item:hover {
  background: rgba(255, 255, 255, 0.15);
  color: #FFFFFF !important; }

.ui.inverted.pointing.menu .active.item:hover:after {
  background: #3D3E3F !important; }

.ui.floated.menu {
  float: left;
  margin: 0rem 0.5rem 0rem 0rem; }
  .ui.floated.menu .item:last-child:before {
    display: none; }

.ui.right.floated.menu {
  float: right;
  margin: 0rem 0rem 0rem 0.5rem; }

.ui.inverted.menu .red.active.item {
  background-color: #DB2828; }

.ui.inverted.red.menu {
  background-color: #DB2828; }
  .ui.inverted.red.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.red.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .orange.active.item {
  background-color: #fc7831; }

.ui.inverted.orange.menu {
  background-color: #fc7831; }
  .ui.inverted.orange.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.orange.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .yellow.active.item {
  background-color: #FBBD08; }

.ui.inverted.yellow.menu {
  background-color: #FBBD08; }
  .ui.inverted.yellow.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.yellow.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .olive.active.item {
  background-color: #B5CC18; }

.ui.inverted.olive.menu {
  background-color: #B5CC18; }
  .ui.inverted.olive.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.olive.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .green.active.item {
  background-color: #21BA45; }

.ui.inverted.green.menu {
  background-color: #21BA45; }
  .ui.inverted.green.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.green.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .teal.active.item {
  background-color: #00B5AD; }

.ui.inverted.teal.menu {
  background-color: #00B5AD; }
  .ui.inverted.teal.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.teal.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .blue.active.item {
  background-color: #4c8bd6; }

.ui.inverted.blue.menu {
  background-color: #4c8bd6; }
  .ui.inverted.blue.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.blue.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .violet.active.item {
  background-color: #6435C9; }

.ui.inverted.violet.menu {
  background-color: #6435C9; }
  .ui.inverted.violet.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.violet.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .purple.active.item {
  background-color: #A333C8; }

.ui.inverted.purple.menu {
  background-color: #A333C8; }
  .ui.inverted.purple.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.purple.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .pink.active.item {
  background-color: #E03997; }

.ui.inverted.pink.menu {
  background-color: #E03997; }
  .ui.inverted.pink.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.pink.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .brown.active.item {
  background-color: #A5673F; }

.ui.inverted.brown.menu {
  background-color: #A5673F; }
  .ui.inverted.brown.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.brown.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.inverted.menu .grey.active.item {
  background-color: #767676; }

.ui.inverted.grey.menu {
  background-color: #767676; }
  .ui.inverted.grey.menu .item:before {
    background-color: rgba(34, 36, 38, 0.1); }
  .ui.inverted.grey.menu .active.item {
    background-color: rgba(0, 0, 0, 0.1) !important; }

.ui.fitted.menu .item {
  padding: 0em; }
  .ui.fitted.menu .item .menu .item {
    padding: 0em; }

.ui.menu .fitted.item {
  padding: 0em; }

.ui.horizontally.fitted.menu .item {
  padding-top: 0.92857143em;
  padding-bottom: 0.92857143em; }
  .ui.horizontally.fitted.menu .item .menu .item {
    padding-top: 0.92857143em;
    padding-bottom: 0.92857143em; }

.ui.menu .horizontally.fitted.item {
  padding-top: 0.92857143em;
  padding-bottom: 0.92857143em; }

.ui.vertically.fitted.menu .item {
  padding-left: 1.14285714em;
  padding-right: 1.14285714em; }
  .ui.vertically.fitted.menu .item .menu .item {
    padding-left: 1.14285714em;
    padding-right: 1.14285714em; }

.ui.menu .vertically.fitted.item {
  padding-left: 1.14285714em;
  padding-right: 1.14285714em; }

.ui.borderless.menu .item:before, .ui.borderless.menu .item .menu .item:before {
  background: none !important; }

.ui.menu .borderless.item:before {
  background: none !important; }

.ui.compact.menu {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  margin: 0em;
  vertical-align: middle; }

.ui.compact.vertical.menu {
  display: inline-block; }

.ui.compact.menu .item:last-child {
  border-radius: 0em 0.28571429rem 0.28571429rem 0em; }
  .ui.compact.menu .item:last-child:before {
    display: none; }

.ui.compact.vertical.menu {
  width: auto !important; }
  .ui.compact.vertical.menu .item:last-child::before {
    display: block; }

.ui.menu.fluid, .ui.vertical.menu.fluid {
  width: 100% !important; }

.ui.item.menu {
  width: 100%;
  padding-left: 0em !important;
  padding-right: 0em !important;
  margin-left: 0em !important;
  margin-right: 0em !important;
  text-align: center;
  -webkit-box-pack: center;
  -ms-flex-pack: center;
  justify-content: center; }
  .ui.item.menu .item {
    width: 100%;
    padding-left: 0em !important;
    padding-right: 0em !important;
    margin-left: 0em !important;
    margin-right: 0em !important;
    text-align: center;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center; }

.ui.attached.item.menu {
  margin: 0em -1px !important; }

.ui.item.menu .item:last-child:before {
  display: none; }

.ui.menu.two.item .item {
  width: 50%; }

.ui.menu.three.item .item {
  width: 33.333%; }

.ui.menu.four.item .item {
  width: 25%; }

.ui.menu.five.item .item {
  width: 20%; }

.ui.menu.six.item .item {
  width: 16.666%; }

.ui.menu.seven.item .item {
  width: 14.285%; }

.ui.menu.eight.item .item {
  width: 12.500%; }

.ui.menu.nine.item .item {
  width: 11.11%; }

.ui.menu.ten.item .item {
  width: 10.0%; }

.ui.menu.eleven.item .item {
  width: 9.09%; }

.ui.menu.twelve.item .item {
  width: 8.333%; }

.ui.menu.fixed {
  position: fixed;
  z-index: 101;
  margin: 0em;
  width: 100%;
  border-radius: 0px !important;
  top: 0px;
  left: 0px;
  right: auto;
  bottom: auto; }
  .ui.menu.fixed .item:first-child, .ui.menu.fixed .item:last-child {
    border-radius: 0px !important; }

.ui[class*="top fixed"].menu {
  top: 0px;
  left: 0px;
  right: auto;
  bottom: auto;
  border-top: none;
  border-left: none;
  border-right: none; }

.ui[class*="right fixed"].menu {
  border-top: none;
  border-bottom: none;
  border-right: none;
  top: 0px;
  right: 0px;
  left: auto;
  bottom: auto;
  width: auto;
  height: 100%; }

.ui[class*="bottom fixed"].menu {
  border-bottom: none;
  border-left: none;
  border-right: none;
  bottom: 0px;
  left: 0px;
  top: auto;
  right: auto; }

.ui[class*="left fixed"].menu {
  border-top: none;
  border-bottom: none;
  border-left: none;
  top: 0px;
  left: 0px;
  right: auto;
  bottom: auto;
  width: auto;
  height: 100%; }

.ui.fixed.menu + .ui.grid {
  padding-top: 2.75rem; }

.ui.pointing.menu .item:after {
  visibility: hidden;
  position: absolute;
  content: '';
  top: 100%;
  left: 50%;
  -webkit-transform: translateX(-50%) translateY(-50%) rotate(45deg);
  transform: translateX(-50%) translateY(-50%) rotate(45deg);
  background: none;
  margin: 0.5px 0em 0em;
  width: 0.57142857em;
  height: 0.57142857em;
  border: none;
  border-bottom: 1px solid #D4D4D5;
  border-right: 1px solid #D4D4D5;
  z-index: 2;
  -webkit-transition: background 0.1s ease;
  transition: background 0.1s ease; }

.ui.vertical.pointing.menu .item:after {
  position: absolute;
  top: 50%;
  right: 0%;
  bottom: auto;
  left: auto;
  -webkit-transform: translateX(50%) translateY(-50%) rotate(45deg);
  transform: translateX(50%) translateY(-50%) rotate(45deg);
  margin: 0em -0.5px 0em 0em;
  border: none;
  border-top: 1px solid #D4D4D5;
  border-right: 1px solid #D4D4D5; }

.ui.pointing.menu .active.item:after {
  visibility: visible; }

.ui.pointing.menu .active.dropdown.item:after {
  visibility: hidden;
  display: none; }

.ui.pointing.menu .active.item .menu .active.item:after {
  display: none; }

.ui.pointing.menu .active.item:hover:after, .ui.pointing.menu .active.item:after, .ui.pointing.menu .active.item:hover:after {
  background-color: #F2F2F2; }

.ui.vertical.pointing.menu .active.item:hover:after, .ui.vertical.pointing.menu .active.item:after {
  background-color: #F2F2F2; }

.ui.vertical.pointing.menu .menu .active.item:after {
  background-color: #FFFFFF; }

.ui.attached.menu {
  top: 0px;
  bottom: 0px;
  border-radius: 0px;
  margin: 0em -1px;
  width: calc(100% +  2px);
  max-width: calc(100% +  2px);
  box-shadow: none; }

.ui.attached + .ui.attached.menu:not(.top) {
  border-top: none; }

.ui[class*="top attached"].menu {
  bottom: 0px;
  margin-bottom: 0em;
  top: 0px;
  margin-top: 1rem;
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }

.ui.menu[class*="top attached"]:first-child {
  margin-top: 0em; }

.ui[class*="bottom attached"].menu {
  bottom: 0px;
  margin-top: 0em;
  top: 0px;
  margin-bottom: 1rem;
  box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15), none;
  border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
  .ui[class*="bottom attached"].menu:last-child {
    margin-bottom: 0em; }

.ui.top.attached.menu > .item:first-child {
  border-radius: 0.28571429rem 0em 0em 0em; }

.ui.bottom.attached.menu > .item:first-child {
  border-radius: 0em 0em 0em 0.28571429rem; }

.ui.attached.menu:not(.tabular) {
  border: 1px solid #D4D4D5; }

.ui.attached.inverted.menu {
  border: none; }

.ui.attached.tabular.menu {
  margin-left: 0;
  margin-right: 0;
  width: 100%; }

.ui.mini.menu {
  font-size: 0.78571429rem; }

.ui.mini.vertical.menu {
  width: 9rem; }

.ui.tiny.menu {
  font-size: 0.85714286rem; }

.ui.tiny.vertical.menu {
  width: 11rem; }

.ui.small.menu {
  font-size: 0.92857143rem; }

.ui.small.vertical.menu {
  width: 13rem; }

.ui.menu {
  font-size: 1rem; }

.ui.vertical.menu {
  width: 15rem; }

.ui.large.menu {
  font-size: 1.07142857rem; }

.ui.large.vertical.menu {
  width: 18rem; }

.ui.huge.menu {
  font-size: 1.14285714rem; }

.ui.huge.vertical.menu {
  width: 20rem; }

.ui.big.menu {
  font-size: 1.21428571rem; }

.ui.big.vertical.menu {
  width: 22rem; }

.ui.massive.menu {
  font-size: 1.28571429rem; }

.ui.massive.vertical.menu {
  width: 25rem; }

/*--------------
    Stackable
---------------*/
@media only screen and (max-width: 767px) {
  .ui.stackable.menu {
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column; }
    .ui.stackable.menu .item {
      width: 100% !important; }
      .ui.stackable.menu .item:before {
        position: absolute;
        content: '';
        top: auto;
        bottom: 0px;
        left: 0px;
        width: 100%;
        height: 1px;
        background: rgba(34, 36, 38, 0.1); }
    .ui.stackable.menu .left.menu, .ui.stackable.menu .left.item {
      margin-right: 0 !important; }
    .ui.stackable.menu .right.menu, .ui.stackable.menu .right.item {
      margin-left: 0 !important; }
    .ui.stackable.menu .right.menu {
      -webkit-box-orient: vertical;
      -webkit-box-direction: normal;
      -ms-flex-direction: column;
      flex-direction: column; }
    .ui.stackable.menu .left.menu {
      -webkit-box-orient: vertical;
      -webkit-box-direction: normal;
      -ms-flex-direction: column;
      flex-direction: column; } }

/*!
 * # Semantic UI 2.2.12 - Message
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Message
*******************************/
.ui.message {
  position: relative;
  min-height: 1em;
  margin: 1em 0em;
  background: #F8F8F9;
  padding: 1em 1.5em;
  line-height: 1.4285em;
  color: rgba(0, 0, 0, 0.87);
  -webkit-transition: opacity 0.1s ease, color 0.1s ease, background 0.1s ease, box-shadow 0.1s ease;
  transition: opacity 0.1s ease, color 0.1s ease, background 0.1s ease, box-shadow 0.1s ease;
  border-radius: 0.28571429rem;
  box-shadow: 0px 0px 0px 1px rgba(34, 36, 38, 0.22) inset, 0px 0px 0px 0px transparent; }
  .ui.message:first-child {
    margin-top: 0em; }
  .ui.message:last-child {
    margin-bottom: 0em; }
  .ui.message .header {
    display: block;
    font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
    font-weight: bold;
    margin: -0.14285714em 0em 0rem 0em; }
    .ui.message .header:not(.ui) {
      font-size: 1.14285714em; }
  .ui.message p {
    opacity: 0.85;
    margin: 0.75em 0em; }
    .ui.message p:first-child {
      margin-top: 0em; }
    .ui.message p:last-child {
      margin-bottom: 0em; }
  .ui.message .header + p {
    margin-top: 0.25em; }
  .ui.message .list:not(.ui) {
    text-align: left;
    padding: 0em;
    opacity: 0.85;
    list-style-position: inside;
    margin: 0.5em 0em 0em; }
    .ui.message .list:not(.ui):first-child {
      margin-top: 0em; }
    .ui.message .list:not(.ui):last-child {
      margin-bottom: 0em; }
    .ui.message .list:not(.ui) li {
      position: relative;
      list-style-type: none;
      margin: 0em 0em 0.3em 1em;
      padding: 0em; }
      .ui.message .list:not(.ui) li:before {
        position: absolute;
        content: '•';
        left: -1em;
        height: 100%;
        vertical-align: baseline; }
      .ui.message .list:not(.ui) li:last-child {
        margin-bottom: 0em; }
  .ui.message > .icon {
    margin-right: 0.6em; }
  .ui.message > .close.icon {
    cursor: pointer;
    position: absolute;
    margin: 0em;
    top: 0.78575em;
    right: 0.5em;
    opacity: 0.7;
    -webkit-transition: opacity 0.1s ease;
    transition: opacity 0.1s ease; }
    .ui.message > .close.icon:hover {
      opacity: 1; }
  .ui.message > :first-child {
    margin-top: 0em; }
  .ui.message > :last-child {
    margin-bottom: 0em; }

.ui.dropdown .menu > .message {
  margin: 0px -1px; }

.ui.visible.visible.visible.visible.message {
  display: block; }

.ui.icon.visible.visible.visible.visible.message {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }

.ui.hidden.hidden.hidden.hidden.message {
  display: none; }

.ui.compact.message {
  display: inline-block; }

.ui.compact.icon.message {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex; }

.ui.attached.message {
  margin-bottom: -1px;
  border-radius: 0.28571429rem 0.28571429rem 0em 0em;
  box-shadow: 0em 0em 0em 1px rgba(34, 36, 38, 0.15) inset;
  margin-left: -1px;
  margin-right: -1px; }

.ui.attached + .ui.attached.message:not(.top):not(.bottom) {
  margin-top: -1px;
  border-radius: 0em; }

.ui.bottom.attached.message {
  margin-top: -1px;
  border-radius: 0em 0em 0.28571429rem 0.28571429rem;
  box-shadow: 0em 0em 0em 1px rgba(34, 36, 38, 0.15) inset, 0px 1px 2px 0 rgba(34, 36, 38, 0.15); }
  .ui.bottom.attached.message:not(:last-child) {
    margin-bottom: 1em; }

.ui.attached.icon.message {
  width: auto; }

.ui.icon.message {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  width: 100%;
  -webkit-box-align: center;
  -ms-flex-align: center;
  align-items: center; }
  .ui.icon.message > .icon:not(.close) {
    display: block;
    -webkit-box-flex: 0;
    -ms-flex: 0 0 auto;
    flex: 0 0 auto;
    width: auto;
    line-height: 1;
    vertical-align: middle;
    font-size: 3em;
    opacity: 0.8; }
  .ui.icon.message > .content {
    display: block;
    -webkit-box-flex: 1;
    -ms-flex: 1 1 auto;
    flex: 1 1 auto;
    vertical-align: middle; }
  .ui.icon.message .icon:not(.close) + .content {
    padding-left: 0rem; }
  .ui.icon.message .circular.icon {
    width: 1em; }

.ui.floating.message {
  box-shadow: 0px 0px 0px 1px rgba(34, 36, 38, 0.22) inset, 0px 2px 4px 0px rgba(34, 36, 38, 0.12), 0px 2px 10px 0px rgba(34, 36, 38, 0.15); }

.ui.black.message {
  background-color: #1B1C1D;
  color: rgba(255, 255, 255, 0.9); }

.ui.positive.message {
  background-color: #FCFFF5;
  color: #2C662D;
  box-shadow: 0px 0px 0px 1px #A3C293 inset, 0px 0px 0px 0px transparent; }

.ui.attached.positive.message {
  box-shadow: 0px 0px 0px 1px #A3C293 inset, 0px 0px 0px 0px transparent; }

.ui.positive.message .header {
  color: #1A531B; }

.ui.negative.message {
  background-color: #FFF6F6;
  color: #9F3A38;
  box-shadow: 0px 0px 0px 1px #E0B4B4 inset, 0px 0px 0px 0px transparent; }

.ui.attached.negative.message {
  box-shadow: 0px 0px 0px 1px #E0B4B4 inset, 0px 0px 0px 0px transparent; }

.ui.negative.message .header {
  color: #912D2B; }

.ui.info.message {
  background-color: #F8FFFF;
  color: #276F86;
  box-shadow: 0px 0px 0px 1px #A9D5DE inset, 0px 0px 0px 0px transparent; }

.ui.attached.info.message {
  box-shadow: 0px 0px 0px 1px #A9D5DE inset, 0px 0px 0px 0px transparent; }

.ui.info.message .header {
  color: #0E566C; }

.ui.warning.message {
  background-color: #FFFAF3;
  color: #573A08;
  box-shadow: 0px 0px 0px 1px #C9BA9B inset, 0px 0px 0px 0px transparent; }

.ui.attached.warning.message {
  box-shadow: 0px 0px 0px 1px #C9BA9B inset, 0px 0px 0px 0px transparent; }

.ui.warning.message .header {
  color: #794B02; }

.ui.error.message {
  background-color: #FFF6F6;
  color: #9F3A38;
  box-shadow: 0px 0px 0px 1px #E0B4B4 inset, 0px 0px 0px 0px transparent; }

.ui.attached.error.message {
  box-shadow: 0px 0px 0px 1px #E0B4B4 inset, 0px 0px 0px 0px transparent; }

.ui.error.message .header {
  color: #912D2B; }

.ui.success.message {
  background-color: #FCFFF5;
  color: #2C662D;
  box-shadow: 0px 0px 0px 1px #A3C293 inset, 0px 0px 0px 0px transparent; }

.ui.attached.success.message {
  box-shadow: 0px 0px 0px 1px #A3C293 inset, 0px 0px 0px 0px transparent; }

.ui.success.message .header {
  color: #1A531B; }

.ui.inverted.message, .ui.black.message {
  background-color: #1B1C1D;
  color: rgba(255, 255, 255, 0.9); }

.ui.red.message {
  background-color: #FFE8E6;
  color: #DB2828;
  box-shadow: 0px 0px 0px 1px #DB2828 inset, 0px 0px 0px 0px transparent; }
  .ui.red.message .header {
    color: #c82121; }

.ui.orange.message {
  background-color: #FFEDDE;
  color: #fc7831;
  box-shadow: 0px 0px 0px 1px #fc7831 inset, 0px 0px 0px 0px transparent; }
  .ui.orange.message .header {
    color: #e7640d; }

.ui.yellow.message {
  background-color: #FFF8DB;
  color: #B58105;
  box-shadow: 0px 0px 0px 1px #B58105 inset, 0px 0px 0px 0px transparent; }
  .ui.yellow.message .header {
    color: #9c6f04; }

.ui.olive.message {
  background-color: #FBFDEF;
  color: #8ABC1E;
  box-shadow: 0px 0px 0px 1px #8ABC1E inset, 0px 0px 0px 0px transparent; }
  .ui.olive.message .header {
    color: #7aa61a; }

.ui.green.message {
  background-color: #E5F9E7;
  color: #1EBC30;
  box-shadow: 0px 0px 0px 1px #1EBC30 inset, 0px 0px 0px 0px transparent; }
  .ui.green.message .header {
    color: #1aa62a; }

.ui.teal.message {
  background-color: #E1F7F7;
  color: #10A3A3;
  box-shadow: 0px 0px 0px 1px #10A3A3 inset, 0px 0px 0px 0px transparent; }
  .ui.teal.message .header {
    color: #0e8c8c; }

.ui.blue.message {
  background-color: #DFF0FF;
  color: #4c8bd6;
  box-shadow: 0px 0px 0px 1px #4c8bd6 inset, 0px 0px 0px 0px transparent; }
  .ui.blue.message .header {
    color: #1e77ba; }

.ui.violet.message {
  background-color: #EAE7FF;
  color: #6435C9;
  box-shadow: 0px 0px 0px 1px #6435C9 inset, 0px 0px 0px 0px transparent; }
  .ui.violet.message .header {
    color: #5a30b5; }

.ui.purple.message {
  background-color: #F6E7FF;
  color: #A333C8;
  box-shadow: 0px 0px 0px 1px #A333C8 inset, 0px 0px 0px 0px transparent; }
  .ui.purple.message .header {
    color: #922eb4; }

.ui.pink.message {
  background-color: #FFE3FB;
  color: #E03997;
  box-shadow: 0px 0px 0px 1px #E03997 inset, 0px 0px 0px 0px transparent; }
  .ui.pink.message .header {
    color: #dd238b; }

.ui.brown.message {
  background-color: #F1E2D3;
  color: #A5673F;
  box-shadow: 0px 0px 0px 1px #A5673F inset, 0px 0px 0px 0px transparent; }
  .ui.brown.message .header {
    color: #935b38; }

.ui.mini.message {
  font-size: 0.78571429em; }

.ui.tiny.message {
  font-size: 0.85714286em; }

.ui.small.message {
  font-size: 0.92857143em; }

.ui.message {
  font-size: 1em; }

.ui.large.message {
  font-size: 1.14285714em; }

.ui.big.message {
  font-size: 1.28571429em; }

.ui.huge.message {
  font-size: 1.42857143em; }

.ui.massive.message {
  font-size: 1.71428571em; }

/*!
 * # Semantic UI 2.2.12 - Table
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Table
*******************************/
/* Prototype */
.ui.table {
  width: 100%;
  background: #FFFFFF;
  margin: 1em 0em;
  border: 1px solid rgba(34, 36, 38, 0.15);
  box-shadow: none;
  border-radius: 0.28571429rem;
  text-align: left;
  color: rgba(0, 0, 0, 0.87);
  border-collapse: separate;
  border-spacing: 0px; }
  .ui.table:first-child {
    margin-top: 0em; }
  .ui.table:last-child {
    margin-bottom: 0em; }
  .ui.table th, .ui.table td {
    -webkit-transition: background 0.1s ease, color 0.1s ease;
    transition: background 0.1s ease, color 0.1s ease; }
  .ui.table thead {
    box-shadow: none; }
    .ui.table thead th {
      cursor: auto;
      background: #F9FAFB;
      text-align: inherit;
      color: rgba(0, 0, 0, 0.87);
      padding: 0.92857143em 0.78571429em;
      vertical-align: inherit;
      font-style: none;
      font-weight: bold;
      text-transform: none;
      border-bottom: 1px solid rgba(34, 36, 38, 0.1);
      border-left: none; }
    .ui.table thead tr > th:first-child {
      border-left: none; }
    .ui.table thead tr:first-child > th:first-child {
      border-radius: 0.28571429rem 0em 0em 0em; }
    .ui.table thead tr:first-child > th:last-child {
      border-radius: 0em 0.28571429rem 0em 0em; }
    .ui.table thead tr:first-child > th:only-child {
      border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
  .ui.table tfoot {
    box-shadow: none; }
    .ui.table tfoot th {
      cursor: auto;
      border-top: 1px solid rgba(34, 36, 38, 0.15);
      background: #F9FAFB;
      text-align: inherit;
      color: rgba(0, 0, 0, 0.87);
      padding: 0.78571429em 0.78571429em;
      vertical-align: middle;
      font-style: normal;
      font-weight: normal;
      text-transform: none; }
    .ui.table tfoot tr > th:first-child {
      border-left: none; }
    .ui.table tfoot tr:first-child > th:first-child {
      border-radius: 0em 0em 0em 0.28571429rem; }
    .ui.table tfoot tr:first-child > th:last-child {
      border-radius: 0em 0em 0.28571429rem 0em; }
    .ui.table tfoot tr:first-child > th:only-child {
      border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
  .ui.table tr td {
    border-top: 1px solid rgba(34, 36, 38, 0.1); }
  .ui.table tr:first-child td {
    border-top: none; }
  .ui.table td {
    padding: 0.78571429em 0.78571429em;
    text-align: inherit; }
  .ui.table > .icon {
    vertical-align: baseline; }
    .ui.table > .icon:only-child {
      margin: 0em; }
  .ui.table.segment {
    padding: 0em; }
    .ui.table.segment:after {
      display: none; }
    .ui.table.segment.stacked:after {
      display: block; }
  .ui.table th .image, .ui.table td .image {
    max-width: none; }
    .ui.table th .image img, .ui.table td .image img {
      max-width: none; }

.ui.structured.table {
  border-collapse: collapse; }
  .ui.structured.table thead th {
    border-left: none;
    border-right: none; }

.ui.structured.sortable.table thead th {
  border-left: 1px solid rgba(34, 36, 38, 0.15);
  border-right: 1px solid rgba(34, 36, 38, 0.15); }

.ui.structured.basic.table th {
  border-left: none;
  border-right: none; }

.ui.structured.celled.table tr th, .ui.structured.celled.table tr td {
  border-left: 1px solid rgba(34, 36, 38, 0.1);
  border-right: 1px solid rgba(34, 36, 38, 0.1); }

.ui.definition.table thead:not(.full-width) th:first-child {
  pointer-events: none;
  background: transparent;
  font-weight: normal;
  color: rgba(0, 0, 0, 0.4);
  box-shadow: -1px -1px 0px 1px #FFFFFF; }

.ui.definition.table tfoot:not(.full-width) th:first-child {
  pointer-events: none;
  background: transparent;
  font-weight: rgba(0, 0, 0, 0.4);
  color: normal;
  box-shadow: 1px 1px 0px 1px #FFFFFF; }

.ui.celled.definition.table thead:not(.full-width) th:first-child {
  box-shadow: 0px -1px 0px 1px #FFFFFF; }

.ui.celled.definition.table tfoot:not(.full-width) th:first-child {
  box-shadow: 0px 1px 0px 1px #FFFFFF; }

.ui.definition.table tr td:first-child:not(.ignored), .ui.definition.table tr td.definition {
  background: rgba(0, 0, 0, 0.03);
  font-weight: bold;
  color: rgba(0, 0, 0, 0.95);
  text-transform: '';
  box-shadow: '';
  text-align: '';
  font-size: 1em;
  padding-left: '';
  padding-right: ''; }

.ui.definition.table thead:not(.full-width) th:nth-child(2), .ui.definition.table tfoot:not(.full-width) th:nth-child(2), .ui.definition.table td:nth-child(2) {
  border-left: 1px solid rgba(34, 36, 38, 0.15); }

.ui.table tr.positive, .ui.table td.positive {
  box-shadow: 0px 0px 0px #A3C293 inset; }

.ui.table tr.positive, .ui.table td.positive {
  background: #FCFFF5 !important;
  color: #2C662D !important; }

.ui.table tr.negative, .ui.table td.negative {
  box-shadow: 0px 0px 0px #E0B4B4 inset; }

.ui.table tr.negative, .ui.table td.negative {
  background: #FFF6F6 !important;
  color: #9F3A38 !important; }

.ui.table tr.error, .ui.table td.error {
  box-shadow: 0px 0px 0px #E0B4B4 inset; }

.ui.table tr.error, .ui.table td.error {
  background: #FFF6F6 !important;
  color: #9F3A38 !important; }

.ui.table tr.warning, .ui.table td.warning {
  box-shadow: 0px 0px 0px #C9BA9B inset; }

.ui.table tr.warning, .ui.table td.warning {
  background: #FFFAF3 !important;
  color: #573A08 !important; }

.ui.table tr.active, .ui.table td.active {
  box-shadow: 0px 0px 0px rgba(0, 0, 0, 0.87) inset; }

.ui.table tr.active, .ui.table td.active {
  background: #E0E0E0 !important;
  color: rgba(0, 0, 0, 0.87) !important; }

.ui.table tr.disabled td, .ui.table tr td.disabled, .ui.table tr.disabled:hover, .ui.table tr:hover td.disabled {
  pointer-events: none;
  color: rgba(40, 40, 40, 0.3); }

.ui.table[class*="left aligned"], .ui.table [class*="left aligned"] {
  text-align: left; }

.ui.table[class*="center aligned"], .ui.table [class*="center aligned"] {
  text-align: center; }

.ui.table[class*="right aligned"], .ui.table [class*="right aligned"] {
  text-align: right; }

.ui.table[class*="top aligned"], .ui.table [class*="top aligned"] {
  vertical-align: top; }

.ui.table[class*="middle aligned"], .ui.table [class*="middle aligned"] {
  vertical-align: middle; }

.ui.table[class*="bottom aligned"], .ui.table [class*="bottom aligned"] {
  vertical-align: bottom; }

.ui.table th.collapsing, .ui.table td.collapsing {
  width: 1px;
  white-space: nowrap; }

.ui.fixed.table {
  table-layout: fixed; }
  .ui.fixed.table th, .ui.fixed.table td {
    overflow: hidden;
    text-overflow: ellipsis; }

.ui.selectable.table tbody tr:hover, .ui.table tbody tr td.selectable:hover {
  background: rgba(0, 0, 0, 0.05) !important;
  color: rgba(0, 0, 0, 0.95) !important; }

.ui.selectable.inverted.table tbody tr:hover, .ui.inverted.table tbody tr td.selectable:hover {
  background: rgba(255, 255, 255, 0.08) !important;
  color: #FFFFFF !important; }

.ui.table tbody tr td.selectable {
  padding: 0em; }
  .ui.table tbody tr td.selectable > a:not(.ui) {
    display: block;
    color: inherit;
    padding: 0.78571429em 0.78571429em; }

.ui.selectable.table tr.error:hover, .ui.table tr td.selectable.error:hover {
  background: #ffe7e7 !important;
  color: #943634 !important; }

.ui.selectable.table tr:hover td.error {
  background: #ffe7e7 !important;
  color: #943634 !important; }

.ui.selectable.table tr.warning:hover {
  background: #fff4e4 !important;
  color: #493107 !important; }

.ui.table tr td.selectable.warning:hover {
  background: #fff4e4 !important;
  color: #493107 !important; }

.ui.selectable.table tr:hover td.warning {
  background: #fff4e4 !important;
  color: #493107 !important; }

.ui.selectable.table tr.active:hover {
  background: #E0E0E0 !important;
  color: rgba(0, 0, 0, 0.87) !important; }

.ui.table tr td.selectable.active:hover {
  background: #E0E0E0 !important;
  color: rgba(0, 0, 0, 0.87) !important; }

.ui.selectable.table tr:hover td.active {
  background: #E0E0E0 !important;
  color: rgba(0, 0, 0, 0.87) !important; }

.ui.selectable.table tr.positive:hover {
  background: #f7ffe6 !important;
  color: #275b28 !important; }

.ui.table tr td.selectable.positive:hover {
  background: #f7ffe6 !important;
  color: #275b28 !important; }

.ui.selectable.table tr:hover td.positive {
  background: #f7ffe6 !important;
  color: #275b28 !important; }

.ui.selectable.table tr.negative:hover {
  background: #ffe7e7 !important;
  color: #943634 !important; }

.ui.table tr td.selectable.negative:hover, .ui.selectable.table tr:hover td.negative {
  background: #ffe7e7 !important;
  color: #943634 !important; }

.ui.attached.table {
  top: 0px;
  bottom: 0px;
  border-radius: 0px;
  margin: 0em -1px;
  width: calc(100% +  2px);
  max-width: calc(100% +  2px);
  box-shadow: none;
  border: 1px solid #D4D4D5; }

.ui.attached + .ui.attached.table:not(.top) {
  border-top: none; }

.ui[class*="top attached"].table {
  bottom: 0px;
  margin-bottom: 0em;
  top: 0px;
  margin-top: 1em;
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }

.ui.table[class*="top attached"]:first-child {
  margin-top: 0em; }

.ui[class*="bottom attached"].table {
  bottom: 0px;
  margin-top: 0em;
  top: 0px;
  margin-bottom: 1em;
  box-shadow: none, none;
  border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
  .ui[class*="bottom attached"].table:last-child {
    margin-bottom: 0em; }

.ui.striped.table > tr:nth-child(2n), .ui.striped.table tbody tr:nth-child(2n) {
  background-color: rgba(0, 0, 50, 0.02); }

.ui.inverted.striped.table > tr:nth-child(2n), .ui.inverted.striped.table tbody tr:nth-child(2n) {
  background-color: rgba(255, 255, 255, 0.05); }

.ui.striped.selectable.selectable.selectable.table tbody tr.active:hover {
  background: #EFEFEF !important;
  color: rgba(0, 0, 0, 0.95) !important; }

.ui.table[class*="single line"], .ui.table [class*="single line"], .ui.table[class*="single line"], .ui.table [class*="single line"] {
  white-space: nowrap; }

.ui.red.table {
  border-top: 0.2em solid #DB2828; }

.ui.inverted.red.table {
  background-color: #DB2828 !important;
  color: #FFFFFF !important; }

.ui.orange.table {
  border-top: 0.2em solid #fc7831; }

.ui.inverted.orange.table {
  background-color: #fc7831 !important;
  color: #FFFFFF !important; }

.ui.yellow.table {
  border-top: 0.2em solid #FBBD08; }

.ui.inverted.yellow.table {
  background-color: #FBBD08 !important;
  color: #FFFFFF !important; }

.ui.olive.table {
  border-top: 0.2em solid #B5CC18; }

.ui.inverted.olive.table {
  background-color: #B5CC18 !important;
  color: #FFFFFF !important; }

.ui.green.table {
  border-top: 0.2em solid #21BA45; }

.ui.inverted.green.table {
  background-color: #21BA45 !important;
  color: #FFFFFF !important; }

.ui.teal.table {
  border-top: 0.2em solid #00B5AD; }

.ui.inverted.teal.table {
  background-color: #00B5AD !important;
  color: #FFFFFF !important; }

.ui.blue.table {
  border-top: 0.2em solid #4c8bd6; }

.ui.inverted.blue.table {
  background-color: #4c8bd6 !important;
  color: #FFFFFF !important; }

.ui.violet.table {
  border-top: 0.2em solid #6435C9; }

.ui.inverted.violet.table {
  background-color: #6435C9 !important;
  color: #FFFFFF !important; }

.ui.purple.table {
  border-top: 0.2em solid #A333C8; }

.ui.inverted.purple.table {
  background-color: #A333C8 !important;
  color: #FFFFFF !important; }

.ui.pink.table {
  border-top: 0.2em solid #E03997; }

.ui.inverted.pink.table {
  background-color: #E03997 !important;
  color: #FFFFFF !important; }

.ui.brown.table {
  border-top: 0.2em solid #A5673F; }

.ui.inverted.brown.table {
  background-color: #A5673F !important;
  color: #FFFFFF !important; }

.ui.grey.table {
  border-top: 0.2em solid #767676; }

.ui.inverted.grey.table {
  background-color: #767676 !important;
  color: #FFFFFF !important; }

.ui.black.table {
  border-top: 0.2em solid #1B1C1D; }

.ui.inverted.black.table {
  background-color: #1B1C1D !important;
  color: #FFFFFF !important; }

.ui.one.column.table td {
  width: 100%; }

.ui.two.column.table td {
  width: 50%; }

.ui.three.column.table td {
  width: 33.33333333%; }

.ui.four.column.table td {
  width: 25%; }

.ui.five.column.table td {
  width: 20%; }

.ui.six.column.table td {
  width: 16.66666667%; }

.ui.seven.column.table td {
  width: 14.28571429%; }

.ui.eight.column.table td {
  width: 12.5%; }

.ui.nine.column.table td {
  width: 11.11111111%; }

.ui.ten.column.table td {
  width: 10%; }

.ui.eleven.column.table td {
  width: 9.09090909%; }

.ui.twelve.column.table td {
  width: 8.33333333%; }

.ui.thirteen.column.table td {
  width: 7.69230769%; }

.ui.fourteen.column.table td {
  width: 7.14285714%; }

.ui.fifteen.column.table td {
  width: 6.66666667%; }

.ui.sixteen.column.table td {
  width: 6.25%; }

.ui.table th.one.wide, .ui.table td.one.wide {
  width: 6.25%; }

.ui.table th.two.wide, .ui.table td.two.wide {
  width: 12.5%; }

.ui.table th.three.wide, .ui.table td.three.wide {
  width: 18.75%; }

.ui.table th.four.wide, .ui.table td.four.wide {
  width: 25%; }

.ui.table th.five.wide, .ui.table td.five.wide {
  width: 31.25%; }

.ui.table th.six.wide, .ui.table td.six.wide {
  width: 37.5%; }

.ui.table th.seven.wide, .ui.table td.seven.wide {
  width: 43.75%; }

.ui.table th.eight.wide, .ui.table td.eight.wide {
  width: 50%; }

.ui.table th.nine.wide, .ui.table td.nine.wide {
  width: 56.25%; }

.ui.table th.ten.wide, .ui.table td.ten.wide {
  width: 62.5%; }

.ui.table th.eleven.wide, .ui.table td.eleven.wide {
  width: 68.75%; }

.ui.table th.twelve.wide, .ui.table td.twelve.wide {
  width: 75%; }

.ui.table th.thirteen.wide, .ui.table td.thirteen.wide {
  width: 81.25%; }

.ui.table th.fourteen.wide, .ui.table td.fourteen.wide {
  width: 87.5%; }

.ui.table th.fifteen.wide, .ui.table td.fifteen.wide {
  width: 93.75%; }

.ui.table th.sixteen.wide, .ui.table td.sixteen.wide {
  width: 100%; }

.ui.sortable.table thead th {
  cursor: pointer;
  white-space: nowrap;
  border-left: 1px solid rgba(34, 36, 38, 0.15);
  color: rgba(0, 0, 0, 0.87); }
  .ui.sortable.table thead th:first-child {
    border-left: none; }
  .ui.sortable.table thead th.sorted {
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none; }
    .ui.sortable.table thead th.sorted:hover {
      -webkit-user-select: none;
      -moz-user-select: none;
      -ms-user-select: none;
      user-select: none; }
  .ui.sortable.table thead th:after {
    display: none;
    font-style: normal;
    font-weight: normal;
    text-decoration: inherit;
    content: '';
    height: 1em;
    width: auto;
    opacity: 0.8;
    margin: 0em 0em 0em 0.5em;
    font-family: 'Icons'; }
  .ui.sortable.table thead th.ascending:after {
    content: '\f0d8'; }
  .ui.sortable.table thead th.descending:after {
    content: '\f0d7'; }

.ui.sortable.table th.disabled:hover {
  cursor: auto;
  color: rgba(40, 40, 40, 0.3); }

.ui.sortable.table thead th:hover {
  background: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.8); }

.ui.sortable.table thead th.sorted {
  background: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.95); }
  .ui.sortable.table thead th.sorted:after {
    display: inline-block; }
  .ui.sortable.table thead th.sorted:hover {
    background: rgba(0, 0, 0, 0.05);
    color: rgba(0, 0, 0, 0.95); }

.ui.inverted.sortable.table thead th {
  border-left-color: transparent;
  border-right-color: transparent; }
  .ui.inverted.sortable.table thead th.sorted {
    background: rgba(255, 255, 255, 0.15) -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05));
    background: rgba(255, 255, 255, 0.15) linear-gradient(transparent, rgba(0, 0, 0, 0.05));
    color: #FFFFFF; }
  .ui.inverted.sortable.table thead th:hover {
    background: rgba(255, 255, 255, 0.08) -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05));
    background: rgba(255, 255, 255, 0.08) linear-gradient(transparent, rgba(0, 0, 0, 0.05));
    color: #FFFFFF; }

.ui.inverted.table {
  background: #333333;
  color: rgba(255, 255, 255, 0.9);
  border: none; }
  .ui.inverted.table th {
    background-color: rgba(0, 0, 0, 0.15);
    border-color: rgba(255, 255, 255, 0.1) !important;
    color: rgba(255, 255, 255, 0.9) !important; }
  .ui.inverted.table tr td {
    border-color: rgba(255, 255, 255, 0.1) !important; }
  .ui.inverted.table tr.disabled td, .ui.inverted.table tr td.disabled, .ui.inverted.table tr.disabled:hover td, .ui.inverted.table tr:hover td.disabled {
    pointer-events: none;
    color: rgba(225, 225, 225, 0.3); }

.ui.inverted.definition.table tfoot:not(.full-width) th:first-child, .ui.inverted.definition.table thead:not(.full-width) th:first-child {
  background: #FFFFFF; }

.ui.inverted.definition.table tr td:first-child {
  background: rgba(255, 255, 255, 0.02);
  color: #FFFFFF; }

.ui.collapsing.table {
  width: auto; }

.ui.basic.table {
  background: transparent;
  border: 1px solid rgba(34, 36, 38, 0.15);
  box-shadow: none; }
  .ui.basic.table thead, .ui.basic.table tfoot {
    box-shadow: none; }
  .ui.basic.table th {
    background: transparent;
    border-left: none; }
  .ui.basic.table tbody tr {
    border-bottom: 1px solid rgba(0, 0, 0, 0.1); }
  .ui.basic.table td {
    background: transparent; }

.ui.basic.striped.table tbody tr:nth-child(2n) {
  background-color: rgba(0, 0, 0, 0.05) !important; }

.ui[class*="very basic"].table {
  border: none; }
  .ui[class*="very basic"].table:not(.sortable):not(.striped) th, .ui[class*="very basic"].table:not(.sortable):not(.striped) td {
    padding: ''; }
  .ui[class*="very basic"].table:not(.sortable):not(.striped) th:first-child, .ui[class*="very basic"].table:not(.sortable):not(.striped) td:first-child {
    padding-left: 0em; }
  .ui[class*="very basic"].table:not(.sortable):not(.striped) th:last-child, .ui[class*="very basic"].table:not(.sortable):not(.striped) td:last-child {
    padding-right: 0em; }
  .ui[class*="very basic"].table:not(.sortable):not(.striped) thead tr:first-child th {
    padding-top: 0em; }

.ui.celled.table tr th, .ui.celled.table tr td {
  border-left: 1px solid rgba(34, 36, 38, 0.1); }

.ui.celled.table tr th:first-child, .ui.celled.table tr td:first-child {
  border-left: none; }

.ui.padded.table th {
  padding-left: 1em;
  padding-right: 1em;
  padding: 1em 1em; }

.ui.padded.table td {
  padding: 1em 1em; }

.ui[class*="very padded"].table th {
  padding-left: 1.5em;
  padding-right: 1.5em; }

.ui[class*="very padded"].table td {
  padding: 1.5em 1.5em; }

.ui.compact.table th {
  padding-left: 0.7em;
  padding-right: 0.7em; }

.ui.compact.table td {
  padding: 0.5em 0.7em; }

.ui[class*="very compact"].table th {
  padding-left: 0.6em;
  padding-right: 0.6em; }

.ui[class*="very compact"].table td {
  padding: 0.4em 0.6em; }

.ui.small.table {
  font-size: 0.9em; }

.ui.table {
  font-size: 1em; }

.ui.large.table {
  font-size: 1.1em; }

@media only screen and (max-width: 767px) {
  .ui.table:not(.unstackable) {
    width: 100%;
    padding: 0em; }
    .ui.table:not(.unstackable) tbody {
      width: auto !important;
      display: block !important; }
    .ui.table:not(.unstackable) tr {
      width: auto !important;
      display: block !important; }
      .ui.table:not(.unstackable) tr > th, .ui.table:not(.unstackable) tr > td {
        width: auto !important;
        display: block !important; }
    .ui.table:not(.unstackable) thead, .ui.table:not(.unstackable) tfoot {
      display: block; }
    .ui.table:not(.unstackable) tr {
      padding-top: 1em;
      padding-bottom: 1em;
      box-shadow: 0px -1px 0px 0px rgba(0, 0, 0, 0.1) inset !important; }
      .ui.table:not(.unstackable) tr > th, .ui.table:not(.unstackable) tr > td {
        background: none;
        border: none !important;
        padding: 0.25em 0.75em !important;
        box-shadow: none !important; }
    .ui.table:not(.unstackable) th:first-child, .ui.table:not(.unstackable) td:first-child {
      font-weight: bold; }
  .ui.definition.table:not(.unstackable) thead th:first-child {
    box-shadow: none !important; } }

@media only screen and (max-width: 991px) {
  .ui[class*="tablet stackable"].table {
    width: 100% !important;
    display: block !important;
    padding: 0em; }
    .ui[class*="tablet stackable"].table tbody {
      width: 100% !important;
      display: block !important; }
    .ui[class*="tablet stackable"].table tr {
      width: 100% !important;
      display: block !important; }
      .ui[class*="tablet stackable"].table tr > th, .ui[class*="tablet stackable"].table tr > td {
        width: 100% !important;
        display: block !important; }
    .ui[class*="tablet stackable"].table thead, .ui[class*="tablet stackable"].table tfoot {
      display: block; }
    .ui[class*="tablet stackable"].table tr {
      padding-top: 1em;
      padding-bottom: 1em;
      box-shadow: 0px -1px 0px 0px rgba(0, 0, 0, 0.1) inset !important; }
      .ui[class*="tablet stackable"].table tr > th, .ui[class*="tablet stackable"].table tr > td {
        background: none;
        border: none !important;
        padding: 0.25em 0.75em;
        box-shadow: none !important; }
  .ui.definition[class*="tablet stackable"].table thead th:first-child {
    box-shadow: none !important; }
  /* Definition Table */ }

/*!
 * # Semantic UI 2.2.12 - Ad
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Copyright 2013 Contributors
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
         Advertisement
*******************************/
.ui.ad {
  display: block;
  overflow: hidden;
  margin: 1em 0em; }
  .ui.ad:first-child, .ui.ad:last-child {
    margin: 0em; }
  .ui.ad iframe {
    margin: 0em;
    padding: 0em;
    border: none;
    overflow: hidden; }

.ui.leaderboard.ad {
  width: 728px;
  height: 90px; }

.ui[class*="medium rectangle"].ad {
  width: 300px;
  height: 250px; }

.ui[class*="large rectangle"].ad {
  width: 336px;
  height: 280px; }

.ui[class*="half page"].ad {
  width: 300px;
  height: 600px; }

.ui.square.ad {
  width: 250px;
  height: 250px; }

.ui[class*="small square"].ad {
  width: 200px;
  height: 200px; }

.ui[class*="small rectangle"].ad {
  width: 180px;
  height: 150px; }

.ui[class*="vertical rectangle"].ad {
  width: 240px;
  height: 400px; }

.ui.button.ad {
  width: 120px;
  height: 90px; }

.ui[class*="square button"].ad {
  width: 125px;
  height: 125px; }

.ui[class*="small button"].ad {
  width: 120px;
  height: 60px; }

.ui.skyscraper.ad {
  width: 120px;
  height: 600px; }

.ui[class*="wide skyscraper"].ad {
  width: 160px; }

.ui.banner.ad {
  width: 468px;
  height: 60px; }

.ui[class*="vertical banner"].ad {
  width: 120px;
  height: 240px; }

.ui[class*="top banner"].ad {
  width: 930px;
  height: 180px; }

.ui[class*="half banner"].ad {
  width: 234px;
  height: 60px; }

.ui[class*="large leaderboard"].ad {
  width: 970px;
  height: 90px; }

.ui.billboard.ad {
  width: 970px;
  height: 250px; }

.ui.panorama.ad {
  width: 980px;
  height: 120px; }

.ui.netboard.ad {
  width: 580px;
  height: 400px; }

.ui[class*="large mobile banner"].ad {
  width: 320px;
  height: 100px; }

.ui[class*="mobile leaderboard"].ad {
  width: 320px;
  height: 50px; }

.ui.mobile.ad {
  display: none; }

.ui.centered.ad {
  margin-left: auto;
  margin-right: auto; }

.ui.test.ad {
  position: relative;
  background: #545454; }
  .ui.test.ad:after {
    position: absolute;
    top: 50%;
    left: 50%;
    width: 100%;
    text-align: center;
    -webkit-transform: translateX(-50%) translateY(-50%);
    transform: translateX(-50%) translateY(-50%);
    content: 'Ad';
    color: #FFFFFF;
    font-size: 1em;
    font-weight: bold; }

.ui.mobile.test.ad:after {
  font-size: 0.85714286em; }

.ui.test.ad[data-text]:after {
  content: attr(data-text); }

/* Mobile Sizes */
@media only screen and (max-width: 767px) {
  .ui.mobile.ad {
    display: block; } }

/*!
 * # Semantic UI 2.2.12 - Item
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Standard
*******************************/
/*--------------
      Card
---------------*/
.ui.cards > .card {
  max-width: 100%;
  position: relative;
  display: flex;
  flex-direction: column;
  width: 290px;
  min-height: 0px;
  background: #FFFFFF;
  padding: 0;
  border: none;
  border-radius: 0.28571429rem;
  box-shadow: 0 1px 3px 0 #D4D4D5, 0 0 0 1px #D4D4D5;
  transition: box-shadow 0.1s ease, transform 0.1s ease;
  z-index: ''; }

.ui.card {
  max-width: 100%;
  position: relative;
  display: flex;
  flex-direction: column;
  width: 290px;
  min-height: 0px;
  background: #FFFFFF;
  padding: 0;
  border: none;
  border-radius: 0.28571429rem;
  box-shadow: 0 1px 3px 0 #D4D4D5, 0 0 0 1px #D4D4D5;
  transition: box-shadow 0.1s ease, transform 0.1s ease;
  z-index: '';
  margin: 1em 0; }

.ui.cards > .card a {
  cursor: pointer; }

.ui.card a {
  cursor: pointer; }

.ui.card:first-child {
  margin-top: 0; }

.ui.card:last-child {
  margin-bottom: 0; }

.ui.cards {
  display: flex;
  margin: -0.875em -0.5em;
  flex-wrap: wrap; }
  .ui.cards > .card {
    display: flex;
    margin: 0.875em 0.5em;
    float: none; }
  .ui.cards:after {
    display: block;
    content: ' ';
    height: 0px;
    clear: both;
    overflow: hidden;
    visibility: hidden; }

.ui.card:after {
  display: block;
  content: ' ';
  height: 0px;
  clear: both;
  overflow: hidden;
  visibility: hidden; }

.ui.cards ~ .ui.cards {
  margin-top: 0.875em; }

.ui.cards > .card > :first-child {
  border-radius: 0.28571429rem 0.28571429rem 0 0em !important;
  border-top: none !important; }

.ui.card > :first-child {
  border-radius: 0.28571429rem 0.28571429rem 0 0em !important;
  border-top: none !important; }

.ui.cards > .card > :last-child, .ui.card > :last-child {
  border-radius: 0 0em 0.28571429rem 0.28571429rem !important; }

.ui.cards > .card > :only-child, .ui.card > :only-child {
  border-radius: 0.28571429rem !important; }

.ui.cards > .card > .image, .ui.card > .image {
  position: relative;
  display: block;
  flex: 0 0 auto;
  padding: 0;
  background: rgba(0, 0, 0, 0.05); }

.ui.cards > .card > .image > img, .ui.card > .image > img {
  display: block;
  width: 100%;
  height: auto;
  border-radius: inherit; }

.ui.cards > .card > .image:not(.ui) > img, .ui.card > .image:not(.ui) > img {
  border: none; }

.ui.cards > .card > .content, .ui.card > .content {
  flex-grow: 1;
  border: none;
  border-top: 1px solid rgba(34, 36, 38, 0.1);
  background: none;
  margin: 0;
  padding: 1em 1em;
  box-shadow: none;
  font-size: 1em;
  border-radius: 0; }

.ui.cards > .card > .content:after, .ui.card > .content:after {
  display: block;
  content: ' ';
  height: 0px;
  clear: both;
  overflow: hidden;
  visibility: hidden; }

.ui.cards > .card > .content > .header, .ui.card > .content > .header {
  display: block;
  margin: '';
  font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
  color: rgba(0, 0, 0, 0.85); }

.ui.cards > .card > .content > .header:not(.ui), .ui.card > .content > .header:not(.ui) {
  font-weight: bold;
  font-size: 1.28571429em;
  margin-top: -0.21425em;
  line-height: 1.28571429em; }

.ui.cards > .card > .content > .meta + .description, .ui.cards > .card > .content > .header + .description {
  margin-top: 0.5em; }

.ui.card > .content > .meta + .description, .ui.card > .content > .header + .description {
  margin-top: 0.5em; }

.ui.cards > .card [class*="left floated"], .ui.card [class*="left floated"] {
  float: left; }

.ui.cards > .card [class*="right floated"], .ui.card [class*="right floated"] {
  float: right; }

.ui.cards > .card [class*="left aligned"], .ui.card [class*="left aligned"] {
  text-align: left; }

.ui.cards > .card [class*="center aligned"], .ui.card [class*="center aligned"] {
  text-align: center; }

.ui.cards > .card [class*="right aligned"], .ui.card [class*="right aligned"] {
  text-align: right; }

.ui.cards > .card .content img, .ui.card .content img {
  display: inline-block;
  vertical-align: middle;
  width: ''; }

.ui.cards > .card img.avatar, .ui.cards > .card .avatar img {
  width: 2em;
  height: 2em;
  border-radius: 500rem; }

.ui.card img.avatar, .ui.card .avatar img {
  width: 2em;
  height: 2em;
  border-radius: 500rem; }

.ui.cards > .card > .content > .description, .ui.card > .content > .description {
  clear: both;
  color: rgba(0, 0, 0, 0.68); }

.ui.cards > .card > .content p, .ui.card > .content p {
  margin: 0 0em 0.5em; }

.ui.cards > .card > .content p:last-child, .ui.card > .content p:last-child {
  margin-bottom: 0; }

.ui.cards > .card .meta, .ui.card .meta {
  font-size: 1em;
  color: rgba(0, 0, 0, 0.4); }

.ui.cards > .card .meta *, .ui.card .meta * {
  margin-right: 0.3em; }

.ui.cards > .card .meta :last-child, .ui.card .meta :last-child {
  margin-right: 0; }

.ui.cards > .card .meta [class*="right floated"], .ui.card .meta [class*="right floated"] {
  margin-right: 0;
  margin-left: 0.3em; }

.ui.cards > .card > .content a:not(.ui), .ui.card > .content a:not(.ui) {
  color: '';
  transition: color 0.1s ease; }

.ui.cards > .card > .content a:not(.ui):hover, .ui.card > .content a:not(.ui):hover {
  color: ''; }

.ui.cards > .card > .content > a.header, .ui.card > .content > a.header {
  color: rgba(0, 0, 0, 0.85); }

.ui.cards > .card > .content > a.header:hover, .ui.card > .content > a.header:hover {
  color: #4679b7; }

.ui.cards > .card .meta > a:not(.ui), .ui.card .meta > a:not(.ui) {
  color: rgba(0, 0, 0, 0.4); }

.ui.cards > .card .meta > a:not(.ui):hover, .ui.card .meta > a:not(.ui):hover {
  color: rgba(0, 0, 0, 0.87); }

.ui.cards > .card > .buttons, .ui.card > .buttons, .ui.cards > .card > .button, .ui.card > .button {
  margin: 0 -1px;
  width: calc(100% +  2px); }

.ui.cards > .card .dimmer, .ui.card .dimmer {
  background-color: '';
  z-index: 10; }

.ui.cards > .card > .content .star.icon, .ui.card > .content .star.icon {
  cursor: pointer;
  opacity: 0.75;
  transition: color 0.1s ease; }

.ui.cards > .card > .content .star.icon:hover, .ui.card > .content .star.icon:hover {
  opacity: 1;
  color: #FFB70A; }

.ui.cards > .card > .content .active.star.icon, .ui.card > .content .active.star.icon {
  color: #FFE623; }

.ui.cards > .card > .content .like.icon, .ui.card > .content .like.icon {
  cursor: pointer;
  opacity: 0.75;
  transition: color 0.1s ease; }

.ui.cards > .card > .content .like.icon:hover, .ui.card > .content .like.icon:hover {
  opacity: 1;
  color: #FF2733; }

.ui.cards > .card > .content .active.like.icon, .ui.card > .content .active.like.icon {
  color: #FF2733; }

.ui.cards > .card > .extra, .ui.card > .extra {
  max-width: 100%;
  min-height: 0 !important;
  flex-grow: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.05) !important;
  position: static;
  background: none;
  width: auto;
  margin: 0 0;
  padding: 0.75em 1em;
  top: 0;
  left: 0;
  color: rgba(0, 0, 0, 0.4);
  box-shadow: none;
  transition: color 0.1s ease; }

.ui.cards > .card > .extra a:not(.ui), .ui.card > .extra a:not(.ui) {
  color: rgba(0, 0, 0, 0.4); }

.ui.cards > .card > .extra a:not(.ui):hover, .ui.card > .extra a:not(.ui):hover {
  color: #4679b7; }

.ui.raised.cards > .card, .ui.raised.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 4px 0 rgba(34, 36, 38, 0.12), 0 2px 10px 0 rgba(34, 36, 38, 0.15); }

.ui.raised.cards a.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 4px 0 rgba(34, 36, 38, 0.15), 0 2px 10px 0 rgba(34, 36, 38, 0.25); }

.ui.link.cards .raised.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 4px 0 rgba(34, 36, 38, 0.15), 0 2px 10px 0 rgba(34, 36, 38, 0.25); }

a.ui.raised.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 4px 0 rgba(34, 36, 38, 0.15), 0 2px 10px 0 rgba(34, 36, 38, 0.25); }

.ui.link.raised.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 4px 0 rgba(34, 36, 38, 0.15), 0 2px 10px 0 rgba(34, 36, 38, 0.25); }

.ui.raised.cards > .card, .ui.raised.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 4px 0 rgba(34, 36, 38, 0.12), 0 2px 10px 0 rgba(34, 36, 38, 0.15); }

.ui.centered.cards {
  justify-content: center; }

.ui.centered.card {
  margin-left: auto;
  margin-right: auto; }

.ui.fluid.card {
  width: 100%;
  max-width: 9999px; }

.ui.cards a.card, .ui.link.cards .card {
  transform: none; }

a.ui.card {
  transform: none; }

.ui.link.card {
  transform: none; }

.ui.cards a.card:hover, .ui.link.cards .card:hover {
  cursor: pointer;
  z-index: 5;
  background: #FFFFFF;
  border: none;
  box-shadow: 0 1px 3px 0 #BCBDBD, 0 0 0 1px #D4D4D5;
  transform: translateY(-3px); }

a.ui.card:hover {
  cursor: pointer;
  z-index: 5;
  background: #FFFFFF;
  border: none;
  box-shadow: 0 1px 3px 0 #BCBDBD, 0 0 0 1px #D4D4D5;
  transform: translateY(-3px); }

.ui.link.card:hover {
  cursor: pointer;
  z-index: 5;
  background: #FFFFFF;
  border: none;
  box-shadow: 0 1px 3px 0 #BCBDBD, 0 0 0 1px #D4D4D5;
  transform: translateY(-3px); }

.ui.red.cards > .card, .ui.cards > .red.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #DB2828, 0 1px 3px 0 #D4D4D5; }

.ui.red.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #DB2828, 0 1px 3px 0 #D4D4D5; }

.ui.red.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #d01919, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .red.card:hover, .ui.red.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #d01919, 0 1px 3px 0 #BCBDBD; }

.ui.orange.cards > .card, .ui.cards > .orange.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #fc7831, 0 1px 3px 0 #D4D4D5; }

.ui.orange.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #fc7831, 0 1px 3px 0 #D4D4D5; }

.ui.orange.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #f26202, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .orange.card:hover, .ui.orange.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #f26202, 0 1px 3px 0 #BCBDBD; }

.ui.yellow.cards > .card, .ui.cards > .yellow.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #FBBD08, 0 1px 3px 0 #D4D4D5; }

.ui.yellow.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #FBBD08, 0 1px 3px 0 #D4D4D5; }

.ui.yellow.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #eaae00, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .yellow.card:hover, .ui.yellow.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #eaae00, 0 1px 3px 0 #BCBDBD; }

.ui.olive.cards > .card, .ui.cards > .olive.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #B5CC18, 0 1px 3px 0 #D4D4D5; }

.ui.olive.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #B5CC18, 0 1px 3px 0 #D4D4D5; }

.ui.olive.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #a7bd0d, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .olive.card:hover, .ui.olive.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #a7bd0d, 0 1px 3px 0 #BCBDBD; }

.ui.green.cards > .card, .ui.cards > .green.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #21BA45, 0 1px 3px 0 #D4D4D5; }

.ui.green.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #21BA45, 0 1px 3px 0 #D4D4D5; }

.ui.green.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #16ab39, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .green.card:hover, .ui.green.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #16ab39, 0 1px 3px 0 #BCBDBD; }

.ui.teal.cards > .card, .ui.cards > .teal.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #00B5AD, 0 1px 3px 0 #D4D4D5; }

.ui.teal.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #00B5AD, 0 1px 3px 0 #D4D4D5; }

.ui.teal.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #009c95, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .teal.card:hover, .ui.teal.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #009c95, 0 1px 3px 0 #BCBDBD; }

.ui.blue.cards > .card, .ui.cards > .blue.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #4c8bd6, 0 1px 3px 0 #D4D4D5; }

.ui.blue.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #4c8bd6, 0 1px 3px 0 #D4D4D5; }

.ui.blue.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #1678c2, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .blue.card:hover, .ui.blue.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #1678c2, 0 1px 3px 0 #BCBDBD; }

.ui.violet.cards > .card, .ui.cards > .violet.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #6435C9, 0 1px 3px 0 #D4D4D5; }

.ui.violet.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #6435C9, 0 1px 3px 0 #D4D4D5; }

.ui.violet.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #5829bb, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .violet.card:hover, .ui.violet.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #5829bb, 0 1px 3px 0 #BCBDBD; }

.ui.purple.cards > .card, .ui.cards > .purple.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #A333C8, 0 1px 3px 0 #D4D4D5; }

.ui.purple.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #A333C8, 0 1px 3px 0 #D4D4D5; }

.ui.purple.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #9627ba, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .purple.card:hover, .ui.purple.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #9627ba, 0 1px 3px 0 #BCBDBD; }

.ui.pink.cards > .card, .ui.cards > .pink.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #E03997, 0 1px 3px 0 #D4D4D5; }

.ui.pink.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #E03997, 0 1px 3px 0 #D4D4D5; }

.ui.pink.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #e61a8d, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .pink.card:hover, .ui.pink.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #e61a8d, 0 1px 3px 0 #BCBDBD; }

.ui.brown.cards > .card, .ui.cards > .brown.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #A5673F, 0 1px 3px 0 #D4D4D5; }

.ui.brown.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #A5673F, 0 1px 3px 0 #D4D4D5; }

.ui.brown.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #975b33, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .brown.card:hover, .ui.brown.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #975b33, 0 1px 3px 0 #BCBDBD; }

.ui.grey.cards > .card, .ui.cards > .grey.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #767676, 0 1px 3px 0 #D4D4D5; }

.ui.grey.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #767676, 0 1px 3px 0 #D4D4D5; }

.ui.grey.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #838383, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .grey.card:hover, .ui.grey.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #838383, 0 1px 3px 0 #BCBDBD; }

.ui.black.cards > .card, .ui.cards > .black.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #1B1C1D, 0 1px 3px 0 #D4D4D5; }

.ui.black.card {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #1B1C1D, 0 1px 3px 0 #D4D4D5; }

.ui.black.cards > .card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #27292a, 0 1px 3px 0 #BCBDBD; }

.ui.cards > .black.card:hover, .ui.black.card:hover {
  box-shadow: 0 0 0 1px #D4D4D5, 0 2px 0 0 #27292a, 0 1px 3px 0 #BCBDBD; }

.ui.one.cards {
  margin-left: 0;
  margin-right: 0; }
  .ui.one.cards > .card {
    width: 100%; }

.ui.two.cards {
  margin-left: -1em;
  margin-right: -1em; }
  .ui.two.cards > .card {
    width: calc( 50%  -  2em);
    margin-left: 1em;
    margin-right: 1em; }

.ui.three.cards {
  margin-left: -1em;
  margin-right: -1em; }
  .ui.three.cards > .card {
    width: calc( 33.33333333%  -  2em);
    margin-left: 1em;
    margin-right: 1em; }

.ui.four.cards {
  margin-left: -0.75em;
  margin-right: -0.75em; }
  .ui.four.cards > .card {
    width: calc( 25%  -  1.5em);
    margin-left: 0.75em;
    margin-right: 0.75em; }

.ui.five.cards {
  margin-left: -0.75em;
  margin-right: -0.75em; }
  .ui.five.cards > .card {
    width: calc( 20%  -  1.5em);
    margin-left: 0.75em;
    margin-right: 0.75em; }

.ui.six.cards {
  margin-left: -0.75em;
  margin-right: -0.75em; }
  .ui.six.cards > .card {
    width: calc( 16.66666667%  -  1.5em);
    margin-left: 0.75em;
    margin-right: 0.75em; }

.ui.seven.cards {
  margin-left: -0.5em;
  margin-right: -0.5em; }
  .ui.seven.cards > .card {
    width: calc( 14.28571429%  -  1em);
    margin-left: 0.5em;
    margin-right: 0.5em; }

.ui.eight.cards {
  margin-left: -0.5em;
  margin-right: -0.5em; }
  .ui.eight.cards > .card {
    width: calc( 12.5%  -  1em);
    margin-left: 0.5em;
    margin-right: 0.5em;
    font-size: 11px; }

.ui.nine.cards {
  margin-left: -0.5em;
  margin-right: -0.5em; }
  .ui.nine.cards > .card {
    width: calc( 11.11111111%  -  1em);
    margin-left: 0.5em;
    margin-right: 0.5em;
    font-size: 10px; }

.ui.ten.cards {
  margin-left: -0.5em;
  margin-right: -0.5em; }
  .ui.ten.cards > .card {
    width: calc( 10%  -  1em);
    margin-left: 0.5em;
    margin-right: 0.5em; }

.ui.cards > .card {
  font-size: 1em; }

/* Mobile Only */
@media only screen and (max-width: 767px) {
  .ui.two.doubling.cards {
    margin-left: 0;
    margin-right: 0; }
    .ui.two.doubling.cards > .card {
      width: 100%;
      margin-left: 0;
      margin-right: 0; }
  .ui.three.doubling.cards, .ui.four.doubling.cards, .ui.five.doubling.cards, .ui.six.doubling.cards {
    margin-left: -1em;
    margin-right: -1em; }
    .ui.three.doubling.cards > .card, .ui.four.doubling.cards > .card, .ui.five.doubling.cards > .card, .ui.six.doubling.cards > .card {
      width: calc( 50%  -  2em);
      margin-left: 1em;
      margin-right: 1em; }
  .ui.seven.doubling.cards, .ui.eight.doubling.cards, .ui.nine.doubling.cards, .ui.ten.doubling.cards {
    margin-left: -1em;
    margin-right: -1em; }
    .ui.seven.doubling.cards > .card, .ui.eight.doubling.cards > .card, .ui.nine.doubling.cards > .card, .ui.ten.doubling.cards > .card {
      width: calc( 33.33333333%  -  2em);
      margin-left: 1em;
      margin-right: 1em; } }

/* Tablet Only */
@media only screen and (min-width: 768px) and (max-width: 991px) {
  .ui.two.doubling.cards {
    margin-left: 0;
    margin-right: 0; }
    .ui.two.doubling.cards > .card {
      width: 100%;
      margin-left: 0;
      margin-right: 0; }
  .ui.three.doubling.cards, .ui.four.doubling.cards {
    margin-left: -1em;
    margin-right: -1em; }
    .ui.three.doubling.cards > .card, .ui.four.doubling.cards > .card {
      width: calc( 50%  -  2em);
      margin-left: 1em;
      margin-right: 1em; }
  .ui.five.doubling.cards, .ui.six.doubling.cards {
    margin-left: -1em;
    margin-right: -1em; }
    .ui.five.doubling.cards > .card, .ui.six.doubling.cards > .card {
      width: calc( 33.33333333%  -  2em);
      margin-left: 1em;
      margin-right: 1em; }
  .ui.eight.doubling.cards {
    margin-left: -1em;
    margin-right: -1em; }
    .ui.eight.doubling.cards > .card {
      width: calc( 33.33333333%  -  2em);
      margin-left: 1em;
      margin-right: 1em; }
  .ui.nine.doubling.cards {
    margin-left: -0.75em;
    margin-right: -0.75em; }
    .ui.nine.doubling.cards > .card {
      width: calc( 25%  -  1.5em);
      margin-left: 0.75em;
      margin-right: 0.75em; }
  .ui.ten.doubling.cards {
    margin-left: -0.75em;
    margin-right: -0.75em; }
    .ui.ten.doubling.cards > .card {
      width: calc( 20%  -  1.5em);
      margin-left: 0.75em;
      margin-right: 0.75em; } }

/*-------------------
      Stackable
--------------------*/
@media only screen and (max-width: 767px) {
  .ui.stackable.cards {
    display: block !important; }
    .ui.stackable.cards .card:first-child {
      margin-top: 0 !important; }
    .ui.stackable.cards > .card {
      display: block !important;
      height: auto !important;
      margin: 1em 1em;
      padding: 0 !important;
      width: calc( 100%  -  2em) !important; } }

/*!
 * # Semantic UI 2.2.12 - Comment
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Standard
*******************************/
/*--------------
    Comments
---------------*/
.ui.comments {
  margin: 1.5em 0;
  max-width: 650px; }
  .ui.comments:first-child {
    margin-top: 0em; }
  .ui.comments:last-child {
    margin-bottom: 0em; }
  .ui.comments .comment {
    position: relative;
    background: none;
    margin: 0.5em 0em 0em;
    padding: 0.5em 0em 0em;
    border: none;
    line-height: 1.2; }
    .ui.comments .comment:first-child {
      margin-top: 0em;
      padding-top: 0em; }
    .ui.comments .comment .comments {
      margin: 0em 0em 0.5em 0.5em;
      padding: 1em 0em 1em 1em; }
      .ui.comments .comment .comments:before {
        position: absolute;
        top: 0px;
        left: 0px; }
      .ui.comments .comment .comments .comment {
        border: none;
        background: none; }
    .ui.comments .comment .avatar {
      display: block;
      width: 2.5em;
      height: auto;
      float: left;
      margin: 0.2em 0em 0em; }
    .ui.comments .comment img.avatar, .ui.comments .comment .avatar img {
      display: block;
      margin: 0em auto;
      width: 100%;
      height: 100%;
      border-radius: 0.25rem; }
    .ui.comments .comment > .content {
      display: block; }
    .ui.comments .comment > .avatar ~ .content {
      margin-left: 3.5em; }
    .ui.comments .comment .author {
      font-size: 1em;
      color: rgba(0, 0, 0, 0.87);
      font-weight: bold; }
    .ui.comments .comment a.author {
      cursor: pointer; }
      .ui.comments .comment a.author:hover {
        color: #4679b7; }
    .ui.comments .comment .metadata {
      display: inline-block;
      margin-left: 0.5em;
      color: rgba(0, 0, 0, 0.4);
      font-size: 0.875em; }
      .ui.comments .comment .metadata > * {
        display: inline-block;
        margin: 0em 0.5em 0em 0em; }
      .ui.comments .comment .metadata > :last-child {
        margin-right: 0em; }
    .ui.comments .comment .text {
      margin: 0.25em 0em 0.5em;
      font-size: 1em;
      word-wrap: break-word;
      color: rgba(0, 0, 0, 0.87);
      line-height: 1.3; }
    .ui.comments .comment .actions {
      font-size: 0.875em; }
      .ui.comments .comment .actions a {
        cursor: pointer;
        display: inline-block;
        margin: 0em 0.75em 0em 0em;
        color: rgba(0, 0, 0, 0.4); }
        .ui.comments .comment .actions a:last-child {
          margin-right: 0em; }
        .ui.comments .comment .actions a.active, .ui.comments .comment .actions a:hover {
          color: rgba(0, 0, 0, 0.8); }
    .ui.comments .comment .reply.form {
      width: 100%;
      margin-top: 1em; }
  .ui.comments > .reply.form {
    margin-top: 1em; }
  .ui.comments .reply.form textarea {
    font-size: 1em;
    height: 12em; }

.ui.collapsed.comments {
  display: none; }

.ui.comments .collapsed.comments, .ui.comments .collapsed.comment {
  display: none; }

.ui.threaded.comments .comment .comments {
  margin: -1.5em 0 -1em 1.25em;
  padding: 3em 0em 2em 2.25em;
  box-shadow: -1px 0px 0px rgba(34, 36, 38, 0.15); }

.ui.minimal.comments .comment .actions {
  opacity: 0;
  position: absolute;
  top: 0px;
  right: 0px;
  left: auto;
  -webkit-transition: opacity 0.2s ease;
  transition: opacity 0.2s ease;
  -webkit-transition-delay: 0.1s;
  transition-delay: 0.1s; }

.ui.minimal.comments .comment > .content:hover > .actions {
  opacity: 1; }

.ui.mini.comments {
  font-size: 0.78571429rem; }

.ui.tiny.comments {
  font-size: 0.85714286rem; }

.ui.small.comments {
  font-size: 0.92857143rem; }

.ui.comments {
  font-size: 1rem; }

.ui.large.comments {
  font-size: 1.14285714rem; }

.ui.big.comments {
  font-size: 1.28571429rem; }

.ui.huge.comments {
  font-size: 1.42857143rem; }

.ui.massive.comments {
  font-size: 1.71428571rem; }

/*!
 * # Semantic UI 2.2.12 - Feed
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
         Activity Feed
*******************************/
.ui.feed {
  margin: 1em 0em; }
  .ui.feed:first-child {
    margin-top: 0em; }
  .ui.feed:last-child {
    margin-bottom: 0em; }
  .ui.feed > .event {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row;
    width: 100%;
    padding: 0.21428571rem 0em;
    margin: 0em;
    background: none;
    border-top: none; }
    .ui.feed > .event:first-child {
      border-top: 0px;
      padding-top: 0em; }
    .ui.feed > .event:last-child {
      padding-bottom: 0em; }
      .ui.feed > .event:last-child > .content {
        padding-bottom: 0em; }
    .ui.feed > .event > .label {
      display: block;
      -webkit-box-flex: 0;
      -ms-flex: 0 0 auto;
      flex: 0 0 auto;
      width: 2.5em;
      height: auto;
      -ms-flex-item-align: stretch;
      -ms-grid-row-align: stretch;
      align-self: stretch;
      text-align: left; }
      .ui.feed > .event > .label .icon {
        opacity: 1;
        font-size: 1.5em;
        width: 100%;
        padding: 0.25em;
        background: none;
        border: none;
        border-radius: none;
        color: rgba(0, 0, 0, 0.6); }
      .ui.feed > .event > .label img {
        width: 100%;
        height: auto;
        border-radius: 500rem; }
      .ui.feed > .event > .label + .content {
        margin: 0.5em 0em 0.35714286em 1.14285714em; }
    .ui.feed > .event > .content {
      display: block;
      -webkit-box-flex: 1;
      -ms-flex: 1 1 auto;
      flex: 1 1 auto;
      -ms-flex-item-align: stretch;
      -ms-grid-row-align: stretch;
      align-self: stretch;
      text-align: left;
      word-wrap: break-word; }
    .ui.feed > .event > .content a {
      cursor: pointer; }
    .ui.feed > .event > .content .date {
      margin: -0.5rem 0em 0em;
      padding: 0em;
      font-weight: normal;
      font-size: 1em;
      font-style: normal;
      color: rgba(0, 0, 0, 0.4); }
    .ui.feed > .event > .content .summary {
      margin: 0em;
      font-size: 1em;
      font-weight: bold;
      color: rgba(0, 0, 0, 0.87); }
      .ui.feed > .event > .content .summary img {
        display: inline-block;
        width: auto;
        height: 10em;
        margin: -0.25em 0.25em 0em 0em;
        border-radius: 0.25em;
        vertical-align: middle; }
    .ui.feed > .event > .content .user {
      display: inline-block;
      font-weight: bold;
      margin-right: 0em;
      vertical-align: baseline; }
      .ui.feed > .event > .content .user img {
        margin: -0.25em 0.25em 0em 0em;
        width: auto;
        height: 10em;
        vertical-align: middle; }
    .ui.feed > .event > .content .summary > .date {
      display: inline-block;
      float: none;
      font-weight: normal;
      font-size: 0.85714286em;
      font-style: normal;
      margin: 0em 0em 0em 0.5em;
      padding: 0em;
      color: rgba(0, 0, 0, 0.4); }
    .ui.feed > .event > .content .extra {
      margin: 0.5em 0em 0em;
      background: none;
      padding: 0em;
      color: rgba(0, 0, 0, 0.87); }
      .ui.feed > .event > .content .extra.images img {
        display: inline-block;
        margin: 0em 0.25em 0em 0em;
        width: 6em; }
      .ui.feed > .event > .content .extra.text {
        padding: 0em;
        border-left: none;
        font-size: 1em;
        max-width: 500px;
        line-height: 1.4285em; }
    .ui.feed > .event > .content .meta {
      display: inline-block;
      font-size: 0.85714286em;
      margin: 0.5em 0em 0em;
      background: none;
      border: none;
      border-radius: 0;
      box-shadow: none;
      padding: 0em;
      color: rgba(0, 0, 0, 0.6); }
      .ui.feed > .event > .content .meta > * {
        position: relative;
        margin-left: 0.75em; }
        .ui.feed > .event > .content .meta > *:after {
          content: '';
          color: rgba(0, 0, 0, 0.2);
          top: 0em;
          left: -1em;
          opacity: 1;
          position: absolute;
          vertical-align: top; }
      .ui.feed > .event > .content .meta .like {
        color: '';
        -webkit-transition: 0.2s color ease;
        transition: 0.2s color ease; }
        .ui.feed > .event > .content .meta .like:hover .icon {
          color: #FF2733; }
      .ui.feed > .event > .content .meta .active.like .icon {
        color: #EF404A; }
      .ui.feed > .event > .content .meta > :first-child {
        margin-left: 0em; }
        .ui.feed > .event > .content .meta > :first-child::after {
          display: none; }
      .ui.feed > .event > .content .meta a {
        cursor: pointer;
        opacity: 1;
        color: rgba(0, 0, 0, 0.5);
        -webkit-transition: color 0.1s ease;
        transition: color 0.1s ease; }
        .ui.feed > .event > .content .meta a:hover {
          color: rgba(0, 0, 0, 0.95); }
          .ui.feed > .event > .content .meta a:hover .icon {
            color: rgba(0, 0, 0, 0.95); }
      .ui.feed > .event > .content .meta > .icon {
        cursor: pointer;
        opacity: 1;
        color: rgba(0, 0, 0, 0.5);
        -webkit-transition: color 0.1s ease;
        transition: color 0.1s ease; }
      .ui.feed > .event > .content .meta > .icon:hover {
        color: rgba(0, 0, 0, 0.95); }

.ui.small.feed {
  font-size: 0.92857143rem; }

.ui.feed {
  font-size: 1rem; }

.ui.large.feed {
  font-size: 1.14285714rem; }

/*!
 * # Semantic UI 2.2.12 - Item
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Standard
*******************************/
/*--------------
      Item
---------------*/
.ui.items {
  margin: 1.5em 0em; }
  .ui.items > .item {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    margin: 1em 0em;
    width: 100%;
    min-height: 0px;
    background: transparent;
    padding: 0em;
    border: none;
    border-radius: 0rem;
    box-shadow: none;
    -webkit-transition: box-shadow 0.1s ease;
    transition: box-shadow 0.1s ease;
    z-index: ''; }
    .ui.items > .item a {
      cursor: pointer; }
  .ui.items:first-child {
    margin-top: 0em !important; }
  .ui.items:last-child {
    margin-bottom: 0em !important; }
  .ui.items > .item:after {
    display: block;
    content: ' ';
    height: 0px;
    clear: both;
    overflow: hidden;
    visibility: hidden; }
  .ui.items > .item:first-child {
    margin-top: 0em; }
  .ui.items > .item:last-child {
    margin-bottom: 0em; }
  .ui.items > .item > .image {
    position: relative;
    -webkit-box-flex: 0;
    -ms-flex: 0 0 auto;
    flex: 0 0 auto;
    display: block;
    float: none;
    margin: 0em;
    padding: 0em;
    max-height: '';
    -ms-flex-item-align: top;
    -ms-grid-row-align: top;
    align-self: top; }
    .ui.items > .item > .image > img {
      display: block;
      width: 100%;
      height: auto;
      border-radius: 0.125rem;
      border: none; }
    .ui.items > .item > .image:only-child > img {
      border-radius: 0rem; }
  .ui.items > .item > .content {
    display: block;
    -webkit-box-flex: 1;
    -ms-flex: 1 1 auto;
    flex: 1 1 auto;
    background: none;
    margin: 0em;
    padding: 0em;
    box-shadow: none;
    font-size: 1em;
    border: none;
    border-radius: 0em; }
    .ui.items > .item > .content:after {
      display: block;
      content: ' ';
      height: 0px;
      clear: both;
      overflow: hidden;
      visibility: hidden; }
  .ui.items > .item > .image + .content {
    min-width: 0;
    width: auto;
    display: block;
    margin-left: 0em;
    -ms-flex-item-align: top;
    -ms-grid-row-align: top;
    align-self: top;
    padding-left: 1.5em; }
  .ui.items > .item > .content > .header {
    display: inline-block;
    margin: -0.21425em 0em 0em;
    font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
    font-weight: bold;
    color: rgba(0, 0, 0, 0.85); }
    .ui.items > .item > .content > .header:not(.ui) {
      font-size: 1.28571429em; }
  .ui.items > .item [class*="left floated"] {
    float: left; }
  .ui.items > .item [class*="right floated"] {
    float: right; }
  .ui.items > .item .content img {
    -ms-flex-item-align: middle;
    -ms-grid-row-align: middle;
    align-self: middle;
    width: ''; }
  .ui.items > .item img.avatar, .ui.items > .item .avatar img {
    width: '';
    height: '';
    border-radius: 500rem; }
  .ui.items > .item > .content > .description {
    margin-top: 0.6em;
    max-width: auto;
    font-size: 1em;
    line-height: 1.4285em;
    color: rgba(0, 0, 0, 0.87); }
  .ui.items > .item > .content p {
    margin: 0em 0em 0.5em; }
    .ui.items > .item > .content p:last-child {
      margin-bottom: 0em; }
  .ui.items > .item .meta {
    margin: 0.5em 0em 0.5em;
    font-size: 1em;
    line-height: 1em;
    color: rgba(0, 0, 0, 0.6); }
    .ui.items > .item .meta * {
      margin-right: 0.3em; }
    .ui.items > .item .meta :last-child {
      margin-right: 0em; }
    .ui.items > .item .meta [class*="right floated"] {
      margin-right: 0em;
      margin-left: 0.3em; }
    .ui.items > .item .meta > a:not(.ui) {
      color: rgba(0, 0, 0, 0.4); }
      .ui.items > .item .meta > a:not(.ui):hover {
        color: rgba(0, 0, 0, 0.87); }
  .ui.items > .item > .content a:not(.ui) {
    color: '';
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease; }
    .ui.items > .item > .content a:not(.ui):hover {
      color: ''; }
  .ui.items > .item > .content > a.header {
    color: rgba(0, 0, 0, 0.85); }
    .ui.items > .item > .content > a.header:hover {
      color: #4679b7; }
  .ui.items > .item > .content .favorite.icon {
    cursor: pointer;
    opacity: 0.75;
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease; }
    .ui.items > .item > .content .favorite.icon:hover {
      opacity: 1;
      color: #FFB70A; }
  .ui.items > .item > .content .active.favorite.icon {
    color: #FFE623; }
  .ui.items > .item > .content .like.icon {
    cursor: pointer;
    opacity: 0.75;
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease; }
    .ui.items > .item > .content .like.icon:hover {
      opacity: 1;
      color: #FF2733; }
  .ui.items > .item > .content .active.like.icon {
    color: #FF2733; }
  .ui.items > .item .extra {
    display: block;
    position: relative;
    background: none;
    margin: 0.5rem 0em 0em;
    width: 100%;
    padding: 0em 0em 0em;
    top: 0em;
    left: 0em;
    color: rgba(0, 0, 0, 0.4);
    box-shadow: none;
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease;
    border-top: none; }
    .ui.items > .item .extra > * {
      margin: 0.25rem 0.5rem 0.25rem 0em; }
    .ui.items > .item .extra > [class*="right floated"] {
      margin: 0.25rem 0em 0.25rem 0.5rem; }
    .ui.items > .item .extra:after {
      display: block;
      content: ' ';
      height: 0px;
      clear: both;
      overflow: hidden;
      visibility: hidden; }
  .ui.items > .item > .image:not(.ui) {
    width: 175px; }
  .ui.items > .item > .image + [class*="top aligned"].content {
    -ms-flex-item-align: start;
    align-self: flex-start; }
  .ui.items > .item > .image + [class*="middle aligned"].content {
    -ms-flex-item-align: center;
    -ms-grid-row-align: center;
    align-self: center; }
  .ui.items > .item > .image + [class*="bottom aligned"].content {
    -ms-flex-item-align: end;
    align-self: flex-end; }

.ui.relaxed.items > .item {
  margin: 1.5em 0em; }

.ui[class*="very relaxed"].items > .item {
  margin: 2em 0em; }

.ui.divided.items > .item {
  border-top: 1px solid rgba(34, 36, 38, 0.15);
  margin: 0em;
  padding: 1em 0em; }
  .ui.divided.items > .item:first-child {
    border-top: none;
    margin-top: 0em !important;
    padding-top: 0em !important; }
  .ui.divided.items > .item:last-child {
    margin-bottom: 0em !important;
    padding-bottom: 0em !important; }

.ui.relaxed.divided.items > .item {
  margin: 0em;
  padding: 1.5em 0em; }

.ui[class*="very relaxed"].divided.items > .item {
  margin: 0em;
  padding: 2em 0em; }

.ui.items a.item:hover, .ui.link.items > .item:hover {
  cursor: pointer; }

.ui.items a.item:hover .content .header, .ui.link.items > .item:hover .content .header {
  color: #4679b7; }

.ui.items > .item {
  font-size: 1em; }

/*--------------
      Items
---------------*/
/*--------------
      Item
---------------*/
/*--------------
     Images
---------------*/
/*--------------
     Content
---------------*/
/* Default Header Size */
/*--------------
     Floated
---------------*/
/*--------------
  Content Image
---------------*/
/*--------------
   Description
---------------*/
/*--------------
    Paragraph
---------------*/
/*--------------
      Meta
---------------*/
/*--------------
      Links
---------------*/
/* Generic */
/* Header */
/* Meta */
/*--------------
     Labels
---------------*/
/*-----Star----- */
/* Icon */
/*-----Like----- */
/* Icon */
/*----------------
  Extra Content
-----------------*/
/*******************************
          Responsive
*******************************/
/* Default Image Width */
/* Tablet Only */
@media only screen and (min-width: 768px) and (max-width: 991px) {
  .ui.items > .item {
    margin: 1em 0em; }
    .ui.items > .item > .image:not(.ui) {
      width: 150px; }
    .ui.items > .item > .image + .content {
      display: block;
      padding: 0em 0em 0em 1em; } }

/* Mobile Only */
@media only screen and (max-width: 767px) {
  .ui.items:not(.unstackable) > .item {
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    margin: 2em 0em; }
    .ui.items:not(.unstackable) > .item > .image {
      display: block;
      margin-left: auto;
      margin-right: auto;
      max-width: 100% !important;
      width: auto !important;
      max-height: 250px !important; }
      .ui.items:not(.unstackable) > .item > .image > img {
        max-width: 100% !important;
        width: auto !important;
        max-height: 250px !important; }
      .ui.items:not(.unstackable) > .item > .image + .content {
        display: block;
        padding: 1.5em 0em 0em; } }

/*---------------
   Unstackable
----------------*/
@media only screen and (max-width: 767px) {
  .ui.unstackable.items > .item > .image {
    width: 125px !important; }
    .ui.unstackable.items > .item > .image > img {
      width: 125px !important; } }

/*!
 * # Semantic UI 2.2.12 - Statistic
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
           Statistic
*******************************/
/* Standalone */
.ui.statistic {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  margin: 1em 0em;
  max-width: auto; }
  .ui.statistic + .ui.statistic {
    margin: 0em 0em 0em 1.5em; }
  .ui.statistic:first-child {
    margin-top: 0em; }
  .ui.statistic:last-child {
    margin-bottom: 0em; }

.ui.statistics {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: start;
  -ms-flex-align: start;
  align-items: flex-start;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  margin: 1em -1.5em -2em; }
  .ui.statistics > .statistic {
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    -webkit-box-flex: 0;
    -ms-flex: 0 1 auto;
    flex: 0 1 auto;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    margin: 0em 1.5em 2em;
    max-width: auto; }
  .ui.statistics:after {
    display: block;
    content: ' ';
    height: 0px;
    clear: both;
    overflow: hidden;
    visibility: hidden; }
  .ui.statistics:first-child {
    margin-top: 0em; }
  .ui.statistics:last-child {
    margin-bottom: 0em; }
  .ui.statistics .statistic > .value {
    font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
    font-size: 4rem;
    font-weight: normal;
    line-height: 1em;
    color: #1B1C1D;
    text-transform: uppercase;
    text-align: center; }

.ui.statistic > .value {
  font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
  font-size: 4rem;
  font-weight: normal;
  line-height: 1em;
  color: #1B1C1D;
  text-transform: uppercase;
  text-align: center; }

.ui.statistics .statistic > .label, .ui.statistic > .label {
  font-family: 'Lato', 'Helvetica Neue', Arial, Helvetica, sans-serif;
  font-size: 1em;
  font-weight: bold;
  color: rgba(0, 0, 0, 0.87);
  text-transform: uppercase;
  text-align: center; }

.ui.statistics .statistic > .label ~ .value, .ui.statistic > .label ~ .value, .ui.statistics .statistic > .value ~ .label, .ui.statistic > .value ~ .label {
  margin-top: 0rem; }

.ui.statistics .statistic > .value .icon, .ui.statistic > .value .icon {
  opacity: 1;
  width: auto;
  margin: 0em; }

.ui.statistics .statistic > .text.value, .ui.statistic > .text.value {
  line-height: 1em;
  min-height: 2em;
  font-weight: bold;
  text-align: center; }

.ui.statistics .statistic > .text.value + .label, .ui.statistic > .text.value + .label {
  text-align: center; }

.ui.statistics .statistic > .value img, .ui.statistic > .value img {
  max-height: 3rem;
  vertical-align: baseline; }

.ui.ten.statistics {
  margin: 0em 0em -2em; }
  .ui.ten.statistics .statistic {
    min-width: 10%;
    margin: 0em 0em 2em; }

.ui.nine.statistics {
  margin: 0em 0em -2em; }
  .ui.nine.statistics .statistic {
    min-width: 11.11111111%;
    margin: 0em 0em 2em; }

.ui.eight.statistics {
  margin: 0em 0em -2em; }
  .ui.eight.statistics .statistic {
    min-width: 12.5%;
    margin: 0em 0em 2em; }

.ui.seven.statistics {
  margin: 0em 0em -2em; }
  .ui.seven.statistics .statistic {
    min-width: 14.28571429%;
    margin: 0em 0em 2em; }

.ui.six.statistics {
  margin: 0em 0em -2em; }
  .ui.six.statistics .statistic {
    min-width: 16.66666667%;
    margin: 0em 0em 2em; }

.ui.five.statistics {
  margin: 0em 0em -2em; }
  .ui.five.statistics .statistic {
    min-width: 20%;
    margin: 0em 0em 2em; }

.ui.four.statistics {
  margin: 0em 0em -2em; }
  .ui.four.statistics .statistic {
    min-width: 25%;
    margin: 0em 0em 2em; }

.ui.three.statistics {
  margin: 0em 0em -2em; }
  .ui.three.statistics .statistic {
    min-width: 33.33333333%;
    margin: 0em 0em 2em; }

.ui.two.statistics {
  margin: 0em 0em -2em; }
  .ui.two.statistics .statistic {
    min-width: 50%;
    margin: 0em 0em 2em; }

.ui.one.statistics {
  margin: 0em 0em -2em; }
  .ui.one.statistics .statistic {
    min-width: 100%;
    margin: 0em 0em 2em; }

.ui.horizontal.statistic {
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-box-align: center;
  -ms-flex-align: center;
  align-items: center; }

.ui.horizontal.statistics {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -ms-flex-direction: column;
  flex-direction: column;
  margin: 0em;
  max-width: none; }
  .ui.horizontal.statistics .statistic {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    max-width: none;
    margin: 1em 0em; }

.ui.horizontal.statistic > .text.value {
  min-height: 0em !important; }

.ui.horizontal.statistics > .statistic > .text.value {
  min-height: 0em !important; }

.ui.horizontal.statistics .statistic > .value .icon {
  width: 1.18em; }

.ui.horizontal.statistic > .value .icon {
  width: 1.18em; }

.ui.horizontal.statistics .statistic > .value, .ui.horizontal.statistic > .value {
  display: inline-block;
  vertical-align: middle; }

.ui.horizontal.statistics .statistic > .label, .ui.horizontal.statistic > .label {
  display: inline-block;
  vertical-align: middle;
  margin: 0em 0em 0em 0.75em; }

.ui.red.statistics .statistic > .value, .ui.statistics .red.statistic > .value, .ui.red.statistic > .value {
  color: #DB2828; }

.ui.orange.statistics .statistic > .value, .ui.statistics .orange.statistic > .value, .ui.orange.statistic > .value {
  color: #fc7831; }

.ui.yellow.statistics .statistic > .value, .ui.statistics .yellow.statistic > .value, .ui.yellow.statistic > .value {
  color: #FBBD08; }

.ui.olive.statistics .statistic > .value, .ui.statistics .olive.statistic > .value, .ui.olive.statistic > .value {
  color: #B5CC18; }

.ui.green.statistics .statistic > .value, .ui.statistics .green.statistic > .value, .ui.green.statistic > .value {
  color: #21BA45; }

.ui.teal.statistics .statistic > .value, .ui.statistics .teal.statistic > .value, .ui.teal.statistic > .value {
  color: #00B5AD; }

.ui.blue.statistics .statistic > .value, .ui.statistics .blue.statistic > .value, .ui.blue.statistic > .value {
  color: #4c8bd6; }

.ui.violet.statistics .statistic > .value, .ui.statistics .violet.statistic > .value, .ui.violet.statistic > .value {
  color: #6435C9; }

.ui.purple.statistics .statistic > .value, .ui.statistics .purple.statistic > .value, .ui.purple.statistic > .value {
  color: #A333C8; }

.ui.pink.statistics .statistic > .value, .ui.statistics .pink.statistic > .value, .ui.pink.statistic > .value {
  color: #E03997; }

.ui.brown.statistics .statistic > .value, .ui.statistics .brown.statistic > .value, .ui.brown.statistic > .value {
  color: #A5673F; }

.ui.grey.statistics .statistic > .value, .ui.statistics .grey.statistic > .value, .ui.grey.statistic > .value {
  color: #767676; }

.ui.inverted.statistics .statistic > .value, .ui.inverted.statistic .value {
  color: #FFFFFF; }

.ui.inverted.statistics .statistic > .label, .ui.inverted.statistic .label {
  color: rgba(255, 255, 255, 0.9); }

.ui.inverted.red.statistics .statistic > .value {
  color: #FF695E; }

.ui.statistics .inverted.red.statistic > .value {
  color: #FF695E; }

.ui.inverted.red.statistic > .value {
  color: #FF695E; }

.ui.inverted.orange.statistics .statistic > .value {
  color: #fc7831; }

.ui.statistics .inverted.orange.statistic > .value {
  color: #fc7831; }

.ui.inverted.orange.statistic > .value {
  color: #fc7831; }

.ui.inverted.yellow.statistics .statistic > .value {
  color: #FFE21F; }

.ui.statistics .inverted.yellow.statistic > .value {
  color: #FFE21F; }

.ui.inverted.yellow.statistic > .value {
  color: #FFE21F; }

.ui.inverted.olive.statistics .statistic > .value {
  color: #D9E778; }

.ui.statistics .inverted.olive.statistic > .value {
  color: #D9E778; }

.ui.inverted.olive.statistic > .value {
  color: #D9E778; }

.ui.inverted.green.statistics .statistic > .value {
  color: #2ECC40; }

.ui.statistics .inverted.green.statistic > .value {
  color: #2ECC40; }

.ui.inverted.green.statistic > .value {
  color: #2ECC40; }

.ui.inverted.teal.statistics .statistic > .value {
  color: #6DFFFF; }

.ui.statistics .inverted.teal.statistic > .value {
  color: #6DFFFF; }

.ui.inverted.teal.statistic > .value {
  color: #6DFFFF; }

.ui.inverted.blue.statistics .statistic > .value {
  color: #4c8bd6; }

.ui.statistics .inverted.blue.statistic > .value {
  color: #4c8bd6; }

.ui.inverted.blue.statistic > .value {
  color: #4c8bd6; }

.ui.inverted.violet.statistics .statistic > .value {
  color: #A291FB; }

.ui.statistics .inverted.violet.statistic > .value {
  color: #A291FB; }

.ui.inverted.violet.statistic > .value {
  color: #A291FB; }

.ui.inverted.purple.statistics .statistic > .value {
  color: #DC73FF; }

.ui.statistics .inverted.purple.statistic > .value {
  color: #DC73FF; }

.ui.inverted.purple.statistic > .value {
  color: #DC73FF; }

.ui.inverted.pink.statistics .statistic > .value {
  color: #FF8EDF; }

.ui.statistics .inverted.pink.statistic > .value {
  color: #FF8EDF; }

.ui.inverted.pink.statistic > .value {
  color: #FF8EDF; }

.ui.inverted.brown.statistics .statistic > .value {
  color: #D67C1C; }

.ui.statistics .inverted.brown.statistic > .value {
  color: #D67C1C; }

.ui.inverted.brown.statistic > .value {
  color: #D67C1C; }

.ui.inverted.grey.statistics .statistic > .value {
  color: #DCDDDE; }

.ui.statistics .inverted.grey.statistic > .value, .ui.inverted.grey.statistic > .value {
  color: #DCDDDE; }

.ui[class*="left floated"].statistic {
  float: left;
  margin: 0em 2em 1em 0em; }

.ui[class*="right floated"].statistic {
  float: right;
  margin: 0em 0em 1em 2em; }

.ui.floated.statistic:last-child {
  margin-bottom: 0em; }

.ui.mini.statistics .statistic > .value, .ui.mini.statistic > .value {
  font-size: 1.5rem !important; }

.ui.mini.horizontal.statistics .statistic > .value, .ui.mini.horizontal.statistic > .value {
  font-size: 1.5rem !important; }

.ui.mini.statistics .statistic > .text.value, .ui.mini.statistic > .text.value {
  font-size: 1rem !important; }

.ui.tiny.statistics .statistic > .value, .ui.tiny.statistic > .value {
  font-size: 2rem !important; }

.ui.tiny.horizontal.statistics .statistic > .value, .ui.tiny.horizontal.statistic > .value {
  font-size: 2rem !important; }

.ui.tiny.statistics .statistic > .text.value, .ui.tiny.statistic > .text.value {
  font-size: 1rem !important; }

.ui.small.statistics .statistic > .value, .ui.small.statistic > .value {
  font-size: 3rem !important; }

.ui.small.horizontal.statistics .statistic > .value, .ui.small.horizontal.statistic > .value {
  font-size: 2rem !important; }

.ui.small.statistics .statistic > .text.value, .ui.small.statistic > .text.value {
  font-size: 1rem !important; }

.ui.statistics .statistic > .value, .ui.statistic > .value {
  font-size: 4rem !important; }

.ui.horizontal.statistics .statistic > .value, .ui.horizontal.statistic > .value {
  font-size: 3rem !important; }

.ui.statistics .statistic > .text.value, .ui.statistic > .text.value {
  font-size: 2rem !important; }

.ui.large.statistics .statistic > .value, .ui.large.statistic > .value {
  font-size: 5rem !important; }

.ui.large.horizontal.statistics .statistic > .value, .ui.large.horizontal.statistic > .value {
  font-size: 4rem !important; }

.ui.large.statistics .statistic > .text.value, .ui.large.statistic > .text.value {
  font-size: 2.5rem !important; }

.ui.huge.statistics .statistic > .value, .ui.huge.statistic > .value {
  font-size: 6rem !important; }

.ui.huge.horizontal.statistics .statistic > .value, .ui.huge.horizontal.statistic > .value {
  font-size: 5rem !important; }

.ui.huge.statistics .statistic > .text.value, .ui.huge.statistic > .text.value {
  font-size: 2.5rem !important; }

/*!
 * # Semantic UI 2.2.12 - Accordion
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Accordion
*******************************/
.ui.accordion {
  max-width: 100%; }
  .ui.accordion .accordion {
    max-width: 100%;
    margin: 1em 0em 0em;
    padding: 0em; }
  .ui.accordion .title, .ui.accordion .accordion .title {
    cursor: pointer; }
  .ui.accordion .title:not(.ui) {
    padding: 0.5em 0em;
    font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
    font-size: 1em;
    color: rgba(0, 0, 0, 0.87); }
  .ui.accordion .title ~ .content {
    display: none; }
  .ui.accordion .accordion .title ~ .content {
    display: none; }
  .ui.accordion:not(.styled) .title ~ .content:not(.ui), .ui.accordion:not(.styled) .accordion .title ~ .content:not(.ui) {
    margin: '';
    padding: 0.5em 0em 1em; }
  .ui.accordion:not(.styled) .title ~ .content:not(.ui):last-child {
    padding-bottom: 0em; }
  .ui.accordion .title .dropdown.icon, .ui.accordion .accordion .title .dropdown.icon {
    display: inline-block;
    float: none;
    opacity: 1;
    width: 1.25em;
    height: 1em;
    margin: 0em 0.25rem 0em 0rem;
    padding: 0em;
    font-size: 1em;
    -webkit-transition: opacity 0.1s ease, -webkit-transform 0.1s ease;
    transition: opacity 0.1s ease, -webkit-transform 0.1s ease;
    transition: transform 0.1s ease, opacity 0.1s ease;
    transition: transform 0.1s ease, opacity 0.1s ease, -webkit-transform 0.1s ease;
    vertical-align: baseline;
    -webkit-transform: none;
    transform: none; }
  .ui.accordion.menu .item .title {
    display: block;
    padding: 0em; }
    .ui.accordion.menu .item .title > .dropdown.icon {
      float: right;
      margin: 0.21425em 0em 0em 1em;
      -webkit-transform: rotate(180deg);
      transform: rotate(180deg); }
  .ui.accordion .ui.header .dropdown.icon {
    font-size: 1em;
    margin: 0em 0.25rem 0em 0rem; }
  .ui.accordion .active.title .dropdown.icon, .ui.accordion .accordion .active.title .dropdown.icon, .ui.accordion.menu .item .active.title > .dropdown.icon {
    -webkit-transform: rotate(90deg);
    transform: rotate(90deg); }

.ui.styled.accordion {
  width: 600px;
  border-radius: 0.28571429rem;
  background: #FFFFFF;
  box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15), 0px 0px 0px 1px rgba(34, 36, 38, 0.15); }
  .ui.styled.accordion .accordion {
    border-radius: 0.28571429rem;
    background: #FFFFFF;
    box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15), 0px 0px 0px 1px rgba(34, 36, 38, 0.15); }
  .ui.styled.accordion .title {
    margin: 0em;
    padding: 0.75em 1em;
    color: rgba(0, 0, 0, 0.4);
    font-weight: bold;
    border-top: 1px solid rgba(34, 36, 38, 0.15);
    -webkit-transition: background 0.1s ease, color 0.1s ease;
    transition: background 0.1s ease, color 0.1s ease; }
  .ui.styled.accordion .accordion .title {
    margin: 0em;
    padding: 0.75em 1em;
    color: rgba(0, 0, 0, 0.4);
    font-weight: bold;
    border-top: 1px solid rgba(34, 36, 38, 0.15);
    -webkit-transition: background 0.1s ease, color 0.1s ease;
    transition: background 0.1s ease, color 0.1s ease; }
    .ui.styled.accordion .accordion .title:first-child {
      border-top: none; }
  .ui.styled.accordion > .title:first-child {
    border-top: none; }
  .ui.styled.accordion .content {
    margin: 0em;
    padding: 0.5em 1em 1.5em; }
  .ui.styled.accordion .accordion .content {
    margin: 0em;
    padding: 0.5em 1em 1.5em;
    padding: 0em;
    padding: 0.5em 1em 1.5em; }
  .ui.styled.accordion .title:hover, .ui.styled.accordion .active.title {
    background: transparent;
    color: rgba(0, 0, 0, 0.87); }
  .ui.styled.accordion .accordion .title:hover, .ui.styled.accordion .accordion .active.title, .ui.styled.accordion .accordion .title:hover, .ui.styled.accordion .accordion .active.title {
    background: transparent;
    color: rgba(0, 0, 0, 0.87); }
  .ui.styled.accordion .active.title, .ui.styled.accordion .accordion .active.title {
    background: transparent;
    color: rgba(0, 0, 0, 0.95); }

.ui.accordion .active.content, .ui.accordion .accordion .active.content {
  display: block; }

.ui.fluid.accordion {
  width: 100%; }
  .ui.fluid.accordion .accordion {
    width: 100%; }

.ui.inverted.accordion .title:not(.ui) {
  color: rgba(255, 255, 255, 0.9); }

.ui.accordion .title .dropdown.icon, .ui.accordion .accordion .title .dropdown.icon {
  font-family: Accordion;
  line-height: 1;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  font-weight: normal;
  font-style: normal;
  text-align: center; }

.ui.accordion .title .dropdown.icon:before, .ui.accordion .accordion .title .dropdown.icon:before {
  content: ""; }

@font-face {
  font-family: 'Accordion';
  src: url(data:application/x-font-ttf;charset=utf-8;base64,AAEAAAALAIAAAwAwT1MvMggjB5AAAAC8AAAAYGNtYXAPfOIKAAABHAAAAExnYXNwAAAAEAAAAWgAAAAIZ2x5Zryj6HgAAAFwAAAAyGhlYWT/0IhHAAACOAAAADZoaGVhApkB5wAAAnAAAAAkaG10eAJuABIAAAKUAAAAGGxvY2EAjABWAAACrAAAAA5tYXhwAAgAFgAAArwAAAAgbmFtZfC1n04AAALcAAABPHBvc3QAAwAAAAAEGAAAACAAAwIAAZAABQAAAUwBZgAAAEcBTAFmAAAA9QAZAIQAAAAAAAAAAAAAAAAAAAABEAAAAAAAAAAAAAAAAAAAAABAAADw2gHg/+D/4AHgACAAAAABAAAAAAAAAAAAAAAgAAAAAAACAAAAAwAAABQAAwABAAAAFAAEADgAAAAKAAgAAgACAAEAIPDa//3//wAAAAAAIPDZ//3//wAB/+MPKwADAAEAAAAAAAAAAAAAAAEAAf//AA8AAQAAAAAAAAAAAAIAADc5AQAAAAABAAAAAAAAAAAAAgAANzkBAAAAAAEAAAAAAAAAAAACAAA3OQEAAAAAAQASAEkAtwFuABMAADc0PwE2FzYXFh0BFAcGJwYvASY1EgaABQgHBQYGBQcIBYAG2wcGfwcBAQcECf8IBAcBAQd/BgYAAAAAAQAAAEkApQFuABMAADcRNDc2MzIfARYVFA8BBiMiJyY1AAUGBwgFgAYGgAUIBwYFWwEACAUGBoAFCAcFgAYGBQcAAAABAAAAAQAAqWYls18PPPUACwIAAAAAAM/9o+4AAAAAz/2j7gAAAAAAtwFuAAAACAACAAAAAAAAAAEAAAHg/+AAAAIAAAAAAAC3AAEAAAAAAAAAAAAAAAAAAAAGAAAAAAAAAAAAAAAAAQAAAAC3ABIAtwAAAAAAAAAKABQAHgBCAGQAAAABAAAABgAUAAEAAAAAAAIAAAAAAAAAAAAAAAAAAAAAAAAADgCuAAEAAAAAAAEADAAAAAEAAAAAAAIADgBAAAEAAAAAAAMADAAiAAEAAAAAAAQADABOAAEAAAAAAAUAFgAMAAEAAAAAAAYABgAuAAEAAAAAAAoANABaAAMAAQQJAAEADAAAAAMAAQQJAAIADgBAAAMAAQQJAAMADAAiAAMAAQQJAAQADABOAAMAAQQJAAUAFgAMAAMAAQQJAAYADAA0AAMAAQQJAAoANABaAHIAYQB0AGkAbgBnAFYAZQByAHMAaQBvAG4AIAAxAC4AMAByAGEAdABpAG4AZ3JhdGluZwByAGEAdABpAG4AZwBSAGUAZwB1AGwAYQByAHIAYQB0AGkAbgBnAEYAbwBuAHQAIABnAGUAbgBlAHIAYQB0AGUAZAAgAGIAeQAgAEkAYwBvAE0AbwBvAG4ALgADAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA) format("truetype"), url(data:application/font-woff;charset=utf-8;base64,d09GRk9UVE8AAASwAAoAAAAABGgAAQAAAAAAAAAAAAAAAAAAAAAAAAAAAABDRkYgAAAA9AAAAS0AAAEtFpovuE9TLzIAAAIkAAAAYAAAAGAIIweQY21hcAAAAoQAAABMAAAATA984gpnYXNwAAAC0AAAAAgAAAAIAAAAEGhlYWQAAALYAAAANgAAADb/0IhHaGhlYQAAAxAAAAAkAAAAJAKZAedobXR4AAADNAAAABgAAAAYAm4AEm1heHAAAANMAAAABgAAAAYABlAAbmFtZQAAA1QAAAE8AAABPPC1n05wb3N0AAAEkAAAACAAAAAgAAMAAAEABAQAAQEBB3JhdGluZwABAgABADr4HAL4GwP4GAQeCgAZU/+Lix4KABlT/4uLDAeLa/iU+HQFHQAAAHkPHQAAAH4RHQAAAAkdAAABJBIABwEBBw0PERQZHnJhdGluZ3JhdGluZ3UwdTF1MjB1RjBEOXVGMERBAAACAYkABAAGAQEEBwoNVp38lA78lA78lA77lA773Z33bxWLkI2Qj44I9xT3FAWOj5CNkIuQi4+JjoePiI2Gi4YIi/uUBYuGiYeHiIiHh4mGi4aLho2Ijwj7FPcUBYeOiY+LkAgO+92L5hWL95QFi5CNkI6Oj4+PjZCLkIuQiY6HCPcU+xQFj4iNhouGi4aJh4eICPsU+xQFiIeGiYaLhouHjYePiI6Jj4uQCA74lBT4lBWLDAoAAAAAAwIAAZAABQAAAUwBZgAAAEcBTAFmAAAA9QAZAIQAAAAAAAAAAAAAAAAAAAABEAAAAAAAAAAAAAAAAAAAAABAAADw2gHg/+D/4AHgACAAAAABAAAAAAAAAAAAAAAgAAAAAAACAAAAAwAAABQAAwABAAAAFAAEADgAAAAKAAgAAgACAAEAIPDa//3//wAAAAAAIPDZ//3//wAB/+MPKwADAAEAAAAAAAAAAAAAAAEAAf//AA8AAQAAAAEAADfYOJZfDzz1AAsCAAAAAADP/aPuAAAAAM/9o+4AAAAAALcBbgAAAAgAAgAAAAAAAAABAAAB4P/gAAACAAAAAAAAtwABAAAAAAAAAAAAAAAAAAAABgAAAAAAAAAAAAAAAAEAAAAAtwASALcAAAAAUAAABgAAAAAADgCuAAEAAAAAAAEADAAAAAEAAAAAAAIADgBAAAEAAAAAAAMADAAiAAEAAAAAAAQADABOAAEAAAAAAAUAFgAMAAEAAAAAAAYABgAuAAEAAAAAAAoANABaAAMAAQQJAAEADAAAAAMAAQQJAAIADgBAAAMAAQQJAAMADAAiAAMAAQQJAAQADABOAAMAAQQJAAUAFgAMAAMAAQQJAAYADAA0AAMAAQQJAAoANABaAHIAYQB0AGkAbgBnAFYAZQByAHMAaQBvAG4AIAAxAC4AMAByAGEAdABpAG4AZ3JhdGluZwByAGEAdABpAG4AZwBSAGUAZwB1AGwAYQByAHIAYQB0AGkAbgBnAEYAbwBuAHQAIABnAGUAbgBlAHIAYQB0AGUAZAAgAGIAeQAgAEkAYwBvAE0AbwBvAG4ALgADAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA) format("woff");
  font-weight: normal;
  font-style: normal; }

/*!
 * # Semantic UI 2.2.12 - Checkbox
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
           Checkbox
*******************************/
.ui.checkbox {
  position: relative;
  display: inline-block;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  outline: none;
  vertical-align: baseline;
  font-style: normal;
  min-height: 17px;
  font-size: 1rem;
  line-height: 17px;
  min-width: 17px; }
  .ui.checkbox input[type="checkbox"], .ui.checkbox input[type="radio"] {
    cursor: pointer;
    position: absolute;
    top: 0px;
    left: 0px;
    opacity: 0 !important;
    outline: none;
    z-index: 3;
    width: 17px;
    height: 17px; }
  .ui.checkbox .box, .ui.checkbox label {
    cursor: auto;
    position: relative;
    display: block;
    padding-left: 1.85714em;
    outline: none;
    font-size: 1em; }
  .ui.checkbox .box:before, .ui.checkbox label:before {
    position: absolute;
    top: 0px;
    left: 0px;
    width: 17px;
    height: 17px;
    content: '';
    background: #FFFFFF;
    border-radius: 0.21428571rem;
    -webkit-transition: border 0.1s ease, opacity 0.1s ease, box-shadow 0.1s ease, -webkit-transform 0.1s ease;
    transition: border 0.1s ease, opacity 0.1s ease, box-shadow 0.1s ease, -webkit-transform 0.1s ease;
    transition: border 0.1s ease, opacity 0.1s ease, transform 0.1s ease, box-shadow 0.1s ease;
    transition: border 0.1s ease, opacity 0.1s ease, transform 0.1s ease, box-shadow 0.1s ease, -webkit-transform 0.1s ease;
    border: 1px solid #D4D4D5; }
  .ui.checkbox .box:after {
    position: absolute;
    font-size: 14px;
    top: 0px;
    left: 0px;
    width: 17px;
    height: 17px;
    text-align: center;
    opacity: 0;
    color: rgba(0, 0, 0, 0.87);
    -webkit-transition: border 0.1s ease, opacity 0.1s ease, box-shadow 0.1s ease, -webkit-transform 0.1s ease;
    transition: border 0.1s ease, opacity 0.1s ease, box-shadow 0.1s ease, -webkit-transform 0.1s ease;
    transition: border 0.1s ease, opacity 0.1s ease, transform 0.1s ease, box-shadow 0.1s ease;
    transition: border 0.1s ease, opacity 0.1s ease, transform 0.1s ease, box-shadow 0.1s ease, -webkit-transform 0.1s ease; }
  .ui.checkbox label {
    color: rgba(0, 0, 0, 0.87);
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease; }
    .ui.checkbox label:after {
      position: absolute;
      font-size: 14px;
      top: 0px;
      left: 0px;
      width: 17px;
      height: 17px;
      text-align: center;
      opacity: 0;
      color: rgba(0, 0, 0, 0.87);
      -webkit-transition: border 0.1s ease, opacity 0.1s ease, box-shadow 0.1s ease, -webkit-transform 0.1s ease;
      transition: border 0.1s ease, opacity 0.1s ease, box-shadow 0.1s ease, -webkit-transform 0.1s ease;
      transition: border 0.1s ease, opacity 0.1s ease, transform 0.1s ease, box-shadow 0.1s ease;
      transition: border 0.1s ease, opacity 0.1s ease, transform 0.1s ease, box-shadow 0.1s ease, -webkit-transform 0.1s ease; }
  .ui.checkbox + label {
    color: rgba(0, 0, 0, 0.87);
    -webkit-transition: color 0.1s ease;
    transition: color 0.1s ease;
    vertical-align: middle; }
  .ui.checkbox .box:hover::before {
    background: #FFFFFF;
    border-color: rgba(34, 36, 38, 0.35); }
  .ui.checkbox label:hover {
    color: rgba(0, 0, 0, 0.8); }
    .ui.checkbox label:hover::before {
      background: #FFFFFF;
      border-color: rgba(34, 36, 38, 0.35); }
  .ui.checkbox + label:hover {
    color: rgba(0, 0, 0, 0.8); }
  .ui.checkbox .box:active::before, .ui.checkbox label:active::before {
    background: #F9FAFB;
    border-color: rgba(34, 36, 38, 0.35); }
  .ui.checkbox .box:active::after, .ui.checkbox label:active::after {
    color: rgba(0, 0, 0, 0.95); }
  .ui.checkbox input:active ~ label {
    color: rgba(0, 0, 0, 0.95); }
  .ui.checkbox input:focus ~ .box:before, .ui.checkbox input:focus ~ label:before {
    background: #FFFFFF;
    border-color: #96C8DA; }
  .ui.checkbox input:focus ~ .box:after {
    color: rgba(0, 0, 0, 0.95); }
  .ui.checkbox input:focus ~ label {
    color: rgba(0, 0, 0, 0.95); }
    .ui.checkbox input:focus ~ label:after {
      color: rgba(0, 0, 0, 0.95); }
  .ui.checkbox input:checked ~ .box:before, .ui.checkbox input:checked ~ label:before {
    background: #FFFFFF;
    border-color: rgba(34, 36, 38, 0.35); }
  .ui.checkbox input:checked ~ .box:after, .ui.checkbox input:checked ~ label:after {
    opacity: 1;
    color: rgba(0, 0, 0, 0.95); }
  .ui.checkbox input:not([type=radio]):indeterminate ~ .box:before, .ui.checkbox input:not([type=radio]):indeterminate ~ label:before {
    background: #FFFFFF;
    border-color: rgba(34, 36, 38, 0.35); }
  .ui.checkbox input:not([type=radio]):indeterminate ~ .box:after, .ui.checkbox input:not([type=radio]):indeterminate ~ label:after {
    opacity: 1;
    color: rgba(0, 0, 0, 0.95); }
  .ui.checkbox input:not([type=radio]):indeterminate:focus ~ .box:before, .ui.checkbox input:not([type=radio]):indeterminate:focus ~ label:before {
    background: #FFFFFF;
    border-color: #96C8DA; }
  .ui.checkbox input:checked:focus ~ .box:before, .ui.checkbox input:checked:focus ~ label:before {
    background: #FFFFFF;
    border-color: #96C8DA; }
  .ui.checkbox input:not([type=radio]):indeterminate:focus ~ .box:after, .ui.checkbox input:not([type=radio]):indeterminate:focus ~ label:after {
    color: rgba(0, 0, 0, 0.95); }
  .ui.checkbox input:checked:focus ~ .box:after, .ui.checkbox input:checked:focus ~ label:after {
    color: rgba(0, 0, 0, 0.95); }

.ui.read-only.checkbox {
  cursor: default; }
  .ui.read-only.checkbox label {
    cursor: default; }

.ui.disabled.checkbox .box:after, .ui.disabled.checkbox label {
  cursor: default !important;
  opacity: 0.5;
  color: #000000; }

.ui.checkbox input[disabled] ~ .box:after, .ui.checkbox input[disabled] ~ label {
  cursor: default !important;
  opacity: 0.5;
  color: #000000; }

.ui.checkbox input.hidden {
  z-index: -1; }
  .ui.checkbox input.hidden + label {
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none; }

.ui.radio.checkbox {
  min-height: 15px; }
  .ui.radio.checkbox .box, .ui.radio.checkbox label {
    padding-left: 1.85714em; }
  .ui.radio.checkbox .box:before, .ui.radio.checkbox label:before {
    content: '';
    -webkit-transform: none;
    transform: none;
    width: 15px;
    height: 15px;
    border-radius: 500rem;
    top: 1px;
    left: 0px; }
  .ui.radio.checkbox .box:after, .ui.radio.checkbox label:after {
    border: none;
    content: '' !important;
    width: 15px;
    height: 15px;
    line-height: 15px; }
  .ui.radio.checkbox .box:after, .ui.radio.checkbox label:after {
    top: 1px;
    left: 0px;
    width: 15px;
    height: 15px;
    border-radius: 500rem;
    -webkit-transform: scale(0.46667);
    transform: scale(0.46667);
    background-color: rgba(0, 0, 0, 0.87); }
  .ui.radio.checkbox input:focus ~ .box:before, .ui.radio.checkbox input:focus ~ label:before {
    background-color: #FFFFFF; }
  .ui.radio.checkbox input:focus ~ .box:after, .ui.radio.checkbox input:focus ~ label:after {
    background-color: rgba(0, 0, 0, 0.95); }
  .ui.radio.checkbox input:indeterminate ~ .box:after, .ui.radio.checkbox input:indeterminate ~ label:after {
    opacity: 0; }
  .ui.radio.checkbox input:checked ~ .box:before, .ui.radio.checkbox input:checked ~ label:before {
    background-color: #FFFFFF; }
  .ui.radio.checkbox input:checked ~ .box:after, .ui.radio.checkbox input:checked ~ label:after {
    background-color: rgba(0, 0, 0, 0.95); }
  .ui.radio.checkbox input:focus:checked ~ .box:before, .ui.radio.checkbox input:focus:checked ~ label:before {
    background-color: #FFFFFF; }
  .ui.radio.checkbox input:focus:checked ~ .box:after, .ui.radio.checkbox input:focus:checked ~ label:after {
    background-color: rgba(0, 0, 0, 0.95); }

.ui.slider.checkbox {
  min-height: 1.25rem; }
  .ui.slider.checkbox input {
    width: 3.5rem;
    height: 1.25rem; }
  .ui.slider.checkbox .box, .ui.slider.checkbox label {
    padding-left: 4.5rem;
    line-height: 1rem;
    color: rgba(0, 0, 0, 0.4); }
  .ui.slider.checkbox .box:before, .ui.slider.checkbox label:before {
    display: block;
    position: absolute;
    content: '';
    border: none !important;
    left: 0em;
    z-index: 1;
    top: 0.4rem;
    background-color: rgba(0, 0, 0, 0.05);
    width: 3.5rem;
    height: 0.21428571rem;
    -webkit-transform: none;
    transform: none;
    border-radius: 500rem;
    -webkit-transition: background 0.3s ease;
    transition: background 0.3s ease; }
  .ui.slider.checkbox .box:after, .ui.slider.checkbox label:after {
    background: #FFFFFF -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05));
    background: #FFFFFF linear-gradient(transparent, rgba(0, 0, 0, 0.05));
    position: absolute;
    content: '' !important;
    opacity: 1;
    z-index: 2;
    border: none;
    box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15), 0px 0px 0px 1px rgba(34, 36, 38, 0.15) inset;
    width: 1.5rem;
    height: 1.5rem;
    top: -0.25rem;
    left: 0em;
    -webkit-transform: none;
    transform: none;
    border-radius: 500rem;
    -webkit-transition: left 0.3s ease;
    transition: left 0.3s ease; }
  .ui.slider.checkbox input:focus ~ .box:before, .ui.slider.checkbox input:focus ~ label:before {
    background-color: rgba(0, 0, 0, 0.15);
    border: none; }
  .ui.slider.checkbox .box:hover, .ui.slider.checkbox label:hover {
    color: rgba(0, 0, 0, 0.8); }
  .ui.slider.checkbox .box:hover::before, .ui.slider.checkbox label:hover::before {
    background: rgba(0, 0, 0, 0.15); }
  .ui.slider.checkbox input:checked ~ .box, .ui.slider.checkbox input:checked ~ label {
    color: rgba(0, 0, 0, 0.95) !important; }
  .ui.slider.checkbox input:checked ~ .box:before, .ui.slider.checkbox input:checked ~ label:before {
    background-color: #545454 !important; }
  .ui.slider.checkbox input:checked ~ .box:after, .ui.slider.checkbox input:checked ~ label:after {
    left: 2rem; }
  .ui.slider.checkbox input:focus:checked ~ .box, .ui.slider.checkbox input:focus:checked ~ label {
    color: rgba(0, 0, 0, 0.95) !important; }
  .ui.slider.checkbox input:focus:checked ~ .box:before, .ui.slider.checkbox input:focus:checked ~ label:before {
    background-color: #000000 !important; }

.ui.toggle.checkbox {
  min-height: 1.5rem; }
  .ui.toggle.checkbox input {
    width: 3.5rem;
    height: 1.5rem; }
  .ui.toggle.checkbox .box {
    min-height: 1.5rem;
    padding-left: 4.5rem;
    color: rgba(0, 0, 0, 0.87); }
  .ui.toggle.checkbox label {
    min-height: 1.5rem;
    padding-left: 4.5rem;
    color: rgba(0, 0, 0, 0.87);
    padding-top: 0.15em; }
  .ui.toggle.checkbox .box:before, .ui.toggle.checkbox label:before {
    display: block;
    position: absolute;
    content: '';
    z-index: 1;
    -webkit-transform: none;
    transform: none;
    border: none;
    top: 0rem;
    background: rgba(0, 0, 0, 0.05);
    box-shadow: none;
    width: 3.5rem;
    height: 1.5rem;
    border-radius: 500rem; }
  .ui.toggle.checkbox .box:after, .ui.toggle.checkbox label:after {
    background: #FFFFFF -webkit-linear-gradient(transparent, rgba(0, 0, 0, 0.05));
    background: #FFFFFF linear-gradient(transparent, rgba(0, 0, 0, 0.05));
    position: absolute;
    content: '' !important;
    opacity: 1;
    z-index: 2;
    border: none;
    box-shadow: 0px 1px 2px 0 rgba(34, 36, 38, 0.15), 0px 0px 0px 1px rgba(34, 36, 38, 0.15) inset;
    width: 1.5rem;
    height: 1.5rem;
    top: 0rem;
    left: 0em;
    border-radius: 500rem;
    -webkit-transition: background 0.3s ease, left 0.3s ease;
    transition: background 0.3s ease, left 0.3s ease; }
  .ui.toggle.checkbox input ~ .box:after, .ui.toggle.checkbox input ~ label:after {
    left: -0.05rem;
    box-shadow: none; }
  .ui.toggle.checkbox input:focus ~ .box:before, .ui.toggle.checkbox input:focus ~ label:before {
    background-color: rgba(0, 0, 0, 0.15);
    border: none; }
  .ui.toggle.checkbox .box:hover::before, .ui.toggle.checkbox label:hover::before {
    background-color: rgba(0, 0, 0, 0.15);
    border: none; }
  .ui.toggle.checkbox input:checked ~ .box, .ui.toggle.checkbox input:checked ~ label {
    color: rgba(0, 0, 0, 0.95) !important; }
  .ui.toggle.checkbox input:checked ~ .box:before, .ui.toggle.checkbox input:checked ~ label:before {
    background-color: #4c8bd6 !important; }
  .ui.toggle.checkbox input:checked ~ .box:after, .ui.toggle.checkbox input:checked ~ label:after {
    left: 2.15rem;
    box-shadow: none; }
  .ui.toggle.checkbox input:focus:checked ~ .box, .ui.toggle.checkbox input:focus:checked ~ label {
    color: rgba(0, 0, 0, 0.95) !important; }
  .ui.toggle.checkbox input:focus:checked ~ .box:before, .ui.toggle.checkbox input:focus:checked ~ label:before {
    background-color: #0d71bb !important; }

.ui.fitted.checkbox .box, .ui.fitted.checkbox label {
  padding-left: 0em !important; }

.ui.fitted.toggle.checkbox, .ui.fitted.slider.checkbox {
  width: 3.5rem; }

.ui.checkbox label:after, .ui.checkbox .box:after {
  font-family: 'Checkbox'; }

.ui.checkbox input:checked ~ .box:after, .ui.checkbox input:checked ~ label:after {
  content: '\e800'; }

.ui.checkbox input:indeterminate ~ .box:after, .ui.checkbox input:indeterminate ~ label:after {
  font-size: 12px;
  content: '\e801'; }

@font-face {
  font-family: 'Checkbox';
  src: url(data:application/x-font-ttf;charset=utf-8;base64,AAEAAAALAIAAAwAwT1MvMg8SBD8AAAC8AAAAYGNtYXAYVtCJAAABHAAAAFRnYXNwAAAAEAAAAXAAAAAIZ2x5Zn4huwUAAAF4AAABYGhlYWQGPe1ZAAAC2AAAADZoaGVhB30DyAAAAxAAAAAkaG10eBBKAEUAAAM0AAAAHGxvY2EAmgESAAADUAAAABBtYXhwAAkALwAAA2AAAAAgbmFtZSC8IugAAAOAAAABknBvc3QAAwAAAAAFFAAAACAAAwMTAZAABQAAApkCzAAAAI8CmQLMAAAB6wAzAQkAAAAAAAAAAAAAAAAAAAABEAAAAAAAAAAAAAAAAAAAAABAAADoAgPA/8AAQAPAAEAAAAABAAAAAAAAAAAAAAAgAAAAAAADAAAAAwAAABwAAQADAAAAHAADAAEAAAAcAAQAOAAAAAoACAACAAIAAQAg6AL//f//AAAAAAAg6AD//f//AAH/4xgEAAMAAQAAAAAAAAAAAAAAAQAB//8ADwABAAAAAAAAAAAAAgAANzkBAAAAAAEAAAAAAAAAAAACAAA3OQEAAAAAAQAAAAAAAAAAAAIAADc5AQAAAAABAEUAUQO7AvgAGgAAARQHAQYjIicBJjU0PwE2MzIfAQE2MzIfARYVA7sQ/hQQFhcQ/uMQEE4QFxcQqAF2EBcXEE4QAnMWEP4UEBABHRAXFhBOEBCoAXcQEE4QFwAAAAABAAABbgMlAkkAFAAAARUUBwYjISInJj0BNDc2MyEyFxYVAyUQEBf9SRcQEBAQFwK3FxAQAhJtFxAQEBAXbRcQEBAQFwAAAAABAAAASQMlA24ALAAAARUUBwYrARUUBwYrASInJj0BIyInJj0BNDc2OwE1NDc2OwEyFxYdATMyFxYVAyUQEBfuEBAXbhYQEO4XEBAQEBfuEBAWbhcQEO4XEBACEm0XEBDuFxAQEBAX7hAQF20XEBDuFxAQEBAX7hAQFwAAAQAAAAIAAHRSzT9fDzz1AAsEAAAAAADRsdR3AAAAANGx1HcAAAAAA7sDbgAAAAgAAgAAAAAAAAABAAADwP/AAAAEAAAAAAADuwABAAAAAAAAAAAAAAAAAAAABwQAAAAAAAAAAAAAAAIAAAAEAABFAyUAAAMlAAAAAAAAAAoAFAAeAE4AcgCwAAEAAAAHAC0AAQAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAOAK4AAQAAAAAAAQAIAAAAAQAAAAAAAgAHAGkAAQAAAAAAAwAIADkAAQAAAAAABAAIAH4AAQAAAAAABQALABgAAQAAAAAABgAIAFEAAQAAAAAACgAaAJYAAwABBAkAAQAQAAgAAwABBAkAAgAOAHAAAwABBAkAAwAQAEEAAwABBAkABAAQAIYAAwABBAkABQAWACMAAwABBAkABgAQAFkAAwABBAkACgA0ALBDaGVja2JveABDAGgAZQBjAGsAYgBvAHhWZXJzaW9uIDIuMABWAGUAcgBzAGkAbwBuACAAMgAuADBDaGVja2JveABDAGgAZQBjAGsAYgBvAHhDaGVja2JveABDAGgAZQBjAGsAYgBvAHhSZWd1bGFyAFIAZQBnAHUAbABhAHJDaGVja2JveABDAGgAZQBjAGsAYgBvAHhGb250IGdlbmVyYXRlZCBieSBJY29Nb29uLgBGAG8AbgB0ACAAZwBlAG4AZQByAGEAdABlAGQAIABiAHkAIABJAGMAbwBNAG8AbwBuAC4AAAADAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA) format("truetype"); }

/*  UTF Reference
.check:before { content: '\e800'; }
.dash:before  { content: '\e801'; }
.plus:before { content: '\e802'; }
*/
/*!
 * # Semantic UI 2.2.12 - Dimmer
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Dimmer
*******************************/
.dimmable:not(body) {
  position: relative; }

.ui.dimmer {
  display: none;
  position: absolute;
  top: 0em !important;
  left: 0em !important;
  width: 100%;
  height: 100%;
  text-align: center;
  vertical-align: middle;
  background-color: rgba(0, 0, 0, 0.85);
  opacity: 0;
  line-height: 1;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
  -webkit-animation-duration: 0.5s;
  animation-duration: 0.5s;
  -webkit-transition: background-color 0.5s linear;
  transition: background-color 0.5s linear;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  will-change: opacity;
  z-index: 1000; }
  .ui.dimmer > .content {
    width: 100%;
    height: 100%;
    display: table;
    -webkit-user-select: text;
    -moz-user-select: text;
    -ms-user-select: text;
    user-select: text; }
    .ui.dimmer > .content > * {
      display: table-cell;
      vertical-align: middle;
      color: #FFFFFF; }

.ui.segment > .ui.dimmer {
  border-radius: inherit !important; }

.ui.dimmer:not(.inverted)::-webkit-scrollbar-track {
  background: rgba(255, 255, 255, 0.1); }

.ui.dimmer:not(.inverted)::-webkit-scrollbar-thumb {
  background: rgba(255, 255, 255, 0.25); }
  .ui.dimmer:not(.inverted)::-webkit-scrollbar-thumb:window-inactive {
    background: rgba(255, 255, 255, 0.15); }
  .ui.dimmer:not(.inverted)::-webkit-scrollbar-thumb:hover {
    background: rgba(255, 255, 255, 0.35); }

/*******************************
            States
*******************************/
.animating.dimmable:not(body) {
  overflow: hidden; }

.dimmed.dimmable:not(body) {
  overflow: hidden; }

.dimmed.dimmable > .ui.animating.dimmer, .dimmed.dimmable > .ui.visible.dimmer {
  display: block;
  opacity: 1; }

.ui.active.dimmer {
  display: block;
  opacity: 1; }

.ui.disabled.dimmer {
  width: 0 !important;
  height: 0 !important; }

.ui.page.dimmer {
  position: fixed;
  -webkit-transform-style: '';
  transform-style: '';
  -webkit-perspective: 2000px;
  perspective: 2000px;
  -webkit-transform-origin: center center;
  transform-origin: center center; }

/*******************************
           Variations
*******************************/
/*--------------
      Page
---------------*/
body.animating.in.dimmable, body.dimmed.dimmable {
  overflow: hidden; }

body.dimmable > .dimmer {
  position: fixed; }

/*--------------
    Blurring
---------------*/
.blurring.dimmable > :not(.dimmer) {
  -webkit-filter: blur(0px) grayscale(0);
  filter: blur(0px) grayscale(0);
  -webkit-transition: 800ms -webkit-filter ease;
  transition: 800ms -webkit-filter ease;
  transition: 800ms filter ease;
  transition: 800ms filter ease, 800ms -webkit-filter ease; }

.blurring.dimmed.dimmable > :not(.dimmer) {
  -webkit-filter: blur(5px) grayscale(0.7);
  filter: blur(5px) grayscale(0.7); }

.blurring.dimmable > .dimmer {
  background-color: rgba(0, 0, 0, 0.6); }

.blurring.dimmable > .inverted.dimmer {
  background-color: rgba(255, 255, 255, 0.6); }

/*--------------
    Aligned
---------------*/
.ui.dimmer > .top.aligned.content > * {
  vertical-align: top; }

.ui.dimmer > .bottom.aligned.content > * {
  vertical-align: bottom; }

.ui.inverted.dimmer {
  background-color: rgba(255, 255, 255, 0.85); }
  .ui.inverted.dimmer > .content > * {
    color: #FFFFFF; }

.ui.simple.dimmer {
  display: block;
  overflow: hidden;
  opacity: 1;
  width: 0%;
  height: 0%;
  z-index: -100;
  background-color: transparent; }

/*--------------
    Inverted
---------------*/
/*--------------
     Simple
---------------*/
/* Displays without javascript */
.dimmed.dimmable > .ui.simple.dimmer {
  overflow: visible;
  opacity: 1;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.85);
  z-index: 1; }

.ui.simple.inverted.dimmer {
  background-color: rgba(255, 255, 255, 0); }

.dimmed.dimmable > .ui.simple.inverted.dimmer {
  background-color: rgba(255, 255, 255, 0.85); }

/*!
 * # Semantic UI 2.2.12 - Dropdown
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Dropdown
*******************************/
.ui.dropdown {
  cursor: pointer;
  position: relative;
  display: inline-block;
  outline: none;
  text-align: left;
  -webkit-transition: box-shadow 0.1s ease, width 0.1s ease;
  transition: box-shadow 0.1s ease, width 0.1s ease;
  -webkit-tap-highlight-color: transparent; }
  .ui.dropdown .menu {
    cursor: auto;
    position: absolute;
    display: none;
    outline: none;
    top: 100%;
    min-width: -webkit-max-content;
    min-width: -moz-max-content;
    min-width: max-content;
    margin: 0em;
    padding: 0em 0em;
    background: #FFFFFF;
    font-size: 1em;
    text-shadow: none;
    text-align: left;
    box-shadow: 0px 2px 3px 0px rgba(34, 36, 38, 0.15);
    border: 1px solid rgba(34, 36, 38, 0.15);
    border-radius: 0.28571429rem;
    -webkit-transition: opacity 0.1s ease;
    transition: opacity 0.1s ease;
    z-index: 11;
    will-change: transform, opacity; }
    .ui.dropdown .menu > * {
      white-space: nowrap; }
    .ui.dropdown .menu > .item .dropdown.icon {
      width: auto;
      float: right;
      margin: 0em 0em 0em 1em; }
      .ui.dropdown .menu > .item .dropdown.icon + .text {
        margin-right: 1em; }
    .ui.dropdown .menu > .item {
      position: relative;
      cursor: pointer;
      display: block;
      border: none;
      height: auto;
      text-align: left;
      border-top: none;
      line-height: 1em;
      color: rgba(0, 0, 0, 0.87);
      padding: 0.78571429rem 1.14285714rem !important;
      font-size: 1rem;
      text-transform: none;
      font-weight: normal;
      box-shadow: none;
      -webkit-touch-callout: none; }
      .ui.dropdown .menu > .item:first-child {
        border-top-width: 0px; }
    .ui.dropdown .menu .item > [class*="right floated"] {
      float: right !important;
      margin-right: 0em !important;
      margin-left: 1em !important; }
    .ui.dropdown .menu .item > [class*="left floated"] {
      float: left !important;
      margin-left: 0em !important;
      margin-right: 1em !important; }
    .ui.dropdown .menu .item > .icon.floated, .ui.dropdown .menu .item > .flag.floated, .ui.dropdown .menu .item > .image.floated, .ui.dropdown .menu .item > img.floated {
      margin-top: 0em; }
    .ui.dropdown .menu > .header {
      margin: 1rem 0rem 0.75rem;
      padding: 0em 1.14285714rem;
      color: rgba(0, 0, 0, 0.85);
      font-size: 0.78571429em;
      font-weight: bold;
      text-transform: uppercase; }
    .ui.dropdown .menu > .divider {
      border-top: 1px solid rgba(34, 36, 38, 0.1);
      height: 0em;
      margin: 0.5em 0em; }
    .ui.dropdown .menu > .input {
      width: auto;
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      margin: 1.14285714rem 0.78571429rem;
      min-width: 10rem; }
    .ui.dropdown .menu > .header + .input {
      margin-top: 0em; }
    .ui.dropdown .menu > .input:not(.transparent) input {
      padding: 0.5em 1em; }
    .ui.dropdown .menu > .input:not(.transparent) .button, .ui.dropdown .menu > .input:not(.transparent) .icon, .ui.dropdown .menu > .input:not(.transparent) .label {
      padding-top: 0.5em;
      padding-bottom: 0.5em; }
    .ui.dropdown .menu > .item > .description {
      float: right;
      margin: 0em 0em 0em 1em;
      color: rgba(0, 0, 0, 0.4); }
    .ui.dropdown .menu > .message {
      padding: 0.78571429rem 1.14285714rem;
      font-weight: normal; }
      .ui.dropdown .menu > .message:not(.ui) {
        color: rgba(0, 0, 0, 0.4); }
    .ui.dropdown .menu .menu {
      top: 0% !important;
      left: 100%;
      right: auto;
      margin: 0em 0em 0em -0.5em !important;
      border-radius: 0.28571429rem !important;
      z-index: 21 !important; }
      .ui.dropdown .menu .menu:after {
        display: none; }
    .ui.dropdown .menu > .item > .icon, .ui.dropdown .menu > .item > .label, .ui.dropdown .menu > .item > .flag, .ui.dropdown .menu > .item > .image, .ui.dropdown .menu > .item > img {
      margin-top: 0em; }
    .ui.dropdown .menu > .item > .icon, .ui.dropdown .menu > .item > .label, .ui.dropdown .menu > .item > .flag, .ui.dropdown .menu > .item > .image, .ui.dropdown .menu > .item > img {
      margin-left: 0em;
      float: none;
      margin-right: 0.78571429rem; }
    .ui.dropdown .menu > .item > .image, .ui.dropdown .menu > .item > img {
      display: inline-block;
      vertical-align: top;
      width: auto;
      margin-top: -0.5em;
      margin-bottom: -0.5em;
      max-height: 2em; }
  .ui.dropdown > input:not(.search):first-child, .ui.dropdown > select {
    display: none !important; }
  .ui.dropdown > .dropdown.icon {
    position: relative;
    width: auto;
    font-size: 0.85714286em;
    margin: 0em 0em 0em 1em; }
  .ui.dropdown > .text {
    display: inline-block;
    -webkit-transition: none;
    transition: none; }
  .ui.dropdown > .text > [class*="right floated"] {
    float: right !important;
    margin-right: 0em !important;
    margin-left: 1em !important; }
  .ui.dropdown > .text > [class*="left floated"] {
    float: left !important;
    margin-left: 0em !important;
    margin-right: 1em !important; }
  .ui.dropdown > .text > .description {
    float: right;
    margin: 0em 0em 0em 1em;
    color: rgba(0, 0, 0, 0.4); }
  .ui.dropdown > .text > .icon, .ui.dropdown > .text > .label, .ui.dropdown > .text > .flag, .ui.dropdown > .text > img, .ui.dropdown > .text > .image {
    margin-top: 0em; }
  .ui.dropdown > .text > .icon, .ui.dropdown > .text > .label, .ui.dropdown > .text > .flag, .ui.dropdown > .text > img, .ui.dropdown > .text > .image {
    margin-left: 0em;
    float: none;
    margin-right: 0.78571429rem; }
  .ui.dropdown > .text > img, .ui.dropdown > .text > .image {
    display: inline-block;
    vertical-align: top;
    width: auto;
    margin-top: -0.5em;
    margin-bottom: -0.5em;
    max-height: 2em; }
  .ui.dropdown .ui.menu > .item:before {
    display: none; }

.ui.menu .ui.dropdown .menu > .item:before {
  display: none; }

.ui.menu .ui.dropdown .menu .active.item {
  border-left: none; }

.ui.menu .right.menu .dropdown:last-child .menu, .ui.menu .right.dropdown.item .menu {
  left: auto;
  right: 0em; }

.ui.buttons > .ui.dropdown:last-child .menu {
  left: auto;
  right: 0em; }

.ui.label.dropdown .menu {
  min-width: 100%; }

.ui.dropdown.icon.button > .dropdown.icon {
  margin: 0em; }

.ui.button.dropdown .menu {
  min-width: 100%; }

.ui.selection.dropdown {
  cursor: pointer;
  word-wrap: break-word;
  line-height: 1em;
  white-space: normal;
  outline: 0;
  -webkit-transform: rotateZ(0deg);
  transform: rotateZ(0deg);
  min-width: 14em;
  min-height: 2.71428571em;
  background: #FFFFFF;
  display: inline-block;
  padding: 0.78571429em 2.1em 0.78571429em 1em;
  color: rgba(0, 0, 0, 0.87);
  box-shadow: none;
  border: 1px solid rgba(34, 36, 38, 0.15);
  border-radius: 0.28571429rem;
  -webkit-transition: box-shadow 0.1s ease, width 0.1s ease;
  transition: box-shadow 0.1s ease, width 0.1s ease; }
  .ui.selection.dropdown.visible, .ui.selection.dropdown.active {
    z-index: 10; }

select.ui.dropdown {
  height: 38px;
  padding: 0.5em;
  border: 1px solid rgba(34, 36, 38, 0.15);
  visibility: visible; }

.ui.selection.dropdown > .search.icon, .ui.selection.dropdown > .delete.icon, .ui.selection.dropdown > .dropdown.icon {
  cursor: pointer;
  position: absolute;
  width: auto;
  height: auto;
  line-height: 1.21428571em;
  top: 0.78571429em;
  right: 1em;
  z-index: 3;
  margin: -0.78571429em;
  padding: 0.91666667em;
  opacity: 0.8;
  -webkit-transition: opacity 0.1s ease;
  transition: opacity 0.1s ease; }

.ui.compact.selection.dropdown {
  min-width: 0px; }

.ui.selection.dropdown .menu {
  overflow-x: hidden;
  overflow-y: auto;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-overflow-scrolling: touch;
  border-top-width: 0px !important;
  width: auto;
  outline: none;
  margin: 0px -1px;
  min-width: calc(100% +  2px);
  width: calc(100% +  2px);
  border-radius: 0em 0em 0.28571429rem 0.28571429rem;
  box-shadow: 0px 2px 3px 0px rgba(34, 36, 38, 0.15);
  -webkit-transition: opacity 0.1s ease;
  transition: opacity 0.1s ease; }
  .ui.selection.dropdown .menu:after, .ui.selection.dropdown .menu:before {
    display: none; }
  .ui.selection.dropdown .menu > .message {
    padding: 0.78571429rem 1.14285714rem; }
  .ui.selection.dropdown .menu > .item {
    border-top: 1px solid #FAFAFA;
    padding: 0.78571429rem 1.14285714rem !important;
    white-space: normal;
    word-wrap: normal; }
  .ui.selection.dropdown .menu > .hidden.addition.item {
    display: none; }

.ui.selection.dropdown:hover {
  border-color: rgba(34, 36, 38, 0.35);
  box-shadow: none; }

.ui.selection.active.dropdown {
  border-color: #96C8DA;
  box-shadow: 0px 2px 3px 0px rgba(34, 36, 38, 0.15); }
  .ui.selection.active.dropdown .menu {
    border-color: #96C8DA;
    box-shadow: 0px 2px 3px 0px rgba(34, 36, 38, 0.15); }

.ui.selection.dropdown:focus {
  border-color: #96C8DA;
  box-shadow: none; }
  .ui.selection.dropdown:focus .menu {
    border-color: #96C8DA;
    box-shadow: 0px 2px 3px 0px rgba(34, 36, 38, 0.15); }

.ui.selection.visible.dropdown > .text:not(.default) {
  font-weight: normal;
  color: rgba(0, 0, 0, 0.8); }

.ui.selection.active.dropdown:hover {
  border-color: #96C8DA;
  box-shadow: 0px 2px 3px 0px rgba(34, 36, 38, 0.15); }
  .ui.selection.active.dropdown:hover .menu {
    border-color: #96C8DA;
    box-shadow: 0px 2px 3px 0px rgba(34, 36, 38, 0.15); }

.ui.active.selection.dropdown > .dropdown.icon, .ui.visible.selection.dropdown > .dropdown.icon {
  opacity: 1;
  z-index: 3; }

.ui.active.selection.dropdown {
  border-bottom-left-radius: 0em !important;
  border-bottom-right-radius: 0em !important; }

.ui.active.empty.selection.dropdown {
  border-radius: 0.28571429rem !important;
  box-shadow: none !important; }
  .ui.active.empty.selection.dropdown .menu {
    border: none !important;
    box-shadow: none !important; }

.ui.search.dropdown {
  min-width: ''; }
  .ui.search.dropdown > input.search {
    background: none transparent !important;
    border: none !important;
    box-shadow: none !important;
    cursor: text;
    top: 0em;
    left: 1px;
    width: 100%;
    outline: none;
    -webkit-tap-highlight-color: rgba(255, 255, 255, 0);
    padding: inherit;
    position: absolute;
    z-index: 2; }
  .ui.search.dropdown > .text {
    cursor: text;
    position: relative;
    left: 1px;
    z-index: 3; }

.ui.search.selection.dropdown > input.search {
  line-height: 1.21428571em;
  padding: 0.67857143em 2.1em 0.67857143em 1em; }

.ui.search.selection.dropdown > span.sizer {
  line-height: 1.21428571em;
  padding: 0.67857143em 2.1em 0.67857143em 1em;
  display: none;
  white-space: pre; }

.ui.search.dropdown.active > input.search, .ui.search.dropdown.visible > input.search {
  cursor: auto; }

.ui.search.dropdown.active > .text, .ui.search.dropdown.visible > .text {
  pointer-events: none; }

.ui.active.search.dropdown input.search:focus + .text {
  color: rgba(115, 115, 115, 0.87) !important; }
  .ui.active.search.dropdown input.search:focus + .text .icon, .ui.active.search.dropdown input.search:focus + .text .flag {
    opacity: 0.45; }

.ui.search.dropdown .menu {
  overflow-x: hidden;
  overflow-y: auto;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-overflow-scrolling: touch; }

.ui.multiple.dropdown {
  padding: 0.22619048em 2.1em 0.22619048em 0.35714286em; }
  .ui.multiple.dropdown .menu {
    cursor: auto; }

.ui.multiple.search.dropdown {
  cursor: text; }
  .ui.multiple.search.dropdown > input.search {
    cursor: text; }

.ui.multiple.dropdown > .label {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  display: inline-block;
  vertical-align: top;
  white-space: normal;
  font-size: 1em;
  padding: 0.35714286em 0.78571429em;
  margin: 0.14285714rem 0.28571429rem 0.14285714rem 0em;
  box-shadow: 0px 0px 0px 1px rgba(34, 36, 38, 0.15) inset; }

.ui.multiple.dropdown .dropdown.icon {
  margin: '';
  padding: ''; }

.ui.multiple.dropdown > .text {
  position: static;
  padding: 0;
  max-width: 100%;
  margin: 0.45238095em 0em 0.45238095em 0.64285714em;
  line-height: 1.21428571em; }

.ui.multiple.dropdown > .label ~ input.search {
  margin-left: 0.14285714em !important; }

.ui.multiple.dropdown > .label ~ .text {
  display: none; }

.ui.multiple.search.dropdown > .text {
  display: inline-block;
  position: absolute;
  top: 0;
  left: 0;
  padding: inherit;
  margin: 0.45238095em 0em 0.45238095em 0.64285714em;
  line-height: 1.21428571em; }

.ui.multiple.search.dropdown > .label ~ .text {
  display: none; }

.ui.multiple.search.dropdown > input.search {
  position: static;
  padding: 0;
  max-width: 100%;
  margin: 0.45238095em 0em 0.45238095em 0.64285714em;
  width: 2.2em;
  line-height: 1.21428571em; }

.ui.inline.dropdown {
  cursor: pointer;
  display: inline-block;
  color: inherit; }
  .ui.inline.dropdown .dropdown.icon {
    margin: 0em 0.5em 0em 0.21428571em;
    vertical-align: baseline; }
  .ui.inline.dropdown > .text {
    font-weight: bold; }
  .ui.inline.dropdown .menu {
    cursor: auto;
    margin-top: 0.21428571em;
    border-radius: 0.28571429rem; }

.ui.dropdown .menu .active.item {
  background: transparent;
  font-weight: bold;
  color: rgba(0, 0, 0, 0.95);
  box-shadow: none;
  z-index: 12; }

.ui.dropdown .menu > .item:hover {
  background: rgba(0, 0, 0, 0.05);
  color: rgba(0, 0, 0, 0.95);
  z-index: 13; }

.ui.loading.dropdown > i.icon {
  height: 1em !important; }

.ui.loading.selection.dropdown > i.icon {
  padding: 1.5em 1.28571429em !important; }

.ui.loading.dropdown > i.icon:before {
  position: absolute;
  content: '';
  top: 50%;
  left: 50%;
  margin: -0.64285714em 0em 0em -0.64285714em;
  width: 1.28571429em;
  height: 1.28571429em;
  border-radius: 500rem;
  border: 0.2em solid rgba(0, 0, 0, 0.1); }

.ui.loading.dropdown > i.icon:after {
  position: absolute;
  content: '';
  top: 50%;
  left: 50%;
  box-shadow: 0px 0px 0px 1px transparent;
  margin: -0.64285714em 0em 0em -0.64285714em;
  width: 1.28571429em;
  height: 1.28571429em;
  -webkit-animation: dropdown-spin 0.6s linear;
  animation: dropdown-spin 0.6s linear;
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite;
  border-radius: 500rem;
  border-color: #767676 transparent transparent;
  border-style: solid;
  border-width: 0.2em; }

.ui.loading.dropdown.button > i.icon:before, .ui.loading.dropdown.button > i.icon:after {
  display: none; }

.ui.dropdown:not(.button) > .default.text, .ui.default.dropdown:not(.button) > .text {
  color: rgba(191, 191, 191, 0.87); }

.ui.dropdown:not(.button) > input:focus ~ .default.text, .ui.default.dropdown:not(.button) > input:focus ~ .text {
  color: rgba(115, 115, 115, 0.87); }

.ui.loading.dropdown > .text {
  -webkit-transition: none;
  transition: none; }

.ui.dropdown .loading.menu {
  display: block;
  visibility: hidden;
  z-index: -1; }

.ui.dropdown > .loading.menu {
  left: 0px !important;
  right: auto !important; }

.ui.dropdown > .menu .loading.menu {
  left: 100% !important;
  right: auto !important; }

.ui.dropdown.selected, .ui.dropdown .menu .selected.item {
  background: rgba(0, 0, 0, 0.03);
  color: rgba(0, 0, 0, 0.95); }

.ui.dropdown > .filtered.text {
  visibility: hidden; }

.ui.dropdown .filtered.item {
  display: none !important; }

.ui.dropdown.error {
  color: #9F3A38; }
  .ui.dropdown.error > .text, .ui.dropdown.error > .default.text {
    color: #9F3A38; }

.ui.selection.dropdown.error {
  background: #FFF6F6;
  border-color: #E0B4B4; }
  .ui.selection.dropdown.error:hover {
    border-color: #E0B4B4; }

.ui.dropdown.error > .menu {
  border-color: #E0B4B4; }
  .ui.dropdown.error > .menu .menu {
    border-color: #E0B4B4; }
  .ui.dropdown.error > .menu > .item {
    color: #9F3A38; }

.ui.multiple.selection.error.dropdown > .label {
  border-color: #E0B4B4; }

.ui.dropdown.error > .menu > .item:hover {
  background-color: #FFF2F2; }

.ui.dropdown.error > .menu .active.item {
  background-color: #FDCFCF; }

.ui.disabled.dropdown {
  cursor: default;
  pointer-events: none;
  opacity: 0.45; }

.ui.dropdown .menu {
  left: 0px; }
  .ui.dropdown .menu > .disabled.item {
    cursor: default;
    pointer-events: none;
    opacity: 0.45; }

.ui.dropdown .right.menu > .menu {
  left: 100% !important;
  right: auto !important;
  border-radius: 0.28571429rem !important; }

.ui.dropdown .menu .right.menu {
  left: 100% !important;
  right: auto !important;
  border-radius: 0.28571429rem !important; }

.ui.dropdown .menu .left.menu {
  left: auto;
  right: 100%;
  margin: 0em -0.5em 0em 0em !important;
  border-radius: 0.28571429rem !important; }

.ui.dropdown > .left.menu {
  left: auto !important;
  right: 0px !important; }
  .ui.dropdown > .left.menu .menu {
    left: auto;
    right: 100%;
    margin: 0em -0.5em 0em 0em !important;
    border-radius: 0.28571429rem !important; }

.ui.dropdown .item .left.dropdown.icon, .ui.dropdown .left.menu .item .dropdown.icon, .ui.dropdown .item .left.dropdown.icon, .ui.dropdown .left.menu .item .dropdown.icon {
  width: auto;
  float: left;
  margin: 0em 0em 0em 0em; }

.ui.dropdown .item .left.dropdown.icon + .text, .ui.dropdown .left.menu .item .dropdown.icon + .text {
  margin-left: 1em;
  margin-right: 0em; }

.ui.upward.dropdown > .menu {
  top: auto;
  bottom: 100%;
  box-shadow: 0px 0px 3px 0px rgba(0, 0, 0, 0.08);
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }

.ui.dropdown .upward.menu {
  top: auto !important;
  bottom: 0 !important; }

.ui.simple.upward.active.dropdown, .ui.simple.upward.dropdown:hover {
  border-radius: 0.28571429rem 0.28571429rem 0em 0em !important; }

.ui.upward.dropdown.button:not(.pointing):not(.floating).active {
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }

.ui.upward.selection.dropdown .menu {
  border-top-width: 1px !important;
  border-bottom-width: 0px !important;
  box-shadow: 0px -2px 3px 0px rgba(0, 0, 0, 0.08); }

.ui.upward.selection.dropdown:hover {
  box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.05); }

.ui.active.upward.selection.dropdown {
  border-radius: 0em 0em 0.28571429rem 0.28571429rem !important; }

.ui.upward.selection.dropdown.visible {
  box-shadow: 0px 0px 3px 0px rgba(0, 0, 0, 0.08);
  border-radius: 0em 0em 0.28571429rem 0.28571429rem !important; }

.ui.upward.active.selection.dropdown:hover {
  box-shadow: 0px 0px 3px 0px rgba(0, 0, 0, 0.05); }
  .ui.upward.active.selection.dropdown:hover .menu {
    box-shadow: 0px -2px 3px 0px rgba(0, 0, 0, 0.08); }

.ui.scrolling.dropdown .menu, .ui.dropdown .scrolling.menu {
  overflow-x: hidden;
  overflow-y: auto; }

.ui.scrolling.dropdown .menu {
  overflow-x: hidden;
  overflow-y: auto;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-overflow-scrolling: touch;
  min-width: 100% !important;
  width: auto !important; }

.ui.dropdown .scrolling.menu {
  position: static;
  overflow-y: auto;
  border: none;
  box-shadow: none !important;
  border-radius: 0 !important;
  margin: 0 !important;
  min-width: 100% !important;
  width: auto !important;
  border-top: 1px solid rgba(34, 36, 38, 0.15); }

.ui.scrolling.dropdown .menu .item.item.item, .ui.dropdown .scrolling.menu > .item.item.item, .ui.scrolling.dropdown .menu .item:first-child {
  border-top: none; }

.ui.dropdown .scrolling.menu .item:first-child {
  border-top: none; }

.ui.dropdown > .animating.menu .scrolling.menu, .ui.dropdown > .visible.menu .scrolling.menu {
  display: block; }

.ui.simple.dropdown .menu {
  position: absolute;
  display: block;
  overflow: hidden;
  top: -9999px !important;
  opacity: 0;
  width: 0;
  height: 0;
  -webkit-transition: opacity 0.1s ease;
  transition: opacity 0.1s ease; }
  .ui.simple.dropdown .menu:before, .ui.simple.dropdown .menu:after {
    display: none; }

.ui.simple.active.dropdown, .ui.simple.dropdown:hover {
  border-bottom-left-radius: 0em !important;
  border-bottom-right-radius: 0em !important; }

.ui.simple.active.dropdown > .menu {
  overflow: visible;
  width: auto;
  height: auto;
  top: 100% !important;
  opacity: 1; }

.ui.simple.dropdown:hover > .menu {
  overflow: visible;
  width: auto;
  height: auto;
  top: 100% !important;
  opacity: 1; }

.ui.simple.dropdown:hover > .menu > .item:hover > .menu {
  overflow: visible;
  width: auto;
  height: auto;
  top: 0% !important;
  left: 100% !important;
  opacity: 1; }

.ui.simple.dropdown > .menu > .item:active > .menu {
  overflow: visible;
  width: auto;
  height: auto;
  top: 0% !important;
  left: 100% !important;
  opacity: 1; }

.ui.simple.disabled.dropdown:hover .menu {
  display: none;
  height: 0px;
  width: 0px;
  overflow: hidden; }

.ui.simple.visible.dropdown > .menu {
  display: block; }

.ui.fluid.dropdown {
  display: block;
  width: 100%;
  min-width: 0em; }
  .ui.fluid.dropdown > .dropdown.icon {
    float: right; }

.ui.floating.dropdown .menu {
  left: 0;
  right: auto;
  box-shadow: 0px 2px 4px 0px rgba(34, 36, 38, 0.12), 0px 2px 10px 0px rgba(34, 36, 38, 0.15) !important;
  border-radius: 0.28571429rem !important; }

.ui.floating.dropdown > .menu {
  margin-top: 0.5em !important;
  border-radius: 0.28571429rem !important; }

.ui.pointing.dropdown > .menu {
  top: 100%;
  margin-top: 0.78571429rem;
  border-radius: 0.28571429rem; }
  .ui.pointing.dropdown > .menu:after {
    display: block;
    position: absolute;
    pointer-events: none;
    content: '';
    visibility: visible;
    -webkit-transform: rotate(45deg);
    transform: rotate(45deg);
    width: 0.5em;
    height: 0.5em;
    box-shadow: -1px -1px 0px 0px rgba(34, 36, 38, 0.15);
    background: #FFFFFF;
    z-index: 2;
    top: -0.25em;
    left: 50%;
    margin: 0em 0em 0em -0.25em; }

.ui.top.left.pointing.dropdown > .menu {
  top: 100%;
  bottom: auto;
  left: 0%;
  right: auto;
  margin: 1em 0em 0em;
  top: 100%;
  bottom: auto;
  left: 0%;
  right: auto;
  margin: 1em 0em 0em; }
  .ui.top.left.pointing.dropdown > .menu:after {
    top: -0.25em;
    left: 1em;
    right: auto;
    margin: 0em;
    -webkit-transform: rotate(45deg);
    transform: rotate(45deg); }

.ui.top.right.pointing.dropdown > .menu {
  top: 100%;
  bottom: auto;
  right: 0%;
  left: auto;
  margin: 1em 0em 0em; }

.ui.top.pointing.dropdown > .left.menu:after, .ui.top.right.pointing.dropdown > .menu:after {
  top: -0.25em;
  left: auto !important;
  right: 1em !important;
  margin: 0em;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg); }

.ui.left.pointing.dropdown > .menu {
  top: 0%;
  left: 100%;
  right: auto;
  margin: 0em 0em 0em 1em; }
  .ui.left.pointing.dropdown > .menu:after {
    top: 1em;
    left: -0.25em;
    margin: 0em 0em 0em 0em;
    -webkit-transform: rotate(-45deg);
    transform: rotate(-45deg); }

.ui.left:not(.top):not(.bottom).pointing.dropdown > .left.menu {
  left: auto !important;
  right: 100% !important;
  margin: 0em 1em 0em 0em; }
  .ui.left:not(.top):not(.bottom).pointing.dropdown > .left.menu:after {
    top: 1em;
    left: auto;
    right: -0.25em;
    margin: 0em 0em 0em 0em;
    -webkit-transform: rotate(135deg);
    transform: rotate(135deg); }

.ui.right.pointing.dropdown > .menu {
  top: 0%;
  left: auto;
  right: 100%;
  margin: 0em 1em 0em 0em; }
  .ui.right.pointing.dropdown > .menu:after {
    top: 1em;
    left: auto;
    right: -0.25em;
    margin: 0em 0em 0em 0em;
    -webkit-transform: rotate(135deg);
    transform: rotate(135deg); }

.ui.bottom.pointing.dropdown > .menu {
  top: auto;
  bottom: 100%;
  left: 0%;
  right: auto;
  margin: 0em 0em 1em; }
  .ui.bottom.pointing.dropdown > .menu:after {
    top: auto;
    bottom: -0.25em;
    right: auto;
    margin: 0em;
    -webkit-transform: rotate(-135deg);
    transform: rotate(-135deg); }
  .ui.bottom.pointing.dropdown > .menu .menu {
    top: auto !important;
    bottom: 0px !important; }

.ui.bottom.left.pointing.dropdown > .menu {
  left: 0%;
  right: auto; }
  .ui.bottom.left.pointing.dropdown > .menu:after {
    left: 1em;
    right: auto; }

.ui.bottom.right.pointing.dropdown > .menu {
  right: 0%;
  left: auto; }
  .ui.bottom.right.pointing.dropdown > .menu:after {
    left: auto;
    right: 1em; }

.ui.pointing.upward.dropdown .menu, .ui.top.pointing.upward.dropdown .menu {
  top: auto !important;
  bottom: 100% !important;
  margin: 0em 0em 0.78571429rem;
  border-radius: 0.28571429rem; }

.ui.pointing.upward.dropdown .menu:after, .ui.top.pointing.upward.dropdown .menu:after {
  top: 100% !important;
  bottom: auto !important;
  box-shadow: 1px 1px 0px 0px rgba(34, 36, 38, 0.15);
  margin: -0.25em 0em 0em; }

.ui.right.pointing.upward.dropdown:not(.top):not(.bottom) .menu {
  top: auto !important;
  bottom: 0 !important;
  margin: 0em 1em 0em 0em; }
  .ui.right.pointing.upward.dropdown:not(.top):not(.bottom) .menu:after {
    top: auto !important;
    bottom: 0 !important;
    margin: 0em 0em 1em 0em;
    box-shadow: -1px -1px 0px 0px rgba(34, 36, 38, 0.15); }

.ui.left.pointing.upward.dropdown:not(.top):not(.bottom) .menu {
  top: auto !important;
  bottom: 0 !important;
  margin: 0em 0em 0em 1em; }
  .ui.left.pointing.upward.dropdown:not(.top):not(.bottom) .menu:after {
    top: auto !important;
    bottom: 0 !important;
    margin: 0em 0em 1em 0em;
    box-shadow: -1px -1px 0px 0px rgba(34, 36, 38, 0.15); }

.ui.dropdown > .dropdown.icon {
  font-family: 'Dropdown';
  line-height: 1;
  height: 1em;
  width: 1.23em;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  font-weight: normal;
  font-style: normal;
  text-align: center;
  width: auto; }
  .ui.dropdown > .dropdown.icon:before {
    content: '\f0d7'; }

.ui.dropdown .menu .item .dropdown.icon:before {
  content: ""; }

.ui.dropdown .item .left.dropdown.icon:before, .ui.dropdown .left.menu .item .dropdown.icon:before {
  content: ""; }

.ui.vertical.menu .dropdown.item > .dropdown.icon:before {
  content: ""; }

@media only screen and (max-width: 767px) {
  .ui.selection.dropdown .menu {
    max-height: 8.01428571rem; } }

@media only screen and (min-width: 768px) {
  .ui.selection.dropdown .menu {
    max-height: 10.68571429rem; } }

@media only screen and (min-width: 992px) {
  .ui.selection.dropdown .menu {
    max-height: 16.02857143rem; } }

@media only screen and (min-width: 1920px) {
  .ui.selection.dropdown .menu {
    max-height: 21.37142857rem; } }

@media only screen and (max-width: 767px) {
  .ui.search.dropdown .menu {
    max-height: 8.01428571rem; } }

@media only screen and (min-width: 768px) {
  .ui.search.dropdown .menu {
    max-height: 10.68571429rem; } }

@media only screen and (min-width: 992px) {
  .ui.search.dropdown .menu {
    max-height: 16.02857143rem; } }

@media only screen and (min-width: 1920px) {
  .ui.search.dropdown .menu {
    max-height: 21.37142857rem; } }

@-webkit-keyframes dropdown-spin {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

@keyframes dropdown-spin {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

@media all and (-ms-high-contrast: none) {
  .ui.scrolling.dropdown .menu, .ui.dropdown .scrolling.menu {
    min-width: calc(100% -  17px); } }

@media only screen and (max-width: 767px) {
  .ui.scrolling.dropdown .menu, .ui.dropdown .scrolling.menu {
    max-height: 10.28571429rem; } }

@media only screen and (min-width: 768px) {
  .ui.scrolling.dropdown .menu, .ui.dropdown .scrolling.menu {
    max-height: 15.42857143rem; } }

@media only screen and (min-width: 992px) {
  .ui.scrolling.dropdown .menu, .ui.dropdown .scrolling.menu {
    max-height: 20.57142857rem; } }

@media only screen and (min-width: 1920px) {
  .ui.scrolling.dropdown .menu, .ui.dropdown .scrolling.menu {
    max-height: 20.57142857rem; } }

/* Dropdown Carets */
@font-face {
  font-family: 'Dropdown';
  src: url(data:application/x-font-ttf;charset=utf-8;base64,AAEAAAALAIAAAwAwT1MvMggjB5AAAAC8AAAAYGNtYXAPfuIIAAABHAAAAExnYXNwAAAAEAAAAWgAAAAIZ2x5Zjo82LgAAAFwAAABVGhlYWQAQ88bAAACxAAAADZoaGVhAwcB6QAAAvwAAAAkaG10eAS4ABIAAAMgAAAAIGxvY2EBNgDeAAADQAAAABJtYXhwAAoAFgAAA1QAAAAgbmFtZVcZpu4AAAN0AAABRXBvc3QAAwAAAAAEvAAAACAAAwIAAZAABQAAAUwBZgAAAEcBTAFmAAAA9QAZAIQAAAAAAAAAAAAAAAAAAAABEAAAAAAAAAAAAAAAAAAAAABAAADw2gHg/+D/4AHgACAAAAABAAAAAAAAAAAAAAAgAAAAAAACAAAAAwAAABQAAwABAAAAFAAEADgAAAAKAAgAAgACAAEAIPDa//3//wAAAAAAIPDX//3//wAB/+MPLQADAAEAAAAAAAAAAAAAAAEAAf//AA8AAQAAAAAAAAAAAAIAADc5AQAAAAABAAAAAAAAAAAAAgAANzkBAAAAAAEAAAAAAAAAAAACAAA3OQEAAAAAAQAAAIABJQElABMAABM0NzY3BTYXFhUUDwEGJwYvASY1AAUGBwEACAUGBoAFCAcGgAUBEgcGBQEBAQcECQYHfwYBAQZ/BwYAAQAAAG4BJQESABMAADc0PwE2MzIfARYVFAcGIyEiJyY1AAWABgcIBYAGBgUI/wAHBgWABwaABQWABgcHBgUFBgcAAAABABIASQC3AW4AEwAANzQ/ATYXNhcWHQEUBwYnBi8BJjUSBoAFCAcFBgYFBwgFgAbbBwZ/BwEBBwQJ/wgEBwEBB38GBgAAAAABAAAASQClAW4AEwAANxE0NzYzMh8BFhUUDwEGIyInJjUABQYHCAWABgaABQgHBgVbAQAIBQYGgAUIBwWABgYFBwAAAAEAAAABAADZuaKOXw889QALAgAAAAAA0ABHWAAAAADQAEdYAAAAAAElAW4AAAAIAAIAAAAAAAAAAQAAAeD/4AAAAgAAAAAAASUAAQAAAAAAAAAAAAAAAAAAAAgAAAAAAAAAAAAAAAABAAAAASUAAAElAAAAtwASALcAAAAAAAAACgAUAB4AQgBkAIgAqgAAAAEAAAAIABQAAQAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAOAK4AAQAAAAAAAQAOAAAAAQAAAAAAAgAOAEcAAQAAAAAAAwAOACQAAQAAAAAABAAOAFUAAQAAAAAABQAWAA4AAQAAAAAABgAHADIAAQAAAAAACgA0AGMAAwABBAkAAQAOAAAAAwABBAkAAgAOAEcAAwABBAkAAwAOACQAAwABBAkABAAOAFUAAwABBAkABQAWAA4AAwABBAkABgAOADkAAwABBAkACgA0AGMAaQBjAG8AbQBvAG8AbgBWAGUAcgBzAGkAbwBuACAAMQAuADAAaQBjAG8AbQBvAG8Abmljb21vb24AaQBjAG8AbQBvAG8AbgBSAGUAZwB1AGwAYQByAGkAYwBvAG0AbwBvAG4ARgBvAG4AdAAgAGcAZQBuAGUAcgBhAHQAZQBkACAAYgB5ACAASQBjAG8ATQBvAG8AbgAuAAAAAAMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA=) format("truetype"), url(data:application/font-woff;charset=utf-8;base64,d09GRk9UVE8AAAVwAAoAAAAABSgAAQAAAAAAAAAAAAAAAAAAAAAAAAAAAABDRkYgAAAA9AAAAdkAAAHZLDXE/09TLzIAAALQAAAAYAAAAGAIIweQY21hcAAAAzAAAABMAAAATA9+4ghnYXNwAAADfAAAAAgAAAAIAAAAEGhlYWQAAAOEAAAANgAAADYAQ88baGhlYQAAA7wAAAAkAAAAJAMHAelobXR4AAAD4AAAACAAAAAgBLgAEm1heHAAAAQAAAAABgAAAAYACFAAbmFtZQAABAgAAAFFAAABRVcZpu5wb3N0AAAFUAAAACAAAAAgAAMAAAEABAQAAQEBCGljb21vb24AAQIAAQA6+BwC+BsD+BgEHgoAGVP/i4seCgAZU/+LiwwHi2v4lPh0BR0AAACIDx0AAACNER0AAAAJHQAAAdASAAkBAQgPERMWGyAlKmljb21vb25pY29tb29udTB1MXUyMHVGMEQ3dUYwRDh1RjBEOXVGMERBAAACAYkABgAIAgABAAQABwAKAA0AVgCfAOgBL/yUDvyUDvyUDvuUDvtvi/emFYuQjZCOjo+Pj42Qiwj3lIsFkIuQiY6Hj4iNhouGi4aJh4eHCPsU+xQFiIiGiYaLhouHjYeOCPsU9xQFiI+Jj4uQCA77b4v3FBWLkI2Pjo8I9xT3FAWPjo+NkIuQi5CJjogI9xT7FAWPh42Hi4aLhomHh4eIiIaJhosI+5SLBYaLh42HjoiPiY+LkAgO+92d928Vi5CNkI+OCPcU9xQFjo+QjZCLkIuPiY6Hj4iNhouGCIv7lAWLhomHh4iIh4eJhouGi4aNiI8I+xT3FAWHjomPi5AIDvvdi+YVi/eUBYuQjZCOjo+Pj42Qi5CLkImOhwj3FPsUBY+IjYaLhouGiYeHiAj7FPsUBYiHhomGi4aLh42Hj4iOiY+LkAgO+JQU+JQViwwKAAAAAAMCAAGQAAUAAAFMAWYAAABHAUwBZgAAAPUAGQCEAAAAAAAAAAAAAAAAAAAAARAAAAAAAAAAAAAAAAAAAAAAQAAA8NoB4P/g/+AB4AAgAAAAAQAAAAAAAAAAAAAAIAAAAAAAAgAAAAMAAAAUAAMAAQAAABQABAA4AAAACgAIAAIAAgABACDw2v/9//8AAAAAACDw1//9//8AAf/jDy0AAwABAAAAAAAAAAAAAAABAAH//wAPAAEAAAABAAA5emozXw889QALAgAAAAAA0ABHWAAAAADQAEdYAAAAAAElAW4AAAAIAAIAAAAAAAAAAQAAAeD/4AAAAgAAAAAAASUAAQAAAAAAAAAAAAAAAAAAAAgAAAAAAAAAAAAAAAABAAAAASUAAAElAAAAtwASALcAAAAAUAAACAAAAAAADgCuAAEAAAAAAAEADgAAAAEAAAAAAAIADgBHAAEAAAAAAAMADgAkAAEAAAAAAAQADgBVAAEAAAAAAAUAFgAOAAEAAAAAAAYABwAyAAEAAAAAAAoANABjAAMAAQQJAAEADgAAAAMAAQQJAAIADgBHAAMAAQQJAAMADgAkAAMAAQQJAAQADgBVAAMAAQQJAAUAFgAOAAMAAQQJAAYADgA5AAMAAQQJAAoANABjAGkAYwBvAG0AbwBvAG4AVgBlAHIAcwBpAG8AbgAgADEALgAwAGkAYwBvAG0AbwBvAG5pY29tb29uAGkAYwBvAG0AbwBvAG4AUgBlAGcAdQBsAGEAcgBpAGMAbwBtAG8AbwBuAEYAbwBuAHQAIABnAGUAbgBlAHIAYQB0AGUAZAAgAGIAeQAgAEkAYwBvAE0AbwBvAG4ALgAAAAADAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA) format("woff");
  font-weight: normal;
  font-style: normal; }

/* Sub Menu */
/* Vertical Menu Dropdown */
/* Icons for Reference
.dropdown.down.icon {
  content: "\f0d7";
}
.dropdown.up.icon {
  content: "\f0d8";
}
.dropdown.left.icon {
  content: "\f0d9";
}
.dropdown.icon.icon {
  content: "\f0da";
}
*/
/*!
 * # Semantic UI 2.2.12 - Video
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Types
*******************************/
.ui.embed {
  position: relative;
  max-width: 100%;
  height: 0px;
  overflow: hidden;
  background: #DCDDDE;
  padding-bottom: 56.25%; }
  .ui.embed iframe, .ui.embed embed, .ui.embed object {
    position: absolute;
    border: none;
    width: 100%;
    height: 100%;
    top: 0px;
    left: 0px;
    margin: 0em;
    padding: 0em; }
  .ui.embed > .embed {
    display: none; }
  .ui.embed > .placeholder {
    position: absolute;
    cursor: pointer;
    top: 0px;
    left: 0px;
    display: block;
    width: 100%;
    height: 100%;
    background-color: radial-gradient(transparent 45%, rgba(0, 0, 0, 0.3)); }
  .ui.embed > .icon {
    cursor: pointer;
    position: absolute;
    top: 0px;
    left: 0px;
    width: 100%;
    height: 100%;
    z-index: 2; }
    .ui.embed > .icon:after {
      position: absolute;
      top: 0%;
      left: 0%;
      width: 100%;
      height: 100%;
      z-index: 3;
      content: '';
      background: -webkit-radial-gradient(transparent 45%, rgba(0, 0, 0, 0.3));
      background: radial-gradient(transparent 45%, rgba(0, 0, 0, 0.3));
      opacity: 0.5;
      -webkit-transition: opacity 0.5s ease;
      transition: opacity 0.5s ease; }
    .ui.embed > .icon:before {
      position: absolute;
      top: 50%;
      left: 50%;
      z-index: 4;
      -webkit-transform: translateX(-50%) translateY(-50%);
      transform: translateX(-50%) translateY(-50%);
      color: #FFFFFF;
      font-size: 6rem;
      text-shadow: 0px 2px 10px rgba(34, 36, 38, 0.2);
      -webkit-transition: opacity 0.5s ease, color 0.5s ease;
      transition: opacity 0.5s ease, color 0.5s ease;
      z-index: 10; }
  .ui.embed .icon:hover:after {
    background: -webkit-radial-gradient(transparent 45%, rgba(0, 0, 0, 0.3));
    background: radial-gradient(transparent 45%, rgba(0, 0, 0, 0.3));
    opacity: 1; }
  .ui.embed .icon:hover:before {
    color: #FFFFFF; }

.ui.active.embed > .icon, .ui.active.embed > .placeholder {
  display: none; }

.ui.active.embed > .embed {
  display: block; }

.ui.square.embed {
  padding-bottom: 100%; }

.ui[class*="4:3"].embed {
  padding-bottom: 75%; }

.ui[class*="16:9"].embed {
  padding-bottom: 56.25%; }

.ui[class*="21:9"].embed {
  padding-bottom: 42.85714286%; }

/*!
 * # Semantic UI 2.2.12 - Modal
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Modal
*******************************/
.ui.modal {
  display: none;
  position: fixed;
  z-index: 1001;
  top: 50%;
  left: 50%;
  text-align: left;
  background: #FFFFFF;
  border: none;
  box-shadow: 1px 3px 3px 0px rgba(0, 0, 0, 0.2), 1px 3px 15px 2px rgba(0, 0, 0, 0.2);
  -webkit-transform-origin: 50% 25%;
  transform-origin: 50% 25%;
  border-radius: 0.28571429rem;
  -webkit-user-select: text;
  -moz-user-select: text;
  -ms-user-select: text;
  user-select: text;
  will-change: top, left, margin, transform, opacity; }
  .ui.modal > :first-child:not(.icon), .ui.modal > .icon:first-child + * {
    border-top-left-radius: 0.28571429rem;
    border-top-right-radius: 0.28571429rem; }
  .ui.modal > :last-child {
    border-bottom-left-radius: 0.28571429rem;
    border-bottom-right-radius: 0.28571429rem; }
  .ui.modal > .close {
    cursor: pointer;
    position: absolute;
    top: -2.5rem;
    right: -2.5rem;
    z-index: 1;
    opacity: 0.8;
    font-size: 1.25em;
    color: #FFFFFF;
    width: 2.25rem;
    height: 2.25rem;
    padding: 0.625rem 0rem 0rem 0rem; }
    .ui.modal > .close:hover {
      opacity: 1; }
  .ui.modal > .header {
    display: block;
    font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
    background: #FFFFFF;
    margin: 0em;
    padding: 1.25rem 1.5rem;
    box-shadow: none;
    color: rgba(0, 0, 0, 0.85);
    border-bottom: 1px solid rgba(34, 36, 38, 0.15); }
    .ui.modal > .header:not(.ui) {
      font-size: 1.42857143rem;
      line-height: 1.28571429em;
      font-weight: bold; }
  .ui.modal > .content {
    display: block;
    width: 100%;
    font-size: 1em;
    line-height: 1.4;
    padding: 1.5rem;
    background: #FFFFFF; }
  .ui.modal > .image.content {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row; }
  .ui.modal > .content > .image {
    display: block;
    -webkit-box-flex: 0;
    -ms-flex: 0 1 auto;
    flex: 0 1 auto;
    width: '';
    -ms-flex-item-align: top;
    -ms-grid-row-align: top;
    align-self: top; }
  .ui.modal > [class*="top aligned"] {
    -ms-flex-item-align: top;
    -ms-grid-row-align: top;
    align-self: top; }
  .ui.modal > [class*="middle aligned"] {
    -ms-flex-item-align: middle;
    -ms-grid-row-align: middle;
    align-self: middle; }
  .ui.modal > [class*="stretched"] {
    -ms-flex-item-align: stretch;
    -ms-grid-row-align: stretch;
    align-self: stretch; }
  .ui.modal > .content > .description {
    display: block;
    -webkit-box-flex: 1;
    -ms-flex: 1 0 auto;
    flex: 1 0 auto;
    min-width: 0px;
    -ms-flex-item-align: top;
    -ms-grid-row-align: top;
    align-self: top; }
  .ui.modal > .content > .icon + .description {
    -webkit-box-flex: 0;
    -ms-flex: 0 1 auto;
    flex: 0 1 auto;
    min-width: '';
    width: auto;
    padding-left: 2em; }
  .ui.modal > .content > .image + .description {
    -webkit-box-flex: 0;
    -ms-flex: 0 1 auto;
    flex: 0 1 auto;
    min-width: '';
    width: auto;
    padding-left: 2em; }
  .ui.modal > .content > .image > i.icon {
    margin: 0em;
    opacity: 1;
    width: auto;
    line-height: 1;
    font-size: 8rem; }
  .ui.modal > .actions {
    background: #F9FAFB;
    padding: 1rem 1rem;
    border-top: 1px solid rgba(34, 36, 38, 0.15);
    text-align: right; }
  .ui.modal .actions > .button {
    margin-left: 0.75em; }

.ui.inverted.dimmer > .ui.modal {
  box-shadow: 1px 3px 10px 2px rgba(0, 0, 0, 0.2); }

.ui.basic.modal {
  background-color: transparent;
  border: none;
  border-radius: 0em;
  box-shadow: none !important;
  color: #FFFFFF; }
  .ui.basic.modal > .header, .ui.basic.modal > .content, .ui.basic.modal > .actions {
    background-color: transparent; }
  .ui.basic.modal > .header {
    color: #FFFFFF; }
  .ui.basic.modal > .close {
    top: 1rem;
    right: 1.5rem; }

.ui.inverted.dimmer > .basic.modal {
  color: rgba(0, 0, 0, 0.87); }

.ui.inverted.dimmer > .ui.basic.modal > .header {
  color: rgba(0, 0, 0, 0.85); }

.ui.loading.modal {
  display: block;
  visibility: hidden;
  z-index: -1; }

.ui.active.modal {
  display: block; }

/*******************************
            Content
*******************************/
/*--------------
     Close
---------------*/
/*--------------
     Header
---------------*/
/*--------------
     Content
---------------*/
/* Image */
/* Description */
/*rtl:ignore*/
/*--------------
     Actions
---------------*/
/*-------------------
       Responsive
--------------------*/
/* Modal Width */
@media only screen and (max-width: 767px) {
  .ui.modal {
    width: 95%;
    margin: 0em 0em 0em -47.5%; } }

@media only screen and (min-width: 768px) {
  .ui.modal {
    width: 88%;
    margin: 0em 0em 0em -44%; } }

@media only screen and (min-width: 992px) {
  .ui.modal {
    width: 850px;
    margin: 0em 0em 0em -425px; } }

@media only screen and (min-width: 1200px) {
  .ui.modal {
    width: 900px;
    margin: 0em 0em 0em -450px; } }

@media only screen and (min-width: 1920px) {
  .ui.modal {
    width: 950px;
    margin: 0em 0em 0em -475px; } }

/* Tablet and Mobile */
@media only screen and (max-width: 991px) {
  .ui.modal > .header {
    padding-right: 2.25rem; }
  .ui.modal > .close {
    top: 1.0535rem;
    right: 1rem;
    color: rgba(0, 0, 0, 0.87); } }

/* Mobile */
@media only screen and (max-width: 767px) {
  .ui.modal > .header {
    padding: 0.75rem 1rem !important;
    padding-right: 2.25rem !important; }
  .ui.modal > .content {
    display: block;
    padding: 1rem !important; }
  .ui.modal > .close {
    top: 0.5rem !important;
    right: 0.5rem !important; }
  .ui.modal .image.content {
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column; }
  .ui.modal .content > .image {
    display: block;
    max-width: 100%;
    margin: 0em auto !important;
    text-align: center;
    padding: 0rem 0rem 1rem !important; }
  .ui.modal .content > .description {
    display: block;
    width: 100% !important;
    margin: 0em !important;
    padding: 1rem 0rem !important;
    box-shadow: none; }
  .ui.modal > .content > .image > i.icon {
    font-size: 5rem;
    text-align: center; }
  .ui.modal > .actions {
    padding: 1rem 1rem 0rem !important; }
  .ui.modal .actions > .buttons, .ui.modal .actions > .button {
    margin-bottom: 1rem; }
  /*rtl:ignore*/
  /*rtl:ignore*/
  /* Let Buttons Stack */ }

/*--------------
    Coupling
---------------*/
/*******************************
             Types
*******************************/
/* Tablet and Mobile */
@media only screen and (max-width: 991px) {
  .ui.basic.modal > .close {
    color: #FFFFFF; } }

/*******************************
             States
*******************************/
/*******************************
           Variations
*******************************/
/*--------------
    Scrolling
---------------*/
/* A modal that cannot fit on the page */
.scrolling.dimmable.dimmed {
  overflow: hidden; }
  .scrolling.dimmable.dimmed > .dimmer {
    overflow: auto;
    -webkit-overflow-scrolling: touch; }

.scrolling.dimmable > .dimmer {
  position: fixed; }

.modals.dimmer .ui.scrolling.modal {
  position: static !important;
  margin: 3.5rem auto !important; }

/* undetached scrolling */
.scrolling.undetached.dimmable.dimmed {
  overflow: auto;
  -webkit-overflow-scrolling: touch; }
  .scrolling.undetached.dimmable.dimmed > .dimmer {
    overflow: hidden; }

.scrolling.undetached.dimmable .ui.scrolling.modal {
  position: absolute;
  left: 50%;
  margin-top: 3.5rem !important; }

/* Coupling with Sidebar */
.undetached.dimmable.dimmed > .pusher {
  z-index: auto; }

@media only screen and (max-width: 991px) {
  .modals.dimmer .ui.scrolling.modal {
    margin-top: 1rem !important;
    margin-bottom: 1rem !important; } }

/* Scrolling Content */
.ui.modal .scrolling.content {
  max-height: calc(70vh);
  overflow: auto; }

.ui.fullscreen.modal {
  width: 95% !important;
  left: 2.5% !important;
  margin: 1em auto; }

.ui.fullscreen.scrolling.modal {
  left: 0em !important; }

.ui.fullscreen.modal > .header {
  padding-right: 2.25rem; }

.ui.fullscreen.modal > .close {
  top: 1.0535rem;
  right: 1rem;
  color: rgba(0, 0, 0, 0.87); }

.ui.modal {
  font-size: 1rem; }

.ui.mini.modal > .header:not(.ui) {
  font-size: 1.3em; }

.ui.small.modal > .header:not(.ui) {
  font-size: 1.3em;
  font-size: 1.3em; }

.ui.large.modal > .header {
  font-size: 1.6em; }

/*--------------
   Full Screen
---------------*/
/*--------------
      Size
---------------*/
/* Mini */
/* Mini Modal Width */
@media only screen and (max-width: 767px) {
  .ui.mini.modal {
    width: 95%;
    margin: 0em 0em 0em -47.5%; } }

@media only screen and (min-width: 768px) {
  .ui.mini.modal {
    width: 35.2%;
    margin: 0em 0em 0em -17.6%; } }

@media only screen and (min-width: 992px) {
  .ui.mini.modal {
    width: 340px;
    margin: 0em 0em 0em -170px; } }

@media only screen and (min-width: 1200px) {
  .ui.mini.modal {
    width: 360px;
    margin: 0em 0em 0em -180px; } }

@media only screen and (min-width: 1920px) {
  .ui.mini.modal {
    width: 380px;
    margin: 0em 0em 0em -190px; } }

/* mini */
/* Tiny Modal Width */
@media only screen and (max-width: 767px) {
  .ui.tiny.modal {
    width: 95%;
    margin: 0em 0em 0em -47.5%; } }

@media only screen and (min-width: 768px) {
  .ui.tiny.modal {
    width: 52.8%;
    margin: 0em 0em 0em -26.4%; } }

@media only screen and (min-width: 992px) {
  .ui.tiny.modal {
    width: 510px;
    margin: 0em 0em 0em -255px; } }

@media only screen and (min-width: 1200px) {
  .ui.tiny.modal {
    width: 540px;
    margin: 0em 0em 0em -270px; } }

@media only screen and (min-width: 1920px) {
  .ui.tiny.modal {
    width: 570px;
    margin: 0em 0em 0em -285px; } }

/* Small */
/* Small Modal Width */
@media only screen and (max-width: 767px) {
  .ui.small.modal {
    width: 95%;
    margin: 0em 0em 0em -47.5%; } }

@media only screen and (min-width: 768px) {
  .ui.small.modal {
    width: 70.4%;
    margin: 0em 0em 0em -35.2%; } }

@media only screen and (min-width: 992px) {
  .ui.small.modal {
    width: 680px;
    margin: 0em 0em 0em -340px; } }

@media only screen and (min-width: 1200px) {
  .ui.small.modal {
    width: 720px;
    margin: 0em 0em 0em -360px; } }

@media only screen and (min-width: 1920px) {
  .ui.small.modal {
    width: 760px;
    margin: 0em 0em 0em -380px; } }

/* Large Modal Width */
@media only screen and (max-width: 767px) {
  .ui.large.modal {
    width: 95%;
    margin: 0em 0em 0em -47.5%; } }

@media only screen and (min-width: 768px) {
  .ui.large.modal {
    width: 88%;
    margin: 0em 0em 0em -44%; } }

@media only screen and (min-width: 992px) {
  .ui.large.modal {
    width: 1020px;
    margin: 0em 0em 0em -510px; } }

@media only screen and (min-width: 1200px) {
  .ui.large.modal {
    width: 1080px;
    margin: 0em 0em 0em -540px; } }

@media only screen and (min-width: 1920px) {
  .ui.large.modal {
    width: 1140px;
    margin: 0em 0em 0em -570px; } }

/*!
 * # Semantic UI 2.2.12 - Nag
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Nag
*******************************/
.ui.nag {
  display: none;
  opacity: 0.95;
  position: relative;
  top: 0em;
  left: 0px;
  z-index: 999;
  min-height: 0em;
  width: 100%;
  margin: 0em;
  padding: 0.75em 1em;
  background: #555555;
  box-shadow: 0px 1px 2px 0px rgba(0, 0, 0, 0.2);
  font-size: 1rem;
  text-align: center;
  color: rgba(0, 0, 0, 0.87);
  border-radius: 0em 0em 0.28571429rem 0.28571429rem;
  -webkit-transition: 0.2s background ease;
  transition: 0.2s background ease; }

a.ui.nag {
  cursor: pointer; }

.ui.nag > .title {
  display: inline-block;
  margin: 0em 0.5em;
  color: #FFFFFF; }

.ui.nag > .close.icon {
  cursor: pointer;
  opacity: 0.4;
  position: absolute;
  top: 50%;
  right: 1em;
  font-size: 1em;
  margin: -0.5em 0em 0em;
  color: #FFFFFF;
  -webkit-transition: opacity 0.2s ease;
  transition: opacity 0.2s ease; }

.ui.nag:hover {
  background: #555555;
  opacity: 1; }

.ui.nag .close:hover {
  opacity: 1; }

.ui.overlay.nag {
  position: absolute;
  display: block; }

.ui.fixed.nag {
  position: fixed; }

.ui.bottom.nags, .ui.bottom.nag {
  border-radius: 0.28571429rem 0.28571429rem 0em 0em;
  top: auto;
  bottom: 0em; }

.ui.inverted.nags .nag, .ui.inverted.nag {
  background-color: #F3F4F5;
  color: rgba(0, 0, 0, 0.85); }

.ui.inverted.nags .nag .close, .ui.inverted.nags .nag .title {
  color: rgba(0, 0, 0, 0.4); }

.ui.inverted.nag .close, .ui.inverted.nag .title {
  color: rgba(0, 0, 0, 0.4); }

.ui.nags .nag {
  border-radius: 0em !important; }
  .ui.nags .nag:last-child {
    border-radius: 0em 0em 0.28571429rem 0.28571429rem; }

.ui.bottom.nags .nag:last-child {
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }

/*!
 * # Semantic UI 2.2.12 - Popup
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Popup
*******************************/
.ui.popup {
  display: none;
  position: absolute;
  top: 0px;
  right: 0px;
  /* Fixes content being squished when inline (moz only) */
  min-width: -webkit-min-content;
  min-width: -moz-min-content;
  min-width: min-content;
  z-index: 1900;
  border: 1px solid #D4D4D5;
  line-height: 1.4285em;
  max-width: 250px;
  background: #FFFFFF;
  padding: 0.833em 1em;
  font-weight: normal;
  font-style: normal;
  color: rgba(0, 0, 0, 0.87);
  border-radius: 0.28571429rem;
  box-shadow: 0px 2px 4px 0px rgba(34, 36, 38, 0.12), 0px 2px 10px 0px rgba(34, 36, 38, 0.15); }
  .ui.popup > .header {
    padding: 0em;
    font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
    font-size: 1.14285714em;
    line-height: 1.2;
    font-weight: bold; }
    .ui.popup > .header + .content {
      padding-top: 0.5em; }
  .ui.popup:before {
    position: absolute;
    content: '';
    width: 0.71428571em;
    height: 0.71428571em;
    background: #FFFFFF;
    -webkit-transform: rotate(45deg);
    transform: rotate(45deg);
    z-index: 2;
    box-shadow: 1px 1px 0px 0px #bababc; }

/*******************************
            Types
*******************************/
/*--------------
    Tooltip
---------------*/
/* Content */
[data-tooltip] {
  position: relative; }
  [data-tooltip]:before {
    pointer-events: none;
    position: absolute;
    content: '';
    font-size: 1rem;
    width: 0.71428571em;
    height: 0.71428571em;
    background: #FFFFFF;
    -webkit-transform: rotate(45deg);
    transform: rotate(45deg);
    z-index: 2;
    box-shadow: 1px 1px 0px 0px #bababc; }
  [data-tooltip]:after {
    pointer-events: none;
    content: attr(data-tooltip);
    position: absolute;
    text-transform: none;
    text-align: left;
    white-space: nowrap;
    font-size: 1rem;
    border: 1px solid #D4D4D5;
    line-height: 1.4285em;
    max-width: none;
    background: #FFFFFF;
    padding: 0.833em 1em;
    font-weight: normal;
    font-style: normal;
    color: rgba(0, 0, 0, 0.87);
    border-radius: 0.28571429rem;
    box-shadow: 0px 2px 4px 0px rgba(34, 36, 38, 0.12), 0px 2px 10px 0px rgba(34, 36, 38, 0.15);
    z-index: 1; }
  [data-tooltip]:not([data-position]):before {
    top: auto;
    right: auto;
    bottom: 100%;
    left: 50%;
    background: #FFFFFF;
    margin-left: -0.07142857rem;
    margin-bottom: 0.14285714rem; }
  [data-tooltip]:not([data-position]):after {
    left: 50%;
    -webkit-transform: translateX(-50%);
    transform: translateX(-50%);
    bottom: 100%;
    margin-bottom: 0.5em; }
  [data-tooltip]:before, [data-tooltip]:after {
    pointer-events: none;
    visibility: hidden; }
  [data-tooltip]:before {
    opacity: 0;
    -webkit-transform: rotate(45deg) scale(0) !important;
    transform: rotate(45deg) scale(0) !important;
    -webkit-transform-origin: center top;
    transform-origin: center top;
    -webkit-transition: all 0.1s ease;
    transition: all 0.1s ease; }
  [data-tooltip]:after {
    opacity: 1;
    -webkit-transform-origin: center bottom;
    transform-origin: center bottom;
    -webkit-transition: all 0.1s ease;
    transition: all 0.1s ease; }
  [data-tooltip]:hover:before, [data-tooltip]:hover:after {
    visibility: visible;
    pointer-events: auto; }
  [data-tooltip]:hover:before {
    -webkit-transform: rotate(45deg) scale(1) !important;
    transform: rotate(45deg) scale(1) !important;
    opacity: 1; }
  [data-tooltip]:after, [data-tooltip][data-position="top center"]:after, [data-tooltip][data-position="bottom center"]:after {
    -webkit-transform: translateX(-50%) scale(0) !important;
    transform: translateX(-50%) scale(0) !important; }
  [data-tooltip]:hover:after, [data-tooltip][data-position="bottom center"]:hover:after {
    -webkit-transform: translateX(-50%) scale(1) !important;
    transform: translateX(-50%) scale(1) !important; }
  [data-tooltip][data-position="left center"]:after, [data-tooltip][data-position="right center"]:after {
    -webkit-transform: translateY(-50%) scale(0) !important;
    transform: translateY(-50%) scale(0) !important; }
  [data-tooltip][data-position="left center"]:hover:after, [data-tooltip][data-position="right center"]:hover:after {
    -webkit-transform: translateY(-50%) scale(1) !important;
    transform: translateY(-50%) scale(1) !important; }
  [data-tooltip][data-position="top left"]:after, [data-tooltip][data-position="top right"]:after, [data-tooltip][data-position="bottom left"]:after, [data-tooltip][data-position="bottom right"]:after {
    -webkit-transform: scale(0) !important;
    transform: scale(0) !important; }
  [data-tooltip][data-position="top left"]:hover:after, [data-tooltip][data-position="top right"]:hover:after, [data-tooltip][data-position="bottom left"]:hover:after, [data-tooltip][data-position="bottom right"]:hover:after {
    -webkit-transform: scale(1) !important;
    transform: scale(1) !important; }
  [data-tooltip][data-inverted]:before {
    box-shadow: none !important;
    background: #1B1C1D; }
  [data-tooltip][data-inverted]:after {
    background: #1B1C1D;
    color: #FFFFFF;
    border: none;
    box-shadow: none; }
    [data-tooltip][data-inverted]:after .header {
      background-color: none;
      color: #FFFFFF; }

/* Arrow */
/* Popup */
/* Default Position (Top Center) */
/* Animation */
/* Animation Position */
/*--------------
    Inverted
---------------*/
/* Arrow */
/* Arrow Position */
/* Popup  */
/*--------------
    Position
---------------*/
/* Top Center */
[data-position="top center"][data-tooltip]:after {
  top: auto;
  right: auto;
  left: 50%;
  bottom: 100%;
  -webkit-transform: translateX(-50%);
  transform: translateX(-50%);
  margin-bottom: 0.5em; }

[data-position="top center"][data-tooltip]:before {
  top: auto;
  right: auto;
  bottom: 100%;
  left: 50%;
  background: #FFFFFF;
  margin-left: -0.07142857rem;
  margin-bottom: 0.14285714rem; }

/* Top Left */
[data-position="top left"][data-tooltip]:after {
  top: auto;
  right: auto;
  left: 0;
  bottom: 100%;
  margin-bottom: 0.5em; }

[data-position="top left"][data-tooltip]:before {
  top: auto;
  right: auto;
  bottom: 100%;
  left: 1em;
  margin-left: -0.07142857rem;
  margin-bottom: 0.14285714rem; }

/* Top Right */
[data-position="top right"][data-tooltip]:after {
  top: auto;
  left: auto;
  right: 0;
  bottom: 100%;
  margin-bottom: 0.5em; }

[data-position="top right"][data-tooltip]:before {
  top: auto;
  left: auto;
  bottom: 100%;
  right: 1em;
  margin-left: -0.07142857rem;
  margin-bottom: 0.14285714rem; }

/* Bottom Center */
[data-position="bottom center"][data-tooltip]:after {
  bottom: auto;
  right: auto;
  left: 50%;
  top: 100%;
  -webkit-transform: translateX(-50%);
  transform: translateX(-50%);
  margin-top: 0.5em; }

[data-position="bottom center"][data-tooltip]:before {
  bottom: auto;
  right: auto;
  top: 100%;
  left: 50%;
  margin-left: -0.07142857rem;
  margin-top: 0.14285714rem; }

/* Bottom Left */
[data-position="bottom left"][data-tooltip]:after {
  left: 0;
  top: 100%;
  margin-top: 0.5em; }

[data-position="bottom left"][data-tooltip]:before {
  bottom: auto;
  right: auto;
  top: 100%;
  left: 1em;
  margin-left: -0.07142857rem;
  margin-top: 0.14285714rem; }

/* Bottom Right */
[data-position="bottom right"][data-tooltip]:after {
  right: 0;
  top: 100%;
  margin-top: 0.5em; }

[data-position="bottom right"][data-tooltip]:before {
  bottom: auto;
  left: auto;
  top: 100%;
  right: 1em;
  margin-left: -0.14285714rem;
  margin-top: 0.07142857rem; }

/* Left Center */
[data-position="left center"][data-tooltip]:after {
  right: 100%;
  top: 50%;
  margin-right: 0.5em;
  -webkit-transform: translateY(-50%);
  transform: translateY(-50%); }

[data-position="left center"][data-tooltip]:before {
  right: 100%;
  top: 50%;
  margin-top: -0.14285714rem;
  margin-right: -0.07142857rem; }

/* Right Center */
[data-position="right center"][data-tooltip]:after {
  left: 100%;
  top: 50%;
  margin-left: 0.5em;
  -webkit-transform: translateY(-50%);
  transform: translateY(-50%); }

[data-position="right center"][data-tooltip]:before {
  left: 100%;
  top: 50%;
  margin-top: -0.07142857rem;
  margin-left: 0.14285714rem; }

/* Arrow */
[data-position~="bottom"][data-tooltip]:before {
  background: #FFFFFF;
  box-shadow: -1px -1px 0px 0px #bababc; }

[data-position="left center"][data-tooltip]:before {
  background: #FFFFFF;
  box-shadow: 1px -1px 0px 0px #bababc; }

[data-position="right center"][data-tooltip]:before {
  background: #FFFFFF;
  box-shadow: -1px 1px 0px 0px #bababc; }

[data-position~="top"][data-tooltip]:before {
  background: #FFFFFF; }

/* Inverted Arrow Color */
[data-inverted][data-position~="bottom"][data-tooltip]:before {
  background: #1B1C1D;
  box-shadow: -1px -1px 0px 0px #bababc; }

[data-inverted][data-position="left center"][data-tooltip]:before {
  background: #1B1C1D;
  box-shadow: 1px -1px 0px 0px #bababc; }

[data-inverted][data-position="right center"][data-tooltip]:before {
  background: #1B1C1D;
  box-shadow: -1px 1px 0px 0px #bababc; }

[data-inverted][data-position~="top"][data-tooltip]:before {
  background: #1B1C1D; }

[data-position~="bottom"][data-tooltip]:before {
  -webkit-transform-origin: center bottom;
  transform-origin: center bottom; }

[data-position~="bottom"][data-tooltip]:after {
  -webkit-transform-origin: center top;
  transform-origin: center top; }

[data-position="left center"][data-tooltip]:before {
  -webkit-transform-origin: top center;
  transform-origin: top center; }

[data-position="left center"][data-tooltip]:after {
  -webkit-transform-origin: right center;
  transform-origin: right center; }

[data-position="right center"][data-tooltip]:before {
  -webkit-transform-origin: right center;
  transform-origin: right center; }

[data-position="right center"][data-tooltip]:after {
  -webkit-transform-origin: left center;
  transform-origin: left center; }

/*--------------
     Spacing
---------------*/
.ui.popup {
  margin: 0em; }

.ui.top.popup {
  margin: 0em 0em 0.71428571em; }

.ui.top.left.popup {
  -webkit-transform-origin: left bottom;
  transform-origin: left bottom; }

.ui.top.center.popup {
  -webkit-transform-origin: center bottom;
  transform-origin: center bottom; }

.ui.top.right.popup {
  -webkit-transform-origin: right bottom;
  transform-origin: right bottom; }

.ui.left.center.popup {
  margin: 0em 0.71428571em 0em 0em;
  -webkit-transform-origin: right 50%;
  transform-origin: right 50%; }

.ui.right.center.popup {
  margin: 0em 0em 0em 0.71428571em;
  -webkit-transform-origin: left 50%;
  transform-origin: left 50%; }

.ui.bottom.popup {
  margin: 0.71428571em 0em 0em; }

.ui.bottom.left.popup {
  -webkit-transform-origin: left top;
  transform-origin: left top; }

.ui.bottom.center.popup {
  -webkit-transform-origin: center top;
  transform-origin: center top; }

.ui.bottom.right.popup {
  -webkit-transform-origin: right top;
  transform-origin: right top; }

.ui.bottom.center.popup:before {
  margin-left: -0.30714286em;
  top: -0.30714286em;
  left: 50%;
  right: auto;
  bottom: auto;
  box-shadow: -1px -1px 0px 0px #bababc; }

.ui.bottom.left.popup {
  margin-left: 0em; }
  .ui.bottom.left.popup:before {
    top: -0.30714286em;
    left: 1em;
    right: auto;
    bottom: auto;
    margin-left: 0em;
    box-shadow: -1px -1px 0px 0px #bababc; }

.ui.bottom.right.popup {
  margin-right: 0em; }
  .ui.bottom.right.popup:before {
    top: -0.30714286em;
    right: 1em;
    bottom: auto;
    left: auto;
    margin-left: 0em;
    box-shadow: -1px -1px 0px 0px #bababc; }

.ui.top.center.popup:before {
  top: auto;
  right: auto;
  bottom: -0.30714286em;
  left: 50%;
  margin-left: -0.30714286em; }

.ui.top.left.popup {
  margin-left: 0em; }
  .ui.top.left.popup:before {
    bottom: -0.30714286em;
    left: 1em;
    top: auto;
    right: auto;
    margin-left: 0em; }

.ui.top.right.popup {
  margin-right: 0em; }
  .ui.top.right.popup:before {
    bottom: -0.30714286em;
    right: 1em;
    top: auto;
    left: auto;
    margin-left: 0em; }

.ui.left.center.popup:before {
  top: 50%;
  right: -0.30714286em;
  bottom: auto;
  left: auto;
  margin-top: -0.30714286em;
  box-shadow: 1px -1px 0px 0px #bababc; }

.ui.right.center.popup:before {
  top: 50%;
  left: -0.30714286em;
  bottom: auto;
  right: auto;
  margin-top: -0.30714286em;
  box-shadow: -1px 1px 0px 0px #bababc; }

.ui.bottom.popup:before, .ui.right.center.popup:before, .ui.left.center.popup:before, .ui.top.popup:before {
  background: #FFFFFF; }

.ui.inverted.bottom.popup:before, .ui.inverted.right.center.popup:before, .ui.inverted.left.center.popup:before, .ui.inverted.top.popup:before {
  background: #1B1C1D; }

.ui.popup > .ui.grid:not(.padded) {
  width: calc(100% + 1.75rem);
  margin: -0.7rem -0.875rem; }

.ui.loading.popup {
  display: block;
  visibility: hidden;
  z-index: -1; }

.ui.animating.popup {
  display: block; }

.ui.visible.popup {
  display: block;
  -webkit-transform: translateZ(0px);
  transform: translateZ(0px);
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden; }

.ui.basic.popup:before {
  display: none; }

.ui.wide.popup {
  max-width: 350px; }

.ui[class*="very wide"].popup {
  max-width: 550px; }

.ui.fluid.popup {
  width: 100%;
  max-width: none; }

.ui.inverted.popup {
  background: #1B1C1D;
  color: #FFFFFF;
  border: none;
  box-shadow: none; }
  .ui.inverted.popup .header {
    background-color: none;
    color: #FFFFFF; }
  .ui.inverted.popup:before {
    background-color: #1B1C1D;
    box-shadow: none !important; }

.ui.flowing.popup {
  max-width: none; }

.ui.mini.popup {
  font-size: 0.78571429rem; }

.ui.tiny.popup {
  font-size: 0.85714286rem; }

.ui.small.popup {
  font-size: 0.92857143rem; }

.ui.popup {
  font-size: 1rem; }

.ui.large.popup {
  font-size: 1.14285714rem; }

.ui.huge.popup {
  font-size: 1.42857143rem; }

@media only screen and (max-width: 767px) {
  .ui.wide.popup, .ui[class*="very wide"].popup {
    max-width: 250px; } }

/*!
 * # Semantic UI 2.2.12 - Progress Bar
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Progress
*******************************/
.ui.progress {
  position: relative;
  display: block;
  max-width: 100%;
  border: none;
  margin: 1em 0em 2.5em;
  box-shadow: none;
  background: rgba(0, 0, 0, 0.1);
  padding: 0em;
  border-radius: 0.28571429rem; }
  .ui.progress:first-child {
    margin: 0em 0em 2.5em; }
  .ui.progress:last-child {
    margin: 0em 0em 1.5em; }
  .ui.progress .bar {
    display: block;
    line-height: 1;
    position: relative;
    width: 0%;
    min-width: 2em;
    background: #888888;
    border-radius: 0.28571429rem;
    -webkit-transition: width 0.1s ease, background-color 0.1s ease;
    transition: width 0.1s ease, background-color 0.1s ease; }
    .ui.progress .bar > .progress {
      white-space: nowrap;
      position: absolute;
      width: auto;
      font-size: 0.92857143em;
      top: 50%;
      right: 0.5em;
      left: auto;
      bottom: auto;
      color: rgba(255, 255, 255, 0.7);
      text-shadow: none;
      margin-top: -0.5em;
      font-weight: bold;
      text-align: left; }
  .ui.progress > .label {
    position: absolute;
    width: 100%;
    font-size: 1em;
    top: 100%;
    right: auto;
    left: 0%;
    bottom: auto;
    color: rgba(0, 0, 0, 0.87);
    font-weight: bold;
    text-shadow: none;
    margin-top: 0.2em;
    text-align: center;
    -webkit-transition: color 0.4s ease;
    transition: color 0.4s ease; }

.ui.indicating.progress[data-percent^="1"] .bar, .ui.indicating.progress[data-percent^="2"] .bar {
  background-color: #D95C5C; }

.ui.indicating.progress[data-percent^="3"] .bar {
  background-color: #EFBC72; }

.ui.indicating.progress[data-percent^="4"] .bar, .ui.indicating.progress[data-percent^="5"] .bar {
  background-color: #E6BB48; }

.ui.indicating.progress[data-percent^="6"] .bar {
  background-color: #DDC928; }

.ui.indicating.progress[data-percent^="7"] .bar, .ui.indicating.progress[data-percent^="8"] .bar {
  background-color: #B4D95C; }

.ui.indicating.progress[data-percent^="9"] .bar, .ui.indicating.progress[data-percent^="100"] .bar {
  background-color: #66DA81; }

.ui.indicating.progress[data-percent^="1"] .label, .ui.indicating.progress[data-percent^="2"] .label, .ui.indicating.progress[data-percent^="3"] .label, .ui.indicating.progress[data-percent^="4"] .label, .ui.indicating.progress[data-percent^="5"] .label, .ui.indicating.progress[data-percent^="6"] .label, .ui.indicating.progress[data-percent^="7"] .label, .ui.indicating.progress[data-percent^="8"] .label, .ui.indicating.progress[data-percent^="9"] .label, .ui.indicating.progress[data-percent^="100"] .label {
  color: rgba(0, 0, 0, 0.87); }

.ui.indicating.progress[data-percent="1"] .bar, .ui.indicating.progress[data-percent="2"] .bar, .ui.indicating.progress[data-percent="3"] .bar, .ui.indicating.progress[data-percent="4"] .bar, .ui.indicating.progress[data-percent="5"] .bar, .ui.indicating.progress[data-percent="6"] .bar, .ui.indicating.progress[data-percent="7"] .bar, .ui.indicating.progress[data-percent="8"] .bar, .ui.indicating.progress[data-percent="9"] .bar {
  background-color: #D95C5C; }

.ui.indicating.progress[data-percent="1"] .label, .ui.indicating.progress[data-percent="2"] .label, .ui.indicating.progress[data-percent="3"] .label, .ui.indicating.progress[data-percent="4"] .label, .ui.indicating.progress[data-percent="5"] .label, .ui.indicating.progress[data-percent="6"] .label, .ui.indicating.progress[data-percent="7"] .label, .ui.indicating.progress[data-percent="8"] .label, .ui.indicating.progress[data-percent="9"] .label {
  color: rgba(0, 0, 0, 0.87); }

.ui.indicating.progress.success .label {
  color: #1A531B; }

.ui.progress.success .bar {
  background-color: #21BA45 !important;
  -webkit-animation: none !important;
  animation: none !important; }
  .ui.progress.success .bar::after {
    -webkit-animation: none !important;
    animation: none !important; }

.ui.progress.success > .label {
  color: #1A531B; }

.ui.progress.warning .bar {
  background-color: #F2C037 !important;
  -webkit-animation: none !important;
  animation: none !important; }
  .ui.progress.warning .bar::after {
    -webkit-animation: none !important;
    animation: none !important; }

.ui.progress.warning > .label {
  color: #794B02; }

.ui.progress.error .bar {
  background-color: #DB2828 !important;
  -webkit-animation: none !important;
  animation: none !important; }
  .ui.progress.error .bar::after {
    -webkit-animation: none !important;
    animation: none !important; }

.ui.progress.error > .label {
  color: #912D2B; }

.ui.active.progress .bar {
  position: relative;
  min-width: 2em; }
  .ui.active.progress .bar::after {
    content: '';
    opacity: 0;
    position: absolute;
    top: 0px;
    left: 0px;
    right: 0px;
    bottom: 0px;
    background: #FFFFFF;
    border-radius: 0.28571429rem;
    -webkit-animation: progress-active 2s ease infinite;
    animation: progress-active 2s ease infinite; }

.ui.disabled.progress {
  opacity: 0.35; }
  .ui.disabled.progress .bar {
    -webkit-animation: none !important;
    animation: none !important; }
    .ui.disabled.progress .bar::after {
      -webkit-animation: none !important;
      animation: none !important; }

.ui.inverted.progress {
  background: rgba(255, 255, 255, 0.08);
  border: none; }
  .ui.inverted.progress .bar {
    background: #888888; }
    .ui.inverted.progress .bar > .progress {
      color: #F9FAFB; }
  .ui.inverted.progress > .label {
    color: #FFFFFF; }
  .ui.inverted.progress.success > .label {
    color: #21BA45; }
  .ui.inverted.progress.warning > .label {
    color: #F2C037; }
  .ui.inverted.progress.error > .label {
    color: #DB2828; }

.ui.progress.attached {
  background: transparent;
  position: relative;
  border: none;
  margin: 0em;
  display: block;
  height: 0.2rem;
  padding: 0px;
  overflow: hidden;
  border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
  .ui.progress.attached .bar {
    display: block;
    height: 0.2rem;
    padding: 0px;
    overflow: hidden;
    border-radius: 0em 0em 0.28571429rem 0.28571429rem;
    border-radius: 0em; }

.ui.progress.top.attached {
  top: 0px;
  border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
  .ui.progress.top.attached .bar {
    top: 0px;
    border-radius: 0.28571429rem 0.28571429rem 0em 0em;
    border-radius: 0em; }

.ui.segment > .ui.attached.progress, .ui.card > .ui.attached.progress {
  position: absolute;
  top: auto;
  left: 0;
  bottom: 100%;
  width: 100%; }

.ui.segment > .ui.bottom.attached.progress, .ui.card > .ui.bottom.attached.progress {
  top: 100%;
  bottom: auto; }

.ui.red.progress .bar {
  background-color: #DB2828; }

.ui.red.inverted.progress .bar {
  background-color: #FF695E; }

.ui.orange.progress .bar {
  background-color: #fc7831; }

.ui.orange.inverted.progress .bar {
  background-color: #fc7831; }

.ui.yellow.progress .bar {
  background-color: #FBBD08; }

.ui.yellow.inverted.progress .bar {
  background-color: #FFE21F; }

.ui.olive.progress .bar {
  background-color: #B5CC18; }

.ui.olive.inverted.progress .bar {
  background-color: #D9E778; }

.ui.green.progress .bar {
  background-color: #21BA45; }

.ui.green.inverted.progress .bar {
  background-color: #2ECC40; }

.ui.teal.progress .bar {
  background-color: #00B5AD; }

.ui.teal.inverted.progress .bar {
  background-color: #6DFFFF; }

.ui.blue.progress .bar {
  background-color: #4c8bd6; }

.ui.blue.inverted.progress .bar {
  background-color: #4c8bd6; }

.ui.violet.progress .bar {
  background-color: #6435C9; }

.ui.violet.inverted.progress .bar {
  background-color: #A291FB; }

.ui.purple.progress .bar {
  background-color: #A333C8; }

.ui.purple.inverted.progress .bar {
  background-color: #DC73FF; }

.ui.pink.progress .bar {
  background-color: #E03997; }

.ui.pink.inverted.progress .bar {
  background-color: #FF8EDF; }

.ui.brown.progress .bar {
  background-color: #A5673F; }

.ui.brown.inverted.progress .bar {
  background-color: #D67C1C; }

.ui.grey.progress .bar {
  background-color: #767676; }

.ui.grey.inverted.progress .bar {
  background-color: #DCDDDE; }

.ui.black.progress .bar {
  background-color: #1B1C1D; }

.ui.black.inverted.progress .bar {
  background-color: #545454; }

.ui.tiny.progress {
  font-size: 0.85714286rem; }
  .ui.tiny.progress .bar {
    height: 0.5em; }

.ui.small.progress {
  font-size: 0.92857143rem; }
  .ui.small.progress .bar {
    height: 1em; }

.ui.progress {
  font-size: 1rem; }
  .ui.progress .bar {
    height: 1.75em; }

.ui.large.progress {
  font-size: 1.14285714rem; }
  .ui.large.progress .bar {
    height: 2.5em; }

.ui.big.progress {
  font-size: 1.28571429rem; }
  .ui.big.progress .bar {
    height: 3.5em; }

@-webkit-keyframes progress-active {
  0% {
    opacity: 0.3;
    width: 0; }
  100% {
    opacity: 0;
    width: 100%; } }

@keyframes progress-active {
  0% {
    opacity: 0.3;
    width: 0; }
  100% {
    opacity: 0;
    width: 100%; } }

/*!
 * # Semantic UI 2.2.12 - Rating
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
           Rating
*******************************/
.ui.rating {
  display: -webkit-inline-box;
  display: -ms-inline-flexbox;
  display: inline-flex;
  white-space: nowrap;
  vertical-align: baseline; }
  .ui.rating:last-child {
    margin-right: 0em; }
  .ui.rating .icon {
    padding: 0em;
    margin: 0em;
    text-align: center;
    font-weight: normal;
    font-style: normal;
    -webkit-box-flex: 1;
    -ms-flex: 1 0 auto;
    flex: 1 0 auto;
    cursor: pointer;
    width: 1.25em;
    height: auto;
    -webkit-transition: opacity 0.1s ease, background 0.1s ease, text-shadow 0.1s ease, color 0.1s ease;
    transition: opacity 0.1s ease, background 0.1s ease, text-shadow 0.1s ease, color 0.1s ease;
    background: transparent;
    color: rgba(0, 0, 0, 0.15); }
  .ui.rating .active.icon {
    background: transparent;
    color: rgba(0, 0, 0, 0.85); }
  .ui.rating .icon.selected {
    background: transparent;
    color: rgba(0, 0, 0, 0.87); }
    .ui.rating .icon.selected.active {
      background: transparent;
      color: rgba(0, 0, 0, 0.87); }

.ui.star.rating .icon {
  width: 1.25em;
  height: auto;
  background: transparent;
  color: rgba(0, 0, 0, 0.15);
  text-shadow: none; }

.ui.star.rating .active.icon {
  background: transparent !important;
  color: #FFE623 !important;
  text-shadow: 0px -1px 0px #DDC507, -1px 0px 0px #DDC507, 0px 1px 0px #DDC507, 1px 0px 0px #DDC507 !important; }

.ui.star.rating .icon.selected {
  background: transparent !important;
  color: #FFCC00 !important;
  text-shadow: 0px -1px 0px #E6A200, -1px 0px 0px #E6A200, 0px 1px 0px #E6A200, 1px 0px 0px #E6A200 !important; }
  .ui.star.rating .icon.selected.active {
    background: transparent !important;
    color: #FFCC00 !important;
    text-shadow: 0px -1px 0px #E6A200, -1px 0px 0px #E6A200, 0px 1px 0px #E6A200, 1px 0px 0px #E6A200 !important; }

.ui.heart.rating .icon {
  width: 1.4em;
  height: auto;
  background: transparent;
  color: rgba(0, 0, 0, 0.15);
  text-shadow: none !important; }

.ui.heart.rating .active.icon {
  background: transparent !important;
  color: #FF6D75 !important;
  text-shadow: 0px -1px 0px #CD0707, -1px 0px 0px #CD0707, 0px 1px 0px #CD0707, 1px 0px 0px #CD0707 !important; }

.ui.heart.rating .icon.selected {
  background: transparent !important;
  color: #FF3000 !important;
  text-shadow: 0px -1px 0px #AA0101, -1px 0px 0px #AA0101, 0px 1px 0px #AA0101, 1px 0px 0px #AA0101 !important; }
  .ui.heart.rating .icon.selected.active {
    background: transparent !important;
    color: #FF3000 !important;
    text-shadow: 0px -1px 0px #AA0101, -1px 0px 0px #AA0101, 0px 1px 0px #AA0101, 1px 0px 0px #AA0101 !important; }

.ui.disabled.rating .icon {
  cursor: default; }

.ui.rating.selected .active.icon, .ui.rating.selected .icon.selected {
  opacity: 1; }

.ui.rating .icon.selected {
  opacity: 1; }

.ui.mini.rating {
  font-size: 0.78571429rem; }

.ui.tiny.rating {
  font-size: 0.85714286rem; }

.ui.small.rating {
  font-size: 0.92857143rem; }

.ui.rating {
  font-size: 1rem; }

.ui.large.rating {
  font-size: 1.14285714rem; }

.ui.huge.rating {
  font-size: 1.42857143rem; }

.ui.massive.rating {
  font-size: 2rem; }

.ui.rating .icon {
  font-family: 'Rating';
  line-height: 1;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  font-weight: normal;
  font-style: normal;
  text-align: center; }
  .ui.rating .icon:before {
    content: '\f005'; }

.ui.rating .active.icon:before {
  content: '\f005'; }

.ui.star.rating .icon:before, .ui.star.rating .active.icon:before {
  content: '\f005'; }

.ui.star.rating .partial.icon {
  content: '\f005'; }
  .ui.star.rating .partial.icon:before {
    content: '\f006'; }

.ui.heart.rating .icon:before, .ui.heart.rating .active.icon:before {
  content: '\f004'; }

@font-face {
  font-family: 'Rating';
  src: url(data:application/x-font-ttf;charset=utf-8;base64, ) format("truetype"), url(data:application/font-woff;charset=utf-8;base64, ) format("woff");
  font-weight: normal;
  font-style: normal; }

/*!
 * # Semantic UI 2.2.12 - Search
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
             Search
*******************************/
.ui.search {
  position: relative; }
  .ui.search > .prompt {
    margin: 0em;
    outline: none;
    -webkit-appearance: none;
    -webkit-tap-highlight-color: rgba(255, 255, 255, 0);
    text-shadow: none;
    font-style: normal;
    font-weight: normal;
    line-height: 1.21428571em;
    padding: 0.67857143em 1em;
    font-size: 1em;
    background: #FFFFFF;
    border: 1px solid rgba(34, 36, 38, 0.15);
    color: rgba(0, 0, 0, 0.87);
    box-shadow: 0em 0em 0em 0em transparent inset;
    -webkit-transition: background-color 0.1s ease, color 0.1s ease, box-shadow 0.1s ease, border-color 0.1s ease;
    transition: background-color 0.1s ease, color 0.1s ease, box-shadow 0.1s ease, border-color 0.1s ease; }
  .ui.search .prompt {
    border-radius: 500rem; }
    .ui.search .prompt ~ .search.icon {
      cursor: pointer; }
  .ui.search > .results {
    display: none;
    position: absolute;
    top: 100%;
    left: 0%;
    -webkit-transform-origin: center top;
    transform-origin: center top;
    white-space: normal;
    background: #FFFFFF;
    margin-top: 0.5em;
    width: 18em;
    border-radius: 0.28571429rem;
    box-shadow: 0px 2px 4px 0px rgba(34, 36, 38, 0.12), 0px 2px 10px 0px rgba(34, 36, 38, 0.15);
    border: 1px solid #D4D4D5;
    z-index: 998; }
    .ui.search > .results > :first-child {
      border-radius: 0.28571429rem 0.28571429rem 0em 0em; }
    .ui.search > .results > :last-child {
      border-radius: 0em 0em 0.28571429rem 0.28571429rem; }
    .ui.search > .results .result {
      cursor: pointer;
      display: block;
      overflow: hidden;
      font-size: 1em;
      padding: 0.85714286em 1.14285714em;
      color: rgba(0, 0, 0, 0.87);
      line-height: 1.33;
      border-bottom: 1px solid rgba(34, 36, 38, 0.1); }
      .ui.search > .results .result:last-child {
        border-bottom: none !important; }
      .ui.search > .results .result .image {
        float: right;
        overflow: hidden;
        background: none;
        width: 5em;
        height: 3em;
        border-radius: 0.25em; }
        .ui.search > .results .result .image img {
          display: block;
          width: auto;
          height: 100%; }
        .ui.search > .results .result .image + .content {
          margin: 0em 6em 0em 0em; }
      .ui.search > .results .result .title {
        margin: -0.14285714em 0em 0em;
        font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
        font-weight: bold;
        font-size: 1em;
        color: rgba(0, 0, 0, 0.85); }
      .ui.search > .results .result .description {
        margin-top: 0;
        font-size: 0.92857143em;
        color: rgba(0, 0, 0, 0.4); }
      .ui.search > .results .result .price {
        float: right;
        color: #21BA45; }
    .ui.search > .results > .message {
      padding: 1em 1em; }
      .ui.search > .results > .message .header {
        font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
        font-size: 1rem;
        font-weight: bold;
        color: rgba(0, 0, 0, 0.87); }
      .ui.search > .results > .message .description {
        margin-top: 0.25rem;
        font-size: 1em;
        color: rgba(0, 0, 0, 0.87); }
    .ui.search > .results > .action {
      display: block;
      border-top: none;
      background: #F3F4F5;
      padding: 0.92857143em 1em;
      color: rgba(0, 0, 0, 0.87);
      font-weight: bold;
      text-align: center; }
  .ui.search > .prompt:focus {
    border-color: rgba(34, 36, 38, 0.35);
    background: #FFFFFF;
    color: rgba(0, 0, 0, 0.95); }

.ui.loading.search .input > i.icon:before {
  position: absolute;
  content: '';
  top: 50%;
  left: 50%;
  margin: -0.64285714em 0em 0em -0.64285714em;
  width: 1.28571429em;
  height: 1.28571429em;
  border-radius: 500rem;
  border: 0.2em solid rgba(0, 0, 0, 0.1); }

.ui.loading.search .input > i.icon:after {
  position: absolute;
  content: '';
  top: 50%;
  left: 50%;
  margin: -0.64285714em 0em 0em -0.64285714em;
  width: 1.28571429em;
  height: 1.28571429em;
  -webkit-animation: button-spin 0.6s linear;
  animation: button-spin 0.6s linear;
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite;
  border-radius: 500rem;
  border-color: #767676 transparent transparent;
  border-style: solid;
  border-width: 0.2em;
  box-shadow: 0px 0px 0px 1px transparent; }

.ui.search > .results .result:hover, .ui.category.search > .results .category .result:hover {
  background: #F9FAFB; }

.ui.search .action:hover {
  background: #E0E0E0; }

.ui.category.search > .results .category.active {
  background: #F3F4F5; }
  .ui.category.search > .results .category.active > .name {
    color: rgba(0, 0, 0, 0.87); }

.ui.search > .results .result.active, .ui.category.search > .results .category .result.active {
  position: relative;
  border-left-color: rgba(34, 36, 38, 0.1);
  background: #F3F4F5;
  box-shadow: none; }

.ui.search > .results .result.active .title, .ui.search > .results .result.active .description {
  color: rgba(0, 0, 0, 0.85); }

.ui.search.selection .prompt {
  border-radius: 0.28571429rem; }

.ui.search.selection > .icon.input > .remove.icon {
  pointer-events: none;
  position: absolute;
  left: auto;
  opacity: 0;
  color: '';
  top: 0em;
  right: 0em;
  -webkit-transition: color 0.1s ease, opacity 0.1s ease;
  transition: color 0.1s ease, opacity 0.1s ease; }

.ui.search.selection > .icon.input > .active.remove.icon {
  cursor: pointer;
  opacity: 0.8;
  pointer-events: auto; }

.ui.search.selection > .icon.input:not([class*="left icon"]) > .icon ~ .remove.icon {
  right: 1.85714em; }

.ui.search.selection > .icon.input > .remove.icon:hover {
  opacity: 1;
  color: #DB2828; }

.ui.category.search .results {
  width: 28em; }

.ui.category.search > .results .category {
  background: #F3F4F5;
  box-shadow: none;
  border-bottom: 1px solid rgba(34, 36, 38, 0.1);
  -webkit-transition: background 0.1s ease, border-color 0.1s ease;
  transition: background 0.1s ease, border-color 0.1s ease; }
  .ui.category.search > .results .category:last-child {
    border-bottom: none; }
  .ui.category.search > .results .category:first-child .name + .result {
    border-radius: 0em 0.28571429rem 0em 0em; }
  .ui.category.search > .results .category:last-child .result:last-child {
    border-radius: 0em 0em 0.28571429rem 0em; }
  .ui.category.search > .results .category .result {
    background: #FFFFFF;
    margin-left: 100px;
    border-left: 1px solid rgba(34, 36, 38, 0.15);
    border-bottom: 1px solid rgba(34, 36, 38, 0.1);
    -webkit-transition: background 0.1s ease, border-color 0.1s ease;
    transition: background 0.1s ease, border-color 0.1s ease;
    padding: 0.85714286em 1.14285714em; }
  .ui.category.search > .results .category:last-child .result:last-child {
    border-bottom: none; }
  .ui.category.search > .results .category > .name {
    width: 100px;
    background: transparent;
    font-family: sans-serif, "Helvetica Neue", Arial, Helvetica, sans-serif;
    font-size: 1em;
    float: 1em;
    float: left;
    padding: 0.4em 1em;
    font-weight: bold;
    color: rgba(0, 0, 0, 0.4); }

.ui[class*="left aligned"].search > .results {
  right: auto;
  left: 0%; }

.ui[class*="right aligned"].search > .results {
  right: 0%;
  left: auto; }

.ui.fluid.search .results {
  width: 100%; }

.ui.mini.search {
  font-size: 0.78571429em; }

.ui.small.search {
  font-size: 0.92857143em; }

.ui.search {
  font-size: 1em; }

.ui.large.search {
  font-size: 1.14285714em; }

.ui.big.search {
  font-size: 1.28571429em; }

.ui.huge.search {
  font-size: 1.42857143em; }

.ui.massive.search {
  font-size: 1.71428571em; }

/*!
 * # Semantic UI 2.2.12 - Shape
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
              Shape
*******************************/
.ui.shape {
  position: relative;
  vertical-align: top;
  display: inline-block;
  -webkit-perspective: 2000px;
  perspective: 2000px;
  -webkit-transition: left 0.6s ease-in-out, width 0.6s ease-in-out, height 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out;
  transition: left 0.6s ease-in-out, width 0.6s ease-in-out, height 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out;
  transition: transform 0.6s ease-in-out, left 0.6s ease-in-out, width 0.6s ease-in-out, height 0.6s ease-in-out;
  transition: transform 0.6s ease-in-out, left 0.6s ease-in-out, width 0.6s ease-in-out, height 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out; }
  .ui.shape .sides {
    -webkit-transform-style: preserve-3d;
    transform-style: preserve-3d; }
  .ui.shape .side {
    opacity: 1;
    width: 100%;
    margin: 0em !important;
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden;
    display: none; }
    .ui.shape .side * {
      -webkit-backface-visibility: visible !important;
      backface-visibility: visible !important; }

.ui.cube.shape .side {
  min-width: 15em;
  height: 15em;
  padding: 2em;
  background-color: #E6E6E6;
  color: rgba(0, 0, 0, 0.87);
  box-shadow: 0px 0px 2px rgba(0, 0, 0, 0.3); }
  .ui.cube.shape .side > .content {
    width: 100%;
    height: 100%;
    display: table;
    text-align: center;
    -webkit-user-select: text;
    -moz-user-select: text;
    -ms-user-select: text;
    user-select: text; }
    .ui.cube.shape .side > .content > div {
      display: table-cell;
      vertical-align: middle;
      font-size: 2em; }

.ui.text.shape.animating .sides {
  position: static; }

.ui.text.shape .side {
  white-space: nowrap; }
  .ui.text.shape .side > * {
    white-space: normal; }

.ui.loading.shape {
  position: absolute;
  top: -9999px;
  left: -9999px; }

.ui.shape .animating.side {
  position: absolute;
  top: 0px;
  left: 0px;
  display: block;
  z-index: 100; }

.ui.shape .hidden.side {
  opacity: 0.6; }

.ui.shape.animating .sides {
  position: absolute;
  -webkit-transition: left 0.6s ease-in-out, width 0.6s ease-in-out, height 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out;
  transition: left 0.6s ease-in-out, width 0.6s ease-in-out, height 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out;
  transition: transform 0.6s ease-in-out, left 0.6s ease-in-out, width 0.6s ease-in-out, height 0.6s ease-in-out;
  transition: transform 0.6s ease-in-out, left 0.6s ease-in-out, width 0.6s ease-in-out, height 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out; }

.ui.shape.animating .side {
  -webkit-transition: opacity 0.6s ease-in-out;
  transition: opacity 0.6s ease-in-out; }

.ui.shape .active.side {
  display: block; }

/*!
 * # Semantic UI 2.2.12 - Sidebar
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Sidebar
*******************************/
/* Sidebar Menu */
.ui.sidebar {
  position: fixed;
  top: 0;
  left: 0;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-transition: none;
  transition: none;
  will-change: transform;
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
  visibility: hidden;
  -webkit-overflow-scrolling: touch;
  height: 100% !important;
  max-height: 100%;
  border-radius: 0em !important;
  margin: 0em !important;
  overflow-y: auto !important;
  z-index: 102; }
  .ui.sidebar > * {
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden; }

.ui.left.sidebar {
  right: auto;
  left: 0px;
  -webkit-transform: translate3d(-100%, 0, 0);
  transform: translate3d(-100%, 0, 0); }

.ui.right.sidebar {
  right: 0px !important;
  left: auto !important;
  -webkit-transform: translate3d(100%, 0%, 0);
  transform: translate3d(100%, 0%, 0); }

.ui.top.sidebar, .ui.bottom.sidebar {
  width: 100% !important;
  height: auto !important; }

.ui.top.sidebar {
  top: 0px !important;
  bottom: auto !important;
  -webkit-transform: translate3d(0, -100%, 0);
  transform: translate3d(0, -100%, 0); }

.ui.bottom.sidebar {
  top: auto !important;
  bottom: 0px !important;
  -webkit-transform: translate3d(0, 100%, 0);
  transform: translate3d(0, 100%, 0); }

/* GPU Layers for Child Elements */
/*--------------
   Direction
---------------*/
/*--------------
     Pushable
---------------*/
.pushable {
  height: 100%;
  overflow-x: hidden;
  padding: 0em !important; }

/* Whole Page */
body.pushable {
  background: #545454 !important; }

/* Page Context */
.pushable:not(body) {
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0); }
  .pushable:not(body) > .ui.sidebar, .pushable:not(body) > .fixed, .pushable:not(body) > .pusher:after {
    position: absolute; }

.pushable > .fixed {
  position: fixed;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease;
  will-change: transform;
  z-index: 101; }

.pushable > .pusher {
  position: relative;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  overflow: hidden;
  min-height: 100%;
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease;
  z-index: 2; }

/*--------------
     Fixed
---------------*/
/*--------------
     Page
---------------*/
body.pushable > .pusher {
  background: #FFFFFF; }

/* Pusher should inherit background from context */
.pushable > .pusher {
  background: inherit; }
  .pushable > .pusher:after {
    position: fixed;
    top: 0px;
    right: 0px;
    content: '';
    background-color: rgba(0, 0, 0, 0.4);
    overflow: hidden;
    opacity: 0;
    -webkit-transition: opacity 500ms;
    transition: opacity 500ms;
    will-change: opacity;
    z-index: 1000; }

/*--------------
     Dimmer
---------------*/
/*--------------
    Coupling
---------------*/
.ui.sidebar.menu .item {
  border-radius: 0em !important; }

/*******************************
            States
*******************************/
/*--------------
     Dimmed
---------------*/
.pushable > .pusher.dimmed:after {
  width: 100% !important;
  height: 100% !important;
  opacity: 1 !important; }

/*--------------
    Animating
---------------*/
.ui.animating.sidebar {
  visibility: visible; }

.ui.visible.sidebar {
  visibility: visible;
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0); }

.ui.left.visible.sidebar, .ui.right.visible.sidebar, .ui.top.visible.sidebar, .ui.bottom.visible.sidebar {
  box-shadow: 0px 0px 20px rgba(34, 36, 38, 0.15); }

.ui.visible.left.sidebar ~ .fixed, .ui.visible.left.sidebar ~ .pusher {
  -webkit-transform: translate3d(260px, 0, 0);
  transform: translate3d(260px, 0, 0); }

.ui.visible.right.sidebar ~ .fixed, .ui.visible.right.sidebar ~ .pusher {
  -webkit-transform: translate3d(-260px, 0, 0);
  transform: translate3d(-260px, 0, 0); }

.ui.visible.top.sidebar ~ .fixed, .ui.visible.top.sidebar ~ .pusher {
  -webkit-transform: translate3d(0, 36px, 0);
  transform: translate3d(0, 36px, 0); }

.ui.visible.bottom.sidebar ~ .fixed, .ui.visible.bottom.sidebar ~ .pusher {
  -webkit-transform: translate3d(0, -36px, 0);
  transform: translate3d(0, -36px, 0); }

.ui.visible.left.sidebar ~ .ui.visible.right.sidebar ~ .fixed, .ui.visible.left.sidebar ~ .ui.visible.right.sidebar ~ .pusher {
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0); }

.ui.visible.right.sidebar ~ .ui.visible.left.sidebar ~ .fixed, .ui.visible.right.sidebar ~ .ui.visible.left.sidebar ~ .pusher {
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0); }

.ui.thin.left.sidebar, .ui.thin.right.sidebar {
  width: 150px; }

.ui[class*="very thin"].left.sidebar, .ui[class*="very thin"].right.sidebar {
  width: 60px; }

.ui.left.sidebar, .ui.right.sidebar {
  width: 260px; }

.ui.wide.left.sidebar, .ui.wide.right.sidebar {
  width: 350px; }

.ui[class*="very wide"].left.sidebar, .ui[class*="very wide"].right.sidebar {
  width: 475px; }

.ui.visible.thin.left.sidebar ~ .fixed, .ui.visible.thin.left.sidebar ~ .pusher {
  -webkit-transform: translate3d(150px, 0, 0);
  transform: translate3d(150px, 0, 0); }

.ui.visible[class*="very thin"].left.sidebar ~ .fixed, .ui.visible[class*="very thin"].left.sidebar ~ .pusher {
  -webkit-transform: translate3d(60px, 0, 0);
  transform: translate3d(60px, 0, 0); }

.ui.visible.wide.left.sidebar ~ .fixed, .ui.visible.wide.left.sidebar ~ .pusher {
  -webkit-transform: translate3d(350px, 0, 0);
  transform: translate3d(350px, 0, 0); }

.ui.visible[class*="very wide"].left.sidebar ~ .fixed, .ui.visible[class*="very wide"].left.sidebar ~ .pusher {
  -webkit-transform: translate3d(475px, 0, 0);
  transform: translate3d(475px, 0, 0); }

.ui.visible.thin.right.sidebar ~ .fixed, .ui.visible.thin.right.sidebar ~ .pusher {
  -webkit-transform: translate3d(-150px, 0, 0);
  transform: translate3d(-150px, 0, 0); }

.ui.visible[class*="very thin"].right.sidebar ~ .fixed, .ui.visible[class*="very thin"].right.sidebar ~ .pusher {
  -webkit-transform: translate3d(-60px, 0, 0);
  transform: translate3d(-60px, 0, 0); }

.ui.visible.wide.right.sidebar ~ .fixed, .ui.visible.wide.right.sidebar ~ .pusher {
  -webkit-transform: translate3d(-350px, 0, 0);
  transform: translate3d(-350px, 0, 0); }

.ui.visible[class*="very wide"].right.sidebar ~ .fixed, .ui.visible[class*="very wide"].right.sidebar ~ .pusher {
  -webkit-transform: translate3d(-475px, 0, 0);
  transform: translate3d(-475px, 0, 0); }

.ui.overlay.sidebar {
  z-index: 102; }

.ui.left.overlay.sidebar {
  -webkit-transform: translate3d(-100%, 0%, 0);
  transform: translate3d(-100%, 0%, 0); }

.ui.right.overlay.sidebar {
  -webkit-transform: translate3d(100%, 0%, 0);
  transform: translate3d(100%, 0%, 0); }

.ui.top.overlay.sidebar {
  -webkit-transform: translate3d(0%, -100%, 0);
  transform: translate3d(0%, -100%, 0); }

.ui.bottom.overlay.sidebar {
  -webkit-transform: translate3d(0%, 100%, 0);
  transform: translate3d(0%, 100%, 0); }

.animating.ui.overlay.sidebar {
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease; }

.ui.visible.overlay.sidebar {
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease; }

.ui.visible.left.overlay.sidebar, .ui.visible.right.overlay.sidebar, .ui.visible.top.overlay.sidebar, .ui.visible.bottom.overlay.sidebar {
  -webkit-transform: translate3d(0%, 0%, 0);
  transform: translate3d(0%, 0%, 0); }

.ui.visible.overlay.sidebar ~ .fixed, .ui.visible.overlay.sidebar ~ .pusher {
  -webkit-transform: none !important;
  transform: none !important; }

.ui.push.sidebar {
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease;
  z-index: 102; }

.ui.left.push.sidebar {
  -webkit-transform: translate3d(-100%, 0, 0);
  transform: translate3d(-100%, 0, 0); }

.ui.right.push.sidebar {
  -webkit-transform: translate3d(100%, 0, 0);
  transform: translate3d(100%, 0, 0); }

.ui.top.push.sidebar {
  -webkit-transform: translate3d(0%, -100%, 0);
  transform: translate3d(0%, -100%, 0); }

.ui.bottom.push.sidebar {
  -webkit-transform: translate3d(0%, 100%, 0);
  transform: translate3d(0%, 100%, 0); }

.ui.visible.push.sidebar {
  -webkit-transform: translate3d(0%, 0, 0);
  transform: translate3d(0%, 0, 0); }

.ui.uncover.sidebar {
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
  z-index: 1; }

.ui.visible.uncover.sidebar {
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease; }

.ui.slide.along.sidebar {
  z-index: 1; }

.ui.left.slide.along.sidebar {
  -webkit-transform: translate3d(-50%, 0, 0);
  transform: translate3d(-50%, 0, 0); }

.ui.right.slide.along.sidebar {
  -webkit-transform: translate3d(50%, 0, 0);
  transform: translate3d(50%, 0, 0); }

.ui.top.slide.along.sidebar {
  -webkit-transform: translate3d(0, -50%, 0);
  transform: translate3d(0, -50%, 0); }

.ui.bottom.slide.along.sidebar {
  -webkit-transform: translate3d(0%, 50%, 0);
  transform: translate3d(0%, 50%, 0); }

.ui.animating.slide.along.sidebar {
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease; }

.ui.visible.slide.along.sidebar {
  -webkit-transform: translate3d(0%, 0, 0);
  transform: translate3d(0%, 0, 0); }

.ui.slide.out.sidebar {
  z-index: 1; }

.ui.left.slide.out.sidebar {
  -webkit-transform: translate3d(50%, 0, 0);
  transform: translate3d(50%, 0, 0); }

.ui.right.slide.out.sidebar {
  -webkit-transform: translate3d(-50%, 0, 0);
  transform: translate3d(-50%, 0, 0); }

.ui.top.slide.out.sidebar {
  -webkit-transform: translate3d(0%, 50%, 0);
  transform: translate3d(0%, 50%, 0); }

.ui.bottom.slide.out.sidebar {
  -webkit-transform: translate3d(0%, -50%, 0);
  transform: translate3d(0%, -50%, 0); }

.ui.animating.slide.out.sidebar {
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease; }

.ui.visible.slide.out.sidebar {
  -webkit-transform: translate3d(0%, 0, 0);
  transform: translate3d(0%, 0, 0); }

.ui.scale.down.sidebar {
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease;
  z-index: 102; }

.ui.left.scale.down.sidebar {
  -webkit-transform: translate3d(-100%, 0, 0);
  transform: translate3d(-100%, 0, 0); }

.ui.right.scale.down.sidebar {
  -webkit-transform: translate3d(100%, 0, 0);
  transform: translate3d(100%, 0, 0); }

.ui.top.scale.down.sidebar {
  -webkit-transform: translate3d(0%, -100%, 0);
  transform: translate3d(0%, -100%, 0); }

.ui.bottom.scale.down.sidebar {
  -webkit-transform: translate3d(0%, 100%, 0);
  transform: translate3d(0%, 100%, 0); }

.ui.scale.down.left.sidebar ~ .pusher {
  -webkit-transform-origin: 75% 50%;
  transform-origin: 75% 50%; }

.ui.scale.down.right.sidebar ~ .pusher {
  -webkit-transform-origin: 25% 50%;
  transform-origin: 25% 50%; }

.ui.scale.down.top.sidebar ~ .pusher {
  -webkit-transform-origin: 50% 75%;
  transform-origin: 50% 75%; }

.ui.scale.down.bottom.sidebar ~ .pusher {
  -webkit-transform-origin: 50% 25%;
  transform-origin: 50% 25%; }

.ui.animating.scale.down > .visible.ui.sidebar {
  -webkit-transition: -webkit-transform 500ms ease;
  transition: -webkit-transform 500ms ease;
  transition: transform 500ms ease;
  transition: transform 500ms ease, -webkit-transform 500ms ease; }

.ui.visible.scale.down.sidebar ~ .pusher, .ui.animating.scale.down.sidebar ~ .pusher {
  display: block !important;
  width: 100%;
  height: 100%;
  overflow: hidden !important; }

.ui.visible.scale.down.sidebar {
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0); }
  .ui.visible.scale.down.sidebar ~ .pusher {
    -webkit-transform: scale(0.75);
    transform: scale(0.75); }

/*!
 * # Semantic UI 2.2.12 - Sticky
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Sticky
*******************************/
.ui.sticky {
  position: static;
  -webkit-transition: none;
  transition: none;
  z-index: 800; }
  .ui.sticky.bound {
    position: absolute;
    left: auto;
    right: auto; }
  .ui.sticky.fixed {
    position: fixed;
    left: auto;
    right: auto; }
  .ui.sticky.bound.top, .ui.sticky.fixed.top {
    top: 0px;
    bottom: auto; }
  .ui.sticky.bound.bottom, .ui.sticky.fixed.bottom {
    top: auto;
    bottom: 0px; }

.ui.native.sticky {
  position: -webkit-sticky;
  position: -moz-sticky;
  position: -ms-sticky;
  position: -o-sticky;
  position: sticky; }

/*!
 * # Semantic UI 2.2.12 - Tab
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
           UI Tabs
*******************************/
.ui.tab {
  display: none; }
  .ui.tab.active, .ui.tab.open {
    display: block; }
  .ui.tab.loading {
    position: relative;
    overflow: hidden;
    display: block;
    min-height: 250px; }
    .ui.tab.loading * {
      position: relative !important;
      left: -10000px !important; }
    .ui.tab.loading:before, .ui.tab.loading.segment:before {
      position: absolute;
      content: '';
      top: 100px;
      left: 50%;
      margin: -1.25em 0em 0em -1.25em;
      width: 2.5em;
      height: 2.5em;
      border-radius: 500rem;
      border: 0.2em solid rgba(0, 0, 0, 0.1); }
    .ui.tab.loading:after, .ui.tab.loading.segment:after {
      position: absolute;
      content: '';
      top: 100px;
      left: 50%;
      margin: -1.25em 0em 0em -1.25em;
      width: 2.5em;
      height: 2.5em;
      -webkit-animation: button-spin 0.6s linear;
      animation: button-spin 0.6s linear;
      -webkit-animation-iteration-count: infinite;
      animation-iteration-count: infinite;
      border-radius: 500rem;
      border-color: #767676 transparent transparent;
      border-style: solid;
      border-width: 0.2em;
      box-shadow: 0px 0px 0px 1px transparent; }

/*!
 * # Semantic UI 2.2.12 - Transition
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
          Transitions
*******************************/
.transition {
  -webkit-animation-iteration-count: 1;
  animation-iteration-count: 1;
  -webkit-animation-duration: 300ms;
  animation-duration: 300ms;
  -webkit-animation-timing-function: ease;
  animation-timing-function: ease;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both; }

/*******************************
            States
*******************************/
/* Animating */
.animating.transition {
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  visibility: visible !important; }

/* Loading */
.loading.transition {
  position: absolute;
  top: -99999px;
  left: -99999px; }

/* Hidden */
.hidden.transition {
  display: none;
  visibility: hidden; }

/* Visible */
.visible.transition {
  display: block !important;
  visibility: visible !important;
  /*  backface-visibility: @backfaceVisibility;
    transform: @use3DAcceleration;*/ }

/* Disabled */
.disabled.transition {
  -webkit-animation-play-state: paused;
  animation-play-state: paused; }

/*******************************
          Variations
*******************************/
.looping.transition {
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite; }

/*******************************
          Transitions
*******************************/
/*
  Some transitions adapted from Animate CSS
  https://github.com/daneden/animate.css

  Additional transitions adapted from Glide
  by Nick Pettit - https://github.com/nickpettit/glide
*/
/*--------------
     Browse
---------------*/
.transition.browse {
  -webkit-animation-duration: 500ms;
  animation-duration: 500ms; }
  .transition.browse.in {
    -webkit-animation-name: browseIn;
    animation-name: browseIn; }
  .transition.browse.out, .transition.browse.left.out {
    -webkit-animation-name: browseOutLeft;
    animation-name: browseOutLeft; }
  .transition.browse.right.out {
    -webkit-animation-name: browseOutRight;
    animation-name: browseOutRight; }

/* In */
@-webkit-keyframes browseIn {
  0% {
    -webkit-transform: scale(0.8) translateZ(0px);
    transform: scale(0.8) translateZ(0px);
    z-index: -1; }
  10% {
    -webkit-transform: scale(0.8) translateZ(0px);
    transform: scale(0.8) translateZ(0px);
    z-index: -1;
    opacity: 0.7; }
  80% {
    -webkit-transform: scale(1.05) translateZ(0px);
    transform: scale(1.05) translateZ(0px);
    opacity: 1;
    z-index: 999; }
  100% {
    -webkit-transform: scale(1) translateZ(0px);
    transform: scale(1) translateZ(0px);
    z-index: 999; } }

@keyframes browseIn {
  0% {
    -webkit-transform: scale(0.8) translateZ(0px);
    transform: scale(0.8) translateZ(0px);
    z-index: -1; }
  10% {
    -webkit-transform: scale(0.8) translateZ(0px);
    transform: scale(0.8) translateZ(0px);
    z-index: -1;
    opacity: 0.7; }
  80% {
    -webkit-transform: scale(1.05) translateZ(0px);
    transform: scale(1.05) translateZ(0px);
    opacity: 1;
    z-index: 999; }
  100% {
    -webkit-transform: scale(1) translateZ(0px);
    transform: scale(1) translateZ(0px);
    z-index: 999; } }

/* Out */
@-webkit-keyframes browseOutLeft {
  0% {
    z-index: 999;
    -webkit-transform: translateX(0%) rotateY(0deg) rotateX(0deg);
    transform: translateX(0%) rotateY(0deg) rotateX(0deg); }
  50% {
    z-index: -1;
    -webkit-transform: translateX(-105%) rotateY(35deg) rotateX(10deg) translateZ(-10px);
    transform: translateX(-105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); }
  80% {
    opacity: 1; }
  100% {
    z-index: -1;
    -webkit-transform: translateX(0%) rotateY(0deg) rotateX(0deg) translateZ(-10px);
    transform: translateX(0%) rotateY(0deg) rotateX(0deg) translateZ(-10px);
    opacity: 0; } }

@keyframes browseOutLeft {
  0% {
    z-index: 999;
    -webkit-transform: translateX(0%) rotateY(0deg) rotateX(0deg);
    transform: translateX(0%) rotateY(0deg) rotateX(0deg); }
  50% {
    z-index: -1;
    -webkit-transform: translateX(-105%) rotateY(35deg) rotateX(10deg) translateZ(-10px);
    transform: translateX(-105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); }
  80% {
    opacity: 1; }
  100% {
    z-index: -1;
    -webkit-transform: translateX(0%) rotateY(0deg) rotateX(0deg) translateZ(-10px);
    transform: translateX(0%) rotateY(0deg) rotateX(0deg) translateZ(-10px);
    opacity: 0; } }

@-webkit-keyframes browseOutRight {
  0% {
    z-index: 999;
    -webkit-transform: translateX(0%) rotateY(0deg) rotateX(0deg);
    transform: translateX(0%) rotateY(0deg) rotateX(0deg); }
  50% {
    z-index: 1;
    -webkit-transform: translateX(105%) rotateY(35deg) rotateX(10deg) translateZ(-10px);
    transform: translateX(105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); }
  80% {
    opacity: 1; }
  100% {
    z-index: 1;
    -webkit-transform: translateX(0%) rotateY(0deg) rotateX(0deg) translateZ(-10px);
    transform: translateX(0%) rotateY(0deg) rotateX(0deg) translateZ(-10px);
    opacity: 0; } }

@keyframes browseOutRight {
  0% {
    z-index: 999;
    -webkit-transform: translateX(0%) rotateY(0deg) rotateX(0deg);
    transform: translateX(0%) rotateY(0deg) rotateX(0deg); }
  50% {
    z-index: 1;
    -webkit-transform: translateX(105%) rotateY(35deg) rotateX(10deg) translateZ(-10px);
    transform: translateX(105%) rotateY(35deg) rotateX(10deg) translateZ(-10px); }
  80% {
    opacity: 1; }
  100% {
    z-index: 1;
    -webkit-transform: translateX(0%) rotateY(0deg) rotateX(0deg) translateZ(-10px);
    transform: translateX(0%) rotateY(0deg) rotateX(0deg) translateZ(-10px);
    opacity: 0; } }

/*--------------
     Drop
---------------*/
.drop.transition {
  -webkit-transform-origin: top center;
  transform-origin: top center;
  -webkit-animation-duration: 400ms;
  animation-duration: 400ms;
  -webkit-animation-timing-function: cubic-bezier(0.34, 1.61, 0.7, 1);
  animation-timing-function: cubic-bezier(0.34, 1.61, 0.7, 1); }
  .drop.transition.in {
    -webkit-animation-name: dropIn;
    animation-name: dropIn; }
  .drop.transition.out {
    -webkit-animation-name: dropOut;
    animation-name: dropOut; }

/* Drop */
@-webkit-keyframes dropIn {
  0% {
    opacity: 0;
    -webkit-transform: scale(0);
    transform: scale(0); }
  100% {
    opacity: 1;
    -webkit-transform: scale(1);
    transform: scale(1); } }

@keyframes dropIn {
  0% {
    opacity: 0;
    -webkit-transform: scale(0);
    transform: scale(0); }
  100% {
    opacity: 1;
    -webkit-transform: scale(1);
    transform: scale(1); } }

@-webkit-keyframes dropOut {
  0% {
    opacity: 1;
    -webkit-transform: scale(1);
    transform: scale(1); }
  100% {
    opacity: 0;
    -webkit-transform: scale(0);
    transform: scale(0); } }

@keyframes dropOut {
  0% {
    opacity: 1;
    -webkit-transform: scale(1);
    transform: scale(1); }
  100% {
    opacity: 0;
    -webkit-transform: scale(0);
    transform: scale(0); } }

/*--------------
      Fade
---------------*/
.transition.fade.in {
  -webkit-animation-name: fadeIn;
  animation-name: fadeIn; }

.transition[class*="fade up"].in {
  -webkit-animation-name: fadeInUp;
  animation-name: fadeInUp; }

.transition[class*="fade down"].in {
  -webkit-animation-name: fadeInDown;
  animation-name: fadeInDown; }

.transition[class*="fade left"].in {
  -webkit-animation-name: fadeInLeft;
  animation-name: fadeInLeft; }

.transition[class*="fade right"].in {
  -webkit-animation-name: fadeInRight;
  animation-name: fadeInRight; }

.transition.fade.out {
  -webkit-animation-name: fadeOut;
  animation-name: fadeOut; }

.transition[class*="fade up"].out {
  -webkit-animation-name: fadeOutUp;
  animation-name: fadeOutUp; }

.transition[class*="fade down"].out {
  -webkit-animation-name: fadeOutDown;
  animation-name: fadeOutDown; }

.transition[class*="fade left"].out {
  -webkit-animation-name: fadeOutLeft;
  animation-name: fadeOutLeft; }

.transition[class*="fade right"].out {
  -webkit-animation-name: fadeOutRight;
  animation-name: fadeOutRight; }

/* In */
@-webkit-keyframes fadeIn {
  0% {
    opacity: 0; }
  100% {
    opacity: 1; } }

@keyframes fadeIn {
  0% {
    opacity: 0; }
  100% {
    opacity: 1; } }

@-webkit-keyframes fadeInUp {
  0% {
    opacity: 0;
    -webkit-transform: translateY(10%);
    transform: translateY(10%); }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0%);
    transform: translateY(0%); } }

@keyframes fadeInUp {
  0% {
    opacity: 0;
    -webkit-transform: translateY(10%);
    transform: translateY(10%); }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0%);
    transform: translateY(0%); } }

@-webkit-keyframes fadeInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-10%);
    transform: translateY(-10%); }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0%);
    transform: translateY(0%); } }

@keyframes fadeInDown {
  0% {
    opacity: 0;
    -webkit-transform: translateY(-10%);
    transform: translateY(-10%); }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0%);
    transform: translateY(0%); } }

@-webkit-keyframes fadeInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(10%);
    transform: translateX(10%); }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0%);
    transform: translateX(0%); } }

@keyframes fadeInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translateX(10%);
    transform: translateX(10%); }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0%);
    transform: translateX(0%); } }

@-webkit-keyframes fadeInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-10%);
    transform: translateX(-10%); }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0%);
    transform: translateX(0%); } }

@keyframes fadeInRight {
  0% {
    opacity: 0;
    -webkit-transform: translateX(-10%);
    transform: translateX(-10%); }
  100% {
    opacity: 1;
    -webkit-transform: translateX(0%);
    transform: translateX(0%); } }

/* Out */
@-webkit-keyframes fadeOut {
  0% {
    opacity: 1; }
  100% {
    opacity: 0; } }

@keyframes fadeOut {
  0% {
    opacity: 1; }
  100% {
    opacity: 0; } }

@-webkit-keyframes fadeOutUp {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0%);
    transform: translateY(0%); }
  100% {
    opacity: 0;
    -webkit-transform: translateY(5%);
    transform: translateY(5%); } }

@keyframes fadeOutUp {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0%);
    transform: translateY(0%); }
  100% {
    opacity: 0;
    -webkit-transform: translateY(5%);
    transform: translateY(5%); } }

@-webkit-keyframes fadeOutDown {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0%);
    transform: translateY(0%); }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-5%);
    transform: translateY(-5%); } }

@keyframes fadeOutDown {
  0% {
    opacity: 1;
    -webkit-transform: translateY(0%);
    transform: translateY(0%); }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-5%);
    transform: translateY(-5%); } }

@-webkit-keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0%);
    transform: translateX(0%); }
  100% {
    opacity: 0;
    -webkit-transform: translateX(5%);
    transform: translateX(5%); } }

@keyframes fadeOutLeft {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0%);
    transform: translateX(0%); }
  100% {
    opacity: 0;
    -webkit-transform: translateX(5%);
    transform: translateX(5%); } }

@-webkit-keyframes fadeOutRight {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0%);
    transform: translateX(0%); }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-5%);
    transform: translateX(-5%); } }

@keyframes fadeOutRight {
  0% {
    opacity: 1;
    -webkit-transform: translateX(0%);
    transform: translateX(0%); }
  100% {
    opacity: 0;
    -webkit-transform: translateX(-5%);
    transform: translateX(-5%); } }

/*--------------
     Flips
---------------*/
.flip.transition.in, .flip.transition.out {
  -webkit-animation-duration: 600ms;
  animation-duration: 600ms; }

.horizontal.flip.transition.in {
  -webkit-animation-name: horizontalFlipIn;
  animation-name: horizontalFlipIn; }

.horizontal.flip.transition.out {
  -webkit-animation-name: horizontalFlipOut;
  animation-name: horizontalFlipOut; }

.vertical.flip.transition.in {
  -webkit-animation-name: verticalFlipIn;
  animation-name: verticalFlipIn; }

.vertical.flip.transition.out {
  -webkit-animation-name: verticalFlipOut;
  animation-name: verticalFlipOut; }

/* In */
@-webkit-keyframes horizontalFlipIn {
  0% {
    -webkit-transform: perspective(2000px) rotateY(-90deg);
    transform: perspective(2000px) rotateY(-90deg);
    opacity: 0; }
  100% {
    -webkit-transform: perspective(2000px) rotateY(0deg);
    transform: perspective(2000px) rotateY(0deg);
    opacity: 1; } }

@keyframes horizontalFlipIn {
  0% {
    -webkit-transform: perspective(2000px) rotateY(-90deg);
    transform: perspective(2000px) rotateY(-90deg);
    opacity: 0; }
  100% {
    -webkit-transform: perspective(2000px) rotateY(0deg);
    transform: perspective(2000px) rotateY(0deg);
    opacity: 1; } }

@-webkit-keyframes verticalFlipIn {
  0% {
    -webkit-transform: perspective(2000px) rotateX(-90deg);
    transform: perspective(2000px) rotateX(-90deg);
    opacity: 0; }
  100% {
    -webkit-transform: perspective(2000px) rotateX(0deg);
    transform: perspective(2000px) rotateX(0deg);
    opacity: 1; } }

@keyframes verticalFlipIn {
  0% {
    -webkit-transform: perspective(2000px) rotateX(-90deg);
    transform: perspective(2000px) rotateX(-90deg);
    opacity: 0; }
  100% {
    -webkit-transform: perspective(2000px) rotateX(0deg);
    transform: perspective(2000px) rotateX(0deg);
    opacity: 1; } }

/* Out */
@-webkit-keyframes horizontalFlipOut {
  0% {
    -webkit-transform: perspective(2000px) rotateY(0deg);
    transform: perspective(2000px) rotateY(0deg);
    opacity: 1; }
  100% {
    -webkit-transform: perspective(2000px) rotateY(90deg);
    transform: perspective(2000px) rotateY(90deg);
    opacity: 0; } }

@keyframes horizontalFlipOut {
  0% {
    -webkit-transform: perspective(2000px) rotateY(0deg);
    transform: perspective(2000px) rotateY(0deg);
    opacity: 1; }
  100% {
    -webkit-transform: perspective(2000px) rotateY(90deg);
    transform: perspective(2000px) rotateY(90deg);
    opacity: 0; } }

@-webkit-keyframes verticalFlipOut {
  0% {
    -webkit-transform: perspective(2000px) rotateX(0deg);
    transform: perspective(2000px) rotateX(0deg);
    opacity: 1; }
  100% {
    -webkit-transform: perspective(2000px) rotateX(-90deg);
    transform: perspective(2000px) rotateX(-90deg);
    opacity: 0; } }

@keyframes verticalFlipOut {
  0% {
    -webkit-transform: perspective(2000px) rotateX(0deg);
    transform: perspective(2000px) rotateX(0deg);
    opacity: 1; }
  100% {
    -webkit-transform: perspective(2000px) rotateX(-90deg);
    transform: perspective(2000px) rotateX(-90deg);
    opacity: 0; } }

/*--------------
      Scale
---------------*/
.scale.transition.in {
  -webkit-animation-name: scaleIn;
  animation-name: scaleIn; }

.scale.transition.out {
  -webkit-animation-name: scaleOut;
  animation-name: scaleOut; }

@-webkit-keyframes scaleIn {
  0% {
    opacity: 0;
    -webkit-transform: scale(0.8);
    transform: scale(0.8); }
  100% {
    opacity: 1;
    -webkit-transform: scale(1);
    transform: scale(1); } }

@keyframes scaleIn {
  0% {
    opacity: 0;
    -webkit-transform: scale(0.8);
    transform: scale(0.8); }
  100% {
    opacity: 1;
    -webkit-transform: scale(1);
    transform: scale(1); } }

/* Out */
@-webkit-keyframes scaleOut {
  0% {
    opacity: 1;
    -webkit-transform: scale(1);
    transform: scale(1); }
  100% {
    opacity: 0;
    -webkit-transform: scale(0.9);
    transform: scale(0.9); } }

@keyframes scaleOut {
  0% {
    opacity: 1;
    -webkit-transform: scale(1);
    transform: scale(1); }
  100% {
    opacity: 0;
    -webkit-transform: scale(0.9);
    transform: scale(0.9); } }

/*--------------
      Fly
---------------*/
/* Inward */
.transition.fly {
  -webkit-animation-duration: 0.6s;
  animation-duration: 0.6s;
  -webkit-transition-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  transition-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }
  .transition.fly.in {
    -webkit-animation-name: flyIn;
    animation-name: flyIn; }

.transition[class*="fly up"].in {
  -webkit-animation-name: flyInUp;
  animation-name: flyInUp; }

.transition[class*="fly down"].in {
  -webkit-animation-name: flyInDown;
  animation-name: flyInDown; }

.transition[class*="fly left"].in {
  -webkit-animation-name: flyInLeft;
  animation-name: flyInLeft; }

.transition[class*="fly right"].in {
  -webkit-animation-name: flyInRight;
  animation-name: flyInRight; }

.transition.fly.out {
  -webkit-animation-name: flyOut;
  animation-name: flyOut; }

.transition[class*="fly up"].out {
  -webkit-animation-name: flyOutUp;
  animation-name: flyOutUp; }

.transition[class*="fly down"].out {
  -webkit-animation-name: flyOutDown;
  animation-name: flyOutDown; }

.transition[class*="fly left"].out {
  -webkit-animation-name: flyOutLeft;
  animation-name: flyOutLeft; }

.transition[class*="fly right"].out {
  -webkit-animation-name: flyOutRight;
  animation-name: flyOutRight; }

.transition.slide.in, .transition[class*="slide down"].in {
  -webkit-animation-name: slideInY;
  animation-name: slideInY;
  -webkit-transform-origin: top center;
  transform-origin: top center; }

.transition[class*="slide up"].in {
  -webkit-animation-name: slideInY;
  animation-name: slideInY;
  -webkit-transform-origin: bottom center;
  transform-origin: bottom center; }

.transition[class*="slide left"].in {
  -webkit-animation-name: slideInX;
  animation-name: slideInX;
  -webkit-transform-origin: center right;
  transform-origin: center right; }

.transition[class*="slide right"].in {
  -webkit-animation-name: slideInX;
  animation-name: slideInX;
  -webkit-transform-origin: center left;
  transform-origin: center left; }

.transition.slide.out, .transition[class*="slide down"].out {
  -webkit-animation-name: slideOutY;
  animation-name: slideOutY;
  -webkit-transform-origin: top center;
  transform-origin: top center; }

.transition[class*="slide up"].out {
  -webkit-animation-name: slideOutY;
  animation-name: slideOutY;
  -webkit-transform-origin: bottom center;
  transform-origin: bottom center; }

.transition[class*="slide left"].out {
  -webkit-animation-name: slideOutX;
  animation-name: slideOutX;
  -webkit-transform-origin: center right;
  transform-origin: center right; }

.transition[class*="slide right"].out {
  -webkit-animation-name: slideOutX;
  animation-name: slideOutX;
  -webkit-transform-origin: center left;
  transform-origin: center left; }

.transition.swing {
  -webkit-animation-duration: 800ms;
  animation-duration: 800ms; }

.transition[class*="swing down"].in {
  -webkit-animation-name: swingInX;
  animation-name: swingInX;
  -webkit-transform-origin: top center;
  transform-origin: top center; }

.transition[class*="swing up"].in {
  -webkit-animation-name: swingInX;
  animation-name: swingInX;
  -webkit-transform-origin: bottom center;
  transform-origin: bottom center; }

.transition[class*="swing left"].in {
  -webkit-animation-name: swingInY;
  animation-name: swingInY;
  -webkit-transform-origin: center right;
  transform-origin: center right; }

.transition[class*="swing right"].in {
  -webkit-animation-name: swingInY;
  animation-name: swingInY;
  -webkit-transform-origin: center left;
  transform-origin: center left; }

.transition.swing.out, .transition[class*="swing down"].out {
  -webkit-animation-name: swingOutX;
  animation-name: swingOutX;
  -webkit-transform-origin: top center;
  transform-origin: top center; }

.transition[class*="swing up"].out {
  -webkit-animation-name: swingOutX;
  animation-name: swingOutX;
  -webkit-transform-origin: bottom center;
  transform-origin: bottom center; }

.transition[class*="swing left"].out {
  -webkit-animation-name: swingOutY;
  animation-name: swingOutY;
  -webkit-transform-origin: center right;
  transform-origin: center right; }

.transition[class*="swing right"].out {
  -webkit-animation-name: swingOutY;
  animation-name: swingOutY;
  -webkit-transform-origin: center left;
  transform-origin: center left; }

/* Outward */
/* In */
@-webkit-keyframes flyIn {
  0% {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); }
  20% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1); }
  40% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9); }
  60% {
    opacity: 1;
    -webkit-transform: scale3d(1.03, 1.03, 1.03);
    transform: scale3d(1.03, 1.03, 1.03); }
  80% {
    -webkit-transform: scale3d(0.97, 0.97, 0.97);
    transform: scale3d(0.97, 0.97, 0.97); }
  100% {
    opacity: 1;
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

@keyframes flyIn {
  0% {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); }
  20% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1); }
  40% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9); }
  60% {
    opacity: 1;
    -webkit-transform: scale3d(1.03, 1.03, 1.03);
    transform: scale3d(1.03, 1.03, 1.03); }
  80% {
    -webkit-transform: scale3d(0.97, 0.97, 0.97);
    transform: scale3d(0.97, 0.97, 0.97); }
  100% {
    opacity: 1;
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

@-webkit-keyframes flyInUp {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, 1500px, 0);
    transform: translate3d(0, 1500px, 0); }
  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0); }
  75% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0); }
  90% {
    -webkit-transform: translate3d(0, -5px, 0);
    transform: translate3d(0, -5px, 0); }
  100% {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

@keyframes flyInUp {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, 1500px, 0);
    transform: translate3d(0, 1500px, 0); }
  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0); }
  75% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0); }
  90% {
    -webkit-transform: translate3d(0, -5px, 0);
    transform: translate3d(0, -5px, 0); }
  100% {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

@-webkit-keyframes flyInDown {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, -1500px, 0);
    transform: translate3d(0, -1500px, 0); }
  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, 25px, 0);
    transform: translate3d(0, 25px, 0); }
  75% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0); }
  90% {
    -webkit-transform: translate3d(0, 5px, 0);
    transform: translate3d(0, 5px, 0); }
  100% {
    -webkit-transform: none;
    transform: none; } }

@keyframes flyInDown {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, -1500px, 0);
    transform: translate3d(0, -1500px, 0); }
  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, 25px, 0);
    transform: translate3d(0, 25px, 0); }
  75% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0); }
  90% {
    -webkit-transform: translate3d(0, 5px, 0);
    transform: translate3d(0, 5px, 0); }
  100% {
    -webkit-transform: none;
    transform: none; } }

@-webkit-keyframes flyInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(1500px, 0, 0);
    transform: translate3d(1500px, 0, 0); }
  60% {
    opacity: 1;
    -webkit-transform: translate3d(-25px, 0, 0);
    transform: translate3d(-25px, 0, 0); }
  75% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0); }
  90% {
    -webkit-transform: translate3d(-5px, 0, 0);
    transform: translate3d(-5px, 0, 0); }
  100% {
    -webkit-transform: none;
    transform: none; } }

@keyframes flyInLeft {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(1500px, 0, 0);
    transform: translate3d(1500px, 0, 0); }
  60% {
    opacity: 1;
    -webkit-transform: translate3d(-25px, 0, 0);
    transform: translate3d(-25px, 0, 0); }
  75% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0); }
  90% {
    -webkit-transform: translate3d(-5px, 0, 0);
    transform: translate3d(-5px, 0, 0); }
  100% {
    -webkit-transform: none;
    transform: none; } }

@-webkit-keyframes flyInRight {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(-1500px, 0, 0);
    transform: translate3d(-1500px, 0, 0); }
  60% {
    opacity: 1;
    -webkit-transform: translate3d(25px, 0, 0);
    transform: translate3d(25px, 0, 0); }
  75% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0); }
  90% {
    -webkit-transform: translate3d(5px, 0, 0);
    transform: translate3d(5px, 0, 0); }
  100% {
    -webkit-transform: none;
    transform: none; } }

@keyframes flyInRight {
  0% {
    opacity: 0;
    -webkit-transform: translate3d(-1500px, 0, 0);
    transform: translate3d(-1500px, 0, 0); }
  60% {
    opacity: 1;
    -webkit-transform: translate3d(25px, 0, 0);
    transform: translate3d(25px, 0, 0); }
  75% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0); }
  90% {
    -webkit-transform: translate3d(5px, 0, 0);
    transform: translate3d(5px, 0, 0); }
  100% {
    -webkit-transform: none;
    transform: none; } }

/* Out */
@-webkit-keyframes flyOut {
  20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9); }
  50%,
  55% {
    opacity: 1;
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1); }
  100% {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); } }

@keyframes flyOut {
  20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9); }
  50%,
  55% {
    opacity: 1;
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1); }
  100% {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); } }

@-webkit-keyframes flyOutUp {
  20% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0); }
  40%,
  45% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0); }
  100% {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0); } }

@keyframes flyOutUp {
  20% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0); }
  40%,
  45% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0); }
  100% {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0); } }

@-webkit-keyframes flyOutDown {
  20% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0); }
  40%,
  45% {
    opacity: 1;
    -webkit-transform: translate3d(0, 20px, 0);
    transform: translate3d(0, 20px, 0); }
  100% {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0); } }

@keyframes flyOutDown {
  20% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0); }
  40%,
  45% {
    opacity: 1;
    -webkit-transform: translate3d(0, 20px, 0);
    transform: translate3d(0, 20px, 0); }
  100% {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0); } }

@-webkit-keyframes flyOutRight {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(20px, 0, 0);
    transform: translate3d(20px, 0, 0); }
  100% {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0); } }

@keyframes flyOutRight {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(20px, 0, 0);
    transform: translate3d(20px, 0, 0); }
  100% {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0); } }

@-webkit-keyframes flyOutLeft {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(-20px, 0, 0);
    transform: translate3d(-20px, 0, 0); }
  100% {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0); } }

@keyframes flyOutLeft {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(-20px, 0, 0);
    transform: translate3d(-20px, 0, 0); }
  100% {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0); } }

/*--------------
     Slide
---------------*/
/* In */
@-webkit-keyframes slideInY {
  0% {
    opacity: 0;
    -webkit-transform: scaleY(0);
    transform: scaleY(0); }
  100% {
    opacity: 1;
    -webkit-transform: scaleY(1);
    transform: scaleY(1); } }

@keyframes slideInY {
  0% {
    opacity: 0;
    -webkit-transform: scaleY(0);
    transform: scaleY(0); }
  100% {
    opacity: 1;
    -webkit-transform: scaleY(1);
    transform: scaleY(1); } }

@-webkit-keyframes slideInX {
  0% {
    opacity: 0;
    -webkit-transform: scaleX(0);
    transform: scaleX(0); }
  100% {
    opacity: 1;
    -webkit-transform: scaleX(1);
    transform: scaleX(1); } }

@keyframes slideInX {
  0% {
    opacity: 0;
    -webkit-transform: scaleX(0);
    transform: scaleX(0); }
  100% {
    opacity: 1;
    -webkit-transform: scaleX(1);
    transform: scaleX(1); } }

/* Out */
@-webkit-keyframes slideOutY {
  0% {
    opacity: 1;
    -webkit-transform: scaleY(1);
    transform: scaleY(1); }
  100% {
    opacity: 0;
    -webkit-transform: scaleY(0);
    transform: scaleY(0); } }

@keyframes slideOutY {
  0% {
    opacity: 1;
    -webkit-transform: scaleY(1);
    transform: scaleY(1); }
  100% {
    opacity: 0;
    -webkit-transform: scaleY(0);
    transform: scaleY(0); } }

@-webkit-keyframes slideOutX {
  0% {
    opacity: 1;
    -webkit-transform: scaleX(1);
    transform: scaleX(1); }
  100% {
    opacity: 0;
    -webkit-transform: scaleX(0);
    transform: scaleX(0); } }

@keyframes slideOutX {
  0% {
    opacity: 1;
    -webkit-transform: scaleX(1);
    transform: scaleX(1); }
  100% {
    opacity: 0;
    -webkit-transform: scaleX(0);
    transform: scaleX(0); } }

/*--------------
     Swing
---------------*/
/* In */
@-webkit-keyframes swingInX {
  0% {
    -webkit-transform: perspective(1000px) rotateX(90deg);
    transform: perspective(1000px) rotateX(90deg);
    opacity: 0; }
  40% {
    -webkit-transform: perspective(1000px) rotateX(-30deg);
    transform: perspective(1000px) rotateX(-30deg);
    opacity: 1; }
  60% {
    -webkit-transform: perspective(1000px) rotateX(15deg);
    transform: perspective(1000px) rotateX(15deg); }
  80% {
    -webkit-transform: perspective(1000px) rotateX(-7.5deg);
    transform: perspective(1000px) rotateX(-7.5deg); }
  100% {
    -webkit-transform: perspective(1000px) rotateX(0deg);
    transform: perspective(1000px) rotateX(0deg); } }

@keyframes swingInX {
  0% {
    -webkit-transform: perspective(1000px) rotateX(90deg);
    transform: perspective(1000px) rotateX(90deg);
    opacity: 0; }
  40% {
    -webkit-transform: perspective(1000px) rotateX(-30deg);
    transform: perspective(1000px) rotateX(-30deg);
    opacity: 1; }
  60% {
    -webkit-transform: perspective(1000px) rotateX(15deg);
    transform: perspective(1000px) rotateX(15deg); }
  80% {
    -webkit-transform: perspective(1000px) rotateX(-7.5deg);
    transform: perspective(1000px) rotateX(-7.5deg); }
  100% {
    -webkit-transform: perspective(1000px) rotateX(0deg);
    transform: perspective(1000px) rotateX(0deg); } }

@-webkit-keyframes swingInY {
  0% {
    -webkit-transform: perspective(1000px) rotateY(-90deg);
    transform: perspective(1000px) rotateY(-90deg);
    opacity: 0; }
  40% {
    -webkit-transform: perspective(1000px) rotateY(30deg);
    transform: perspective(1000px) rotateY(30deg);
    opacity: 1; }
  60% {
    -webkit-transform: perspective(1000px) rotateY(-17.5deg);
    transform: perspective(1000px) rotateY(-17.5deg); }
  80% {
    -webkit-transform: perspective(1000px) rotateY(7.5deg);
    transform: perspective(1000px) rotateY(7.5deg); }
  100% {
    -webkit-transform: perspective(1000px) rotateY(0deg);
    transform: perspective(1000px) rotateY(0deg); } }

@keyframes swingInY {
  0% {
    -webkit-transform: perspective(1000px) rotateY(-90deg);
    transform: perspective(1000px) rotateY(-90deg);
    opacity: 0; }
  40% {
    -webkit-transform: perspective(1000px) rotateY(30deg);
    transform: perspective(1000px) rotateY(30deg);
    opacity: 1; }
  60% {
    -webkit-transform: perspective(1000px) rotateY(-17.5deg);
    transform: perspective(1000px) rotateY(-17.5deg); }
  80% {
    -webkit-transform: perspective(1000px) rotateY(7.5deg);
    transform: perspective(1000px) rotateY(7.5deg); }
  100% {
    -webkit-transform: perspective(1000px) rotateY(0deg);
    transform: perspective(1000px) rotateY(0deg); } }

/* Out */
@-webkit-keyframes swingOutX {
  0% {
    -webkit-transform: perspective(1000px) rotateX(0deg);
    transform: perspective(1000px) rotateX(0deg); }
  40% {
    -webkit-transform: perspective(1000px) rotateX(-7.5deg);
    transform: perspective(1000px) rotateX(-7.5deg); }
  60% {
    -webkit-transform: perspective(1000px) rotateX(17.5deg);
    transform: perspective(1000px) rotateX(17.5deg); }
  80% {
    -webkit-transform: perspective(1000px) rotateX(-30deg);
    transform: perspective(1000px) rotateX(-30deg);
    opacity: 1; }
  100% {
    -webkit-transform: perspective(1000px) rotateX(90deg);
    transform: perspective(1000px) rotateX(90deg);
    opacity: 0; } }

@keyframes swingOutX {
  0% {
    -webkit-transform: perspective(1000px) rotateX(0deg);
    transform: perspective(1000px) rotateX(0deg); }
  40% {
    -webkit-transform: perspective(1000px) rotateX(-7.5deg);
    transform: perspective(1000px) rotateX(-7.5deg); }
  60% {
    -webkit-transform: perspective(1000px) rotateX(17.5deg);
    transform: perspective(1000px) rotateX(17.5deg); }
  80% {
    -webkit-transform: perspective(1000px) rotateX(-30deg);
    transform: perspective(1000px) rotateX(-30deg);
    opacity: 1; }
  100% {
    -webkit-transform: perspective(1000px) rotateX(90deg);
    transform: perspective(1000px) rotateX(90deg);
    opacity: 0; } }

@-webkit-keyframes swingOutY {
  0% {
    -webkit-transform: perspective(1000px) rotateY(0deg);
    transform: perspective(1000px) rotateY(0deg); }
  40% {
    -webkit-transform: perspective(1000px) rotateY(7.5deg);
    transform: perspective(1000px) rotateY(7.5deg); }
  60% {
    -webkit-transform: perspective(1000px) rotateY(-10deg);
    transform: perspective(1000px) rotateY(-10deg); }
  80% {
    -webkit-transform: perspective(1000px) rotateY(30deg);
    transform: perspective(1000px) rotateY(30deg);
    opacity: 1; }
  100% {
    -webkit-transform: perspective(1000px) rotateY(-90deg);
    transform: perspective(1000px) rotateY(-90deg);
    opacity: 0; } }

@keyframes swingOutY {
  0% {
    -webkit-transform: perspective(1000px) rotateY(0deg);
    transform: perspective(1000px) rotateY(0deg); }
  40% {
    -webkit-transform: perspective(1000px) rotateY(7.5deg);
    transform: perspective(1000px) rotateY(7.5deg); }
  60% {
    -webkit-transform: perspective(1000px) rotateY(-10deg);
    transform: perspective(1000px) rotateY(-10deg); }
  80% {
    -webkit-transform: perspective(1000px) rotateY(30deg);
    transform: perspective(1000px) rotateY(30deg);
    opacity: 1; }
  100% {
    -webkit-transform: perspective(1000px) rotateY(-90deg);
    transform: perspective(1000px) rotateY(-90deg);
    opacity: 0; } }

/*******************************
       Static Animations
*******************************/
/*--------------
    Emphasis
---------------*/
.flash.transition {
  -webkit-animation-duration: 750ms;
  animation-duration: 750ms;
  -webkit-animation-name: flash;
  animation-name: flash; }

.shake.transition {
  -webkit-animation-duration: 750ms;
  animation-duration: 750ms;
  -webkit-animation-name: shake;
  animation-name: shake; }

.bounce.transition {
  -webkit-animation-duration: 750ms;
  animation-duration: 750ms;
  -webkit-animation-name: bounce;
  animation-name: bounce; }

.tada.transition {
  -webkit-animation-duration: 750ms;
  animation-duration: 750ms;
  -webkit-animation-name: tada;
  animation-name: tada; }

.pulse.transition {
  -webkit-animation-duration: 500ms;
  animation-duration: 500ms;
  -webkit-animation-name: pulse;
  animation-name: pulse; }

.jiggle.transition {
  -webkit-animation-duration: 750ms;
  animation-duration: 750ms;
  -webkit-animation-name: jiggle;
  animation-name: jiggle; }

/* Flash */
@-webkit-keyframes flash {
  0%,
  50%,
  100% {
    opacity: 1; }
  25%,
  75% {
    opacity: 0; } }

@keyframes flash {
  0%,
  50%,
  100% {
    opacity: 1; }
  25%,
  75% {
    opacity: 0; } }

/* Shake */
@-webkit-keyframes shake {
  0%,
  100% {
    -webkit-transform: translateX(0);
    transform: translateX(0); }
  10%,
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: translateX(-10px);
    transform: translateX(-10px); }
  20%,
  40%,
  60%,
  80% {
    -webkit-transform: translateX(10px);
    transform: translateX(10px); } }

@keyframes shake {
  0%,
  100% {
    -webkit-transform: translateX(0);
    transform: translateX(0); }
  10%,
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: translateX(-10px);
    transform: translateX(-10px); }
  20%,
  40%,
  60%,
  80% {
    -webkit-transform: translateX(10px);
    transform: translateX(10px); } }

/* Bounce */
@-webkit-keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    -webkit-transform: translateY(0);
    transform: translateY(0); }
  40% {
    -webkit-transform: translateY(-30px);
    transform: translateY(-30px); }
  60% {
    -webkit-transform: translateY(-15px);
    transform: translateY(-15px); } }

@keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    -webkit-transform: translateY(0);
    transform: translateY(0); }
  40% {
    -webkit-transform: translateY(-30px);
    transform: translateY(-30px); }
  60% {
    -webkit-transform: translateY(-15px);
    transform: translateY(-15px); } }

/* Tada */
@-webkit-keyframes tada {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1); }
  10%,
  20% {
    -webkit-transform: scale(0.9) rotate(-3deg);
    transform: scale(0.9) rotate(-3deg); }
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale(1.1) rotate(3deg);
    transform: scale(1.1) rotate(3deg); }
  40%,
  60%,
  80% {
    -webkit-transform: scale(1.1) rotate(-3deg);
    transform: scale(1.1) rotate(-3deg); }
  100% {
    -webkit-transform: scale(1) rotate(0);
    transform: scale(1) rotate(0); } }

@keyframes tada {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1); }
  10%,
  20% {
    -webkit-transform: scale(0.9) rotate(-3deg);
    transform: scale(0.9) rotate(-3deg); }
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale(1.1) rotate(3deg);
    transform: scale(1.1) rotate(3deg); }
  40%,
  60%,
  80% {
    -webkit-transform: scale(1.1) rotate(-3deg);
    transform: scale(1.1) rotate(-3deg); }
  100% {
    -webkit-transform: scale(1) rotate(0);
    transform: scale(1) rotate(0); } }

/* Pulse */
@-webkit-keyframes pulse {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
    opacity: 1; }
  50% {
    -webkit-transform: scale(0.9);
    transform: scale(0.9);
    opacity: 0.7; }
  100% {
    -webkit-transform: scale(1);
    transform: scale(1);
    opacity: 1; } }

@keyframes pulse {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1);
    opacity: 1; }
  50% {
    -webkit-transform: scale(0.9);
    transform: scale(0.9);
    opacity: 0.7; }
  100% {
    -webkit-transform: scale(1);
    transform: scale(1);
    opacity: 1; } }

/* Rubberband */
@-webkit-keyframes jiggle {
  0% {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); }
  30% {
    -webkit-transform: scale3d(1.25, 0.75, 1);
    transform: scale3d(1.25, 0.75, 1); }
  40% {
    -webkit-transform: scale3d(0.75, 1.25, 1);
    transform: scale3d(0.75, 1.25, 1); }
  50% {
    -webkit-transform: scale3d(1.15, 0.85, 1);
    transform: scale3d(1.15, 0.85, 1); }
  65% {
    -webkit-transform: scale3d(0.95, 1.05, 1);
    transform: scale3d(0.95, 1.05, 1); }
  75% {
    -webkit-transform: scale3d(1.05, 0.95, 1);
    transform: scale3d(1.05, 0.95, 1); }
  100% {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

@keyframes jiggle {
  0% {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); }
  30% {
    -webkit-transform: scale3d(1.25, 0.75, 1);
    transform: scale3d(1.25, 0.75, 1); }
  40% {
    -webkit-transform: scale3d(0.75, 1.25, 1);
    transform: scale3d(0.75, 1.25, 1); }
  50% {
    -webkit-transform: scale3d(1.15, 0.85, 1);
    transform: scale3d(1.15, 0.85, 1); }
  65% {
    -webkit-transform: scale3d(0.95, 1.05, 1);
    transform: scale3d(0.95, 1.05, 1); }
  75% {
    -webkit-transform: scale3d(1.05, 0.95, 1);
    transform: scale3d(1.05, 0.95, 1); }
  100% {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

/*!
 * # Semantic UI 2.0.0 - Video
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Copyright 2014 Contributors
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
            Video
*******************************/
.ui.video {
  background-color: #dddddd;
  position: relative;
  max-width: 100%;
  padding-bottom: 56.25%;
  height: 0px;
  overflow: hidden; }
  .ui.video .placeholder {
    background-color: #333333; }
  .ui.video .play {
    cursor: pointer;
    position: absolute;
    top: 0px;
    left: 0px;
    z-index: 10;
    width: 100%;
    height: 100%;
    background: transparent;
    -webkit-transition: background 0.2s ease;
    transition: background 0.2s ease; }
    .ui.video .play.icon:before {
      position: absolute;
      top: 50%;
      left: 50%;
      z-index: 11;
      -webkit-transform: translateX(-50%) translateY(-50%);
      -ms-transform: translateX(-50%) translateY(-50%);
      transform: translateX(-50%) translateY(-50%);
      color: rgba(255, 255, 255, 0.7);
      font-size: 7rem;
      text-shadow: 2px 2px 0px rgba(0, 0, 0, 0.15);
      -webkit-transition: color 0.2s ease;
      transition: color 0.2s ease; }
  .ui.video .placeholder {
    position: absolute;
    top: 0px;
    left: 0px;
    display: block;
    width: 100%;
    height: 100%; }
  .ui.video .embed iframe, .ui.video .embed embed, .ui.video .embed object {
    position: absolute;
    border: none;
    width: 100%;
    height: 100%;
    top: 0px;
    left: 0px;
    margin: 0em;
    padding: 0em; }
  .ui.video .play:hover {
    background: transparent; }
    .ui.video .play:hover:before {
      color: #FFFFFF; }

.ui.active.video .play, .ui.active.video .placeholder {
  display: none; }

.ui.active.video .embed {
  display: inline; }

#navbar {
  background-color: #364154;
  display: flex; }
  #navbar #navbar-item-logout {
    margin-top: auto; }

#panel {
  max-width: 1000px;
  margin: 1.5em; }

#logo {
  max-height: 50px;
  margin: 1em;
  fill: #ffffff; }

@keyframes blinkenlights {
  50% {
    fill: #4679b7; } }
  #logo .lit {
    animation: blinkenlights;
    animation-duration: 300ms; }

/* BASICS */
.CodeMirror {
  /* Set height, width, borders, and global font properties here */
  font-family: monospace;
  height: auto;
  color: #364154;
  direction: ltr; }

.segment > .CodeMirror {
  height: 150px; }

/* PADDING */
.CodeMirror-lines {
  padding: 2px 0;
  /* Vertical padding around content */ }

.CodeMirror pre {
  padding: 0 2px;
  /* Horizontal padding of content */ }

.CodeMirror-scrollbar-filler, .CodeMirror-gutter-filler {
  background-color: #FFFFFF;
  /* The little square between H and V scrollbars */ }

/* GUTTER */
.CodeMirror-gutters {
  background-color: #FFFFFF;
  white-space: nowrap; }

.CodeMirror-linenumber {
  padding: 0 3px 0 5px;
  min-width: 20px;
  text-align: right;
  color: #DCDDDE;
  white-space: nowrap; }

.CodeMirror-guttermarker {
  color: #364154; }

.CodeMirror-guttermarker-subtle {
  color: #DCDDDE; }

/* CURSOR */
.CodeMirror-cursor {
  border-left: 1px solid black;
  border-right: none;
  width: 0; }

/* Shown when moving in bi-directional text */
.CodeMirror div.CodeMirror-secondarycursor {
  border-left: 1px solid #DCDDDE; }

.cm-fat-cursor .CodeMirror-cursor {
  width: auto;
  border: 0 !important;
  background: #384d68; }

.cm-fat-cursor div.CodeMirror-cursors {
  z-index: 1; }

.cm-fat-cursor-mark {
  background-color: rgba(20, 255, 20, 0.5);
  -webkit-animation: blink 1.06s steps(1) infinite;
  -moz-animation: blink 1.06s steps(1) infinite;
  animation: blink 1.06s steps(1) infinite; }

.cm-animate-fat-cursor {
  width: auto;
  border: 0;
  -webkit-animation: blink 1.06s steps(1) infinite;
  -moz-animation: blink 1.06s steps(1) infinite;
  animation: blink 1.06s steps(1) infinite;
  background-color: #7e7; }

@-moz-keyframes blink {
  0% { }
  50% {
    background-color: transparent; }
  100% { } }

@-webkit-keyframes blink {
  0% { }
  50% {
    background-color: transparent; }
  100% { } }

@keyframes blink {
  0% { }
  50% {
    background-color: transparent; }
  100% { } }

/* Can style cursor different in overwrite (non-insert) mode */
.cm-tab {
  display: inline-block;
  text-decoration: inherit; }

.CodeMirror-rulers {
  position: absolute;
  left: 0;
  right: 0;
  top: -50px;
  bottom: -20px;
  overflow: hidden; }

.CodeMirror-ruler {
  border-left: 1px solid #rgba 34, 36, 38, 0.15;
  top: 0;
  bottom: 0;
  position: absolute; }

/* DEFAULT THEME */
.cm-s-default .cm-header {
  color: #4c8bd6; }

.cm-s-default .cm-quote {
  color: #19b884; }

.cm-negative {
  color: #fc6019; }

.cm-positive {
  color: #19b884; }

.cm-header, .cm-strong {
  font-weight: bold; }

.cm-em {
  font-style: italic; }

.cm-link {
  text-decoration: underline; }

.cm-strikethrough {
  text-decoration: line-through; }

.cm-s-default .cm-keyword {
  color: #4c8bd6;
  font-weight: bold; }

.cm-s-default .cm-function {
  color: #4679b7;
  font-weight: bold; }

.cm-s-default .cm-number {
  color: #fc8f50; }

.cm-s-default .cm-operator {
  font-weight: bold; }

.cm-s-default .cm-string {
  color: #19b884; }

.cm-s-default .cm-ip-address {
  color: #19b884; }

.cm-s-default .cm-timestamp {
  color: #876fe6; }

.cm-s-default .cm-duration {
  color: #876fe6;
  font-weight: bold; }

.cm-s-default .cm-error {
  color: #fc7831; }

.cm-invalidchar {
  color: #DB2828; }

.CodeMirror-composing {
  border-bottom: 2px solid; }

/* Default styles for common addons */
div.CodeMirror span.CodeMirror-matchingbracket {
  color: #4c8bd6; }

.CodeMirror-matchingtag {
  background: rgba(255, 150, 0, 0.3); }

.CodeMirror-activeline-background {
  background: #e8f2ff; }

/* STOP */
/* The rest of this file contains styles related to the mechanics of
   the editor. You probably shouldn't touch them. */
.CodeMirror {
  position: relative;
  overflow: hidden;
  background: white; }

.CodeMirror-scroll {
  overflow: scroll !important;
  /* Things will break if this is overridden */
  /* 30px is the magic margin used to hide the element's real scrollbars */
  /* See overflow: hidden in .CodeMirror */
  margin-bottom: -30px;
  margin-right: -30px;
  padding-bottom: 30px;
  height: 100%;
  outline: none;
  /* Prevent dragging from highlighting the element */
  position: relative; }

.CodeMirror-sizer {
  position: relative;
  border-right: 30px solid transparent; }

/* The fake, visible scrollbars. Used to force redraw during scrolling
   before actual scrolling happens, thus preventing shaking and
   flickering artifacts. */
.CodeMirror-vscrollbar, .CodeMirror-hscrollbar, .CodeMirror-scrollbar-filler, .CodeMirror-gutter-filler {
  position: absolute;
  z-index: 6;
  display: none; }

.CodeMirror-vscrollbar {
  right: 0;
  top: 0;
  overflow-x: hidden;
  overflow-y: scroll; }

.CodeMirror-hscrollbar {
  bottom: 0;
  left: 0;
  overflow-y: hidden;
  overflow-x: scroll; }

.CodeMirror-scrollbar-filler {
  right: 0;
  bottom: 0; }

.CodeMirror-gutter-filler {
  left: 0;
  bottom: 0; }

.CodeMirror-gutters {
  position: absolute;
  left: 0;
  top: 0;
  min-height: 100%;
  z-index: 3; }

.CodeMirror-gutter {
  white-space: normal;
  height: 100%;
  display: inline-block;
  vertical-align: top;
  margin-bottom: -30px; }

.CodeMirror-gutter-wrapper {
  position: absolute;
  z-index: 4;
  background: none !important;
  border: none !important; }

.CodeMirror-gutter-background {
  position: absolute;
  top: 0;
  bottom: 0;
  z-index: 4; }

.CodeMirror-gutter-elt {
  position: absolute;
  cursor: default;
  z-index: 4; }

.CodeMirror-gutter-wrapper ::selection {
  background-color: transparent; }

.CodeMirror-gutter-wrapper ::-moz-selection {
  background-color: transparent; }

.CodeMirror-lines {
  cursor: text;
  min-height: 1px;
  /* prevents collapsing before first draw */ }

.CodeMirror pre {
  /* Reset some styles that the rest of the page might have set */
  -moz-border-radius: 0;
  -webkit-border-radius: 0;
  border-radius: 0;
  border-width: 0;
  background: transparent;
  font-family: inherit;
  font-size: inherit;
  margin: 0;
  white-space: pre;
  word-wrap: normal;
  line-height: inherit;
  color: inherit;
  z-index: 2;
  position: relative;
  overflow: visible;
  -webkit-tap-highlight-color: transparent;
  -webkit-font-variant-ligatures: contextual;
  font-variant-ligatures: contextual; }

.CodeMirror-wrap pre {
  word-wrap: break-word;
  white-space: pre-wrap;
  word-break: normal; }

.CodeMirror-linebackground {
  position: absolute;
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  z-index: 0; }

.CodeMirror-linewidget {
  position: relative;
  z-index: 2;
  overflow: auto; }

.CodeMirror-rtl pre {
  direction: rtl; }

.CodeMirror-code {
  outline: none; }

/* Force content-box sizing for the elements where we expect it */
.CodeMirror-scroll,
.CodeMirror-sizer,
.CodeMirror-gutter,
.CodeMirror-gutters,
.CodeMirror-linenumber {
  -moz-box-sizing: content-box;
  box-sizing: content-box; }

.CodeMirror-measure {
  position: absolute;
  width: 100%;
  height: 0;
  overflow: hidden;
  visibility: hidden; }

.CodeMirror-cursor {
  position: absolute;
  pointer-events: none; }

.CodeMirror-measure pre {
  position: static; }

div.CodeMirror-cursors {
  visibility: hidden;
  position: relative;
  z-index: 3; }

div.CodeMirror-dragcursors {
  visibility: visible; }

.CodeMirror-focused div.CodeMirror-cursors {
  visibility: visible; }

.CodeMirror-selected {
  background: #d9d9d9; }

.CodeMirror-focused .CodeMirror-selected {
  background: #d7d4f0; }

.CodeMirror-crosshair {
  cursor: crosshair; }

.CodeMirror-line::selection, .CodeMirror-line > span::selection, .CodeMirror-line > span > span::selection {
  background: #d7d4f0; }

.CodeMirror-line::-moz-selection, .CodeMirror-line > span::-moz-selection, .CodeMirror-line > span > span::-moz-selection {
  background: #d7d4f0; }

.cm-searching {
  background-color: #ffa;
  background-color: rgba(255, 255, 0, 0.4); }

/* Used to force a border model for a node */
.cm-force-border {
  padding-right: .1px; }

@media print {
  /* Hide the cursor when printing */
  .CodeMirror div.CodeMirror-cursors {
    visibility: hidden; } }

/* See issue #2901 */
.cm-tab-wrap-hack:after {
  content: ''; }

/* Help users use markselection to safely style text background */
span.CodeMirror-selectedtext {
  background: none; }

/*# sourceMappingURL=screen.css.map */